/**
 * console
 */
// 当某些调试场景下需要用到 JS 引擎自带的 console 时，保留其原生 console 对象，如没有则为 undefined
var dmServiceInvokeStartTime = Date.now()
var __console__ = console
var __setTimeout__ = setTimeout
var __clearTimeout__ = clearTimeout
var __setInterval__ = setInterval
var __clearInterval__ = clearInterval
var console = (function() {
  var CONSOLE_TYPE_ENUM = {
    LOG: 0,
    INFO: 1,
    WARN: 2,
    ERROR: 3
  };
  var DEFAULT_LABEL = 'default';
  var timeMap = Object.create(null);
  return {
    log: function() {
      try {
        var msg = '';
        for (var i = 0, item; i < arguments.length; i++) {
          item = arguments[i];
          msg += (typeof item === 'string' ? item : JSON.stringify(item));
        }
        nativeLog(CONSOLE_TYPE_ENUM.LOG, msg);
      } catch (e) {
        nativeLog(CONSOLE_TYPE_ENUM.ERROR, e.message);
      }
    },
    info: function() {
      try {
        var msg = '';
        for (var i = 0, item; i < arguments.length; i++) {
          item = arguments[i];
          msg += (typeof item === 'string' ? item : JSON.stringify(item));
        }
        nativeLog(CONSOLE_TYPE_ENUM.INFO, msg);
      } catch (e) {
        nativeLog(CONSOLE_TYPE_ENUM.ERROR, e.message);
      }
    },
    warn: function() {
      try {
        var msg = '';
        for (var i = 0, item; i < arguments.length; i++) {
          item = arguments[i];
          msg += (typeof item === 'string' ? item : JSON.stringify(item));
        }
        nativeLog(CONSOLE_TYPE_ENUM.WARN, msg);
      } catch (e) {
        nativeLog(CONSOLE_TYPE_ENUM.ERROR, e.message);
      }
    },
    group: function() {
    },
    groupEnd: function() {
    },
    dmReportError: function(err) {
      // 主动调用底层异常上报功能
      if (err instanceof Error) {
        __appServiceSDK__.reportUncaughtError({
          info: `User report ${err.toString()}`,
          stack: err.stack,
          disableAppError: true
        });
      }
    },
    error: function() {
      try {
        var msg = '';
        for (var i = 0, item; i < arguments.length; i++) {
          item = arguments[i];
          msg += (typeof item === 'string' ? item : JSON.stringify(item));
        }
        nativeLog(CONSOLE_TYPE_ENUM.ERROR, msg);
      } catch (e) {
        nativeLog(CONSOLE_TYPE_ENUM.ERROR, e.message);
      }
    },
    time: function(label) {
      label = label == null ? DEFAULT_LABEL : label.toString();
      timeMap[label] = Date.now();
    },
    timeLog: function(label) {
      label = label == null ? DEFAULT_LABEL : label.toString();
      if (timeMap[label]) {
        var old = timeMap[label]
        nativeLog(CONSOLE_TYPE_ENUM.LOG, label + ': ' + ((timeMap[label] = Date.now()) - old) + ' ms')
      } else {
        nativeLog(CONSOLE_TYPE_ENUM.WARN, 'Timer \'' + label + '\' does not exist')
      }
    },
    timeEnd: function(label) {
      label = label == null ? DEFAULT_LABEL : label.toString();
      if (timeMap[label]) {
        var old = timeMap[label]
        delete timeMap[label]
        nativeLog(CONSOLE_TYPE_ENUM.LOG, label + ': ' + (Date.now() - old) + ' ms')
      } else {
        nativeLog(CONSOLE_TYPE_ENUM.WARN, 'Timer \'' + label + '\' does not exist')
      }
    }
  };
})();


/**
 * Timeout & Interval
 */

var timeoutMap = {};
var timeoutId = 0;

var setTimeout = function(cb, timeout) {
  if (timeout === undefined || timeout === null) {
    timeout = 0
  }
  var funcId = timeoutId++
  timeoutMap[funcId] = cb
  // native的方法
  setTimeoutNative(funcId, timeout)
  return funcId
}

// native 方法 ，需要暴露在全局
var setTimeoutCallback = function(funcId) {
  if (typeof timeoutMap[funcId] === 'function') {
    try {
      timeoutMap[funcId]();
    } catch (err) {
      // 计时器处理函数未处理异常
      __appServiceSDK__.reportUncaughtError({
        info: err.toString(),
        stack: err.stack
      })
    } finally {
      timeoutMap[funcId] = null
      delete timeoutMap[funcId]
    }


  } else {
    console.error("[setTimeoutNative]: setTimeOut fn is not a fn " + funcId)
  }
}

var clearTimeout = function(funcId) {
  if (funcId && timeoutMap[funcId]) {
    clearTimeoutNative(funcId);
    timeoutMap[funcId] = null;
    delete timeoutMap[funcId];
  }
}

var setInterval = function(cb, timeout) {
  if (timeout === undefined || timeout === null) {
    timeout = 0
  }
  var funcId = timeoutId++;
  timeoutMap[funcId] = cb;
  setIntervalNative(funcId, timeout);
  return funcId;
}

var setIntervalCallback = function(funcId) {
  if (typeof timeoutMap[funcId] === 'function') {
    try {
      timeoutMap[funcId]();
    } catch (err) {
      // 计时器处理函数未处理异常
      __appServiceSDK__.reportUncaughtError({
        info: err.toString(),
        stack: err.stack
      })
    }
  } else {
    console.error("[setIntervalCallback]: setInterval fn is not a fn " + funcId);
  }
}

var clearInterval = function(funcId) {
  if (funcId && timeoutMap[funcId]) {
    clearIntervalNative(funcId);
    timeoutMap[funcId] = null;
    delete timeoutMap[funcId];
  }
}

/**
 * 全局变量
 */
var globalThis = (function() {
  return this
})();

// 谷歌渠道,jscore改成webview,因此window上会存在全局变量,会去访问document变量
globalThis && globalThis.MutationObserver && (MutationObserver = null)
globalThis && globalThis.WebKitMutationObserver && (WebKitMutationObserver = null)
if (globalThis) {
  globalThis.onunhandledrejection = function(params) {
    __appServiceSDK__.dd && __appServiceSDK__.dd.emitUnhandledRejection && __appServiceSDK__.dd.emitUnhandledRejection(params)
  }
  globalThis.onunhandledrejectionForNative = function(promise, reason) {
    reason && globalThis.onunhandledrejection && globalThis.onunhandledrejection({ promise, reason })

    __appServiceSDK__.reportNative('pub_native_unhandlereject_bt', {
      reason: '' + reason
    })
  }
}
globalThis && globalThis.WebKitMutationObserver && (WebKitMutationObserver = null)

var __ddLibrary = {
  envType: 'Service',
  contextType: '',
  fileName: 'WAService.js',
  execStart: Date.now()
};
var __libVersionInfo__ = {}
/** wcc config start */
var window = {};
window.__wcc_version_info__ = {
  customComponents: true,
  fixZeroRpx: true,
  propValueDeepCopy: false
};
/** wcc config end */

var __ddAppData = __ddAppData || {};
var __ddRoute = __ddRoute || '';
var __ddRouteBegin = __ddRouteBegin || "";
var __ddAppCurrentFile__ = __ddAppCurrentFile__ || "";
var __define__;
var __routePackages__;
var global = global || {};
var __ddConfigWindow__ = {};
var Reporter = {};
var __vd_version_info__ = {
  delayedGwx: true
};
var __ddConfig = {
  envVersion: 'release',
  platform: '',
  isIsolateContext: false     // 是否是游戏，游戏为true，不是游戏，字段缺省或者为false
};
var __MAIN_PKG_DIR__ = 'app';
var __APP_RESOURCES_SUB_DIR__ = 'res';
var currentStackId = -1;
var tabBarTapList = []

var isDevTools = typeof acquireLocalBridge === 'function'
if (isDevTools) {
  __ddConfig.platform = 'devtools'
}

if (isDevTools) {
  // ide 环境重写对象
  console = __console__;
  setTimeout = __setTimeout__;
  clearTimeout = __clearTimeout__;
  setInterval = __setInterval__;
  clearInterval = __clearInterval__;
}


/**
 * 基础库的 service 的代码
 */
if (isDevTools) {
  __ddConfig.platform = 'devtools'
}
var Foundation=function(){"use strict";function t(n){return t="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},t(n)}function n(){return n=Object.assign||function(t){for(var n=1;n<arguments.length;n++){var e=arguments[n];for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&(t[r]=e[r])}return t},n.apply(this,arguments)}
/*! *****************************************************************************
  Copyright (c) Microsoft Corporation.

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
  REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
  AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
  INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
  LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
  OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
  PERFORMANCE OF THIS SOFTWARE.
  ***************************************************************************** */var e=function(t,n){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(t,n){t.__proto__=n}||function(t,n){for(var e in n)Object.prototype.hasOwnProperty.call(n,e)&&(t[e]=n[e])},e(t,n)};var r="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function o(t,n,e){return t(e={path:n,exports:{},require:function(t,n){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==n&&e.path)}},e.exports),e.exports}var i,u,c=function(t){return t&&t.Math==Math&&t},a=c("object"==typeof globalThis&&globalThis)||c("object"==typeof window&&window)||c("object"==typeof self&&self)||c("object"==typeof r&&r)||function(){return this}()||Function("return this")(),f={CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0},s=function(t){return"function"==typeof t},l=function(t){return"object"==typeof t?null!==t:s(t)},p=a.document,y=l(p)&&l(p.createElement),d=function(t){return y?p.createElement(t):{}},g=d("span").classList,v=g&&g.constructor&&g.constructor.prototype,h=v===Object.prototype?void 0:v,b=function(t){try{return!!t()}catch(t){return!0}},m=!b((function(){var t=function(){}.bind();return"function"!=typeof t||t.hasOwnProperty("prototype")})),S=Function.prototype,x=S.bind,O=S.call,w=m&&x.bind(O,O),_=m?function(t){return t&&w(t)}:function(t){return t&&function(){return O.apply(t,arguments)}},E=a.String,C=a.TypeError,I=function(t){if(s(t))return t;throw C(function(t){try{return E(t)}catch(t){return"Object"}}(t)+" is not a function")},j=_(_.bind),R=_({}.toString),T=_("".slice),A=function(t){return T(R(t),8,-1)},L=a.Object,P=_("".split),D=b((function(){return!L("z").propertyIsEnumerable(0)}))?function(t){return"String"==A(t)?P(t,""):L(t)}:L,F=a.TypeError,k=function(t){if(null==t)throw F("Can't call method on "+t);return t},M=a.Object,N=function(t){return M(k(t))},G=Math.ceil,V=Math.floor,Y=function(t){var n=+t;return n!=n||0===n?0:(n>0?V:G)(n)},B=Math.min,W=function(t){return t>0?B(Y(t),9007199254740991):0},z=function(t){return W(t.length)},U=Array.isArray||function(t){return"Array"==A(t)},K=Object.defineProperty,q=function(t,n){try{K(a,t,{value:n,configurable:!0,writable:!0})}catch(e){a[t]=n}return n},H="__core-js_shared__",$=a[H]||q(H,{}),X=o((function(t){(t.exports=function(t,n){return $[t]||($[t]=void 0!==n?n:{})})("versions",[]).push({version:"3.21.1",mode:"global",copyright:"© 2014-2022 Denis Pushkarev (zloirock.ru)",license:"https://github.com/zloirock/core-js/blob/v3.21.1/LICENSE",source:"https://github.com/zloirock/core-js"})})),J=_({}.hasOwnProperty),Q=Object.hasOwn||function(t,n){return J(N(t),n)},Z=0,tt=Math.random(),nt=_(1..toString),et=function(t){return"Symbol("+(void 0===t?"":t)+")_"+nt(++Z+tt,36)},rt=function(t){return s(t)?t:void 0},ot=function(t,n){return arguments.length<2?rt(a[t]):a[t]&&a[t][n]},it=ot("navigator","userAgent")||"",ut=a.process,ct=a.Deno,at=ut&&ut.versions||ct&&ct.version,ft=at&&at.v8;ft&&(u=(i=ft.split("."))[0]>0&&i[0]<4?1:+(i[0]+i[1])),!u&&it&&(!(i=it.match(/Edge\/(\d+)/))||i[1]>=74)&&(i=it.match(/Chrome\/(\d+)/))&&(u=+i[1]);var st=u,lt=!!Object.getOwnPropertySymbols&&!b((function(){var t=Symbol();return!String(t)||!(Object(t)instanceof Symbol)||!Symbol.sham&&st&&st<41})),pt=lt&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,yt=X("wks"),dt=a.Symbol,gt=dt&&dt.for,vt=pt?dt:dt&&dt.withoutSetter||et,ht=function(t){if(!Q(yt,t)||!lt&&"string"!=typeof yt[t]){var n="Symbol."+t;lt&&Q(dt,t)?yt[t]=dt[t]:yt[t]=pt&&gt?gt(n):vt(n)}return yt[t]},bt={};bt[ht("toStringTag")]="z";var mt="[object z]"===String(bt),St=ht("toStringTag"),xt=a.Object,Ot="Arguments"==A(function(){return arguments}()),wt=mt?A:function(t){var n,e,r;return void 0===t?"Undefined":null===t?"Null":"string"==typeof(e=function(t,n){try{return t[n]}catch(t){}}(n=xt(t),St))?e:Ot?A(n):"Object"==(r=A(n))&&s(n.callee)?"Arguments":r},_t=_(Function.toString);s($.inspectSource)||($.inspectSource=function(t){return _t(t)});var Et=$.inspectSource,Ct=function(){},It=[],jt=ot("Reflect","construct"),Rt=/^\s*(?:class|function)\b/,Tt=_(Rt.exec),At=!Rt.exec(Ct),Lt=function(t){if(!s(t))return!1;try{return jt(Ct,It,t),!0}catch(t){return!1}},Pt=function(t){if(!s(t))return!1;switch(wt(t)){case"AsyncFunction":case"GeneratorFunction":case"AsyncGeneratorFunction":return!1}try{return At||!!Tt(Rt,Et(t))}catch(t){return!0}};Pt.sham=!0;var Dt=!jt||b((function(){var t;return Lt(Lt.call)||!Lt(Object)||!Lt((function(){t=!0}))||t}))?Pt:Lt,Ft=ht("species"),kt=a.Array,Mt=function(t,n){return new(function(t){var n;return U(t)&&(n=t.constructor,(Dt(n)&&(n===kt||U(n.prototype))||l(n)&&null===(n=n[Ft]))&&(n=void 0)),void 0===n?kt:n}(t))(0===n?0:n)},Nt=_([].push),Gt=function(t){var n=1==t,e=2==t,r=3==t,o=4==t,i=6==t,u=7==t,c=5==t||i;return function(a,f,s,l){for(var p,y,d=N(a),g=D(d),v=function(t,n){return I(t),void 0===n?t:m?j(t,n):function(){return t.apply(n,arguments)}}(f,s),h=z(g),b=0,S=l||Mt,x=n?S(a,h):e||u?S(a,0):void 0;h>b;b++)if((c||b in g)&&(y=v(p=g[b],b,d),t))if(n)x[b]=y;else if(y)switch(t){case 3:return!0;case 5:return p;case 6:return b;case 2:Nt(x,p)}else switch(t){case 4:return!1;case 7:Nt(x,p)}return i?-1:r||o?o:x}},Vt={forEach:Gt(0),map:Gt(1),filter:Gt(2),some:Gt(3),every:Gt(4),find:Gt(5),findIndex:Gt(6),filterReject:Gt(7)},Yt=function(t,n){var e=[][t];return!!e&&b((function(){e.call(null,n||function(){return 1},1)}))},Bt=Vt.forEach,Wt=Yt("forEach")?[].forEach:function(t){return Bt(this,t,arguments.length>1?arguments[1]:void 0)},zt=!b((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),Ut=!zt&&!b((function(){return 7!=Object.defineProperty(d("div"),"a",{get:function(){return 7}}).a})),Kt=zt&&b((function(){return 42!=Object.defineProperty((function(){}),"prototype",{value:42,writable:!1}).prototype})),qt=a.String,Ht=a.TypeError,$t=function(t){if(l(t))return t;throw Ht(qt(t)+" is not an object")},Xt=Function.prototype.call,Jt=m?Xt.bind(Xt):function(){return Xt.apply(Xt,arguments)},Qt=_({}.isPrototypeOf),Zt=a.Object,tn=pt?function(t){return"symbol"==typeof t}:function(t){var n=ot("Symbol");return s(n)&&Qt(n.prototype,Zt(t))},nn=function(t,n){var e=t[n];return null==e?void 0:I(e)},en=a.TypeError,rn=a.TypeError,on=ht("toPrimitive"),un=function(t,n){if(!l(t)||tn(t))return t;var e,r=nn(t,on);if(r){if(void 0===n&&(n="default"),e=Jt(r,t,n),!l(e)||tn(e))return e;throw rn("Can't convert object to primitive value")}return void 0===n&&(n="number"),function(t,n){var e,r;if("string"===n&&s(e=t.toString)&&!l(r=Jt(e,t)))return r;if(s(e=t.valueOf)&&!l(r=Jt(e,t)))return r;if("string"!==n&&s(e=t.toString)&&!l(r=Jt(e,t)))return r;throw en("Can't convert object to primitive value")}(t,n)},cn=function(t){var n=un(t,"string");return tn(n)?n:n+""},an=a.TypeError,fn=Object.defineProperty,sn=Object.getOwnPropertyDescriptor,ln="enumerable",pn="configurable",yn="writable",dn={f:zt?Kt?function(t,n,e){if($t(t),n=cn(n),$t(e),"function"==typeof t&&"prototype"===n&&"value"in e&&yn in e&&!e.writable){var r=sn(t,n);r&&r.writable&&(t[n]=e.value,e={configurable:pn in e?e.configurable:r.configurable,enumerable:ln in e?e.enumerable:r.enumerable,writable:!1})}return fn(t,n,e)}:fn:function(t,n,e){if($t(t),n=cn(n),$t(e),Ut)try{return fn(t,n,e)}catch(t){}if("get"in e||"set"in e)throw an("Accessors not supported");return"value"in e&&(t[n]=e.value),t}},gn=function(t,n){return{enumerable:!(1&t),configurable:!(2&t),writable:!(4&t),value:n}},vn=zt?function(t,n,e){return dn.f(t,n,gn(1,e))}:function(t,n,e){return t[n]=e,t},hn=function(t){if(t&&t.forEach!==Wt)try{vn(t,"forEach",Wt)}catch(n){t.forEach=Wt}};for(var bn in f)f[bn]&&hn(a[bn]&&a[bn].prototype);hn(h);var mn,Sn,xn,On={}.propertyIsEnumerable,wn=Object.getOwnPropertyDescriptor,_n={f:wn&&!On.call({1:2},1)?function(t){var n=wn(this,t);return!!n&&n.enumerable}:On},En=function(t){return D(k(t))},Cn=Object.getOwnPropertyDescriptor,In={f:zt?Cn:function(t,n){if(t=En(t),n=cn(n),Ut)try{return Cn(t,n)}catch(t){}if(Q(t,n))return gn(!Jt(_n.f,t,n),t[n])}},jn=a.WeakMap,Rn=s(jn)&&/native code/.test(Et(jn)),Tn=X("keys"),An=function(t){return Tn[t]||(Tn[t]=et(t))},Ln={},Pn="Object already initialized",Dn=a.TypeError,Fn=a.WeakMap;if(Rn||$.state){var kn=$.state||($.state=new Fn),Mn=_(kn.get),Nn=_(kn.has),Gn=_(kn.set);mn=function(t,n){if(Nn(kn,t))throw new Dn(Pn);return n.facade=t,Gn(kn,t,n),n},Sn=function(t){return Mn(kn,t)||{}},xn=function(t){return Nn(kn,t)}}else{var Vn=An("state");Ln[Vn]=!0,mn=function(t,n){if(Q(t,Vn))throw new Dn(Pn);return n.facade=t,vn(t,Vn,n),n},Sn=function(t){return Q(t,Vn)?t[Vn]:{}},xn=function(t){return Q(t,Vn)}}var Yn,Bn={set:mn,get:Sn,has:xn,enforce:function(t){return xn(t)?Sn(t):mn(t,{})},getterFor:function(t){return function(n){var e;if(!l(n)||(e=Sn(n)).type!==t)throw Dn("Incompatible receiver, "+t+" required");return e}}},Wn=Function.prototype,zn=zt&&Object.getOwnPropertyDescriptor,Un=Q(Wn,"name"),Kn={EXISTS:Un,PROPER:Un&&"something"===function(){}.name,CONFIGURABLE:Un&&(!zt||zt&&zn(Wn,"name").configurable)},qn=o((function(t){var n=Kn.CONFIGURABLE,e=Bn.get,r=Bn.enforce,o=String(String).split("String");(t.exports=function(t,e,i,u){var c,f=!!u&&!!u.unsafe,l=!!u&&!!u.enumerable,p=!!u&&!!u.noTargetGet,y=u&&void 0!==u.name?u.name:e;s(i)&&("Symbol("===String(y).slice(0,7)&&(y="["+String(y).replace(/^Symbol\(([^)]*)\)/,"$1")+"]"),(!Q(i,"name")||n&&i.name!==y)&&vn(i,"name",y),(c=r(i)).source||(c.source=o.join("string"==typeof y?y:""))),t!==a?(f?!p&&t[e]&&(l=!0):delete t[e],l?t[e]=i:vn(t,e,i)):l?t[e]=i:q(e,i)})(Function.prototype,"toString",(function(){return s(this)&&e(this).source||Et(this)}))})),Hn=Math.max,$n=Math.min,Xn=function(t){return function(n,e,r){var o,i=En(n),u=z(i),c=function(t,n){var e=Y(t);return e<0?Hn(e+n,0):$n(e,n)}(r,u);if(t&&e!=e){for(;u>c;)if((o=i[c++])!=o)return!0}else for(;u>c;c++)if((t||c in i)&&i[c]===e)return t||c||0;return!t&&-1}},Jn={includes:Xn(!0),indexOf:Xn(!1)},Qn=Jn.indexOf,Zn=_([].push),te=function(t,n){var e,r=En(t),o=0,i=[];for(e in r)!Q(Ln,e)&&Q(r,e)&&Zn(i,e);for(;n.length>o;)Q(r,e=n[o++])&&(~Qn(i,e)||Zn(i,e));return i},ne=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],ee=ne.concat("length","prototype"),re={f:Object.getOwnPropertyNames||function(t){return te(t,ee)}},oe={f:Object.getOwnPropertySymbols},ie=_([].concat),ue=ot("Reflect","ownKeys")||function(t){var n=re.f($t(t)),e=oe.f;return e?ie(n,e(t)):n},ce=function(t,n,e){for(var r=ue(n),o=dn.f,i=In.f,u=0;u<r.length;u++){var c=r[u];Q(t,c)||e&&Q(e,c)||o(t,c,i(n,c))}},ae=/#|\.prototype\./,fe=function(t,n){var e=le[se(t)];return e==ye||e!=pe&&(s(n)?b(n):!!n)},se=fe.normalize=function(t){return String(t).replace(ae,".").toLowerCase()},le=fe.data={},pe=fe.NATIVE="N",ye=fe.POLYFILL="P",de=fe,ge=In.f,ve=function(t,n){var e,r,o,i,u,c=t.target,f=t.global,s=t.stat;if(e=f?a:s?a[c]||q(c,{}):(a[c]||{}).prototype)for(r in n){if(i=n[r],o=t.noTargetGet?(u=ge(e,r))&&u.value:e[r],!de(f?r:c+(s?".":"#")+r,t.forced)&&void 0!==o){if(typeof i==typeof o)continue;ce(i,o)}(t.sham||o&&o.sham)&&vn(i,"sham",!0),qn(e,r,i,t)}},he=ht("species"),be=Vt.filter;ve({target:"Array",proto:!0,forced:!(Yn="filter",st>=51||!b((function(){var t=[];return(t.constructor={})[he]=function(){return{foo:1}},1!==t[Yn](Boolean).foo})))},{filter:function(t){return be(this,t,arguments.length>1?arguments[1]:void 0)}});var me=function(){function t(){this.listeners={}}return t.prototype.emit=function(t,n){if(this.listeners[t]&&this.listeners[t].length>0){var e=!1;return this.listeners[t].forEach((function(t){0!==t.count&&t.cb(n),t.count>0&&t.count--,0===t.count&&(e=!0)})),e&&(this.listeners[t]=this.listeners[t].filter((function(t){return 0!==t.count}))),!0}return!1},t.prototype.many=function(t,n,e){if(!n)return this;var r={count:e,cb:n};return this.listeners[t]?this.listeners[t].push(r):this.listeners[t]=[r],this},t.prototype.on=function(t,n){this.many(t,n,-1)},t.prototype.off=function(t,n){for(var e=0;e<this.listeners[t].length;e++){var r=this.listeners[t][e];if(r.cb===n)return void(r.count=0)}},t.prototype.once=function(t,n){this.many(t,n,1)},t}(),Se=a.String,xe=a.TypeError,Oe=Object.setPrototypeOf||("__proto__"in{}?function(){var t,n=!1,e={};try{(t=_(Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set))(e,[]),n=e instanceof Array}catch(t){}return function(e,r){return $t(e),function(t){if("object"==typeof t||s(t))return t;throw xe("Can't set "+Se(t)+" as a prototype")}(r),n?t(e,r):e.__proto__=r,e}}():void 0),we=ht("match"),_e=a.String,Ee=function(t){if("Symbol"===wt(t))throw TypeError("Cannot convert a Symbol value to a string");return _e(t)},Ce=function(){var t=$t(this),n="";return t.global&&(n+="g"),t.ignoreCase&&(n+="i"),t.multiline&&(n+="m"),t.dotAll&&(n+="s"),t.unicode&&(n+="u"),t.sticky&&(n+="y"),n},Ie=a.RegExp,je=b((function(){var t=Ie("a","y");return t.lastIndex=2,null!=t.exec("abcd")})),Re=je||b((function(){return!Ie("a","y").sticky})),Te={BROKEN_CARET:je||b((function(){var t=Ie("^r","gy");return t.lastIndex=2,null!=t.exec("str")})),MISSED_STICKY:Re,UNSUPPORTED_Y:je},Ae=ht("species"),Le=a.RegExp,Pe=b((function(){var t=Le(".","s");return!(t.dotAll&&t.exec("\n")&&"s"===t.flags)})),De=a.RegExp,Fe=b((function(){var t=De("(?<a>b)","g");return"b"!==t.exec("b").groups.a||"bc"!=="b".replace(t,"$<a>c")})),ke=dn.f,Me=re.f,Ne=Bn.enforce,Ge=ht("match"),Ve=a.RegExp,Ye=Ve.prototype,Be=a.SyntaxError,We=_(Ce),ze=_(Ye.exec),Ue=_("".charAt),Ke=_("".replace),qe=_("".indexOf),He=_("".slice),$e=/^\?<[^\s\d!#%&*+<=>@^][^\s!#%&*+<=>@^]*>/,Xe=/a/g,Je=/a/g,Qe=new Ve(Xe)!==Xe,Ze=Te.MISSED_STICKY,tr=Te.UNSUPPORTED_Y,nr=zt&&(!Qe||Ze||Pe||Fe||b((function(){return Je[Ge]=!1,Ve(Xe)!=Xe||Ve(Je)==Je||"/a/i"!=Ve(Xe,"i")})));if(de("RegExp",nr)){for(var er=function(t,n){var e,r,o,i,u,c,a,f,p,y,d,g,v,h=Qt(Ye,this),b=l(e=t)&&(void 0!==(r=e[we])?!!r:"RegExp"==A(e)),m=void 0===n,S=[],x=t;if(!h&&b&&m&&t.constructor===er)return t;if((b||Qt(Ye,t))&&(t=t.source,m&&(n="flags"in x?x.flags:We(x))),t=void 0===t?"":Ee(t),n=void 0===n?"":Ee(n),x=t,Pe&&"dotAll"in Xe&&(i=!!n&&qe(n,"s")>-1)&&(n=Ke(n,/s/g,"")),o=n,Ze&&"sticky"in Xe&&(u=!!n&&qe(n,"y")>-1)&&tr&&(n=Ke(n,/y/g,"")),Fe&&(c=function(t){for(var n,e=t.length,r=0,o="",i=[],u={},c=!1,a=!1,f=0,s="";r<=e;r++){if("\\"===(n=Ue(t,r)))n+=Ue(t,++r);else if("]"===n)c=!1;else if(!c)switch(!0){case"["===n:c=!0;break;case"("===n:ze($e,He(t,r+1))&&(r+=2,a=!0),o+=n,f++;continue;case">"===n&&a:if(""===s||Q(u,s))throw new Be("Invalid capture group name");u[s]=!0,i[i.length]=[s,f],a=!1,s="";continue}a?s+=n:o+=n}return[o,i]}(t),t=c[0],S=c[1]),p=Ve(t,n),y=h?this:Ye,d=er,Oe&&s(g=y.constructor)&&g!==d&&l(v=g.prototype)&&v!==d.prototype&&Oe(p,v),a=p,(i||u||S.length)&&(f=Ne(a),i&&(f.dotAll=!0,f.raw=er(function(t){for(var n,e=t.length,r=0,o="",i=!1;r<=e;r++)"\\"!==(n=Ue(t,r))?i||"."!==n?("["===n?i=!0:"]"===n&&(i=!1),o+=n):o+="[\\s\\S]":o+=n+Ue(t,++r);return o}(t),o)),u&&(f.sticky=!0),S.length&&(f.groups=S)),t!==x)try{vn(a,"source",""===x?"(?:)":x)}catch(t){}return a},rr=function(t){t in er||ke(er,t,{configurable:!0,get:function(){return Ve[t]},set:function(n){Ve[t]=n}})},or=Me(Ve),ir=0;or.length>ir;)rr(or[ir++]);Ye.constructor=er,er.prototype=Ye,qn(a,"RegExp",er)}!function(t){var n=ot(t),e=dn.f;zt&&n&&!n[Ae]&&e(n,Ae,{configurable:!0,get:function(){return this}})}("RegExp");var ur,cr=Object.keys||function(t){return te(t,ne)},ar=zt&&!Kt?Object.defineProperties:function(t,n){$t(t);for(var e,r=En(n),o=cr(n),i=o.length,u=0;i>u;)dn.f(t,e=o[u++],r[e]);return t},fr={f:ar},sr=ot("document","documentElement"),lr=An("IE_PROTO"),pr=function(){},yr=function(t){return"<script>"+t+"</"+"script>"},dr=function(t){t.write(yr("")),t.close();var n=t.parentWindow.Object;return t=null,n},gr=function(){try{ur=new ActiveXObject("htmlfile")}catch(t){}var t,n;gr="undefined"!=typeof document?document.domain&&ur?dr(ur):((n=d("iframe")).style.display="none",sr.appendChild(n),n.src=String("javascript:"),(t=n.contentWindow.document).open(),t.write(yr("document.F=Object")),t.close(),t.F):dr(ur);for(var e=ne.length;e--;)delete gr.prototype[ne[e]];return gr()};Ln[lr]=!0;var vr=Object.create||function(t,n){var e;return null!==t?(pr.prototype=$t(t),e=new pr,pr.prototype=null,e[lr]=t):e=gr(),void 0===n?e:fr.f(e,n)},hr=Bn.get,br=X("native-string-replace",String.prototype.replace),mr=RegExp.prototype.exec,Sr=mr,xr=_("".charAt),Or=_("".indexOf),wr=_("".replace),_r=_("".slice),Er=function(){var t=/a/,n=/b*/g;return Jt(mr,t,"a"),Jt(mr,n,"a"),0!==t.lastIndex||0!==n.lastIndex}(),Cr=Te.BROKEN_CARET,Ir=void 0!==/()??/.exec("")[1];(Er||Ir||Cr||Pe||Fe)&&(Sr=function(t){var n,e,r,o,i,u,c,a=this,f=hr(a),s=Ee(t),l=f.raw;if(l)return l.lastIndex=a.lastIndex,n=Jt(Sr,l,s),a.lastIndex=l.lastIndex,n;var p=f.groups,y=Cr&&a.sticky,d=Jt(Ce,a),g=a.source,v=0,h=s;if(y&&(d=wr(d,"y",""),-1===Or(d,"g")&&(d+="g"),h=_r(s,a.lastIndex),a.lastIndex>0&&(!a.multiline||a.multiline&&"\n"!==xr(s,a.lastIndex-1))&&(g="(?: "+g+")",h=" "+h,v++),e=new RegExp("^(?:"+g+")",d)),Ir&&(e=new RegExp("^"+g+"$(?!\\s)",d)),Er&&(r=a.lastIndex),o=Jt(mr,y?e:a,h),y?o?(o.input=_r(o.input,v),o[0]=_r(o[0],v),o.index=a.lastIndex,a.lastIndex+=o[0].length):a.lastIndex=0:Er&&o&&(a.lastIndex=a.global?o.index+o[0].length:r),Ir&&o&&o.length>1&&Jt(br,o[0],e,(function(){for(i=1;i<arguments.length-2;i++)void 0===arguments[i]&&(o[i]=void 0)})),o&&p)for(o.groups=u=vr(null),i=0;i<p.length;i++)u[(c=p[i])[0]]=o[c[1]];return o});var jr=Sr;ve({target:"RegExp",proto:!0,forced:/./.exec!==jr},{exec:jr});var Rr=Kn.PROPER,Tr="toString",Ar=RegExp.prototype,Lr=Ar.toString,Pr=_(Ce),Dr=b((function(){return"/a/b"!=Lr.call({source:"a",flags:"b"})})),Fr=Rr&&Lr.name!=Tr;(Dr||Fr)&&qn(RegExp.prototype,Tr,(function(){var t=$t(this),n=Ee(t.source),e=t.flags;return"/"+n+"/"+Ee(void 0===e&&Qt(Ar,t)&&!("flags"in Ar)?Pr(t):e)}),{unsafe:!0});var kr=Jn.indexOf,Mr=_([].indexOf),Nr=!!Mr&&1/Mr([1],1,-0)<0,Gr=Yt("indexOf");ve({target:"Array",proto:!0,forced:Nr||!Gr},{indexOf:function(t){var n=arguments.length>1?arguments[1]:void 0;return Nr?Mr(this,t,n)||0:kr(this,t,n)}});var Vr=ht("species"),Yr=RegExp.prototype,Br=_("".charAt),Wr=_("".charCodeAt),zr=_("".slice),Ur=function(t){return function(n,e){var r,o,i=Ee(k(n)),u=Y(e),c=i.length;return u<0||u>=c?t?"":void 0:(r=Wr(i,u))<55296||r>56319||u+1===c||(o=Wr(i,u+1))<56320||o>57343?t?Br(i,u):r:t?zr(i,u,u+2):o-56320+(r-55296<<10)+65536}},Kr={codeAt:Ur(!1),charAt:Ur(!0)}.charAt,qr=function(t,n,e){return n+(e?Kr(t,n).length:1)},Hr=a.TypeError,$r=function(t,n){var e=t.exec;if(s(e)){var r=Jt(e,t,n);return null!==r&&$t(r),r}if("RegExp"===A(t))return Jt(jr,t,n);throw Hr("RegExp#exec called on incompatible receiver")};!function(t,n,e,r){var o=ht(t),i=!b((function(){var n={};return n[o]=function(){return 7},7!=""[t](n)})),u=i&&!b((function(){var n=!1,e=/a/;return"split"===t&&((e={}).constructor={},e.constructor[Vr]=function(){return e},e.flags="",e[o]=/./[o]),e.exec=function(){return n=!0,null},e[o](""),!n}));if(!i||!u||e){var c=_(/./[o]),a=n(o,""[t],(function(t,n,e,r,o){var u=_(t),a=n.exec;return a===jr||a===Yr.exec?i&&!o?{done:!0,value:c(n,e,r)}:{done:!0,value:u(e,n,r)}:{done:!1}}));qn(String.prototype,t,a[0]),qn(Yr,o,a[1])}r&&vn(Yr[o],"sham",!0)}("match",(function(t,n,e){return[function(n){var e=k(this),r=null==n?void 0:nn(n,t);return r?Jt(r,n,e):new RegExp(n)[t](Ee(e))},function(t){var r=$t(this),o=Ee(t),i=e(n,r,o);if(i.done)return i.value;if(!r.global)return $r(r,o);var u=r.unicode;r.lastIndex=0;for(var c,a=[],f=0;null!==(c=$r(r,o));){var s=Ee(c[0]);a[f]=s,""===s&&(r.lastIndex=qr(o,W(r.lastIndex),u)),f++}return 0===f?null:a}]}));var Xr="((?:(?:[0-9]|(?:[1-9](?:[0-9]*))).){2}(?:[0-9]|(?:[1-9](?:[0-9]*))))",Jr=new RegExp("native_sdk/".concat(Xr)),Qr=new RegExp("native_app_version/".concat(Xr));var Zr=new me,to={},no=function(){var n=function(){return this}();try{n=n||new Function("return this")()}catch(e){"object"===("undefined"==typeof window?"undefined":t(window))&&(n=window)}return n}();function eo(t,n){t in to?n&&n(to[t]):Zr.once("lifeCycle:".concat(t),n)}function ro(t,n){t in to||(to[t]=n,Zr.emit("lifeCycle:".concat(t),n))}var oo=function(t){function r(){var n=t.call(this)||this;return n._STATIC_CONFIG_READY="configReady",n._STATIC_LIB_READY="libraryReady",n.init(),n}return function(t,n){if("function"!=typeof n&&null!==n)throw new TypeError("Class extends value "+String(n)+" is not a constructor or null");function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}(r,t),r.prototype.init=function(){this.env=function(t){var n=t.__ddLibrary,e=t.__ddConfig,r=n.envType,o=n.contextType,i="Service"===r,u="WebView"===r,c="Worker"===r,a="Widget"===r,f=u||i&&0===o.indexOf("App:"),s=i&&0===o.indexOf("Game:"),l=c&&"function"==typeof t.workerInvokeJsApi,p=!!e.isIsolateContext,y=i&&(p&&0<=o.indexOf("Uncertain")||0<=o.indexOf("MainContext")),d=i&&0<=o.indexOf("SubContext"),g=y||d,v=u||y,h=e.platform,b=e.SDKVersion,m=e.version;if(u){var S=window.navigator.userAgent.toLowerCase();!h&&u&&0<=S.indexOf("devtools")?h="devtools":0<=S.indexOf("miniprogramenv/windows")?h="windows":0<=S.indexOf("miniprogramenv/mac")?h="mac":0<=S.indexOf("iphone")||0<=S.indexOf("ipad")?h="ios":0<=S.indexOf("android")&&(h="android");var x=S.match(Jr),O=S.match(Qr);x&&(b=x[1]||""),O&&(m=O[1]||"")}return{platform:(h||"unknown").toLowerCase(),jssdkVersion:"undefined"==typeof __libVersionInfo__||"develop"===__libVersionInfo__.version?"9.9.9":__libVersionInfo__.version,SDKVersion:b,version:m,isIsolateContext:g,isGame:s,isApp:f,isMainContext:y,isSubContext:d,isSafeEnv:v,isService:i,isWebView:u,isWorker:c,isWidget:a,isSupportWorkerAPI:l,typeStr:r}}(no),this.global=no,this.EventEmitter=me,this.exportConfig={}},r.prototype.emitConfigReady=function(t){ro(this._STATIC_CONFIG_READY,t)},r.prototype.onConfigReady=function(t){eo(this._STATIC_CONFIG_READY,t)},Object.defineProperty(r.prototype,"isConfigReady",{get:function(){return this._STATIC_CONFIG_READY in to},enumerable:!1,configurable:!0}),r.prototype.onLibraryReady=function(t){eo(this._STATIC_LIB_READY,t)},r.prototype.emitLibraryReady=function(t){ro(this._STATIC_LIB_READY,t)},Object.defineProperty(r.prototype,"isLibraryReady",{get:function(){return this._STATIC_LIB_READY in to},enumerable:!1,configurable:!0}),Object.defineProperty(r.prototype,"isBridgeReady",{get:function(){return!1},enumerable:!1,configurable:!0}),r.prototype.onBridgeReady=function(){},r.prototype.refreshDDConfig=function(t){void 0===t&&(t={}),n(__ddConfig,t),n(this.exportConfig,t)},r.prototype.getExportConfig=function(){return this.exportConfig},r.prototype.setExportConfig=function(t){void 0===t&&(t={}),this.exportConfig=t},r.prototype.setDDConfig=function(t){void 0===t&&(t={}),n(__ddConfig,t)},r}(me);void 0!==no.__Function__&&(no.Function=function(){},no.Function.prototype=no.__Function__.prototype);var io=new oo;return no.__ddLibrary&&(no.__ddLibrary.onEnd=function(){io.emitLibraryReady({})}),io}();


var didiJsBridge=function(){"use strict";var t="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function r(t,r,n){return t(n={path:r,exports:{},require:function(t,r){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==r&&n.path)}},n.exports),n.exports}var n,e,o=function(t){return t&&t.Math==Math&&t},i=o("object"==typeof globalThis&&globalThis)||o("object"==typeof window&&window)||o("object"==typeof self&&self)||o("object"==typeof t&&t)||function(){return this}()||Function("return this")(),u=Object.defineProperty,c=function(t,r){try{u(i,t,{value:r,configurable:!0,writable:!0})}catch(n){i[t]=r}return r},a="__core-js_shared__",f=i[a]||c(a,{}),s=r((function(t){(t.exports=function(t,r){return f[t]||(f[t]=void 0!==r?r:{})})("versions",[]).push({version:"3.21.1",mode:"global",copyright:"© 2014-2022 Denis Pushkarev (zloirock.ru)",license:"https://github.com/zloirock/core-js/blob/v3.21.1/LICENSE",source:"https://github.com/zloirock/core-js"})})),l=function(t){try{return!!t()}catch(t){return!0}},p=!l((function(){var t=function(){}.bind();return"function"!=typeof t||t.hasOwnProperty("prototype")})),v=Function.prototype,g=v.bind,y=v.call,b=p&&g.bind(y,y),h=p?function(t){return t&&b(t)}:function(t){return t&&function(){return y.apply(t,arguments)}},d=i.TypeError,m=function(t){if(null==t)throw d("Can't call method on "+t);return t},S=i.Object,w=function(t){return S(m(t))},O=h({}.hasOwnProperty),E=Object.hasOwn||function(t,r){return O(w(t),r)},j=0,T=Math.random(),_=h(1..toString),k=function(t){return"Symbol("+(void 0===t?"":t)+")_"+_(++j+T,36)},I=function(t){return"function"==typeof t},A=function(t){return I(t)?t:void 0},N=function(t,r){return arguments.length<2?A(i[t]):i[t]&&i[t][r]},B=N("navigator","userAgent")||"",P=i.process,x=i.Deno,C=P&&P.versions||x&&x.version,M=C&&C.v8;M&&(e=(n=M.split("."))[0]>0&&n[0]<4?1:+(n[0]+n[1])),!e&&B&&(!(n=B.match(/Edge\/(\d+)/))||n[1]>=74)&&(n=B.match(/Chrome\/(\d+)/))&&(e=+n[1]);var D=e,F=!!Object.getOwnPropertySymbols&&!l((function(){var t=Symbol();return!String(t)||!(Object(t)instanceof Symbol)||!Symbol.sham&&D&&D<41})),R=F&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,L=s("wks"),z=i.Symbol,U=z&&z.for,G=R?z:z&&z.withoutSetter||k,H=function(t){if(!E(L,t)||!F&&"string"!=typeof L[t]){var r="Symbol."+t;F&&E(z,t)?L[t]=z[t]:L[t]=R&&U?U(r):G(r)}return L[t]},V={};V[H("toStringTag")]="z";var W="[object z]"===String(V),q=!l((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),J=function(t){return"object"==typeof t?null!==t:I(t)},K=i.document,X=J(K)&&J(K.createElement),Y=!q&&!l((function(){return 7!=Object.defineProperty((t="div",X?K.createElement(t):{}),"a",{get:function(){return 7}}).a;var t})),Z=q&&l((function(){return 42!=Object.defineProperty((function(){}),"prototype",{value:42,writable:!1}).prototype})),$=i.String,Q=i.TypeError,tt=function(t){if(J(t))return t;throw Q($(t)+" is not an object")},rt=Function.prototype.call,nt=p?rt.bind(rt):function(){return rt.apply(rt,arguments)},et=h({}.isPrototypeOf),ot=i.Object,it=R?function(t){return"symbol"==typeof t}:function(t){var r=N("Symbol");return I(r)&&et(r.prototype,ot(t))},ut=i.String,ct=i.TypeError,at=function(t){if(I(t))return t;throw ct(function(t){try{return ut(t)}catch(t){return"Object"}}(t)+" is not a function")},ft=i.TypeError,st=i.TypeError,lt=H("toPrimitive"),pt=function(t,r){if(!J(t)||it(t))return t;var n,e,o=null==(n=t[lt])?void 0:at(n);if(o){if(void 0===r&&(r="default"),e=nt(o,t,r),!J(e)||it(e))return e;throw st("Can't convert object to primitive value")}return void 0===r&&(r="number"),function(t,r){var n,e;if("string"===r&&I(n=t.toString)&&!J(e=nt(n,t)))return e;if(I(n=t.valueOf)&&!J(e=nt(n,t)))return e;if("string"!==r&&I(n=t.toString)&&!J(e=nt(n,t)))return e;throw ft("Can't convert object to primitive value")}(t,r)},vt=function(t){var r=pt(t,"string");return it(r)?r:r+""},gt=i.TypeError,yt=Object.defineProperty,bt=Object.getOwnPropertyDescriptor,ht="enumerable",dt="configurable",mt="writable",St={f:q?Z?function(t,r,n){if(tt(t),r=vt(r),tt(n),"function"==typeof t&&"prototype"===r&&"value"in n&&mt in n&&!n.writable){var e=bt(t,r);e&&e.writable&&(t[r]=n.value,n={configurable:dt in n?n.configurable:e.configurable,enumerable:ht in n?n.enumerable:e.enumerable,writable:!1})}return yt(t,r,n)}:yt:function(t,r,n){if(tt(t),r=vt(r),tt(n),Y)try{return yt(t,r,n)}catch(t){}if("get"in n||"set"in n)throw gt("Accessors not supported");return"value"in n&&(t[r]=n.value),t}},wt=function(t,r){return{enumerable:!(1&t),configurable:!(2&t),writable:!(4&t),value:r}},Ot=q?function(t,r,n){return St.f(t,r,wt(1,n))}:function(t,r,n){return t[r]=n,t},Et=h(Function.toString);I(f.inspectSource)||(f.inspectSource=function(t){return Et(t)});var jt,Tt,_t,kt=f.inspectSource,It=i.WeakMap,At=I(It)&&/native code/.test(kt(It)),Nt=s("keys"),Bt={},Pt="Object already initialized",xt=i.TypeError,Ct=i.WeakMap;if(At||f.state){var Mt=f.state||(f.state=new Ct),Dt=h(Mt.get),Ft=h(Mt.has),Rt=h(Mt.set);jt=function(t,r){if(Ft(Mt,t))throw new xt(Pt);return r.facade=t,Rt(Mt,t,r),r},Tt=function(t){return Dt(Mt,t)||{}},_t=function(t){return Ft(Mt,t)}}else{var Lt=function(t){return Nt[t]||(Nt[t]=k(t))}("state");Bt[Lt]=!0,jt=function(t,r){if(E(t,Lt))throw new xt(Pt);return r.facade=t,Ot(t,Lt,r),r},Tt=function(t){return E(t,Lt)?t[Lt]:{}},_t=function(t){return E(t,Lt)}}var zt={set:jt,get:Tt,has:_t,enforce:function(t){return _t(t)?Tt(t):jt(t,{})},getterFor:function(t){return function(r){var n;if(!J(r)||(n=Tt(r)).type!==t)throw xt("Incompatible receiver, "+t+" required");return n}}},Ut=Function.prototype,Gt=q&&Object.getOwnPropertyDescriptor,Ht=E(Ut,"name"),Vt={EXISTS:Ht,PROPER:Ht&&"something"===function(){}.name,CONFIGURABLE:Ht&&(!q||q&&Gt(Ut,"name").configurable)},Wt=r((function(t){var r=Vt.CONFIGURABLE,n=zt.get,e=zt.enforce,o=String(String).split("String");(t.exports=function(t,n,u,a){var f,s=!!a&&!!a.unsafe,l=!!a&&!!a.enumerable,p=!!a&&!!a.noTargetGet,v=a&&void 0!==a.name?a.name:n;I(u)&&("Symbol("===String(v).slice(0,7)&&(v="["+String(v).replace(/^Symbol\(([^)]*)\)/,"$1")+"]"),(!E(u,"name")||r&&u.name!==v)&&Ot(u,"name",v),(f=e(u)).source||(f.source=o.join("string"==typeof v?v:""))),t!==i?(s?!p&&t[n]&&(l=!0):delete t[n],l?t[n]=u:Ot(t,n,u)):l?t[n]=u:c(n,u)})(Function.prototype,"toString",(function(){return I(this)&&n(this).source||kt(this)}))})),qt=h({}.toString),Jt=h("".slice),Kt=function(t){return Jt(qt(t),8,-1)},Xt=H("toStringTag"),Yt=i.Object,Zt="Arguments"==Kt(function(){return arguments}()),$t=W?Kt:function(t){var r,n,e;return void 0===t?"Undefined":null===t?"Null":"string"==typeof(n=function(t,r){try{return t[r]}catch(t){}}(r=Yt(t),Xt))?n:Zt?Kt(r):"Object"==(e=Kt(r))&&I(r.callee)?"Arguments":e},Qt=W?{}.toString:function(){return"[object "+$t(this)+"]"};W||Wt(Object.prototype,"toString",Qt,{unsafe:!0});var tr=i.String,rr=function(t){if("Symbol"===$t(t))throw TypeError("Cannot convert a Symbol value to a string");return tr(t)},nr=Vt.PROPER,er="toString",or=RegExp.prototype,ir=or.toString,ur=h((function(){var t=tt(this),r="";return t.global&&(r+="g"),t.ignoreCase&&(r+="i"),t.multiline&&(r+="m"),t.dotAll&&(r+="s"),t.unicode&&(r+="u"),t.sticky&&(r+="y"),r})),cr=l((function(){return"/a/b"!=ir.call({source:"a",flags:"b"})})),ar=nr&&ir.name!=er;(cr||ar)&&Wt(RegExp.prototype,er,(function(){var t=tt(this),r=rr(t.source),n=t.flags;return"/"+r+"/"+rr(void 0===n&&et(or,t)&&!("flags"in or)?ur(t):n)}),{unsafe:!0});var fr={}.propertyIsEnumerable,sr=Object.getOwnPropertyDescriptor,lr={f:sr&&!fr.call({1:2},1)?function(t){var r=sr(this,t);return!!r&&r.enumerable}:fr},pr=i.Object,vr=h("".split),gr=l((function(){return!pr("z").propertyIsEnumerable(0)}))?function(t){return"String"==Kt(t)?vr(t,""):pr(t)}:pr,yr=function(t){return gr(m(t))},br=Object.getOwnPropertyDescriptor,hr={f:q?br:function(t,r){if(t=yr(t),r=vt(r),Y)try{return br(t,r)}catch(t){}if(E(t,r))return wt(!nt(lr.f,t,r),t[r])}},dr=Math.ceil,mr=Math.floor,Sr=function(t){var r=+t;return r!=r||0===r?0:(r>0?mr:dr)(r)},wr=Math.max,Or=Math.min,Er=function(t,r){var n=Sr(t);return n<0?wr(n+r,0):Or(n,r)},jr=Math.min,Tr=function(t){return(r=t.length)>0?jr(Sr(r),9007199254740991):0;var r},_r=function(t){return function(r,n,e){var o,i=yr(r),u=Tr(i),c=Er(e,u);if(t&&n!=n){for(;u>c;)if((o=i[c++])!=o)return!0}else for(;u>c;c++)if((t||c in i)&&i[c]===n)return t||c||0;return!t&&-1}},kr={includes:_r(!0),indexOf:_r(!1)}.indexOf,Ir=h([].push),Ar=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"].concat("length","prototype"),Nr=Object.getOwnPropertyNames||function(t){return function(t,r){var n,e=yr(t),o=0,i=[];for(n in e)!E(Bt,n)&&E(e,n)&&Ir(i,n);for(;r.length>o;)E(e,n=r[o++])&&(~kr(i,n)||Ir(i,n));return i}(t,Ar)},Br={f:Nr},Pr={f:Object.getOwnPropertySymbols},xr=h([].concat),Cr=N("Reflect","ownKeys")||function(t){var r=Br.f(tt(t)),n=Pr.f;return n?xr(r,n(t)):r},Mr=function(t,r,n){for(var e=Cr(r),o=St.f,i=hr.f,u=0;u<e.length;u++){var c=e[u];E(t,c)||n&&E(n,c)||o(t,c,i(r,c))}},Dr=/#|\.prototype\./,Fr=function(t,r){var n=Lr[Rr(t)];return n==Ur||n!=zr&&(I(r)?l(r):!!r)},Rr=Fr.normalize=function(t){return String(t).replace(Dr,".").toLowerCase()},Lr=Fr.data={},zr=Fr.NATIVE="N",Ur=Fr.POLYFILL="P",Gr=Fr,Hr=hr.f,Vr=function(t,r){var n,e,o,u,a,f=t.target,s=t.global,l=t.stat;if(n=s?i:l?i[f]||c(f,{}):(i[f]||{}).prototype)for(e in r){if(u=r[e],o=t.noTargetGet?(a=Hr(n,e))&&a.value:n[e],!Gr(s?e:f+(l?".":"#")+e,t.forced)&&void 0!==o){if(typeof u==typeof o)continue;Mr(u,o)}(t.sham||o&&o.sham)&&Ot(u,"sham",!0),Wt(n,e,u,t)}},Wr=Array.isArray||function(t){return"Array"==Kt(t)},qr=function(t,r,n){var e=vt(r);e in t?St.f(t,e,wt(0,n)):t[e]=n},Jr=function(){},Kr=[],Xr=N("Reflect","construct"),Yr=/^\s*(?:class|function)\b/,Zr=h(Yr.exec),$r=!Yr.exec(Jr),Qr=function(t){if(!I(t))return!1;try{return Xr(Jr,Kr,t),!0}catch(t){return!1}},tn=function(t){if(!I(t))return!1;switch($t(t)){case"AsyncFunction":case"GeneratorFunction":case"AsyncGeneratorFunction":return!1}try{return $r||!!Zr(Yr,kt(t))}catch(t){return!0}};tn.sham=!0;var rn=!Xr||l((function(){var t;return Qr(Qr.call)||!Qr(Object)||!Qr((function(){t=!0}))||t}))?tn:Qr,nn=H("species"),en=i.Array,on=function(t,r){return new(function(t){var r;return Wr(t)&&(r=t.constructor,(rn(r)&&(r===en||Wr(r.prototype))||J(r)&&null===(r=r[nn]))&&(r=void 0)),void 0===r?en:r}(t))(0===r?0:r)},un=H("species"),cn=function(t){return D>=51||!l((function(){var r=[];return(r.constructor={})[un]=function(){return{foo:1}},1!==r[t](Boolean).foo}))},an=H("isConcatSpreadable"),fn=9007199254740991,sn="Maximum allowed index exceeded",ln=i.TypeError,pn=D>=51||!l((function(){var t=[];return t[an]=!1,t.concat()[0]!==t})),vn=cn("concat"),gn=function(t){if(!J(t))return!1;var r=t[an];return void 0!==r?!!r:Wr(t)};Vr({target:"Array",proto:!0,forced:!pn||!vn},{concat:function(t){var r,n,e,o,i,u=w(this),c=on(u,0),a=0;for(r=-1,e=arguments.length;r<e;r++)if(gn(i=-1===r?u:arguments[r])){if(a+(o=Tr(i))>fn)throw ln(sn);for(n=0;n<o;n++,a++)n in i&&qr(c,a,i[n])}else{if(a>=fn)throw ln(sn);qr(c,a++,i)}return c.length=a,c}});var yn=cn("splice"),bn=i.TypeError,hn=Math.max,dn=Math.min,mn=9007199254740991,Sn="Maximum allowed length exceeded";Vr({target:"Array",proto:!0,forced:!yn},{splice:function(t,r){var n,e,o,i,u,c,a=w(this),f=Tr(a),s=Er(t,f),l=arguments.length;if(0===l?n=e=0:1===l?(n=0,e=f-s):(n=l-2,e=dn(hn(Sr(r),0),f-s)),f+n-e>mn)throw bn(Sn);for(o=on(a,e),i=0;i<e;i++)(u=s+i)in a&&qr(o,i,a[u]);if(o.length=e,n<e){for(i=s;i<f-e;i++)c=i+n,(u=i+e)in a?a[c]=a[u]:delete a[c];for(i=f;i>f-e+n;i--)delete a[i-1]}else if(n>e)for(i=f-e;i>s;i--)c=i+n-1,(u=i+e-1)in a?a[c]=a[u]:delete a[c];for(i=0;i<n;i++)a[i+s]=arguments[i+2];return a.length=f-e+n,o}});var wn=i.String,On=i.TypeError,En=Object.setPrototypeOf||("__proto__"in{}?function(){var t,r=!1,n={};try{(t=h(Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set))(n,[]),r=n instanceof Array}catch(t){}return function(n,e){return tt(n),function(t){if("object"==typeof t||I(t))return t;throw On("Can't set "+wn(t)+" as a prototype")}(e),r?t(n,e):n.__proto__=e,n}}():void 0),jn=function(t,r,n){var e,o;return En&&I(e=r.constructor)&&e!==n&&J(o=e.prototype)&&o!==n.prototype&&En(t,o),t},Tn=h(1..valueOf),_n=h("".replace),kn="[\t\n\v\f\r                　\u2028\u2029\ufeff]",In=RegExp("^"+kn+kn+"*"),An=RegExp(kn+kn+"*$"),Nn=function(t){return function(r){var n=rr(m(r));return 1&t&&(n=_n(n,In,"")),2&t&&(n=_n(n,An,"")),n}},Bn={start:Nn(1),end:Nn(2),trim:Nn(3)},Pn=Br.f,xn=hr.f,Cn=St.f,Mn=Bn.trim,Dn="Number",Fn=i.Number,Rn=Fn.prototype,Ln=i.TypeError,zn=h("".slice),Un=h("".charCodeAt),Gn=function(t){var r=pt(t,"number");return"bigint"==typeof r?r:Hn(r)},Hn=function(t){var r,n,e,o,i,u,c,a,f=pt(t,"number");if(it(f))throw Ln("Cannot convert a Symbol value to a number");if("string"==typeof f&&f.length>2)if(f=Mn(f),43===(r=Un(f,0))||45===r){if(88===(n=Un(f,2))||120===n)return NaN}else if(48===r){switch(Un(f,1)){case 66:case 98:e=2,o=49;break;case 79:case 111:e=8,o=55;break;default:return+f}for(u=(i=zn(f,2)).length,c=0;c<u;c++)if((a=Un(i,c))<48||a>o)return NaN;return parseInt(i,e)}return+f};if(Gr(Dn,!Fn(" 0o1")||!Fn("0b1")||Fn("+0x1"))){for(var Vn,Wn=function(t){var r=arguments.length<1?0:Fn(Gn(t)),n=this;return et(Rn,n)&&l((function(){Tn(n)}))?jn(Object(r),n,Wn):r},qn=q?Pn(Fn):"MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,EPSILON,MAX_SAFE_INTEGER,MIN_SAFE_INTEGER,isFinite,isInteger,isNaN,isSafeInteger,parseFloat,parseInt,fromString,range".split(","),Jn=0;qn.length>Jn;Jn++)E(Fn,Vn=qn[Jn])&&!E(Wn,Vn)&&Cn(Wn,Vn,xn(Fn,Vn));Wn.prototype=Rn,Rn.constructor=Wn,Wt(i,Dn,Wn)}var Kn=r((function(t){!function(){var r="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",n={rotl:function(t,r){return t<<r|t>>>32-r},rotr:function(t,r){return t<<32-r|t>>>r},endian:function(t){if(t.constructor==Number)return 16711935&n.rotl(t,8)|4278255360&n.rotl(t,24);for(var r=0;r<t.length;r++)t[r]=n.endian(t[r]);return t},randomBytes:function(t){for(var r=[];t>0;t--)r.push(Math.floor(256*Math.random()));return r},bytesToWords:function(t){for(var r=[],n=0,e=0;n<t.length;n++,e+=8)r[e>>>5]|=t[n]<<24-e%32;return r},wordsToBytes:function(t){for(var r=[],n=0;n<32*t.length;n+=8)r.push(t[n>>>5]>>>24-n%32&255);return r},bytesToHex:function(t){for(var r=[],n=0;n<t.length;n++)r.push((t[n]>>>4).toString(16)),r.push((15&t[n]).toString(16));return r.join("")},hexToBytes:function(t){for(var r=[],n=0;n<t.length;n+=2)r.push(parseInt(t.substr(n,2),16));return r},bytesToBase64:function(t){for(var n=[],e=0;e<t.length;e+=3)for(var o=t[e]<<16|t[e+1]<<8|t[e+2],i=0;i<4;i++)8*e+6*i<=8*t.length?n.push(r.charAt(o>>>6*(3-i)&63)):n.push("=");return n.join("")},base64ToBytes:function(t){t=t.replace(/[^A-Z0-9+\/]/gi,"");for(var n=[],e=0,o=0;e<t.length;o=++e%4)0!=o&&n.push((r.indexOf(t.charAt(e-1))&Math.pow(2,-2*o+8)-1)<<2*o|r.indexOf(t.charAt(e))>>>6-2*o);return n}};t.exports=n}()})),Xn={utf8:{stringToBytes:function(t){return Xn.bin.stringToBytes(unescape(encodeURIComponent(t)))},bytesToString:function(t){return decodeURIComponent(escape(Xn.bin.bytesToString(t)))}},bin:{stringToBytes:function(t){for(var r=[],n=0;n<t.length;n++)r.push(255&t.charCodeAt(n));return r},bytesToString:function(t){for(var r=[],n=0;n<t.length;n++)r.push(String.fromCharCode(t[n]));return r.join("")}}},Yn=Xn,Zn=function(t){return null!=t&&($n(t)||function(t){return"function"==typeof t.readFloatLE&&"function"==typeof t.slice&&$n(t.slice(0,0))}(t)||!!t._isBuffer)};function $n(t){return!!t.constructor&&"function"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}r((function(t){!function(){var r=Kn,n=Yn.utf8,e=Zn,o=Yn.bin,i=function(t,u){t.constructor==String?t=u&&"binary"===u.encoding?o.stringToBytes(t):n.stringToBytes(t):e(t)?t=Array.prototype.slice.call(t,0):Array.isArray(t)||t.constructor===Uint8Array||(t=t.toString());for(var c=r.bytesToWords(t),a=8*t.length,f=1732584193,s=-271733879,l=-1732584194,p=271733878,v=0;v<c.length;v++)c[v]=16711935&(c[v]<<8|c[v]>>>24)|4278255360&(c[v]<<24|c[v]>>>8);c[a>>>5]|=128<<a%32,c[14+(a+64>>>9<<4)]=a;var g=i._ff,y=i._gg,b=i._hh,h=i._ii;for(v=0;v<c.length;v+=16){var d=f,m=s,S=l,w=p;f=g(f,s,l,p,c[v+0],7,-680876936),p=g(p,f,s,l,c[v+1],12,-389564586),l=g(l,p,f,s,c[v+2],17,606105819),s=g(s,l,p,f,c[v+3],22,-1044525330),f=g(f,s,l,p,c[v+4],7,-176418897),p=g(p,f,s,l,c[v+5],12,1200080426),l=g(l,p,f,s,c[v+6],17,-1473231341),s=g(s,l,p,f,c[v+7],22,-45705983),f=g(f,s,l,p,c[v+8],7,1770035416),p=g(p,f,s,l,c[v+9],12,-1958414417),l=g(l,p,f,s,c[v+10],17,-42063),s=g(s,l,p,f,c[v+11],22,-1990404162),f=g(f,s,l,p,c[v+12],7,1804603682),p=g(p,f,s,l,c[v+13],12,-40341101),l=g(l,p,f,s,c[v+14],17,-1502002290),f=y(f,s=g(s,l,p,f,c[v+15],22,1236535329),l,p,c[v+1],5,-165796510),p=y(p,f,s,l,c[v+6],9,-1069501632),l=y(l,p,f,s,c[v+11],14,643717713),s=y(s,l,p,f,c[v+0],20,-373897302),f=y(f,s,l,p,c[v+5],5,-701558691),p=y(p,f,s,l,c[v+10],9,38016083),l=y(l,p,f,s,c[v+15],14,-660478335),s=y(s,l,p,f,c[v+4],20,-405537848),f=y(f,s,l,p,c[v+9],5,568446438),p=y(p,f,s,l,c[v+14],9,-1019803690),l=y(l,p,f,s,c[v+3],14,-187363961),s=y(s,l,p,f,c[v+8],20,1163531501),f=y(f,s,l,p,c[v+13],5,-1444681467),p=y(p,f,s,l,c[v+2],9,-51403784),l=y(l,p,f,s,c[v+7],14,1735328473),f=b(f,s=y(s,l,p,f,c[v+12],20,-1926607734),l,p,c[v+5],4,-378558),p=b(p,f,s,l,c[v+8],11,-2022574463),l=b(l,p,f,s,c[v+11],16,1839030562),s=b(s,l,p,f,c[v+14],23,-35309556),f=b(f,s,l,p,c[v+1],4,-1530992060),p=b(p,f,s,l,c[v+4],11,1272893353),l=b(l,p,f,s,c[v+7],16,-155497632),s=b(s,l,p,f,c[v+10],23,-1094730640),f=b(f,s,l,p,c[v+13],4,681279174),p=b(p,f,s,l,c[v+0],11,-358537222),l=b(l,p,f,s,c[v+3],16,-722521979),s=b(s,l,p,f,c[v+6],23,76029189),f=b(f,s,l,p,c[v+9],4,-640364487),p=b(p,f,s,l,c[v+12],11,-421815835),l=b(l,p,f,s,c[v+15],16,530742520),f=h(f,s=b(s,l,p,f,c[v+2],23,-995338651),l,p,c[v+0],6,-198630844),p=h(p,f,s,l,c[v+7],10,1126891415),l=h(l,p,f,s,c[v+14],15,-1416354905),s=h(s,l,p,f,c[v+5],21,-57434055),f=h(f,s,l,p,c[v+12],6,1700485571),p=h(p,f,s,l,c[v+3],10,-1894986606),l=h(l,p,f,s,c[v+10],15,-1051523),s=h(s,l,p,f,c[v+1],21,-2054922799),f=h(f,s,l,p,c[v+8],6,1873313359),p=h(p,f,s,l,c[v+15],10,-30611744),l=h(l,p,f,s,c[v+6],15,-1560198380),s=h(s,l,p,f,c[v+13],21,1309151649),f=h(f,s,l,p,c[v+4],6,-145523070),p=h(p,f,s,l,c[v+11],10,-1120210379),l=h(l,p,f,s,c[v+2],15,718787259),s=h(s,l,p,f,c[v+9],21,-343485551),f=f+d>>>0,s=s+m>>>0,l=l+S>>>0,p=p+w>>>0}return r.endian([f,s,l,p])};i._ff=function(t,r,n,e,o,i,u){var c=t+(r&n|~r&e)+(o>>>0)+u;return(c<<i|c>>>32-i)+r},i._gg=function(t,r,n,e,o,i,u){var c=t+(r&e|n&~e)+(o>>>0)+u;return(c<<i|c>>>32-i)+r},i._hh=function(t,r,n,e,o,i,u){var c=t+(r^n^e)+(o>>>0)+u;return(c<<i|c>>>32-i)+r},i._ii=function(t,r,n,e,o,i,u){var c=t+(n^(r|~e))+(o>>>0)+u;return(c<<i|c>>>32-i)+r},i._blocksize=16,i._digestsize=16,t.exports=function(t,n){if(null==t)throw new Error("Illegal argument "+t);var e=r.wordsToBytes(i(t,n));return n&&n.asBytes?e:n&&n.asString?o.bytesToString(e):r.bytesToHex(e)}}()}));function Qn(t){return"function"==typeof t}var te={},re={},ne={};function ee(t){var r=t.invokeId,n=t.event,e=t.payload;if(r||n){e=r?{data:e}:e;for(var o=(r?ne[r]:re[n])||[],i=0;i<o.length;i++){var u=o[i];try{u.callback(e)}catch(t){__appServiceSDK__.reportUncaughtError({info:t.toString(),stack:t.stack})}}}}function oe(t){if("string"==typeof t)try{t=JSON.parse(t)}catch(t){}for(var r=t.payload,n=t.event,e=te[n]||[],o=0;o<e.length;o++){var i=e[o];i.isSustain||(e.splice(o,1),o--);try{i.callback(r)}catch(t){__appServiceSDK__.reportUncaughtError({info:t.toString(),stack:t.stack})}}}var ie=function(t){var r=t.isSustain,n=void 0===r||r,e=t.method,o=t.callback,i=t.invokeId;if(o){var u={method:e,callback:o,isSustain:n};ne[i]?ne[i].push(u):ne[i]=[u]}},ue=DiminaServiceBridge&&Qn(DiminaServiceBridge.invoke),ce=DiminaServiceBridge&&Qn(DiminaServiceBridge.publish),ae={invoke:function(t){var r=t.method,n=t.module,e=void 0===n?"":n,o=t.data,i=t.invokeId,u=t.isSustain,c=void 0!==u&&u,a=t.callback;if(r){if(a&&(i||(i=Number(Math.random().toString().substr(3,13)+Date.now()).toString(36)),ie({invokeId:i,method:r,isSustain:c,callback:a})),ue)return DiminaServiceBridge.invoke(r,o,i,e);throw new Error("Service bridge invoke failed.")}},publish:function(t){var r=t.event,n=t.webViewId,e=t.data;if(r){if(!ce)throw new Error("Service bridge publish failed.");var o={data:e};DiminaServiceBridge.publish(JSON.stringify({event:r,payload:o}),n)}},on:function(t,r){var n=t.isSustain,e=void 0===n||n,o=t.method,i=t.callback,u=t.event;if(i=i||r){var c={method:o,callback:i,isSustain:e};re[u]?re[u].push(c):re[u]=[c]}},onBridgeCb:ie,off:function(t){var r=t.event,n=t.callback;if(r){if(n&&!Qn(n))throw new Error("Error in off: callback should be function");if(n)for(var e=re[r]||[],o=0;o<e.length;++o){(e[o]||{}).callback===n&&(e.splice(o,1),o--)}else re[r]=[]}},subscribe:function(t,r){var n=t.event,e=t.isSustain,o=void 0===e||e,i=t.callback;if(i=i||r){var u={event:n,callback:i,isSustain:o};te[u.event]?te[u.event].push(u):te[u.event]=[u]}},clearAll:function(){te={},ne={},re={}},invokeCallbackHandler:ee,subscribeHandler:oe};return DiminaServiceBridge&&(DiminaServiceBridge.invokeCallbackHandler=ee,DiminaServiceBridge.subscribeHandler=oe),ae}();


// ide 在全局注入的 变量
if (isDevTools) {
  didiJsBridge = new acquireLocalBridge({ from: 'AppService' })
}

var Reporter=function(){"use strict";function t(r){return t="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},t(r)}function r(){return r=Object.assign||function(t){for(var r=1;r<arguments.length;r++){var e=arguments[r];for(var n in e)Object.prototype.hasOwnProperty.call(e,n)&&(t[n]=e[n])}return t},r.apply(this,arguments)}var e="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function n(t,r,e){return t(e={path:r,exports:{},require:function(t,r){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==r&&e.path)}},e.exports),e.exports}var o,i,a=function(t){return t&&t.Math==Math&&t},u=a("object"==typeof globalThis&&globalThis)||a("object"==typeof window&&window)||a("object"==typeof self&&self)||a("object"==typeof e&&e)||function(){return this}()||Function("return this")(),c=function(t){try{return!!t()}catch(t){return!0}},f=!c((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),s=!c((function(){var t=function(){}.bind();return"function"!=typeof t||t.hasOwnProperty("prototype")})),p=Function.prototype.call,l=s?p.bind(p):function(){return p.apply(p,arguments)},v={}.propertyIsEnumerable,y=Object.getOwnPropertyDescriptor,m={f:y&&!v.call({1:2},1)?function(t){var r=y(this,t);return!!r&&r.enumerable}:v},g=function(t,r){return{enumerable:!(1&t),configurable:!(2&t),writable:!(4&t),value:r}},b=Function.prototype,d=b.bind,h=b.call,S=s&&d.bind(h,h),_=s?function(t){return t&&S(t)}:function(t){return t&&function(){return h.apply(t,arguments)}},w=_({}.toString),O=_("".slice),j=function(t){return O(w(t),8,-1)},E=u.Object,N=_("".split),P=c((function(){return!E("z").propertyIsEnumerable(0)}))?function(t){return"String"==j(t)?N(t,""):E(t)}:E,T=u.TypeError,I=function(t){if(null==t)throw T("Can't call method on "+t);return t},R=function(t){return P(I(t))},A=function(t){return"function"==typeof t},L=function(t){return"object"==typeof t?null!==t:A(t)},k=function(t){return A(t)?t:void 0},M=function(t,r){return arguments.length<2?k(u[t]):u[t]&&u[t][r]},F=_({}.isPrototypeOf),C=M("navigator","userAgent")||"",x=u.process,D=u.Deno,B=x&&x.versions||D&&D.version,G=B&&B.v8;G&&(i=(o=G.split("."))[0]>0&&o[0]<4?1:+(o[0]+o[1])),!i&&C&&(!(o=C.match(/Edge\/(\d+)/))||o[1]>=74)&&(o=C.match(/Chrome\/(\d+)/))&&(i=+o[1]);var z=i,J=!!Object.getOwnPropertySymbols&&!c((function(){var t=Symbol();return!String(t)||!(Object(t)instanceof Symbol)||!Symbol.sham&&z&&z<41})),U=J&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,V=u.Object,q=U?function(t){return"symbol"==typeof t}:function(t){var r=M("Symbol");return A(r)&&F(r.prototype,V(t))},X=u.String,Y=u.TypeError,W=function(t){if(A(t))return t;throw Y(function(t){try{return X(t)}catch(t){return"Object"}}(t)+" is not a function")},$=u.TypeError,K=Object.defineProperty,H=function(t,r){try{K(u,t,{value:r,configurable:!0,writable:!0})}catch(e){u[t]=r}return r},Q="__core-js_shared__",Z=u[Q]||H(Q,{}),tt=n((function(t){(t.exports=function(t,r){return Z[t]||(Z[t]=void 0!==r?r:{})})("versions",[]).push({version:"3.21.1",mode:"global",copyright:"© 2014-2022 Denis Pushkarev (zloirock.ru)",license:"https://github.com/zloirock/core-js/blob/v3.21.1/LICENSE",source:"https://github.com/zloirock/core-js"})})),rt=u.Object,et=function(t){return rt(I(t))},nt=_({}.hasOwnProperty),ot=Object.hasOwn||function(t,r){return nt(et(t),r)},it=0,at=Math.random(),ut=_(1..toString),ct=function(t){return"Symbol("+(void 0===t?"":t)+")_"+ut(++it+at,36)},ft=tt("wks"),st=u.Symbol,pt=st&&st.for,lt=U?st:st&&st.withoutSetter||ct,vt=function(t){if(!ot(ft,t)||!J&&"string"!=typeof ft[t]){var r="Symbol."+t;J&&ot(st,t)?ft[t]=st[t]:ft[t]=U&&pt?pt(r):lt(r)}return ft[t]},yt=u.TypeError,mt=vt("toPrimitive"),gt=function(t,r){if(!L(t)||q(t))return t;var e,n,o=null==(e=t[mt])?void 0:W(e);if(o){if(void 0===r&&(r="default"),n=l(o,t,r),!L(n)||q(n))return n;throw yt("Can't convert object to primitive value")}return void 0===r&&(r="number"),function(t,r){var e,n;if("string"===r&&A(e=t.toString)&&!L(n=l(e,t)))return n;if(A(e=t.valueOf)&&!L(n=l(e,t)))return n;if("string"!==r&&A(e=t.toString)&&!L(n=l(e,t)))return n;throw $("Can't convert object to primitive value")}(t,r)},bt=function(t){var r=gt(t,"string");return q(r)?r:r+""},dt=u.document,ht=L(dt)&&L(dt.createElement),St=!f&&!c((function(){return 7!=Object.defineProperty((t="div",ht?dt.createElement(t):{}),"a",{get:function(){return 7}}).a;var t})),_t=Object.getOwnPropertyDescriptor,wt={f:f?_t:function(t,r){if(t=R(t),r=bt(r),St)try{return _t(t,r)}catch(t){}if(ot(t,r))return g(!l(m.f,t,r),t[r])}},Ot=f&&c((function(){return 42!=Object.defineProperty((function(){}),"prototype",{value:42,writable:!1}).prototype})),jt=u.String,Et=u.TypeError,Nt=function(t){if(L(t))return t;throw Et(jt(t)+" is not an object")},Pt=u.TypeError,Tt=Object.defineProperty,It=Object.getOwnPropertyDescriptor,Rt="enumerable",At="configurable",Lt="writable",kt={f:f?Ot?function(t,r,e){if(Nt(t),r=bt(r),Nt(e),"function"==typeof t&&"prototype"===r&&"value"in e&&Lt in e&&!e.writable){var n=It(t,r);n&&n.writable&&(t[r]=e.value,e={configurable:At in e?e.configurable:n.configurable,enumerable:Rt in e?e.enumerable:n.enumerable,writable:!1})}return Tt(t,r,e)}:Tt:function(t,r,e){if(Nt(t),r=bt(r),Nt(e),St)try{return Tt(t,r,e)}catch(t){}if("get"in e||"set"in e)throw Pt("Accessors not supported");return"value"in e&&(t[r]=e.value),t}},Mt=f?function(t,r,e){return kt.f(t,r,g(1,e))}:function(t,r,e){return t[r]=e,t},Ft=_(Function.toString);A(Z.inspectSource)||(Z.inspectSource=function(t){return Ft(t)});var Ct,xt,Dt,Bt=Z.inspectSource,Gt=u.WeakMap,zt=A(Gt)&&/native code/.test(Bt(Gt)),Jt=tt("keys"),Ut={},Vt="Object already initialized",qt=u.TypeError,Xt=u.WeakMap;if(zt||Z.state){var Yt=Z.state||(Z.state=new Xt),Wt=_(Yt.get),$t=_(Yt.has),Kt=_(Yt.set);Ct=function(t,r){if($t(Yt,t))throw new qt(Vt);return r.facade=t,Kt(Yt,t,r),r},xt=function(t){return Wt(Yt,t)||{}},Dt=function(t){return $t(Yt,t)}}else{var Ht=function(t){return Jt[t]||(Jt[t]=ct(t))}("state");Ut[Ht]=!0,Ct=function(t,r){if(ot(t,Ht))throw new qt(Vt);return r.facade=t,Mt(t,Ht,r),r},xt=function(t){return ot(t,Ht)?t[Ht]:{}},Dt=function(t){return ot(t,Ht)}}var Qt={set:Ct,get:xt,has:Dt,enforce:function(t){return Dt(t)?xt(t):Ct(t,{})},getterFor:function(t){return function(r){var e;if(!L(r)||(e=xt(r)).type!==t)throw qt("Incompatible receiver, "+t+" required");return e}}},Zt=Function.prototype,tr=f&&Object.getOwnPropertyDescriptor,rr=ot(Zt,"name"),er={EXISTS:rr,PROPER:rr&&"something"===function(){}.name,CONFIGURABLE:rr&&(!f||f&&tr(Zt,"name").configurable)},nr=n((function(t){var r=er.CONFIGURABLE,e=Qt.get,n=Qt.enforce,o=String(String).split("String");(t.exports=function(t,e,i,a){var c,f=!!a&&!!a.unsafe,s=!!a&&!!a.enumerable,p=!!a&&!!a.noTargetGet,l=a&&void 0!==a.name?a.name:e;A(i)&&("Symbol("===String(l).slice(0,7)&&(l="["+String(l).replace(/^Symbol\(([^)]*)\)/,"$1")+"]"),(!ot(i,"name")||r&&i.name!==l)&&Mt(i,"name",l),(c=n(i)).source||(c.source=o.join("string"==typeof l?l:""))),t!==u?(f?!p&&t[e]&&(s=!0):delete t[e],s?t[e]=i:Mt(t,e,i)):s?t[e]=i:H(e,i)})(Function.prototype,"toString",(function(){return A(this)&&e(this).source||Bt(this)}))})),or=Math.ceil,ir=Math.floor,ar=function(t){var r=+t;return r!=r||0===r?0:(r>0?ir:or)(r)},ur=Math.max,cr=Math.min,fr=Math.min,sr=function(t){return(r=t.length)>0?fr(ar(r),9007199254740991):0;var r},pr=function(t){return function(r,e,n){var o,i=R(r),a=sr(i),u=function(t,r){var e=ar(t);return e<0?ur(e+r,0):cr(e,r)}(n,a);if(t&&e!=e){for(;a>u;)if((o=i[u++])!=o)return!0}else for(;a>u;u++)if((t||u in i)&&i[u]===e)return t||u||0;return!t&&-1}},lr={includes:pr(!0),indexOf:pr(!1)}.indexOf,vr=_([].push),yr=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"].concat("length","prototype"),mr=Object.getOwnPropertyNames||function(t){return function(t,r){var e,n=R(t),o=0,i=[];for(e in n)!ot(Ut,e)&&ot(n,e)&&vr(i,e);for(;r.length>o;)ot(n,e=r[o++])&&(~lr(i,e)||vr(i,e));return i}(t,yr)},gr={f:mr},br={f:Object.getOwnPropertySymbols},dr=_([].concat),hr=M("Reflect","ownKeys")||function(t){var r=gr.f(Nt(t)),e=br.f;return e?dr(r,e(t)):r},Sr=function(t,r,e){for(var n=hr(r),o=kt.f,i=wt.f,a=0;a<n.length;a++){var u=n[a];ot(t,u)||e&&ot(e,u)||o(t,u,i(r,u))}},_r=/#|\.prototype\./,wr=function(t,r){var e=jr[Or(t)];return e==Nr||e!=Er&&(A(r)?c(r):!!r)},Or=wr.normalize=function(t){return String(t).replace(_r,".").toLowerCase()},jr=wr.data={},Er=wr.NATIVE="N",Nr=wr.POLYFILL="P",Pr=wr,Tr=wt.f,Ir=Array.isArray||function(t){return"Array"==j(t)},Rr=function(t,r,e){var n=bt(r);n in t?kt.f(t,n,g(0,e)):t[n]=e},Ar={};Ar[vt("toStringTag")]="z";var Lr="[object z]"===String(Ar),kr=vt("toStringTag"),Mr=u.Object,Fr="Arguments"==j(function(){return arguments}()),Cr=Lr?j:function(t){var r,e,n;return void 0===t?"Undefined":null===t?"Null":"string"==typeof(e=function(t,r){try{return t[r]}catch(t){}}(r=Mr(t),kr))?e:Fr?j(r):"Object"==(n=j(r))&&A(r.callee)?"Arguments":n},xr=function(){},Dr=[],Br=M("Reflect","construct"),Gr=/^\s*(?:class|function)\b/,zr=_(Gr.exec),Jr=!Gr.exec(xr),Ur=function(t){if(!A(t))return!1;try{return Br(xr,Dr,t),!0}catch(t){return!1}},Vr=function(t){if(!A(t))return!1;switch(Cr(t)){case"AsyncFunction":case"GeneratorFunction":case"AsyncGeneratorFunction":return!1}try{return Jr||!!zr(Gr,Bt(t))}catch(t){return!0}};Vr.sham=!0;var qr,Xr=!Br||c((function(){var t;return Ur(Ur.call)||!Ur(Object)||!Ur((function(){t=!0}))||t}))?Vr:Ur,Yr=vt("species"),Wr=u.Array,$r=function(t,r){return new(function(t){var r;return Ir(t)&&(r=t.constructor,(Xr(r)&&(r===Wr||Ir(r.prototype))||L(r)&&null===(r=r[Yr]))&&(r=void 0)),void 0===r?Wr:r}(t))(0===r?0:r)},Kr=vt("species"),Hr=vt("isConcatSpreadable"),Qr=9007199254740991,Zr="Maximum allowed index exceeded",te=u.TypeError,re=z>=51||!c((function(){var t=[];return t[Hr]=!1,t.concat()[0]!==t})),ee=(qr="concat",z>=51||!c((function(){var t=[];return(t.constructor={})[Kr]=function(){return{foo:1}},1!==t[qr](Boolean).foo}))),ne=function(t){if(!L(t))return!1;var r=t[Hr];return void 0!==r?!!r:Ir(t)};!function(t,r){var e,n,o,i,a,c=t.target,f=t.global,s=t.stat;if(e=f?u:s?u[c]||H(c,{}):(u[c]||{}).prototype)for(n in r){if(i=r[n],o=t.noTargetGet?(a=Tr(e,n))&&a.value:e[n],!Pr(f?n:c+(s?".":"#")+n,t.forced)&&void 0!==o){if(typeof i==typeof o)continue;Sr(i,o)}(t.sham||o&&o.sham)&&Mt(i,"sham",!0),nr(e,n,i,t)}}({target:"Array",proto:!0,forced:!re||!ee},{concat:function(t){var r,e,n,o,i,a=et(this),u=$r(a,0),c=0;for(r=-1,n=arguments.length;r<n;r++)if(ne(i=-1===r?a:arguments[r])){if(c+(o=sr(i))>Qr)throw te(Zr);for(e=0;e<o;e++,c++)e in i&&Rr(u,c,i[e])}else{if(c>=Qr)throw te(Zr);Rr(u,c++,i)}return u.length=c,u}});var oe=u.String,ie=u.TypeError,ae=Object.setPrototypeOf||("__proto__"in{}?function(){var t,r=!1,e={};try{(t=_(Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set))(e,[]),r=e instanceof Array}catch(t){}return function(e,n){return Nt(e),function(t){if("object"==typeof t||A(t))return t;throw ie("Can't set "+oe(t)+" as a prototype")}(n),r?t(e,n):e.__proto__=n,e}}():void 0),ue=function(t,r,e){var n,o;return ae&&A(n=r.constructor)&&n!==e&&L(o=n.prototype)&&o!==e.prototype&&ae(t,o),t},ce=_(1..valueOf),fe=u.String,se=_("".replace),pe="[\t\n\v\f\r                　\u2028\u2029\ufeff]",le=RegExp("^"+pe+pe+"*"),ve=RegExp(pe+pe+"*$"),ye=function(t){return function(r){var e=function(t){if("Symbol"===Cr(t))throw TypeError("Cannot convert a Symbol value to a string");return fe(t)}(I(r));return 1&t&&(e=se(e,le,"")),2&t&&(e=se(e,ve,"")),e}},me={start:ye(1),end:ye(2),trim:ye(3)},ge=gr.f,be=wt.f,de=kt.f,he=me.trim,Se="Number",_e=u.Number,we=_e.prototype,Oe=u.TypeError,je=_("".slice),Ee=_("".charCodeAt),Ne=function(t){var r=gt(t,"number");return"bigint"==typeof r?r:Pe(r)},Pe=function(t){var r,e,n,o,i,a,u,c,f=gt(t,"number");if(q(f))throw Oe("Cannot convert a Symbol value to a number");if("string"==typeof f&&f.length>2)if(f=he(f),43===(r=Ee(f,0))||45===r){if(88===(e=Ee(f,2))||120===e)return NaN}else if(48===r){switch(Ee(f,1)){case 66:case 98:n=2,o=49;break;case 79:case 111:n=8,o=55;break;default:return+f}for(a=(i=je(f,2)).length,u=0;u<a;u++)if((c=Ee(i,u))<48||c>o)return NaN;return parseInt(i,n)}return+f};if(Pr(Se,!_e(" 0o1")||!_e("0b1")||_e("+0x1"))){for(var Te,Ie=function(t){var r=arguments.length<1?0:_e(Ne(t)),e=this;return F(we,e)&&c((function(){ce(e)}))?ue(Object(r),e,Ie):r},Re=f?ge(_e):"MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,EPSILON,MAX_SAFE_INTEGER,MIN_SAFE_INTEGER,isFinite,isInteger,isNaN,isSafeInteger,parseFloat,parseInt,fromString,range".split(","),Ae=0;Re.length>Ae;Ae++)ot(_e,Te=Re[Ae])&&!ot(Ie,Te)&&de(Ie,Te,be(_e,Te));Ie.prototype=we,we.constructor=Ie,nr(u,Se,Ie)}
/*! *****************************************************************************
  Copyright (c) Microsoft Corporation.

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
  REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
  AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
  INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
  LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
  OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
  PERFORMANCE OF THIS SOFTWARE.
  ***************************************************************************** */var Le,ke=function(){return ke=Object.assign||function(t){for(var r,e=1,n=arguments.length;e<n;e++)for(var o in r=arguments[e])Object.prototype.hasOwnProperty.call(r,o)&&(t[o]=r[o]);return t},ke.apply(this,arguments)},Me=[],Fe=0,Ce=(new Date).getTime();!function(t){t.pageLoad="pub_saga_page_load_bt",t.errorMessage="pub_saga_error_message_bt"}(Le||(Le={}));var xe=!1,De={},Be=function(){function e(){}return e.ddBridge=function(t,r){t&&t.event&&didiJsBridge.invoke({method:t.event,module:"DMServiceBridgeModule",data:t.data||{},isSustain:t.isSustain||!1,callback:r||function(r){(r=r.data).success?t.success&&t.success(r.data):t.fail&&t.fail({errMsg:r.errMsg}),t.complete&&t.complete()}})},e.reportNative=function(r,n){var o={};if(r){if(n)for(var i in n){var a=n[i];void 0===a||!a&&void 0!==a&&0!==a||(o[i]=n[i]),"object"===t(a)&&(o[i]=JSON.stringify(n[i]))}xe?(o=e.formatReportParmas(De,n),e.reportAnalytics(r,o)):e.ddBridge({event:"getSystemInfo",data:{},success:function(i){for(var a in i){var u=i[a];void 0===u||!u&&void 0!==u&&0!==u||(De[a.toLowerCase()]=u),"object"===t(u)&&(De[a.toLowerCase()]=JSON.stringify(u))}o=e.formatReportParmas(De,n),e.reportAnalytics(r,o),xe=!0}})}},e.reportAnalytics=function(t,r){e.ddBridge({event:"reportAnalytics",data:{eventName:t,data:r}})},e.traceBeginEvent=function(t,r){if(t&&r)try{var e={category:t,name:r,timeStamp:(new Date).getTime()};if(Me.length>=1){var n=Me.length-1;Fe=(new Date).getTime()-Me[n].timeStamp}Me.push(e)}catch(t){}},e.traceEndEvent=function(){if(Me&&Me.length)try{var t=Me.pop(),r=(new Date).getTime(),n=r-t.timeStamp,o={category:"",name:"",timeStamp:r};Me&&Me.length&&(o=Me[Me.length-1]),e.reportNative("pub_saga_".concat(t.category,"_").concat(t.name,"_bt").toLowerCase(),{reportId:Ce,start_time:t.timeStamp,end_time:r,take_up_time:n,take_begin_time:Fe,take_before_name:o.name,take_before_category:o.category})}catch(t){}},e.reportAppLaunchTime=function(t){void 0===t&&(t={app_launch_time:"",saga_launch:""}),t.app_launch_time&&(e.appLaunchTime=Number(t.app_launch_time)),t.saga_launch&&(e.sagaLaunchTime=Number(t.saga_launch))},e.pageLoadReport=function(t,r){var n=(new Date).getTime();e.reportNative("".concat(Le.pageLoad),{timetigger:n,path:t,webviewid:r,app_launch_time:n-(e.appLaunchTime||n),saga_launch_time:n-(e.sagaLaunchTime||n)})},e.errorReport=function(t){e.reportNative("".concat(Le.errorMessage),{key:t.key,type:t.type,error:t.error})},e.ravenReport=function(r,n,o){var i={};r&&(xe?(i=e.formatReportParmas(De,n),e.reportRavenNative(r,i,n,o)):e.ddBridge({event:"getSystemInfo",data:{},success:function(a){for(var u in a){var c=a[u];void 0===c||!c&&void 0!==c&&0!==c||(De[u.toLowerCase()]=c),"object"===t(c)&&(De[u.toLowerCase()]=JSON.stringify(c))}i=e.formatReportParmas(De,n),e.reportRavenNative(r,i,n,o),xe=!0}}))},e.formatReportParmas=function(n,o){var i={};if(o)for(var a in o){var u=o[a];void 0===u||!u&&void 0!==u&&0!==u||"fail"===a||(i[a]=o[a]),"object"===t(u)&&"fail"!==a&&(i[a]=JSON.stringify(o[a]))}return e.publicReportParams.jssdk_version=n.jssdkversion,e.publicReportParams.platform=n.platform,e.publicReportParams.brand="",e.publicReportParams.app_version=n.sdkversion,e.publicReportParams.applets_version=n.appversion,e.publicReportParams.app_id=n.appid,i=r(ke({},i),e.publicReportParams)},e.reportRavenNative=function(t,r,e,n){didiJsBridge.invoke({method:"traceRaven",data:{eventName:t,data:r||{}},callback:n||function(t){(t=t.data).success?e.success&&e.success(t.data):e.fail&&e.fail({errMsg:t.errMsg}),e.complete&&e.complete()}})},e.appLaunchTime=0,e.sagaLaunchTime=0,e.publicReportParams={jssdk_version:"",app_id:"",app_version:"",applets_version:"",platform:"",brand:"",user_info:""},e}();return Be}();


!function(){"use strict";var t="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function n(t,n,e){return t(e={path:n,exports:{},require:function(t,n){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==n&&e.path)}},e.exports),e.exports}var e,r,o=function(t){return t&&t.Math==Math&&t},i=o("object"==typeof globalThis&&globalThis)||o("object"==typeof window&&window)||o("object"==typeof self&&self)||o("object"==typeof t&&t)||function(){return this}()||Function("return this")(),c={CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0},a=function(t){return"function"==typeof t},u=function(t){return"object"==typeof t?null!==t:a(t)},f=i.document,s=u(f)&&u(f.createElement),l=function(t){return s?f.createElement(t):{}},p=l("span").classList,d=p&&p.constructor&&p.constructor.prototype,v=d===Object.prototype?void 0:d,h=function(t){try{return!!t()}catch(t){return!0}},y=!h((function(){var t=function(){}.bind();return"function"!=typeof t||t.hasOwnProperty("prototype")})),g=Function.prototype,b=g.bind,m=g.call,_=y&&b.bind(m,m),w=y?function(t){return t&&_(t)}:function(t){return t&&function(){return m.apply(t,arguments)}},S=i.String,O=function(t){try{return S(t)}catch(t){return"Object"}},j=i.TypeError,C=function(t){if(a(t))return t;throw j(O(t)+" is not a function")},E=w(w.bind),P=function(t,n){return C(t),void 0===n?t:y?E(t,n):function(){return t.apply(n,arguments)}},T=w({}.toString),x=w("".slice),R=function(t){return x(T(t),8,-1)},A=i.Object,I=w("".split),L=h((function(){return!A("z").propertyIsEnumerable(0)}))?function(t){return"String"==R(t)?I(t,""):A(t)}:A,k=i.TypeError,F=function(t){if(null==t)throw k("Can't call method on "+t);return t},D=i.Object,M=function(t){return D(F(t))},N=Math.ceil,G=Math.floor,V=function(t){var n=+t;return n!=n||0===n?0:(n>0?G:N)(n)},B=Math.min,U=function(t){return(n=t.length)>0?B(V(n),9007199254740991):0;var n},W=Array.isArray||function(t){return"Array"==R(t)},z=Object.defineProperty,H=function(t,n){try{z(i,t,{value:n,configurable:!0,writable:!0})}catch(e){i[t]=n}return n},q="__core-js_shared__",K=i[q]||H(q,{}),Y=n((function(t){(t.exports=function(t,n){return K[t]||(K[t]=void 0!==n?n:{})})("versions",[]).push({version:"3.21.1",mode:"global",copyright:"© 2014-2022 Denis Pushkarev (zloirock.ru)",license:"https://github.com/zloirock/core-js/blob/v3.21.1/LICENSE",source:"https://github.com/zloirock/core-js"})})),J=w({}.hasOwnProperty),X=Object.hasOwn||function(t,n){return J(M(t),n)},$=0,Q=Math.random(),Z=w(1..toString),tt=function(t){return"Symbol("+(void 0===t?"":t)+")_"+Z(++$+Q,36)},nt=function(t){return a(t)?t:void 0},et=function(t,n){return arguments.length<2?nt(i[t]):i[t]&&i[t][n]},rt=et("navigator","userAgent")||"",ot=i.process,it=i.Deno,ct=ot&&ot.versions||it&&it.version,at=ct&&ct.v8;at&&(r=(e=at.split("."))[0]>0&&e[0]<4?1:+(e[0]+e[1])),!r&&rt&&(!(e=rt.match(/Edge\/(\d+)/))||e[1]>=74)&&(e=rt.match(/Chrome\/(\d+)/))&&(r=+e[1]);var ut=r,ft=!!Object.getOwnPropertySymbols&&!h((function(){var t=Symbol();return!String(t)||!(Object(t)instanceof Symbol)||!Symbol.sham&&ut&&ut<41})),st=ft&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,lt=Y("wks"),pt=i.Symbol,dt=pt&&pt.for,vt=st?pt:pt&&pt.withoutSetter||tt,ht=function(t){if(!X(lt,t)||!ft&&"string"!=typeof lt[t]){var n="Symbol."+t;ft&&X(pt,t)?lt[t]=pt[t]:lt[t]=st&&dt?dt(n):vt(n)}return lt[t]},yt={};yt[ht("toStringTag")]="z";var gt="[object z]"===String(yt),bt=ht("toStringTag"),mt=i.Object,_t="Arguments"==R(function(){return arguments}()),wt=gt?R:function(t){var n,e,r;return void 0===t?"Undefined":null===t?"Null":"string"==typeof(e=function(t,n){try{return t[n]}catch(t){}}(n=mt(t),bt))?e:_t?R(n):"Object"==(r=R(n))&&a(n.callee)?"Arguments":r},St=w(Function.toString);a(K.inspectSource)||(K.inspectSource=function(t){return St(t)});var Ot=K.inspectSource,jt=function(){},Ct=[],Et=et("Reflect","construct"),Pt=/^\s*(?:class|function)\b/,Tt=w(Pt.exec),xt=!Pt.exec(jt),Rt=function(t){if(!a(t))return!1;try{return Et(jt,Ct,t),!0}catch(t){return!1}},At=function(t){if(!a(t))return!1;switch(wt(t)){case"AsyncFunction":case"GeneratorFunction":case"AsyncGeneratorFunction":return!1}try{return xt||!!Tt(Pt,Ot(t))}catch(t){return!0}};At.sham=!0;var It,Lt,kt=!Et||h((function(){var t;return Rt(Rt.call)||!Rt(Object)||!Rt((function(){t=!0}))||t}))?At:Rt,Ft=ht("species"),Dt=i.Array,Mt=function(t,n){return new(function(t){var n;return W(t)&&(n=t.constructor,(kt(n)&&(n===Dt||W(n.prototype))||u(n)&&null===(n=n[Ft]))&&(n=void 0)),void 0===n?Dt:n}(t))(0===n?0:n)},Nt=w([].push),Gt=function(t){var n=1==t,e=2==t,r=3==t,o=4==t,i=6==t,c=7==t,a=5==t||i;return function(u,f,s,l){for(var p,d,v=M(u),h=L(v),y=P(f,s),g=U(h),b=0,m=l||Mt,_=n?m(u,g):e||c?m(u,0):void 0;g>b;b++)if((a||b in h)&&(d=y(p=h[b],b,v),t))if(n)_[b]=d;else if(d)switch(t){case 3:return!0;case 5:return p;case 6:return b;case 2:Nt(_,p)}else switch(t){case 4:return!1;case 7:Nt(_,p)}return i?-1:r||o?o:_}},Vt={forEach:Gt(0),map:Gt(1),filter:Gt(2),some:Gt(3),every:Gt(4),find:Gt(5),findIndex:Gt(6),filterReject:Gt(7)}.forEach,Bt=!!(Lt=[]["forEach"])&&h((function(){Lt.call(null,It||function(){return 1},1)}))?[].forEach:function(t){return Vt(this,t,arguments.length>1?arguments[1]:void 0)},Ut=!h((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),Wt=!Ut&&!h((function(){return 7!=Object.defineProperty(l("div"),"a",{get:function(){return 7}}).a})),zt=Ut&&h((function(){return 42!=Object.defineProperty((function(){}),"prototype",{value:42,writable:!1}).prototype})),Ht=i.String,qt=i.TypeError,Kt=function(t){if(u(t))return t;throw qt(Ht(t)+" is not an object")},Yt=Function.prototype.call,Jt=y?Yt.bind(Yt):function(){return Yt.apply(Yt,arguments)},Xt=w({}.isPrototypeOf),$t=i.Object,Qt=st?function(t){return"symbol"==typeof t}:function(t){var n=et("Symbol");return a(n)&&Xt(n.prototype,$t(t))},Zt=function(t,n){var e=t[n];return null==e?void 0:C(e)},tn=i.TypeError,nn=i.TypeError,en=ht("toPrimitive"),rn=function(t,n){if(!u(t)||Qt(t))return t;var e,r=Zt(t,en);if(r){if(void 0===n&&(n="default"),e=Jt(r,t,n),!u(e)||Qt(e))return e;throw nn("Can't convert object to primitive value")}return void 0===n&&(n="number"),function(t,n){var e,r;if("string"===n&&a(e=t.toString)&&!u(r=Jt(e,t)))return r;if(a(e=t.valueOf)&&!u(r=Jt(e,t)))return r;if("string"!==n&&a(e=t.toString)&&!u(r=Jt(e,t)))return r;throw tn("Can't convert object to primitive value")}(t,n)},on=function(t){var n=rn(t,"string");return Qt(n)?n:n+""},cn=i.TypeError,an=Object.defineProperty,un=Object.getOwnPropertyDescriptor,fn="enumerable",sn="configurable",ln="writable",pn={f:Ut?zt?function(t,n,e){if(Kt(t),n=on(n),Kt(e),"function"==typeof t&&"prototype"===n&&"value"in e&&ln in e&&!e.writable){var r=un(t,n);r&&r.writable&&(t[n]=e.value,e={configurable:sn in e?e.configurable:r.configurable,enumerable:fn in e?e.enumerable:r.enumerable,writable:!1})}return an(t,n,e)}:an:function(t,n,e){if(Kt(t),n=on(n),Kt(e),Wt)try{return an(t,n,e)}catch(t){}if("get"in e||"set"in e)throw cn("Accessors not supported");return"value"in e&&(t[n]=e.value),t}},dn=function(t,n){return{enumerable:!(1&t),configurable:!(2&t),writable:!(4&t),value:n}},vn=Ut?function(t,n,e){return pn.f(t,n,dn(1,e))}:function(t,n,e){return t[n]=e,t},hn=function(t){if(t&&t.forEach!==Bt)try{vn(t,"forEach",Bt)}catch(n){t.forEach=Bt}};for(var yn in c)c[yn]&&hn(i[yn]&&i[yn].prototype);hn(v);var gn,bn=function(t){return L(F(t))},mn=Math.max,_n=Math.min,wn=function(t){return function(n,e,r){var o,i=bn(n),c=U(i),a=function(t,n){var e=V(t);return e<0?mn(e+n,0):_n(e,n)}(r,c);if(t&&e!=e){for(;c>a;)if((o=i[a++])!=o)return!0}else for(;c>a;a++)if((t||a in i)&&i[a]===e)return t||a||0;return!t&&-1}},Sn={includes:wn(!0),indexOf:wn(!1)},On={},jn=Sn.indexOf,Cn=w([].push),En=function(t,n){var e,r=bn(t),o=0,i=[];for(e in r)!X(On,e)&&X(r,e)&&Cn(i,e);for(;n.length>o;)X(r,e=n[o++])&&(~jn(i,e)||Cn(i,e));return i},Pn=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],Tn=Object.keys||function(t){return En(t,Pn)},xn=Ut&&!zt?Object.defineProperties:function(t,n){Kt(t);for(var e,r=bn(n),o=Tn(n),i=o.length,c=0;i>c;)pn.f(t,e=o[c++],r[e]);return t},Rn={f:xn},An=et("document","documentElement"),In=Y("keys"),Ln=function(t){return In[t]||(In[t]=tt(t))},kn=Ln("IE_PROTO"),Fn=function(){},Dn=function(t){return"<script>"+t+"</"+"script>"},Mn=function(t){t.write(Dn("")),t.close();var n=t.parentWindow.Object;return t=null,n},Nn=function(){try{gn=new ActiveXObject("htmlfile")}catch(t){}var t,n;Nn="undefined"!=typeof document?document.domain&&gn?Mn(gn):((n=l("iframe")).style.display="none",An.appendChild(n),n.src=String("javascript:"),(t=n.contentWindow.document).open(),t.write(Dn("document.F=Object")),t.close(),t.F):Mn(gn);for(var e=Pn.length;e--;)delete Nn.prototype[Pn[e]];return Nn()};On[kn]=!0;var Gn=Object.create||function(t,n){var e;return null!==t?(Fn.prototype=Kt(t),e=new Fn,Fn.prototype=null,e[kn]=t):e=Nn(),void 0===n?e:Rn.f(e,n)},Vn=ht("unscopables"),Bn=Array.prototype;null==Bn[Vn]&&pn.f(Bn,Vn,{configurable:!0,value:Gn(null)});var Un,Wn,zn,Hn=function(t){Bn[Vn][t]=!0},qn={},Kn=i.WeakMap,Yn=a(Kn)&&/native code/.test(Ot(Kn)),Jn="Object already initialized",Xn=i.TypeError,$n=i.WeakMap;if(Yn||K.state){var Qn=K.state||(K.state=new $n),Zn=w(Qn.get),te=w(Qn.has),ne=w(Qn.set);Un=function(t,n){if(te(Qn,t))throw new Xn(Jn);return n.facade=t,ne(Qn,t,n),n},Wn=function(t){return Zn(Qn,t)||{}},zn=function(t){return te(Qn,t)}}else{var ee=Ln("state");On[ee]=!0,Un=function(t,n){if(X(t,ee))throw new Xn(Jn);return n.facade=t,vn(t,ee,n),n},Wn=function(t){return X(t,ee)?t[ee]:{}},zn=function(t){return X(t,ee)}}var re,oe,ie,ce={set:Un,get:Wn,has:zn,enforce:function(t){return zn(t)?Wn(t):Un(t,{})},getterFor:function(t){return function(n){var e;if(!u(n)||(e=Wn(n)).type!==t)throw Xn("Incompatible receiver, "+t+" required");return e}}},ae={}.propertyIsEnumerable,ue=Object.getOwnPropertyDescriptor,fe={f:ue&&!ae.call({1:2},1)?function(t){var n=ue(this,t);return!!n&&n.enumerable}:ae},se=Object.getOwnPropertyDescriptor,le={f:Ut?se:function(t,n){if(t=bn(t),n=on(n),Wt)try{return se(t,n)}catch(t){}if(X(t,n))return dn(!Jt(fe.f,t,n),t[n])}},pe=Function.prototype,de=Ut&&Object.getOwnPropertyDescriptor,ve=X(pe,"name"),he={EXISTS:ve,PROPER:ve&&"something"===function(){}.name,CONFIGURABLE:ve&&(!Ut||Ut&&de(pe,"name").configurable)},ye=n((function(t){var n=he.CONFIGURABLE,e=ce.get,r=ce.enforce,o=String(String).split("String");(t.exports=function(t,e,c,u){var f,s=!!u&&!!u.unsafe,l=!!u&&!!u.enumerable,p=!!u&&!!u.noTargetGet,d=u&&void 0!==u.name?u.name:e;a(c)&&("Symbol("===String(d).slice(0,7)&&(d="["+String(d).replace(/^Symbol\(([^)]*)\)/,"$1")+"]"),(!X(c,"name")||n&&c.name!==d)&&vn(c,"name",d),(f=r(c)).source||(f.source=o.join("string"==typeof d?d:""))),t!==i?(s?!p&&t[e]&&(l=!0):delete t[e],l?t[e]=c:vn(t,e,c)):l?t[e]=c:H(e,c)})(Function.prototype,"toString",(function(){return a(this)&&e(this).source||Ot(this)}))})),ge=Pn.concat("length","prototype"),be={f:Object.getOwnPropertyNames||function(t){return En(t,ge)}},me={f:Object.getOwnPropertySymbols},_e=w([].concat),we=et("Reflect","ownKeys")||function(t){var n=be.f(Kt(t)),e=me.f;return e?_e(n,e(t)):n},Se=function(t,n,e){for(var r=we(n),o=pn.f,i=le.f,c=0;c<r.length;c++){var a=r[c];X(t,a)||e&&X(e,a)||o(t,a,i(n,a))}},Oe=/#|\.prototype\./,je=function(t,n){var e=Ee[Ce(t)];return e==Te||e!=Pe&&(a(n)?h(n):!!n)},Ce=je.normalize=function(t){return String(t).replace(Oe,".").toLowerCase()},Ee=je.data={},Pe=je.NATIVE="N",Te=je.POLYFILL="P",xe=je,Re=le.f,Ae=function(t,n){var e,r,o,c,a,u=t.target,f=t.global,s=t.stat;if(e=f?i:s?i[u]||H(u,{}):(i[u]||{}).prototype)for(r in n){if(c=n[r],o=t.noTargetGet?(a=Re(e,r))&&a.value:e[r],!xe(f?r:u+(s?".":"#")+r,t.forced)&&void 0!==o){if(typeof c==typeof o)continue;Se(c,o)}(t.sham||o&&o.sham)&&vn(c,"sham",!0),ye(e,r,c,t)}},Ie=!h((function(){function t(){}return t.prototype.constructor=null,Object.getPrototypeOf(new t)!==t.prototype})),Le=Ln("IE_PROTO"),ke=i.Object,Fe=ke.prototype,De=Ie?ke.getPrototypeOf:function(t){var n=M(t);if(X(n,Le))return n[Le];var e=n.constructor;return a(e)&&n instanceof e?e.prototype:n instanceof ke?Fe:null},Me=ht("iterator"),Ne=!1;[].keys&&("next"in(ie=[].keys())?(oe=De(De(ie)))!==Object.prototype&&(re=oe):Ne=!0);var Ge=null==re||h((function(){var t={};return re[Me].call(t)!==t}));Ge&&(re={}),a(re[Me])||ye(re,Me,(function(){return this}));var Ve={IteratorPrototype:re,BUGGY_SAFARI_ITERATORS:Ne},Be=pn.f,Ue=ht("toStringTag"),We=function(t,n,e){t&&!e&&(t=t.prototype),t&&!X(t,Ue)&&Be(t,Ue,{configurable:!0,value:n})},ze=Ve.IteratorPrototype,He=function(){return this},qe=i.String,Ke=i.TypeError,Ye=Object.setPrototypeOf||("__proto__"in{}?function(){var t,n=!1,e={};try{(t=w(Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set))(e,[]),n=e instanceof Array}catch(t){}return function(e,r){return Kt(e),function(t){if("object"==typeof t||a(t))return t;throw Ke("Can't set "+qe(t)+" as a prototype")}(r),n?t(e,r):e.__proto__=r,e}}():void 0),Je=he.PROPER,Xe=he.CONFIGURABLE,$e=Ve.IteratorPrototype,Qe=Ve.BUGGY_SAFARI_ITERATORS,Ze=ht("iterator"),tr="keys",nr="values",er="entries",rr=function(){return this},or=function(t,n,e,r,o,i,c){!function(t,n,e,r){var o=n+" Iterator";t.prototype=Gn(ze,{next:dn(+!r,e)}),We(t,o,!1),qn[o]=He}(e,n,r);var u,f,s,l=function(t){if(t===o&&y)return y;if(!Qe&&t in v)return v[t];switch(t){case tr:case nr:case er:return function(){return new e(this,t)}}return function(){return new e(this)}},p=n+" Iterator",d=!1,v=t.prototype,h=v[Ze]||v["@@iterator"]||o&&v[o],y=!Qe&&h||l(o),g="Array"==n&&v.entries||h;if(g&&(u=De(g.call(new t)))!==Object.prototype&&u.next&&(De(u)!==$e&&(Ye?Ye(u,$e):a(u[Ze])||ye(u,Ze,rr)),We(u,p,!0)),Je&&o==nr&&h&&h.name!==nr&&(Xe?vn(v,"name",nr):(d=!0,y=function(){return Jt(h,this)})),o)if(f={values:l(nr),keys:i?y:l(tr),entries:l(er)},c)for(s in f)(Qe||d||!(s in v))&&ye(v,s,f[s]);else Ae({target:n,proto:!0,forced:Qe||d},f);return v[Ze]!==y&&ye(v,Ze,y,{name:o}),qn[n]=y,f},ir=pn.f,cr="Array Iterator",ar=ce.set,ur=ce.getterFor(cr),fr=or(Array,"Array",(function(t,n){ar(this,{type:cr,target:bn(t),index:0,kind:n})}),(function(){var t=ur(this),n=t.target,e=t.kind,r=t.index++;return!n||r>=n.length?(t.target=void 0,{value:void 0,done:!0}):"keys"==e?{value:r,done:!1}:"values"==e?{value:n[r],done:!1}:{value:[r,n[r]],done:!1}}),"values"),sr=qn.Arguments=qn.Array;if(Hn("keys"),Hn("values"),Hn("entries"),Ut&&"values"!==sr.name)try{ir(sr,"name",{value:"values"})}catch(t){}var lr=gt?{}.toString:function(){return"[object "+wt(this)+"]"};gt||ye(Object.prototype,"toString",lr,{unsafe:!0});var pr=i.Promise,dr=ht("species"),vr=i.TypeError,hr=ht("iterator"),yr=Array.prototype,gr=ht("iterator"),br=function(t){if(null!=t)return Zt(t,gr)||Zt(t,"@@iterator")||qn[wt(t)]},mr=i.TypeError,_r=function(t,n,e){var r,o;Kt(t);try{if(!(r=Zt(t,"return"))){if("throw"===n)throw e;return e}r=Jt(r,t)}catch(t){o=!0,r=t}if("throw"===n)throw e;if(o)throw r;return Kt(r),e},wr=i.TypeError,Sr=function(t,n){this.stopped=t,this.result=n},Or=Sr.prototype,jr=function(t,n,e){var r,o,i,c,a,u,f,s,l=e&&e.that,p=!(!e||!e.AS_ENTRIES),d=!(!e||!e.IS_ITERATOR),v=!(!e||!e.INTERRUPTED),h=P(n,l),y=function(t){return r&&_r(r,"normal",t),new Sr(!0,t)},g=function(t){return p?(Kt(t),v?h(t[0],t[1],y):h(t[0],t[1])):v?h(t,y):h(t)};if(d)r=t;else{if(!(o=br(t)))throw wr(O(t)+" is not iterable");if(void 0!==(s=o)&&(qn.Array===s||yr[hr]===s)){for(i=0,c=U(t);c>i;i++)if((a=g(t[i]))&&Xt(Or,a))return a;return new Sr(!1)}r=function(t,n){var e=arguments.length<2?br(t):n;if(C(e))return Kt(Jt(e,t));throw mr(O(t)+" is not iterable")}(t,o)}for(u=r.next;!(f=Jt(u,r)).done;){try{a=g(f.value)}catch(t){_r(r,"throw",t)}if("object"==typeof a&&a&&Xt(Or,a))return a}return new Sr(!1)},Cr=ht("iterator"),Er=!1;try{var Pr=0,Tr={next:function(){return{done:!!Pr++}},return:function(){Er=!0}};Tr[Cr]=function(){return this},Array.from(Tr,(function(){throw 2}))}catch(t){}var xr,Rr,Ar,Ir,Lr=i.TypeError,kr=ht("species"),Fr=function(t,n){var e,r=Kt(t).constructor;return void 0===r||null==(e=Kt(r)[kr])?n:function(t){if(kt(t))return t;throw Lr(O(t)+" is not a constructor")}(e)},Dr=Function.prototype,Mr=Dr.apply,Nr=Dr.call,Gr="object"==typeof Reflect&&Reflect.apply||(y?Nr.bind(Mr):function(){return Nr.apply(Mr,arguments)}),Vr=w([].slice),Br=i.TypeError,Ur=function(t,n){if(t<n)throw Br("Not enough arguments");return t},Wr=/(?:ipad|iphone|ipod).*applewebkit/i.test(rt),zr="process"==R(i.process),Hr=i.setImmediate,qr=i.clearImmediate,Kr=i.process,Yr=i.Dispatch,Jr=i.Function,Xr=i.MessageChannel,$r=i.String,Qr=0,Zr={},to="onreadystatechange";try{xr=i.location}catch(t){}var no=function(t){if(X(Zr,t)){var n=Zr[t];delete Zr[t],n()}},eo=function(t){return function(){no(t)}},ro=function(t){no(t.data)},oo=function(t){i.postMessage($r(t),xr.protocol+"//"+xr.host)};Hr&&qr||(Hr=function(t){Ur(arguments.length,1);var n=a(t)?t:Jr(t),e=Vr(arguments,1);return Zr[++Qr]=function(){Gr(n,void 0,e)},Rr(Qr),Qr},qr=function(t){delete Zr[t]},zr?Rr=function(t){Kr.nextTick(eo(t))}:Yr&&Yr.now?Rr=function(t){Yr.now(eo(t))}:Xr&&!Wr?(Ir=(Ar=new Xr).port2,Ar.port1.onmessage=ro,Rr=P(Ir.postMessage,Ir)):i.addEventListener&&a(i.postMessage)&&!i.importScripts&&xr&&"file:"!==xr.protocol&&!h(oo)?(Rr=oo,i.addEventListener("message",ro,!1)):Rr=to in l("script")?function(t){An.appendChild(l("script")).onreadystatechange=function(){An.removeChild(this),no(t)}}:function(t){setTimeout(eo(t),0)});var io,co,ao,uo,fo,so,lo,po,vo={set:Hr,clear:qr},ho=/ipad|iphone|ipod/i.test(rt)&&void 0!==i.Pebble,yo=/web0s(?!.*chrome)/i.test(rt),go=le.f,bo=vo.set,mo=i.MutationObserver||i.WebKitMutationObserver,_o=i.document,wo=i.process,So=i.Promise,Oo=go(i,"queueMicrotask"),jo=Oo&&Oo.value;jo||(io=function(){var t,n;for(zr&&(t=wo.domain)&&t.exit();co;){n=co.fn,co=co.next;try{n()}catch(t){throw co?uo():ao=void 0,t}}ao=void 0,t&&t.enter()},Wr||zr||yo||!mo||!_o?!ho&&So&&So.resolve?((lo=So.resolve(void 0)).constructor=So,po=P(lo.then,lo),uo=function(){po(io)}):zr?uo=function(){wo.nextTick(io)}:(bo=P(bo,i),uo=function(){bo(io)}):(fo=!0,so=_o.createTextNode(""),new mo(io).observe(so,{characterData:!0}),uo=function(){so.data=fo=!fo}));var Co=jo||function(t){var n={fn:t,next:void 0};ao&&(ao.next=n),co||(co=n,uo()),ao=n},Eo=function(t){var n,e;this.promise=new t((function(t,r){if(void 0!==n||void 0!==e)throw TypeError("Bad Promise constructor");n=t,e=r})),this.resolve=C(n),this.reject=C(e)},Po={f:function(t){return new Eo(t)}},To=function(t){try{return{error:!1,value:t()}}catch(t){return{error:!0,value:t}}},xo=function(){this.head=null,this.tail=null};xo.prototype={add:function(t){var n={item:t,next:null};this.head?this.tail.next=n:this.head=n,this.tail=n},get:function(){var t=this.head;if(t)return this.head=t.next,this.tail===t&&(this.tail=null),t.item}};var Ro,Ao,Io,Lo,ko=xo,Fo="object"==typeof window,Do=vo.set,Mo=ht("species"),No="Promise",Go=ce.getterFor(No),Vo=ce.set,Bo=ce.getterFor(No),Uo=pr&&pr.prototype,Wo=pr,zo=Uo,Ho=i.TypeError,qo=i.document,Ko=i.process,Yo=Po.f,Jo=Yo,Xo=!!(qo&&qo.createEvent&&i.dispatchEvent),$o=a(i.PromiseRejectionEvent),Qo="unhandledrejection",Zo=!1,ti=xe(No,(function(){var t=Ot(Wo),n=t!==String(Wo);if(!n&&66===ut)return!0;if(ut>=51&&/native code/.test(t))return!1;var e=new Wo((function(t){t(1)})),r=function(t){t((function(){}),(function(){}))};return(e.constructor={})[Mo]=r,!(Zo=e.then((function(){}))instanceof r)||!n&&Fo&&!$o})),ni=ti||!function(t,n){if(!n&&!Er)return!1;var e=!1;try{var r={};r[Cr]=function(){return{next:function(){return{done:e=!0}}}},t(r)}catch(t){}return e}((function(t){Wo.all(t).catch((function(){}))})),ei=function(t){var n;return!(!u(t)||!a(n=t.then))&&n},ri=function(t,n){var e,r,o,i=n.value,c=1==n.state,a=c?t.ok:t.fail,u=t.resolve,f=t.reject,s=t.domain;try{a?(c||(2===n.rejection&&ui(n),n.rejection=1),!0===a?e=i:(s&&s.enter(),e=a(i),s&&(s.exit(),o=!0)),e===t.promise?f(Ho("Promise-chain cycle")):(r=ei(e))?Jt(r,e,u,f):u(e)):f(i)}catch(t){s&&!o&&s.exit(),f(t)}},oi=function(t,n){t.notified||(t.notified=!0,Co((function(){for(var e,r=t.reactions;e=r.get();)ri(e,t);t.notified=!1,n&&!t.rejection&&ci(t)})))},ii=function(t,n,e){var r,o;Xo?((r=qo.createEvent("Event")).promise=n,r.reason=e,r.initEvent(t,!1,!0),i.dispatchEvent(r)):r={promise:n,reason:e},!$o&&(o=i["on"+t])?o(r):t===Qo&&function(t,n){var e=i.console;e&&e.error&&(1==arguments.length?e.error(t):e.error(t,n))}("Unhandled promise rejection",e)},ci=function(t){Jt(Do,i,(function(){var n,e=t.facade,r=t.value;if(ai(t)&&(n=To((function(){zr?Ko.emit("unhandledRejection",r,e):ii(Qo,e,r)})),t.rejection=zr||ai(t)?2:1,n.error))throw n.value}))},ai=function(t){return 1!==t.rejection&&!t.parent},ui=function(t){Jt(Do,i,(function(){var n=t.facade;zr?Ko.emit("rejectionHandled",n):ii("rejectionhandled",n,t.value)}))},fi=function(t,n,e){return function(r){t(n,r,e)}},si=function(t,n,e){t.done||(t.done=!0,e&&(t=e),t.value=n,t.state=2,oi(t,!0))},li=function(t,n,e){if(!t.done){t.done=!0,e&&(t=e);try{if(t.facade===n)throw Ho("Promise can't be resolved itself");var r=ei(n);r?Co((function(){var e={done:!1};try{Jt(r,n,fi(li,e,t),fi(si,e,t))}catch(n){si(e,n,t)}})):(t.value=n,t.state=1,oi(t,!1))}catch(n){si({done:!1},n,t)}}};if(ti&&(zo=(Wo=function(t){!function(t,n){if(Xt(n,t))return t;throw vr("Incorrect invocation")}(this,zo),C(t),Jt(Ro,this);var n=Go(this);try{t(fi(li,n),fi(si,n))}catch(t){si(n,t)}}).prototype,(Ro=function(t){Vo(this,{type:No,done:!1,notified:!1,parent:!1,reactions:new ko,rejection:!1,state:0,value:void 0})}).prototype=function(t,n,e){for(var r in n)ye(t,r,n[r],e);return t}(zo,{then:function(t,n){var e=Bo(this),r=Yo(Fr(this,Wo));return e.parent=!0,r.ok=!a(t)||t,r.fail=a(n)&&n,r.domain=zr?Ko.domain:void 0,0==e.state?e.reactions.add(r):Co((function(){ri(r,e)})),r.promise},catch:function(t){return this.then(void 0,t)}}),Ao=function(){var t=new Ro,n=Go(t);this.promise=t,this.resolve=fi(li,n),this.reject=fi(si,n)},Po.f=Yo=function(t){return t===Wo||t===Io?new Ao(t):Jo(t)},a(pr)&&Uo!==Object.prototype)){Lo=Uo.then,Zo||(ye(Uo,"then",(function(t,n){var e=this;return new Wo((function(t,n){Jt(Lo,e,t,n)})).then(t,n)}),{unsafe:!0}),ye(Uo,"catch",zo.catch,{unsafe:!0}));try{delete Uo.constructor}catch(t){}Ye&&Ye(Uo,zo)}Ae({global:!0,wrap:!0,forced:ti},{Promise:Wo}),We(Wo,No,!1),function(t){var n=et(t),e=pn.f;Ut&&n&&!n[dr]&&e(n,dr,{configurable:!0,get:function(){return this}})}(No),Io=et(No),Ae({target:No,stat:!0,forced:ti},{reject:function(t){var n=Yo(this);return Jt(n.reject,void 0,t),n.promise}}),Ae({target:No,stat:!0,forced:ti},{resolve:function(t){return function(t,n){if(Kt(t),u(n)&&n.constructor===t)return n;var e=Po.f(t);return(0,e.resolve)(n),e.promise}(this,t)}}),Ae({target:No,stat:!0,forced:ni},{all:function(t){var n=this,e=Yo(n),r=e.resolve,o=e.reject,i=To((function(){var e=C(n.resolve),i=[],c=0,a=1;jr(t,(function(t){var u=c++,f=!1;a++,Jt(e,n,t).then((function(t){f||(f=!0,i[u]=t,--a||r(i))}),o)})),--a||r(i)}));return i.error&&o(i.value),e.promise},race:function(t){var n=this,e=Yo(n),r=e.reject,o=To((function(){var o=C(n.resolve);jr(t,(function(t){Jt(o,n,t).then(e.resolve,r)}))}));return o.error&&r(o.value),e.promise}});var pi=i.String,di=function(t){if("Symbol"===wt(t))throw TypeError("Cannot convert a Symbol value to a string");return pi(t)},vi=w("".charAt),hi=w("".charCodeAt),yi=w("".slice),gi=function(t){return function(n,e){var r,o,i=di(F(n)),c=V(e),a=i.length;return c<0||c>=a?t?"":void 0:(r=hi(i,c))<55296||r>56319||c+1===a||(o=hi(i,c+1))<56320||o>57343?t?vi(i,c):r:t?yi(i,c,c+2):o-56320+(r-55296<<10)+65536}},bi={codeAt:gi(!1),charAt:gi(!0)}.charAt,mi="String Iterator",_i=ce.set,wi=ce.getterFor(mi);or(String,"String",(function(t){_i(this,{type:mi,string:di(t),index:0})}),(function(){var t,n=wi(this),e=n.string,r=n.index;return r>=e.length?{value:void 0,done:!0}:(t=bi(e,r),n.index+=t.length,{value:t,done:!1})}));var Si=ht("iterator"),Oi=ht("toStringTag"),ji=fr.values,Ci=function(t,n){if(t){if(t[Si]!==ji)try{vn(t,Si,ji)}catch(n){t[Si]=ji}if(t[Oi]||vn(t,Oi,n),c[n])for(var e in fr)if(t[e]!==fr[e])try{vn(t,e,fr[e])}catch(n){t[e]=fr[e]}}};for(var Ei in c)Ci(i[Ei]&&i[Ei].prototype,Ei);Ci(v,"DOMTokenList");var Pi=Foundation.env.isSubContext,Ti=Foundation.env.isSafeEnv,xi=["env","appLaunchInfo","ext","wxAppInfo","debug","entryPagePath","envVersion","tabBar","pages","page","accountInfo","global","platform","system","appType","networkTimeout","navigateToMiniProgramAppIdList","plugins","extAppid","host","prerender"],Ri={};function Ai(t,n,e,r){Object.defineProperty(t,e,{configurable:!0,enumerable:!0,get:function(){if(e in n)return n[e];try{return"function"!=typeof r?r:r()}catch(t){return}},set:function(t){n[e]=t}})}var Ii=!0===__ddConfig.preload,Li=!1,ki=[],Fi=[],Di=Foundation.env.typeStr;function Mi(t,n){try{Date.now(),t(n),Date.now()}catch(t){}}function Ni(t){Fi.push(t)}function Gi(t){Li?void 0!==__ddConfig&&Mi(t,__ddConfig):"function"==typeof t&&ki.push(t)}function Vi(t){t.tabBar&&t.tabBar.list&&t.tabBar.list.forEach((function(t){delete t.iconData,delete t.selectedIconData})),delete t.permission;var n=t.subPackages||t.subpackages;return n&&0<n.length&&(n.forEach((function(t){delete t.pages})),t.subPackages=t.subpackages=n),Li&&(__libVersionInfo__.features&&__libVersionInfo__.features.pruneWxConfigByPage&&(Pi||(__ddConfig._preloadRule=__ddConfig.preloadRule||{},__ddConfig._page=__ddConfig.page||{},delete __ddConfig.preloadRule,delete __ddConfig.page),__ddConfig.updatePage=function(t,n){var e;__ddConfig.page=__ddConfig.page||{},__ddConfig.page[t]=__ddConfig.page["".concat(t,".html")]=n,Ri["".concat(t,".html")]=(e=n,JSON.parse(JSON.stringify(e)))},__ddConfig.updatePreloadRule=function(t,n){__ddConfig.preloadRule=__ddConfig.preloadRule||{},__ddConfig.preloadRule[t]=n}),__ddConfig.page=__ddConfig.page||{}),t}function Bi(t){return t.onReady=Gi,t.beforeReady=Ni,Pi||(t.preload=Ii),t.isReady=Li,t.isSubContext=Pi,t.envTag=Di,t.isSafeContext=Ti,t.sdkVersion=t.SDKVersion=Foundation.env.SDKVersion,t.twoPhaseInject=!0,t.platform=Foundation.env.platform,t.brand||"ios"!==t.platform||(t.brand="iPhone"),"number"==typeof t.pixelRatio?t.devicePixelRatio=t.pixelRatio:"number"==typeof t.devicePixelRatio&&(t.pixelRatio=t.devicePixelRatio),t}function Ui(){if(__ddConfig.onReadyStart=Date.now(),ki.forEach((function(t){Mi(t,__ddConfig)})),__ddConfig.onReadyEnd=Date.now(),ki=[],!Ti){var t=__ddConfig,n={},e={};Ri=t.page||{},__libVersionInfo__.features&&__libVersionInfo__.features.pruneWxConfigByPage&&(Ri={});try{Ai(e,n,"deprecated",!0),xi.forEach((function(r){if(r in t){var o=t[r];switch(r){case"page":Ai(e,n,r,Ri);break;case"env":Ai(e,n,r,(function(){return{USER_DATA_PATH:o.USER_DATA_PATH||""}}));break;case"accountInfo":Ai(e,n,r,{appId:o.appId,icon:o.icon,nickname:o.nickname});break;case"appLaunchInfo":Ai(e,n,r,(function(){return dd&&"function"==typeof dd.getLaunchOptionsSync?dd.getLaunchOptionsSync():{}}));break;case"wxAppInfo":Ai(e,n,r,{maxRequestConcurrent:o.maxRequestConcurrent,maxUploadConcurrent:o.maxUploadConcurrent,maxDownloadConcurrent:o.maxDownloadConcurrent,maxWorkerConcurrent:o.maxWorkerConcurrent,maxWebsocketConnect:o.maxWebsocketConnect});break;default:Ai(e,n,r,o)}}})),Foundation.setExportConfig(e)}catch(n){Foundation.setExportConfig(t)}}}function Wi(){void 0===__ddConfig||Li||(Li=!0,__ddConfig=Bi(__ddConfig),__ddConfig=Vi(__ddConfig),function(t){if(!Fi.length)return t();var n=!1;setTimeout((function(){n||(n=!0,t())}),3e3),Promise.all(Fi).catch((function(t){})).then((function(){n||(n=!0,t())})),Fi=[]}(Ui))}function zi(){Foundation.emitConfigReady(__ddConfig)}Foundation.env.isSubContext&&(Di="SubContext"),__ddConfig=Bi(__ddConfig),__ddConfig=Vi(__ddConfig),Foundation.onConfigReady((function(){Wi()})),Pi?__ddConfig.__readyHandler=zi:Foundation.onLibraryReady(zi)}();

var __appServiceSDK__=function(){"use strict";function e(t){return e="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},e(t)}function t(){return t=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},t.apply(this,arguments)}var n=function(){return this}();try{n=globalThis||new Function("return this")()}catch(t){"object"===("undefined"==typeof window?"undefined":e(window))&&(n=window)}var r=n,i="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function o(e,t,n){return e(n={path:t,exports:{},require:function(e,t){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==t&&n.path)}},n.exports),n.exports}var a,s,c=function(e){return e&&e.Math==Math&&e},u=c("object"==typeof globalThis&&globalThis)||c("object"==typeof window&&window)||c("object"==typeof self&&self)||c("object"==typeof i&&i)||function(){return this}()||Function("return this")(),f=function(e){try{return!!e()}catch(e){return!0}},d=!f((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),l=!f((function(){var e=function(){}.bind();return"function"!=typeof e||e.hasOwnProperty("prototype")})),p=Function.prototype.call,h=l?p.bind(p):function(){return p.apply(p,arguments)},y={}.propertyIsEnumerable,g=Object.getOwnPropertyDescriptor,v=g&&!y.call({1:2},1)?function(e){var t=g(this,e);return!!t&&t.enumerable}:y,m={f:v},b=function(e,t){return{enumerable:!(1&e),configurable:!(2&e),writable:!(4&e),value:t}},S=Function.prototype,w=S.bind,_=S.call,k=l&&w.bind(_,_),M=l?function(e){return e&&k(e)}:function(e){return e&&function(){return _.apply(e,arguments)}},T=M({}.toString),N=M("".slice),I=function(e){return N(T(e),8,-1)},x=u.Object,O=M("".split),P=f((function(){return!x("z").propertyIsEnumerable(0)}))?function(e){return"String"==I(e)?O(e,""):x(e)}:x,L=u.TypeError,E=function(e){if(null==e)throw L("Can't call method on "+e);return e},A=function(e){return P(E(e))},C=function(e){return"function"==typeof e},j=function(e){return"object"==typeof e?null!==e:C(e)},V=function(e){return C(e)?e:void 0},B=function(e,t){return arguments.length<2?V(u[e]):u[e]&&u[e][t]},R=M({}.isPrototypeOf),z=B("navigator","userAgent")||"",F=u.process,D=u.Deno,W=F&&F.versions||D&&D.version,U=W&&W.v8;U&&(s=(a=U.split("."))[0]>0&&a[0]<4?1:+(a[0]+a[1])),!s&&z&&(!(a=z.match(/Edge\/(\d+)/))||a[1]>=74)&&(a=z.match(/Chrome\/(\d+)/))&&(s=+a[1]);var q=s,J=!!Object.getOwnPropertySymbols&&!f((function(){var e=Symbol();return!String(e)||!(Object(e)instanceof Symbol)||!Symbol.sham&&q&&q<41})),G=J&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,H=u.Object,Q=G?function(e){return"symbol"==typeof e}:function(e){var t=B("Symbol");return C(t)&&R(t.prototype,H(e))},$=u.String,K=function(e){try{return $(e)}catch(e){return"Object"}},X=u.TypeError,Y=function(e){if(C(e))return e;throw X(K(e)+" is not a function")},Z=function(e,t){var n=e[t];return null==n?void 0:Y(n)},ee=u.TypeError,te=Object.defineProperty,ne=function(e,t){try{te(u,e,{value:t,configurable:!0,writable:!0})}catch(n){u[e]=t}return t},re="__core-js_shared__",ie=u[re]||ne(re,{}),oe=o((function(e){(e.exports=function(e,t){return ie[e]||(ie[e]=void 0!==t?t:{})})("versions",[]).push({version:"3.21.1",mode:"global",copyright:"© 2014-2022 Denis Pushkarev (zloirock.ru)",license:"https://github.com/zloirock/core-js/blob/v3.21.1/LICENSE",source:"https://github.com/zloirock/core-js"})})),ae=u.Object,se=function(e){return ae(E(e))},ce=M({}.hasOwnProperty),ue=Object.hasOwn||function(e,t){return ce(se(e),t)},fe=0,de=Math.random(),le=M(1..toString),pe=function(e){return"Symbol("+(void 0===e?"":e)+")_"+le(++fe+de,36)},he=oe("wks"),ye=u.Symbol,ge=ye&&ye.for,ve=G?ye:ye&&ye.withoutSetter||pe,me=function(e){if(!ue(he,e)||!J&&"string"!=typeof he[e]){var t="Symbol."+e;J&&ue(ye,e)?he[e]=ye[e]:he[e]=G&&ge?ge(t):ve(t)}return he[e]},be=u.TypeError,Se=me("toPrimitive"),we=function(e,t){if(!j(e)||Q(e))return e;var n,r=Z(e,Se);if(r){if(void 0===t&&(t="default"),n=h(r,e,t),!j(n)||Q(n))return n;throw be("Can't convert object to primitive value")}return void 0===t&&(t="number"),function(e,t){var n,r;if("string"===t&&C(n=e.toString)&&!j(r=h(n,e)))return r;if(C(n=e.valueOf)&&!j(r=h(n,e)))return r;if("string"!==t&&C(n=e.toString)&&!j(r=h(n,e)))return r;throw ee("Can't convert object to primitive value")}(e,t)},_e=function(e){var t=we(e,"string");return Q(t)?t:t+""},ke=u.document,Me=j(ke)&&j(ke.createElement),Te=function(e){return Me?ke.createElement(e):{}},Ne=!d&&!f((function(){return 7!=Object.defineProperty(Te("div"),"a",{get:function(){return 7}}).a})),Ie=Object.getOwnPropertyDescriptor,xe={f:d?Ie:function(e,t){if(e=A(e),t=_e(t),Ne)try{return Ie(e,t)}catch(e){}if(ue(e,t))return b(!h(m.f,e,t),e[t])}},Oe=d&&f((function(){return 42!=Object.defineProperty((function(){}),"prototype",{value:42,writable:!1}).prototype})),Pe=u.String,Le=u.TypeError,Ee=function(e){if(j(e))return e;throw Le(Pe(e)+" is not an object")},Ae=u.TypeError,Ce=Object.defineProperty,je=Object.getOwnPropertyDescriptor,Ve="enumerable",Be="configurable",Re="writable",ze={f:d?Oe?function(e,t,n){if(Ee(e),t=_e(t),Ee(n),"function"==typeof e&&"prototype"===t&&"value"in n&&Re in n&&!n.writable){var r=je(e,t);r&&r.writable&&(e[t]=n.value,n={configurable:Be in n?n.configurable:r.configurable,enumerable:Ve in n?n.enumerable:r.enumerable,writable:!1})}return Ce(e,t,n)}:Ce:function(e,t,n){if(Ee(e),t=_e(t),Ee(n),Ne)try{return Ce(e,t,n)}catch(e){}if("get"in n||"set"in n)throw Ae("Accessors not supported");return"value"in n&&(e[t]=n.value),e}},Fe=d?function(e,t,n){return ze.f(e,t,b(1,n))}:function(e,t,n){return e[t]=n,e},De=M(Function.toString);C(ie.inspectSource)||(ie.inspectSource=function(e){return De(e)});var We,Ue,qe,Je=ie.inspectSource,Ge=u.WeakMap,He=C(Ge)&&/native code/.test(Je(Ge)),Qe=oe("keys"),$e=function(e){return Qe[e]||(Qe[e]=pe(e))},Ke={},Xe="Object already initialized",Ye=u.TypeError,Ze=u.WeakMap;if(He||ie.state){var et=ie.state||(ie.state=new Ze),tt=M(et.get),nt=M(et.has),rt=M(et.set);We=function(e,t){if(nt(et,e))throw new Ye(Xe);return t.facade=e,rt(et,e,t),t},Ue=function(e){return tt(et,e)||{}},qe=function(e){return nt(et,e)}}else{var it=$e("state");Ke[it]=!0,We=function(e,t){if(ue(e,it))throw new Ye(Xe);return t.facade=e,Fe(e,it,t),t},Ue=function(e){return ue(e,it)?e[it]:{}},qe=function(e){return ue(e,it)}}var ot={set:We,get:Ue,has:qe,enforce:function(e){return qe(e)?Ue(e):We(e,{})},getterFor:function(e){return function(t){var n;if(!j(t)||(n=Ue(t)).type!==e)throw Ye("Incompatible receiver, "+e+" required");return n}}},at=Function.prototype,st=d&&Object.getOwnPropertyDescriptor,ct=ue(at,"name"),ut={EXISTS:ct,PROPER:ct&&"something"===function(){}.name,CONFIGURABLE:ct&&(!d||d&&st(at,"name").configurable)},ft=o((function(e){var t=ut.CONFIGURABLE,n=ot.get,r=ot.enforce,i=String(String).split("String");(e.exports=function(e,n,o,a){var s,c=!!a&&!!a.unsafe,f=!!a&&!!a.enumerable,d=!!a&&!!a.noTargetGet,l=a&&void 0!==a.name?a.name:n;C(o)&&("Symbol("===String(l).slice(0,7)&&(l="["+String(l).replace(/^Symbol\(([^)]*)\)/,"$1")+"]"),(!ue(o,"name")||t&&o.name!==l)&&Fe(o,"name",l),(s=r(o)).source||(s.source=i.join("string"==typeof l?l:""))),e!==u?(c?!d&&e[n]&&(f=!0):delete e[n],f?e[n]=o:Fe(e,n,o)):f?e[n]=o:ne(n,o)})(Function.prototype,"toString",(function(){return C(this)&&n(this).source||Je(this)}))})),dt=Math.ceil,lt=Math.floor,pt=function(e){var t=+e;return t!=t||0===t?0:(t>0?lt:dt)(t)},ht=Math.max,yt=Math.min,gt=function(e,t){var n=pt(e);return n<0?ht(n+t,0):yt(n,t)},vt=Math.min,mt=function(e){return e>0?vt(pt(e),9007199254740991):0},bt=function(e){return mt(e.length)},St=function(e){return function(t,n,r){var i,o=A(t),a=bt(o),s=gt(r,a);if(e&&n!=n){for(;a>s;)if((i=o[s++])!=i)return!0}else for(;a>s;s++)if((e||s in o)&&o[s]===n)return e||s||0;return!e&&-1}},wt={includes:St(!0),indexOf:St(!1)},_t=wt.indexOf,kt=M([].push),Mt=function(e,t){var n,r=A(e),i=0,o=[];for(n in r)!ue(Ke,n)&&ue(r,n)&&kt(o,n);for(;t.length>i;)ue(r,n=t[i++])&&(~_t(o,n)||kt(o,n));return o},Tt=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],Nt=Tt.concat("length","prototype"),It={f:Object.getOwnPropertyNames||function(e){return Mt(e,Nt)}},xt={f:Object.getOwnPropertySymbols},Ot=M([].concat),Pt=B("Reflect","ownKeys")||function(e){var t=It.f(Ee(e)),n=xt.f;return n?Ot(t,n(e)):t},Lt=function(e,t,n){for(var r=Pt(t),i=ze.f,o=xe.f,a=0;a<r.length;a++){var s=r[a];ue(e,s)||n&&ue(n,s)||i(e,s,o(t,s))}},Et=/#|\.prototype\./,At=function(e,t){var n=jt[Ct(e)];return n==Bt||n!=Vt&&(C(t)?f(t):!!t)},Ct=At.normalize=function(e){return String(e).replace(Et,".").toLowerCase()},jt=At.data={},Vt=At.NATIVE="N",Bt=At.POLYFILL="P",Rt=At,zt=xe.f,Ft=function(e,t){var n,r,i,o,a,s=e.target,c=e.global,f=e.stat;if(n=c?u:f?u[s]||ne(s,{}):(u[s]||{}).prototype)for(r in t){if(o=t[r],i=e.noTargetGet?(a=zt(n,r))&&a.value:n[r],!Rt(c?r:s+(f?".":"#")+r,e.forced)&&void 0!==i){if(typeof o==typeof i)continue;Lt(o,i)}(e.sham||i&&i.sham)&&Fe(o,"sham",!0),ft(n,r,o,e)}},Dt=function(e,t){var n=[][e];return!!n&&f((function(){n.call(null,t||function(){return 1},1)}))},Wt=wt.indexOf,Ut=M([].indexOf),qt=!!Ut&&1/Ut([1],1,-0)<0,Jt=Dt("indexOf");Ft({target:"Array",proto:!0,forced:qt||!Jt},{indexOf:function(e){var t=arguments.length>1?arguments[1]:void 0;return qt?Ut(this,e,t)||0:Wt(this,e,t)}});var Gt={};Gt[me("toStringTag")]="z";var Ht="[object z]"===String(Gt),Qt=me("toStringTag"),$t=u.Object,Kt="Arguments"==I(function(){return arguments}()),Xt=Ht?I:function(e){var t,n,r;return void 0===e?"Undefined":null===e?"Null":"string"==typeof(n=function(e,t){try{return e[t]}catch(e){}}(t=$t(e),Qt))?n:Kt?I(t):"Object"==(r=I(t))&&C(t.callee)?"Arguments":r},Yt=Ht?{}.toString:function(){return"[object "+Xt(this)+"]"};Ht||ft(Object.prototype,"toString",Yt,{unsafe:!0});var Zt=u.Promise,en=function(e,t,n){for(var r in t)ft(e,r,t[r],n);return e},tn=u.String,nn=u.TypeError,rn=Object.setPrototypeOf||("__proto__"in{}?function(){var e,t=!1,n={};try{(e=M(Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set))(n,[]),t=n instanceof Array}catch(e){}return function(n,r){return Ee(n),function(e){if("object"==typeof e||C(e))return e;throw nn("Can't set "+tn(e)+" as a prototype")}(r),t?e(n,r):n.__proto__=r,n}}():void 0),on=ze.f,an=me("toStringTag"),sn=function(e,t,n){e&&!n&&(e=e.prototype),e&&!ue(e,an)&&on(e,an,{configurable:!0,value:t})},cn=me("species"),un=function(e){var t=B(e),n=ze.f;d&&t&&!t[cn]&&n(t,cn,{configurable:!0,get:function(){return this}})},fn=u.TypeError,dn=function(e,t){if(R(t,e))return e;throw fn("Incorrect invocation")},ln=M(M.bind),pn=function(e,t){return Y(e),void 0===t?e:l?ln(e,t):function(){return e.apply(t,arguments)}},hn={},yn=me("iterator"),gn=Array.prototype,vn=me("iterator"),mn=function(e){if(null!=e)return Z(e,vn)||Z(e,"@@iterator")||hn[Xt(e)]},bn=u.TypeError,Sn=function(e,t,n){var r,i;Ee(e);try{if(!(r=Z(e,"return"))){if("throw"===t)throw n;return n}r=h(r,e)}catch(e){i=!0,r=e}if("throw"===t)throw n;if(i)throw r;return Ee(r),n},wn=u.TypeError,_n=function(e,t){this.stopped=e,this.result=t},kn=_n.prototype,Mn=function(e,t,n){var r,i,o,a,s,c,u,f,d=n&&n.that,l=!(!n||!n.AS_ENTRIES),p=!(!n||!n.IS_ITERATOR),y=!(!n||!n.INTERRUPTED),g=pn(t,d),v=function(e){return r&&Sn(r,"normal",e),new _n(!0,e)},m=function(e){return l?(Ee(e),y?g(e[0],e[1],v):g(e[0],e[1])):y?g(e,v):g(e)};if(p)r=e;else{if(!(i=mn(e)))throw wn(K(e)+" is not iterable");if(void 0!==(f=i)&&(hn.Array===f||gn[yn]===f)){for(o=0,a=bt(e);a>o;o++)if((s=m(e[o]))&&R(kn,s))return s;return new _n(!1)}r=function(e,t){var n=arguments.length<2?mn(e):t;if(Y(n))return Ee(h(n,e));throw bn(K(e)+" is not iterable")}(e,i)}for(c=r.next;!(u=h(c,r)).done;){try{s=m(u.value)}catch(e){Sn(r,"throw",e)}if("object"==typeof s&&s&&R(kn,s))return s}return new _n(!1)},Tn=me("iterator"),Nn=!1;try{var In=0,xn={next:function(){return{done:!!In++}},return:function(){Nn=!0}};xn[Tn]=function(){return this},Array.from(xn,(function(){throw 2}))}catch(e){}var On=function(e,t){if(!t&&!Nn)return!1;var n=!1;try{var r={};r[Tn]=function(){return{next:function(){return{done:n=!0}}}},e(r)}catch(e){}return n},Pn=function(){},Ln=[],En=B("Reflect","construct"),An=/^\s*(?:class|function)\b/,Cn=M(An.exec),jn=!An.exec(Pn),Vn=function(e){if(!C(e))return!1;try{return En(Pn,Ln,e),!0}catch(e){return!1}},Bn=function(e){if(!C(e))return!1;switch(Xt(e)){case"AsyncFunction":case"GeneratorFunction":case"AsyncGeneratorFunction":return!1}try{return jn||!!Cn(An,Je(e))}catch(e){return!0}};Bn.sham=!0;var Rn,zn,Fn,Dn,Wn=!En||f((function(){var e;return Vn(Vn.call)||!Vn(Object)||!Vn((function(){e=!0}))||e}))?Bn:Vn,Un=u.TypeError,qn=me("species"),Jn=function(e,t){var n,r=Ee(e).constructor;return void 0===r||null==(n=Ee(r)[qn])?t:function(e){if(Wn(e))return e;throw Un(K(e)+" is not a constructor")}(n)},Gn=Function.prototype,Hn=Gn.apply,Qn=Gn.call,$n="object"==typeof Reflect&&Reflect.apply||(l?Qn.bind(Hn):function(){return Qn.apply(Hn,arguments)}),Kn=B("document","documentElement"),Xn=M([].slice),Yn=u.TypeError,Zn=function(e,t){if(e<t)throw Yn("Not enough arguments");return e},er=/(?:ipad|iphone|ipod).*applewebkit/i.test(z),tr="process"==I(u.process),nr=u.setImmediate,rr=u.clearImmediate,ir=u.process,or=u.Dispatch,ar=u.Function,sr=u.MessageChannel,cr=u.String,ur=0,fr={},dr="onreadystatechange";try{Rn=u.location}catch(e){}var lr=function(e){if(ue(fr,e)){var t=fr[e];delete fr[e],t()}},pr=function(e){return function(){lr(e)}},hr=function(e){lr(e.data)},yr=function(e){u.postMessage(cr(e),Rn.protocol+"//"+Rn.host)};nr&&rr||(nr=function(e){Zn(arguments.length,1);var t=C(e)?e:ar(e),n=Xn(arguments,1);return fr[++ur]=function(){$n(t,void 0,n)},zn(ur),ur},rr=function(e){delete fr[e]},tr?zn=function(e){ir.nextTick(pr(e))}:or&&or.now?zn=function(e){or.now(pr(e))}:sr&&!er?(Dn=(Fn=new sr).port2,Fn.port1.onmessage=hr,zn=pn(Dn.postMessage,Dn)):u.addEventListener&&C(u.postMessage)&&!u.importScripts&&Rn&&"file:"!==Rn.protocol&&!f(yr)?(zn=yr,u.addEventListener("message",hr,!1)):zn=dr in Te("script")?function(e){Kn.appendChild(Te("script")).onreadystatechange=function(){Kn.removeChild(this),lr(e)}}:function(e){setTimeout(pr(e),0)});var gr,vr,mr,br,Sr,wr,_r,kr,Mr={set:nr,clear:rr},Tr=/ipad|iphone|ipod/i.test(z)&&void 0!==u.Pebble,Nr=/web0s(?!.*chrome)/i.test(z),Ir=xe.f,xr=Mr.set,Or=u.MutationObserver||u.WebKitMutationObserver,Pr=u.document,Lr=u.process,Er=u.Promise,Ar=Ir(u,"queueMicrotask"),Cr=Ar&&Ar.value;Cr||(gr=function(){var e,t;for(tr&&(e=Lr.domain)&&e.exit();vr;){t=vr.fn,vr=vr.next;try{t()}catch(e){throw vr?br():mr=void 0,e}}mr=void 0,e&&e.enter()},er||tr||Nr||!Or||!Pr?!Tr&&Er&&Er.resolve?((_r=Er.resolve(void 0)).constructor=Er,kr=pn(_r.then,_r),br=function(){kr(gr)}):tr?br=function(){Lr.nextTick(gr)}:(xr=pn(xr,u),br=function(){xr(gr)}):(Sr=!0,wr=Pr.createTextNode(""),new Or(gr).observe(wr,{characterData:!0}),br=function(){wr.data=Sr=!Sr}));var jr=Cr||function(e){var t={fn:e,next:void 0};mr&&(mr.next=t),vr||(vr=t,br()),mr=t},Vr=function(e){var t,n;this.promise=new e((function(e,r){if(void 0!==t||void 0!==n)throw TypeError("Bad Promise constructor");t=e,n=r})),this.resolve=Y(t),this.reject=Y(n)},Br={f:function(e){return new Vr(e)}},Rr=function(e,t){if(Ee(e),j(t)&&t.constructor===e)return t;var n=Br.f(e);return(0,n.resolve)(t),n.promise},zr=function(e){try{return{error:!1,value:e()}}catch(e){return{error:!0,value:e}}},Fr=function(){this.head=null,this.tail=null};Fr.prototype={add:function(e){var t={item:e,next:null};this.head?this.tail.next=t:this.head=t,this.tail=t},get:function(){var e=this.head;if(e)return this.head=e.next,this.tail===e&&(this.tail=null),e.item}};var Dr,Wr,Ur,qr,Jr=Fr,Gr="object"==typeof window,Hr=Mr.set,Qr=me("species"),$r="Promise",Kr=ot.getterFor($r),Xr=ot.set,Yr=ot.getterFor($r),Zr=Zt&&Zt.prototype,ei=Zt,ti=Zr,ni=u.TypeError,ri=u.document,ii=u.process,oi=Br.f,ai=oi,si=!!(ri&&ri.createEvent&&u.dispatchEvent),ci=C(u.PromiseRejectionEvent),ui="unhandledrejection",fi=!1,di=Rt($r,(function(){var e=Je(ei),t=e!==String(ei);if(!t&&66===q)return!0;if(q>=51&&/native code/.test(e))return!1;var n=new ei((function(e){e(1)})),r=function(e){e((function(){}),(function(){}))};return(n.constructor={})[Qr]=r,!(fi=n.then((function(){}))instanceof r)||!t&&Gr&&!ci})),li=di||!On((function(e){ei.all(e).catch((function(){}))})),pi=function(e){var t;return!(!j(e)||!C(t=e.then))&&t},hi=function(e,t){var n,r,i,o=t.value,a=1==t.state,s=a?e.ok:e.fail,c=e.resolve,u=e.reject,f=e.domain;try{s?(a||(2===t.rejection&&bi(t),t.rejection=1),!0===s?n=o:(f&&f.enter(),n=s(o),f&&(f.exit(),i=!0)),n===e.promise?u(ni("Promise-chain cycle")):(r=pi(n))?h(r,n,c,u):c(n)):u(o)}catch(e){f&&!i&&f.exit(),u(e)}},yi=function(e,t){e.notified||(e.notified=!0,jr((function(){for(var n,r=e.reactions;n=r.get();)hi(n,e);e.notified=!1,t&&!e.rejection&&vi(e)})))},gi=function(e,t,n){var r,i;si?((r=ri.createEvent("Event")).promise=t,r.reason=n,r.initEvent(e,!1,!0),u.dispatchEvent(r)):r={promise:t,reason:n},!ci&&(i=u["on"+e])?i(r):e===ui&&function(e,t){var n=u.console;n&&n.error&&(1==arguments.length?n.error(e):n.error(e,t))}("Unhandled promise rejection",n)},vi=function(e){h(Hr,u,(function(){var t,n=e.facade,r=e.value;if(mi(e)&&(t=zr((function(){tr?ii.emit("unhandledRejection",r,n):gi(ui,n,r)})),e.rejection=tr||mi(e)?2:1,t.error))throw t.value}))},mi=function(e){return 1!==e.rejection&&!e.parent},bi=function(e){h(Hr,u,(function(){var t=e.facade;tr?ii.emit("rejectionHandled",t):gi("rejectionhandled",t,e.value)}))},Si=function(e,t,n){return function(r){e(t,r,n)}},wi=function(e,t,n){e.done||(e.done=!0,n&&(e=n),e.value=t,e.state=2,yi(e,!0))},_i=function(e,t,n){if(!e.done){e.done=!0,n&&(e=n);try{if(e.facade===t)throw ni("Promise can't be resolved itself");var r=pi(t);r?jr((function(){var n={done:!1};try{h(r,t,Si(_i,n,e),Si(wi,n,e))}catch(t){wi(n,t,e)}})):(e.value=t,e.state=1,yi(e,!1))}catch(t){wi({done:!1},t,e)}}};if(di&&(ti=(ei=function(e){dn(this,ti),Y(e),h(Dr,this);var t=Kr(this);try{e(Si(_i,t),Si(wi,t))}catch(e){wi(t,e)}}).prototype,(Dr=function(e){Xr(this,{type:$r,done:!1,notified:!1,parent:!1,reactions:new Jr,rejection:!1,state:0,value:void 0})}).prototype=en(ti,{then:function(e,t){var n=Yr(this),r=oi(Jn(this,ei));return n.parent=!0,r.ok=!C(e)||e,r.fail=C(t)&&t,r.domain=tr?ii.domain:void 0,0==n.state?n.reactions.add(r):jr((function(){hi(r,n)})),r.promise},catch:function(e){return this.then(void 0,e)}}),Wr=function(){var e=new Dr,t=Kr(e);this.promise=e,this.resolve=Si(_i,t),this.reject=Si(wi,t)},Br.f=oi=function(e){return e===ei||e===Ur?new Wr(e):ai(e)},C(Zt)&&Zr!==Object.prototype)){qr=Zr.then,fi||(ft(Zr,"then",(function(e,t){var n=this;return new ei((function(e,t){h(qr,n,e,t)})).then(e,t)}),{unsafe:!0}),ft(Zr,"catch",ti.catch,{unsafe:!0}));try{delete Zr.constructor}catch(e){}rn&&rn(Zr,ti)}Ft({global:!0,wrap:!0,forced:di},{Promise:ei}),sn(ei,$r,!1),un($r),Ur=B($r),Ft({target:$r,stat:!0,forced:di},{reject:function(e){var t=oi(this);return h(t.reject,void 0,e),t.promise}}),Ft({target:$r,stat:!0,forced:di},{resolve:function(e){return Rr(this,e)}}),Ft({target:$r,stat:!0,forced:li},{all:function(e){var t=this,n=oi(t),r=n.resolve,i=n.reject,o=zr((function(){var n=Y(t.resolve),o=[],a=0,s=1;Mn(e,(function(e){var c=a++,u=!1;s++,h(n,t,e).then((function(e){u||(u=!0,o[c]=e,--s||r(o))}),i)})),--s||r(o)}));return o.error&&i(o.value),n.promise},race:function(e){var t=this,n=oi(t),r=n.reject,i=zr((function(){var i=Y(t.resolve);Mn(e,(function(e){h(i,t,e).then(n.resolve,r)}))}));return i.error&&r(i.value),n.promise}});
/*! *****************************************************************************
  Copyright (c) Microsoft Corporation.

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
  REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
  AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
  INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
  LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
  OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
  PERFORMANCE OF THIS SOFTWARE.
  ***************************************************************************** */
var ki=function(){return ki=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e},ki.apply(this,arguments)};function Mi(e,t,n,r){return new(n||(n=Promise))((function(i,o){function a(e){try{c(r.next(e))}catch(e){o(e)}}function s(e){try{c(r.throw(e))}catch(e){o(e)}}function c(e){e.done?i(e.value):function(e){return e instanceof n?e:new n((function(t){t(e)}))}(e.value).then(a,s)}c((r=r.apply(e,t||[])).next())}))}function Ti(e,t){var n,r,i,o,a={label:0,sent:function(){if(1&i[0])throw i[1];return i[1]},trys:[],ops:[]};return o={next:s(0),throw:s(1),return:s(2)},"function"==typeof Symbol&&(o[Symbol.iterator]=function(){return this}),o;function s(o){return function(s){return function(o){if(n)throw new TypeError("Generator is already executing.");for(;a;)try{if(n=1,r&&(i=2&o[0]?r.return:o[0]?r.throw||((i=r.return)&&i.call(r),0):r.next)&&!(i=i.call(r,o[1])).done)return i;switch(r=0,i&&(o=[2&o[0],i.value]),o[0]){case 0:case 1:i=o;break;case 4:return a.label++,{value:o[1],done:!1};case 5:a.label++,r=o[1],o=[0];continue;case 7:o=a.ops.pop(),a.trys.pop();continue;default:if(!(i=a.trys,(i=i.length>0&&i[i.length-1])||6!==o[0]&&2!==o[0])){a=0;continue}if(3===o[0]&&(!i||o[1]>i[0]&&o[1]<i[3])){a.label=o[1];break}if(6===o[0]&&a.label<i[1]){a.label=i[1],i=o;break}if(i&&a.label<i[2]){a.label=i[2],a.ops.push(o);break}i[2]&&a.ops.pop(),a.trys.pop();continue}o=t.call(e,a)}catch(e){o=[6,e],r=0}finally{n=i=0}if(5&o[0])throw o[1];return{value:o[0]?o[1]:void 0,done:!0}}([o,s])}}}var Ni={customShare:{type:"async",event:"customShare",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},image:{type:["String"],ifMustNeed:!1,default:void 0,desc:"分享图片"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},showShareEntrance:{type:"async",event:"showShareEntrance",argsSize:1,agrs0Type:"Object",params:{buttons:{type:["Array"],ifMustNeed:!0,default:"",desc:"转发按钮名称列表"}}},hideShareEntrance:{type:"async",event:"hideShareEntrance",argsSize:0,agrs0Type:"any",params:null},shareWeixinTimeline:{type:"async",event:"shareWeixinTimeline",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"}}},shareWeixinAppmsg:{type:"async",event:"shareWeixinAppmsg",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareQqAppmsg:{type:"async",event:"shareQqAppmsg",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareQzone:{type:"async",event:"shareQzone",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareAlipayFriend:{type:"async",event:"shareAlipayFriend",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareAlipayLife:{type:"async",event:"shareAlipayLife",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareMessage:{type:"async",event:"shareMessage",argsSize:1,agrs0Type:"Object",params:{recipients:{type:["Array"],ifMustNeed:!1,default:[],desc:"收件人号码"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareSinaWeibo:{type:"async",event:"shareSinaWeibo",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareFacebook:{type:"async",event:"shareFacebook",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareTwitter:{type:"async",event:"shareTwitter",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareWhatsApp:{type:"async",event:"shareWhatsApp",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareEMail:{type:"async",event:"shareEMail",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareSavePicture:{type:"async",event:"shareSavePicture",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}}},Ii=ki(ki(ki(ki(ki(ki(ki(ki(ki(ki(ki(ki(ki(ki({},{getStorageSync:{type:"sync",event:"getStorageSync",argsSize:1,agrs0Type:"String",needReturn:!0,params:{key:{type:["String"],ifMustNeed:!0,default:"",desc:"本地缓存中指定的key"}}},setStorageSync:{type:"sync",event:"setStorageSync",argsSize:2,agrs0Type:"String",needReturn:!1,params:{key:{type:["String"],ifMustNeed:!0,default:"",desc:"本地缓存中指定的key"},data:{type:"any",ifMustNeed:!0,default:"",desc:"需要存储的内容"}}},removeStorageSync:{type:"sync",event:"removeStorageSync",argsSize:1,agrs0Type:"String",needReturn:!1,params:{key:{type:["String"],ifMustNeed:!0,default:"",desc:"本地缓存中指定的key"}}},removeStorage:{type:"async",event:"removeStorage",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{key:{type:["String"],ifMustNeed:!0,default:"",desc:"本地缓存中指定的key"}}},getStorageInfo:{type:"async",event:"getStorageInfo",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},getStorageInfoSync:{type:"sync",event:"getStorageInfoSync",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},setStorage:{type:"async",event:"setStorage",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{key:{type:["String"],ifMustNeed:!0,default:"",desc:"本地缓存中指定的key"},data:{type:"any",ifMustNeed:!0,default:"",desc:"需要存储的内容"}}},getStorage:{type:"async",event:"getStorage",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{key:{type:["String"],ifMustNeed:!0,default:"",desc:"本地缓存中指定的key"}}},clearStorage:{type:"async",event:"clearStorage",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},setBackgroundFetchToken:{type:"async",event:"setBackgroundFetchToken",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{token:{type:["String"],ifMustNeed:!0,default:"",desc:"传给端上获取预加载数据的token"}}},getBackgroundFetchData:{type:"async",event:"getBackgroundFetchData",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{fetchType:{type:["String"],ifMustNeed:!0,defult:"",desc:"获取端上预加载的数据"}}}}),{checkBridgeExist:{type:"async",event:"checkBridgeExist",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{methodName:{type:["String"],ifMustNeed:!0,default:"",desc:"bridge名"},moduleName:{type:["String"],ifMustNeed:!1,default:"",desc:"bridge所在的模块名"}}},getSystemInfo:{type:"async",event:"getSystemInfo",argsSize:0,agrs0Type:"any",params:null,usePromise:!0},getSystemInfoSync:{type:"sync",event:"getSystemInfoSync",argsSize:0,agrs0Type:"any",needReturn:!0,params:null},getSystemSetting:{type:"sync",event:"getSystemInfoSync",argsSize:0,agrs0Type:"any",needReturn:!0,params:null},getAccountInfoSync:{type:"sync",event:"getAccountInfoSync",argsSize:0,agrs0Type:"any",needReturn:!0,params:null},getLaunchOptionsSync:{type:"sync",event:"getLaunchOptionsSync",argsSize:0,agrs0Type:"any",needReturn:!0,params:null},getNetworkType:{type:"async",event:"getNetworkType",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},authorize:{type:"async",event:"authorize",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{scope:{type:["String"],ifMustNeed:!0,default:"",desc:"需要获取权限的 scope"}}},businessAuthorize:{type:"async",event:"businessAuthorize",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{scope:{type:["String"],ifMustNeed:!0,default:"",desc:"需要获取权限的 scope"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"需要获取权限的 title"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"需要获取权限的 icon 仅支持difile格式"},subTitle:{type:["String"],ifMustNeed:!1,default:"",desc:"需要获取权限的 subTitle"},desc:{type:["String"],ifMustNeed:!1,default:"",desc:"需要获取权限的 desc"},showType:{type:["String"],ifMustNeed:!1,default:"bottom",desc:'需要获取权限的 showType ["bottom","center"]'}}},openSetting:{type:"async",event:"openSetting",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},getSetting:{type:"async",event:"getSetting",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},vibrateShort:{type:"async",event:"vibrateShort",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{type:{type:["String"],ifMustNeed:!0,default:"",desc:"震动强度类型，有效值为：heavy、medium、light"}}},vibrateLong:{type:"async",event:"vibrateLong",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},makePhoneCall:{type:"async",event:"makePhoneCall",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{phoneNumber:{type:["String"],ifMustNeed:!0,default:"",desc:"需要拨打的电话号码"}}},getClipboardData:{type:"async",event:"makePgetClipboardDatahoneCall",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},setClipboardData:{type:"async",event:"setClipboardData",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{data:{type:["String"],ifMustNeed:!0,default:"",desc:"剪贴板的内容"},disableToast:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"是否禁用拷贝成功toast"}}},getLocation:{type:"async",event:"getLocation",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{type:{type:["String"],ifMustNeed:!1,default:"wgs84",desc:"wgs84 返回 gps 坐标，gcj02 返回可用于 dd.openLocation 的坐标"},altitude:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"传入 true 会返回高度信息，由于获取高度需要较高精确度，会减慢接口返回速度"},isHighAccuracy:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"开启高精度定位"},highAccuracyExpireTime:{type:["Number"],ifMustNeed:!1,default:3e3,desc:"高精度定位超时时间(ms)，指定时间内返回最高精度，该值3000ms以上高精度定位才有效果"}}},openLocation:{type:"async",event:"openLocation",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{latitude:{type:["Number"],ifMustNeed:!0,default:"",desc:"纬度，范围为-90~90，负数表示南纬。使用 gcj02 国测局坐标系"},longitude:{type:["Number"],ifMustNeed:!0,default:"",desc:"经度，范围为-180~180，负数表示西经。使用 gcj02 国测局坐标系"},scale:{type:["Number"],ifMustNeed:!1,default:18,desc:"缩放比例，范围5~18"},name:{type:["String"],ifMustNeed:!1,default:"",desc:"位置名"},address:{type:["String"],ifMustNeed:!1,default:"",desc:"地址的详细说明"}}},choosePoi:{type:"async",event:"choosePoi",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},chooseLocation:{type:"async",event:"chooseLocation",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{latitude:{type:["Number"],ifMustNeed:!1,default:"",desc:"目标地纬度"},longitude:{type:["Number"],ifMustNeed:!1,default:"",desc:"目标地经度"}}},request:{type:"async",event:"request",agrs0Type:"Object",argsSize:1,params:{url:{type:["String"],ifMustNeed:!0,default:"",desc:"开发者服务器接口地址"},data:{type:["String","Object","ArrayBuffer"],ifMustNeed:!1,default:"",desc:"请求的参数"},header:{type:["Object"],ifMustNeed:!1,default:{"content-type":"application/json"},desc:"设置请求的 header，header 中不能设置 Referer。content-type 默认为 application/json"},timeout:{type:["Number"],ifMustNeed:!1,default:"",desc:"超时时间，单位为毫秒"},method:{type:["String"],ifMustNeed:!1,default:"GET",desc:"HTTP 请求方法"},dataType:{type:["String"],ifMustNeed:!1,default:"json",desc:"返回的数据格式"},responseType:{type:["String"],ifMustNeed:!1,default:"text",desc:"响应的数据类型"}}},startRecord:{type:"async",event:"startRecord",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},stopRecord:{type:"async",event:"stopRecord",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},startWifi:{type:"async",event:"startWifi",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},stopWifi:{type:"async",event:"stopWifi",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},getWifiList:{type:"async",event:"getWifiList",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},getConnectedWifi:{type:"async",event:"getConnectedWifi",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},closeDimina:{type:"async",event:"closeDimina",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},showActionSheet:{type:"async",event:"showActionSheet",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{alertText:{type:["String"],ifMustNeed:!1,default:"",desc:"警示文案"},itemList:{type:["Array"],ifMustNeed:!0,default:"",desc:"按钮的文字数组，数组长度最大为 6"},itemColor:{type:["String"],ifMustNeed:!1,default:"#000000",desc:"按钮的文字颜色"}}},enableAlertBeforeUnload:{type:"async",event:"enableAlertBeforeUnload",agrs0Type:"Object",argsSize:1,params:{message:{type:["String"],ifMustNeed:!0,default:"",desc:"震动强度类型，有效值为：heavy、medium、light"}}},disableAlertBeforeUnload:{type:"async",event:"disableAlertBeforeUnload",agrs0Type:"any",argsSize:0,params:null},onMemoryWarning:{type:"monitor",event:"onMemoryWarning",eventManagerName:"onMemoryWarning",nativeEvent:"onMemoryWarningReceive",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"内存紧张时的回调函数"}}},offMemoryWarning:{type:"offMonitor",event:"offMemoryWarning",eventManagerName:"onMemoryWarning",nativeEvent:"onMemoryWarningReceive",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"内存紧张时的回调函数"}}},onNetworkStatusChange:{type:"monitor",event:"onNetworkStatusChange",eventManagerName:"onNetworkStatusChange",nativeEvent:"onNetworkStatusChange",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"监听网络状态变化事件"}}},offNetworkStatusChange:{type:"offMonitor",event:"offNetworkStatusChange",eventManagerName:"onNetworkStatusChange",nativeEvent:"onNetworkStatusChange",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"监听网络状态变化事件"}}},onGetWifiList:{type:"monitor",event:"onGetWifiList",eventManagerName:"onGetWifiList",nativeEvent:"onGetWifiList",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"获取到 Wi-Fi 列表数据事件的回调函数"}}},offGetWifiList:{type:"offMonitor",event:"offGetWifiList",eventManagerName:"onGetWifiList",nativeEvent:"onGetWifiList",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"获取到 Wi-Fi 列表数据事件的回调函数"}}},onWifiConnected:{type:"monitor",event:"onWifiConnected",eventManagerName:"onWifiConnected",nativeEvent:"onWifiConnected",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"连接上 Wi-Fi 的事件的回调函数"}}},offWifiConnected:{type:"offMonitor",event:"offWifiConnected",eventManagerName:"onWifiConnected",nativeEvent:"onWifiConnected",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"连接上 Wi-Fi 的事件的回调函数"}}},onLoginStatusChanged:{type:"monitor",event:"onLoginStatusChanged",eventManagerName:"notifyLoginStatusChanged",nativeEvent:"notifyLoginStatusChanged",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"登录状态变化时的回调函数"}}},offLoginStatusChanged:{type:"offMonitor",event:"offLoginStatusChanged",eventManagerName:"notifyLoginStatusChanged",nativeEvent:"notifyLoginStatusChanged",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"登录状态变化时的回调函数"}}},onUserCaptureScreen:{type:"monitor",event:"onUserCaptureScreen",eventManagerName:"onUserCaptureScreen",nativeEvent:"onUserCaptureScreen",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"用户主动截屏事件的回调函数"}}},offUserCaptureScreen:{type:"offMonitor",event:"offUserCaptureScreen",eventManagerName:"onUserCaptureScreen",nativeEvent:"onUserCaptureScreen",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"用户主动截屏事件的回调函数"}}},showTabBar:{type:"async",event:"showTabBar",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{animation:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"是否需要动画效果"}}},hideTabBar:{type:"async",event:"hideTabBar",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{animation:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"是否需要动画效果"}}}}),{showLoading:{type:"async",event:"showLoading",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{title:{type:["String"],ifMustNeed:!0,default:"",desc:"提示的内容"},mask:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"是否显示透明蒙层，防止触摸穿透"}}},hideLoading:{type:"async",event:"hideLoading",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},showToast:{type:"async",event:"showToast",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{title:{type:["String"],ifMustNeed:!0,default:"",desc:"提示的内容"},icon:{type:["String"],ifMustNeed:!1,default:"success",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"自定义图标的本地路径，image 的优先级高于 icon"},duration:{type:["Number"],ifMustNeed:!1,default:1500,desc:"提示的延迟时间"},mask:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"是否显示透明蒙层，防止触摸穿透"}}},hideToast:{type:"async",event:"hideToast",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},showModal:{type:"async",event:"showModal",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{title:{type:["String"],ifMustNeed:!1,default:"",desc:"提示的标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"提示的内容"},showCancel:{type:["Boolean"],ifMustNeed:!1,default:!0,desc:"是否显示取消按钮"},cancelText:{type:["String"],ifMustNeed:!1,default:"取消",desc:"取消按钮的文字，最多 4 个字符"},cancelColor:{type:["String"],ifMustNeed:!1,default:"#000000",desc:"取消按钮的文字颜色，必须是 16 进制格式的颜色字符串"},confirmText:{type:["String"],ifMustNeed:!1,default:"确定",desc:"确认按钮的文字，最多 4 个字符"},confirmColor:{type:["String"],ifMustNeed:!1,default:"#576B95",desc:"确认按钮的文字颜色，必须是 16 进制格式的颜色字符串"}}},setNavigationBarTitle:{type:"async",event:"setNavigationBarTitle",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{title:{type:["String"],ifMustNeed:!0,default:"",desc:"页面标题"}}},setNavigationBarColor:{type:"async",event:"setNavigationBarColor",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{frontColor:{type:["String"],ifMustNeed:!0,default:"",desc:"前景颜色值，包括按钮、标题、状态栏的颜色，仅支持 #ffffff 和 #000000"},backgroundColor:{type:["String"],ifMustNeed:!0,default:"",desc:"背景颜色值，有效值为十六进制颜色"},animation:{type:["Object"],ifMustNeed:!1,default:{},desc:"动画效果"}}},getMenuButtonBoundingClientRect:{type:"sync",event:"getMenuButtonBoundingClientRect",argsSize:0,agrs0Type:"any",needReturn:!0,params:null},setTabBarBadge:{type:"async",event:"setTabBarBadge",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{index:{type:["Number"],ifMustNeed:!0,default:0,desc:"tabBar 的哪一项，从左边算起"},text:{type:["String"],ifMustNeed:!0,default:"",desc:"显示的文本，超过 4 个字符则显示成 ..."}}},showCapsuleButton:{type:"async",event:"showCapsuleButton",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},hideCapsuleButton:{type:"async",event:"hideCapsuleButton",argsSize:0,agrs0Type:"any",usePromise:!0,params:null}}),{getImageInfo:{type:"async",event:"getImageInfo",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{src:{type:["String"],ifMustNeed:!0,default:"",desc:"图片的路径，支持网络路径、本地路径、代码包路径"}}},saveImageToPhotosAlbum:{type:"async",event:"saveImageToPhotosAlbum",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{filePath:{type:["String"],ifMustNeed:!0,default:"",desc:"图片文件路径，可以是临时文件路径或永久文件路径 (本地路径) ，不支持网络路径"}}},chooseImage:{type:"async",event:"chooseImage",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{count:{type:["Number"],ifMustNeed:!1,default:9,desc:"最多可以选择的图片张数"},sizeType:{type:["Array"],ifMustNeed:!1,default:["original"],desc:"所选的图片的尺寸"},sourceType:{type:["Array"],ifMustNeed:!1,default:["album"],desc:"选择图片的来源"}}},scanCode:{type:"async",event:"scanCode",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{onlyFromCamera:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"是否只能从相机扫码，不允许从相册选择图片"},scanType:{type:["Array"],ifMustNeed:!1,default:["barCode","qrCode"],desc:"扫码类型"}}},previewImage:{type:"async",event:"previewImage",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{urls:{type:["Array"],ifMustNeed:!0,default:"",desc:"需要预览的图片链接列表"},current:{type:["String"],ifMustNeed:!1,default:"",desc:"当前显示图片的链接"},showmenu:{type:["Boolean"],ifMustNeed:!1,default:!0,desc:"是否显示长按菜单"}}},compressImage:{type:"async",event:"compressImage",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{src:{type:["String"],ifMustNeed:!0,default:"",desc:"图片路径，图片的路径，支持本地路径、代码包路径"},quality:{type:["Number"],ifMustNeed:!1,default:80,desc:"压缩质量，范围0～100，数值越小，质量越低，压缩率越高（仅对jpg有效）。"}}}}),{getSavedFileInfo:{type:"async",event:"getSavedFileInfo",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{filePath:{type:["String"],ifMustNeed:!0,default:"",desc:"文件路径 (本地路径)"}}},getFileInfo:{type:"async",event:"getFileInfo",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{filePath:{type:["String"],ifMustNeed:!0,default:"",desc:"本地文件路径 (本地路径)"},digestAlgorithm:{type:["String"],ifMustNeed:!1,default:"md5",desc:"计算文件摘要的算法"}}},saveFile:{type:"async",event:"saveFile",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{tempFilePath:{type:["String"],ifMustNeed:!0,default:!1,desc:"需要保存的文件的临时路径 (本地路径)"}}},removeSavedFile:{type:"async",event:"removeSavedFile",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{filePath:{type:["String"],ifMustNeed:!0,default:"",desc:"需要删除的文件路径 (本地路径)"}}}}),{startPullDownRefresh:{type:"async",event:"startPullDownRefresh",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},stopPullDownRefresh:{type:"async",event:"stopPullDownRefresh",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},enablePullDownRefresh:{type:"async",event:"enablePullDownRefresh",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},disablePullDownRefresh:{type:"async",event:"disablePullDownRefresh",argsSize:0,agrs0Type:"any",usePromise:!0,params:null}}),Ni),{login:{type:"async",event:"login",argsSize:1,agrs0Type:"Object",params:{needLoginPage:{type:["Boolean"],ifMustNeed:!0,default:!1,desc:"needLoginPage"}}},passportLogin:{type:"async",event:"passportLogin",argsSize:0,agrs0Type:"any",params:null},loginAndShowLegalDialog:{type:"async",event:"loginAndShowLegalDialog",argsSize:1,agrs0Type:"Object",params:{scene:{type:["String"],ifMustNeed:!0,default:"",desc:"场景值"}}},getLoginLegalInfo:{type:"async",event:"getLoginLegalInfo",argsSize:1,agrs0Type:"Object",params:{scene:{type:["String"],ifMustNeed:!0,default:"",desc:"场景值"}}},getUserInfo:{type:"async",event:"getUserInfo",argsSize:0,agrs0Type:"any",params:null},logout:{type:"async",event:"logout",argsSize:0,agrs0Type:"any",params:null}}),{openBluetoothAdapter:{type:"async",event:"openBluetoothAdapter",argsSize:0,agrs0Type:"any",params:null,usePromise:!0},getBluetoothAdapterState:{type:"async",event:"getBluetoothAdapterState",argsSize:0,agrs0Type:"any",params:null,usePromise:!0},onBluetoothDeviceFound:{type:"async",event:"onBluetoothDeviceFound",isSustain:!0,argsSize:0,agrs0Type:"any",params:null},startBluetoothDevicesDiscovery:{type:"async",event:"startBluetoothDevicesDiscovery",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{services:{type:["Array"],ifMustNeed:!1,default:"",desc:"要搜索的蓝牙设备主 service 的 uuid 列表"},allowDuplicatesKey:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"是否允许重复上报同一设备"},interval:{type:["Number"],ifMustNeed:!1,default:0,desc:"上报设备的间隔"}}},onBluetoothAdapterStateChange:{type:"async",event:"onBluetoothAdapterStateChange",isSustain:!0,argsSize:0,agrs0Type:"any",params:null},stopBluetoothDevicesDiscovery:{type:"async",event:"stopBluetoothDevicesDiscovery",argsSize:0,agrs0Type:"any",params:null,usePromise:!0},createBLEConnection:{type:"async",event:"createBLEConnection",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{deviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"用于区分设备的 id"},timeout:{type:["Number"],ifMustNeed:!1,default:"",desc:"超时时间，单位ms，不填表示不会超时"}}},onBLEConnectionStateChange:{type:"async",event:"onBLEConnectionStateChange",isSustain:!0,argsSize:0,agrs0Type:"any",params:null},getBLEDeviceServices:{type:"async",event:"getBLEDeviceServices",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{deviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙设备id"}}},getBLEDeviceCharacteristics:{type:"async",event:"getBLEDeviceCharacteristics",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{deviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙设备 id"},serviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙服务 uuid，需要使用 getBLEDeviceServices 获取"}}},notifyBLECharacteristicValueChange:{type:"async",event:"notifyBLECharacteristicValueChange",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{deviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙设备 id"},serviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙特征值对应服务的 uuid"},characteristicId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙特征值的 uuid"},state:{type:["Boolean"],ifMustNeed:!0,default:"",desc:"是否启用 notify"}}},writeBLECharacteristicValue:{type:"async",event:"writeBLECharacteristicValue",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{deviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙设备 id"},serviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙特征值对应服务的 uuid"},characteristicId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙特征值的 uuid"},value:{type:["ArrayBuffer"],ifMustNeed:!0,default:"",desc:"蓝牙设备特征值对应的二进制值"}}},onBLECharacteristicValueChange:{type:"async",event:"onBLECharacteristicValueChange",isSustain:!0,argsSize:0,agrs0Type:"any",params:null},closeBluetoothAdapter:{type:"async",event:"closeBluetoothAdapter",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},closeBLEConnection:{type:"async",event:"closeBLEConnection",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{deviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙设备id"}}},getConnectedBluetoothDevices:{type:"async",event:"getConnectedBluetoothDevices",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{services:{type:["Array"],ifMustNeed:!0,default:"",desc:"蓝牙设备主 service 的 uuid 列表"}}},getBluetoothDevices:{type:"async",event:"getBluetoothDevices",argsSize:0,agrs0Type:"any",params:null,usePromise:!0},readBLECharacteristicValue:{type:"async",event:"readBLECharacteristicValue",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{deviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙设备 id"},serviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙特征值对应服务的 uuid"},characteristicId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙特征值的 uuid"}}}}),{hideKeyboard:{type:"async",event:"hideKeyboard",argsSize:0,agrs0Type:"any",usePromise:!0,params:null}}),{setScreenBrightness:{type:"async",event:"setScreenBrightness",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{value:{type:["Number"],ifMustNeed:!0,default:"",desc:"屏幕亮度值，范围 0 ~ 1。0 最暗，1 最亮"}}},setKeepScreenOn:{type:"async",event:"setKeepScreenOn",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{keepScreenOn:{type:["Boolean"],ifMustNeed:!0,default:"",desc:"是否保持屏幕常亮"}}},getScreenBrightness:{type:"async",event:"getScreenBrightness",argsSize:0,agrs0Type:"any",usePromise:!0,params:null}}),{chooseContact:{type:"async",event:"chooseContact",agrs0Type:"any",argsSize:0,params:null},addPhoneContact:{type:"async",event:"addPhoneContact",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{firstName:{type:["String"],ifMustNeed:!0,default:"",desc:"名字"},photoFilePath:{type:["String"],ifMustNeed:!1,default:"",desc:"头像本地文件路径"},nickName:{type:["String"],ifMustNeed:!1,default:"",desc:"昵称"},lastName:{type:["String"],ifMustNeed:!1,default:"",desc:"姓氏"},middleName:{type:["String"],ifMustNeed:!1,default:"",desc:"中间名"},remark:{type:["String"],ifMustNeed:!1,default:"",desc:"备注"},mobilePhoneNumber:{type:["String"],ifMustNeed:!1,default:"",desc:"手机号"},weChatNumber:{type:["String"],ifMustNeed:!1,default:"",desc:"微信号"},addressCountry:{type:["String"],ifMustNeed:!1,default:"",desc:"联系地址国家"},addressState:{type:["String"],ifMustNeed:!1,default:"",desc:"联系地址省份"},addressCity:{type:["String"],ifMustNeed:!1,default:"",desc:"联系地址城市"},addressStreet:{type:["String"],ifMustNeed:!1,default:"",desc:"联系地址街道"},addressPostalCode:{type:["String"],ifMustNeed:!1,default:"",desc:"联系地址邮政编码"},organization:{type:["String"],ifMustNeed:!1,default:"",desc:"公司"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"职位"},workFaxNumber:{type:["String"],ifMustNeed:!1,default:"",desc:"工作传真"},workPhoneNumber:{type:["String"],ifMustNeed:!1,default:"",desc:"工作电话"},hostNumber:{type:["String"],ifMustNeed:!1,default:"",desc:"公司电话"},email:{type:["String"],ifMustNeed:!1,default:"",desc:"电子邮件"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"网站"},workAddressCountry:{type:["String"],ifMustNeed:!1,default:"",desc:"工作地址国家"},workAddressState:{type:["String"],ifMustNeed:!1,default:"",desc:"工作地址省份"},workAddressCity:{type:["String"],ifMustNeed:!1,default:"",desc:"工作地址城市"},workAddressStreet:{type:["String"],ifMustNeed:!1,default:"",desc:"工作地址街道"},workAddressPostalCode:{type:["String"],ifMustNeed:!1,default:"",desc:"工作地址邮政编码"},homeFaxNumber:{type:["String"],ifMustNeed:!1,default:"",desc:"住宅传真"},homePhoneNumber:{type:["String"],ifMustNeed:!1,default:"",desc:"住宅电话"},homeAddressCountry:{type:["String"],ifMustNeed:!1,default:"",desc:"住宅地址国家"},homeAddressState:{type:["String"],ifMustNeed:!1,default:"",desc:"住宅地址省份"},homeAddressCity:{type:["String"],ifMustNeed:!1,default:"",desc:"住宅地址城市"},homeAddressStreet:{type:["String"],ifMustNeed:!1,default:"",desc:"住宅地址街道"},homeAddressPostalCode:{type:["String"],ifMustNeed:!1,default:"",desc:"住宅地址邮政编码"}}}}),{chooseVideo:{type:"async",event:"chooseVideo",agrs0Type:"Object",argsSize:1,params:{compressed:{type:["Boolean"],ifMustNeed:!1,default:!0,desc:"是否压缩所选择的视频文件"},maxDuration:{type:["Number"],ifMustNeed:!1,default:60,desc:"拍摄视频最长拍摄时间，单位秒"},camera:{type:["String"],ifMustNeed:!1,default:"back",desc:"默认拉起的是前置或者后置摄像头。部分 Android 手机下由于系统 ROM 不支持无法生效"},sourceType:{type:["Array"],ifMustNeed:!1,default:[],desc:"视频选择的来源"}}},getVideoInfo:{type:"async",event:"getVideoInfo",agrs0Type:"any",argsSize:1,params:{src:{type:["String"],ifMustNeed:!0,default:"",desc:"视频文件路径，可以是临时文件路径也可以是永久文件路径"}}},saveVideoToPhotosAlbum:{type:"async",event:"saveVideoToPhotosAlbum",agrs0Type:"Object",argsSize:1,params:{filePath:{type:["String"],ifMustNeed:!0,default:"",desc:"视频文件路径，可以是临时文件路径也可以是永久文件路径 (本地路径)"}}},chooseMedia:{type:"async",event:"chooseMedia",agrs0Type:"Object",argsSize:1,params:{count:{type:["Number"],ifMustNeed:!1,default:9,desc:"最多可以选择的文件个数"},mediaType:{type:["Array"],ifMustNeed:!1,default:[],desc:"文件类型"},sourceType:{type:["Array"],ifMustNeed:!1,default:[],desc:"图片和视频选择的来源"},sizeType:{type:["Array"],ifMustNeed:!1,default:[],desc:"仅对mediaType为 image 时有效，是否压缩所选文件"},maxDuration:{type:["Number"],ifMustNeed:!1,default:10,desc:"拍摄视频最长拍摄时间，单位秒。时间范围为 3s 至 60s 之间。不限制相册。"},camera:{type:["String"],ifMustNeed:!1,default:"back",desc:"默认拉起的是前置或者后置摄像头。部分 Android 手机下由于系统 ROM 不支持无法生效"}}},compressVideo:{type:"async",event:"compressVideo",agrs0Type:"Object",argsSize:1,params:{src:{type:["String"],ifMustNeed:!0,default:"",desc:"视频文件路径，可以是临时文件路径也可以是永久文件路径"},quality:{type:["String"],ifMustNeed:!0,default:"",desc:"压缩质量"},bitrate:{type:["Number"],ifMustNeed:!0,default:0,desc:"码率，单位 kbps"},fps:{type:["Number"],ifMustNeed:!0,default:0,desc:"帧率"},resolution:{type:["Number"],ifMustNeed:!0,default:0,desc:"相对于原视频的分辨率比例，取值范围(0, 1]"}}}}),{registerLocalNotify:{type:"async",event:"registerLocalNotify",argsSize:1,agrs0Type:"Object",needReturn:!1,params:{notifyid:{type:["String"],ifMustNeed:!0,default:"",desc:"notifyid"},title:{type:["String"],ifMustNeed:!0,default:"",desc:"标题"},subtitle:{type:["String"],ifMustNeed:!1,default:"",desc:"副标题"},body:{type:["String"],ifMustNeed:!1,default:"",desc:"body"},badge:{type:["Number"],ifMustNeed:!1,default:"",desc:"badge"},year:{type:["Number"],ifMustNeed:!1,default:"",desc:"year"},month:{type:["Number"],ifMustNeed:!1,default:"",desc:"month"},day:{type:["Number"],ifMustNeed:!1,default:"",desc:"day"},hour:{type:["Number"],ifMustNeed:!1,default:"",desc:"hour"},minute:{type:["Number"],ifMustNeed:!1,default:"",desc:"minute"},second:{type:["Number"],ifMustNeed:!1,default:"",desc:"second"},repeats:{type:["Boolean"],ifMustNeed:!1,default:"",desc:"second"},attachmenturl:{type:["String"],ifMustNeed:!1,default:"",desc:"attachmenturl"}}},checkLocalNotify:{type:"async",event:"checkLocalNotify",argsSize:1,agrs0Type:"Object",needReturn:!1,params:null},removeLocalNotify:{type:"async",event:"removeLocalNotify",argsSize:1,agrs0Type:"Object",needReturn:!1,params:{notifyid:{type:["String"],ifMustNeed:!0,default:"",desc:"notifyid"}}}}),xi=Array.isArray||function(e){return"Array"==I(e)},Oi=function(e,t,n){var r=_e(t);r in e?ze.f(e,r,b(0,n)):e[r]=n},Pi=me("species"),Li=function(e){return q>=51||!f((function(){var t=[];return(t.constructor={})[Pi]=function(){return{foo:1}},1!==t[e](Boolean).foo}))},Ei=Li("slice"),Ai=me("species"),Ci=u.Array,ji=Math.max;Ft({target:"Array",proto:!0,forced:!Ei},{slice:function(e,t){var n,r,i,o=A(this),a=bt(o),s=gt(e,a),c=gt(void 0===t?a:t,a);if(xi(o)&&(n=o.constructor,(Wn(n)&&(n===Ci||xi(n.prototype))||j(n)&&null===(n=n[Ai]))&&(n=void 0),n===Ci||void 0===n))return Xn(o,s,c);for(r=new(void 0===n?Ci:n)(ji(c-s,0)),i=0;s<c;s++,i++)s in o&&Oi(r,i,o[s]);return r.length=i,r}});var Vi=function(e,t,n){var r,i;return rn&&C(r=t.constructor)&&r!==n&&j(i=r.prototype)&&i!==n.prototype&&rn(e,i),e},Bi=M(1..valueOf),Ri=u.String,zi=function(e){if("Symbol"===Xt(e))throw TypeError("Cannot convert a Symbol value to a string");return Ri(e)},Fi="\t\n\v\f\r                　\u2028\u2029\ufeff",Di=M("".replace),Wi="["+Fi+"]",Ui=RegExp("^"+Wi+Wi+"*"),qi=RegExp(Wi+Wi+"*$"),Ji=function(e){return function(t){var n=zi(E(t));return 1&e&&(n=Di(n,Ui,"")),2&e&&(n=Di(n,qi,"")),n}},Gi={start:Ji(1),end:Ji(2),trim:Ji(3)},Hi=It.f,Qi=xe.f,$i=ze.f,Ki=Gi.trim,Xi="Number",Yi=u.Number,Zi=Yi.prototype,eo=u.TypeError,to=M("".slice),no=M("".charCodeAt),ro=function(e){var t=we(e,"number");return"bigint"==typeof t?t:io(t)},io=function(e){var t,n,r,i,o,a,s,c,u=we(e,"number");if(Q(u))throw eo("Cannot convert a Symbol value to a number");if("string"==typeof u&&u.length>2)if(u=Ki(u),43===(t=no(u,0))||45===t){if(88===(n=no(u,2))||120===n)return NaN}else if(48===t){switch(no(u,1)){case 66:case 98:r=2,i=49;break;case 79:case 111:r=8,i=55;break;default:return+u}for(a=(o=to(u,2)).length,s=0;s<a;s++)if((c=no(o,s))<48||c>i)return NaN;return parseInt(o,r)}return+u};if(Rt(Xi,!Yi(" 0o1")||!Yi("0b1")||Yi("+0x1"))){for(var oo,ao=function(e){var t=arguments.length<1?0:Yi(ro(e)),n=this;return R(Zi,n)&&f((function(){Bi(n)}))?Vi(Object(t),n,ao):t},so=d?Hi(Yi):"MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,EPSILON,MAX_SAFE_INTEGER,MIN_SAFE_INTEGER,isFinite,isInteger,isNaN,isSafeInteger,parseFloat,parseInt,fromString,range".split(","),co=0;so.length>co;co++)ue(Yi,oo=so[co])&&!ue(ao,oo)&&$i(ao,oo,Qi(Yi,oo));ao.prototype=Zi,Zi.constructor=ao,ft(u,Xi,ao)}var uo="undefined"!=typeof ArrayBuffer&&"undefined"!=typeof DataView,fo=u.RangeError,lo=function(e){if(void 0===e)return 0;var t=pt(e),n=mt(t);if(t!==n)throw fo("Wrong length or index");return n},po=u.Array,ho=Math.abs,yo=Math.pow,go=Math.floor,vo=Math.log,mo=Math.LN2,bo=function(e,t,n){var r,i,o,a=po(n),s=8*n-t-1,c=(1<<s)-1,u=c>>1,f=23===t?yo(2,-24)-yo(2,-77):0,d=e<0||0===e&&1/e<0?1:0,l=0;for((e=ho(e))!=e||e===1/0?(i=e!=e?1:0,r=c):(r=go(vo(e)/mo),e*(o=yo(2,-r))<1&&(r--,o*=2),(e+=r+u>=1?f/o:f*yo(2,1-u))*o>=2&&(r++,o/=2),r+u>=c?(i=0,r=c):r+u>=1?(i=(e*o-1)*yo(2,t),r+=u):(i=e*yo(2,u-1)*yo(2,t),r=0));t>=8;)a[l++]=255&i,i/=256,t-=8;for(r=r<<t|i,s+=t;s>0;)a[l++]=255&r,r/=256,s-=8;return a[--l]|=128*d,a},So=function(e,t){var n,r=e.length,i=8*r-t-1,o=(1<<i)-1,a=o>>1,s=i-7,c=r-1,u=e[c--],f=127&u;for(u>>=7;s>0;)f=256*f+e[c--],s-=8;for(n=f&(1<<-s)-1,f>>=-s,s+=t;s>0;)n=256*n+e[c--],s-=8;if(0===f)f=1-a;else{if(f===o)return n?NaN:u?-1/0:1/0;n+=yo(2,t),f-=a}return(u?-1:1)*n*yo(2,f-t)},wo=!f((function(){function e(){}return e.prototype.constructor=null,Object.getPrototypeOf(new e)!==e.prototype})),_o=$e("IE_PROTO"),ko=u.Object,Mo=ko.prototype,To=wo?ko.getPrototypeOf:function(e){var t=se(e);if(ue(t,_o))return t[_o];var n=t.constructor;return C(n)&&t instanceof n?n.prototype:t instanceof ko?Mo:null},No=u.Array,Io=Math.max,xo=function(e,t,n){for(var r=bt(e),i=gt(t,r),o=gt(void 0===n?r:n,r),a=No(Io(o-i,0)),s=0;i<o;i++,s++)Oi(a,s,e[i]);return a.length=s,a},Oo=It.f,Po=ze.f,Lo=ut.PROPER,Eo=ut.CONFIGURABLE,Ao=ot.get,Co=ot.set,jo="ArrayBuffer",Vo="DataView",Bo="Wrong index",Ro=u.ArrayBuffer,zo=Ro,Fo=zo&&zo.prototype,Do=u.DataView,Wo=Do&&Do.prototype,Uo=Object.prototype,qo=u.Array,Jo=u.RangeError,Go=M((function(e){for(var t=se(this),n=bt(t),r=arguments.length,i=gt(r>1?arguments[1]:void 0,n),o=r>2?arguments[2]:void 0,a=void 0===o?n:gt(o,n);a>i;)t[i++]=e;return t})),Ho=M([].reverse),Qo=bo,$o=So,Ko=function(e){return[255&e]},Xo=function(e){return[255&e,e>>8&255]},Yo=function(e){return[255&e,e>>8&255,e>>16&255,e>>24&255]},Zo=function(e){return e[3]<<24|e[2]<<16|e[1]<<8|e[0]},ea=function(e){return Qo(e,23,4)},ta=function(e){return Qo(e,52,8)},na=function(e,t){Po(e.prototype,t,{get:function(){return Ao(this)[t]}})},ra=function(e,t,n,r){var i=lo(n),o=Ao(e);if(i+t>o.byteLength)throw Jo(Bo);var a=Ao(o.buffer).bytes,s=i+o.byteOffset,c=xo(a,s,s+t);return r?c:Ho(c)},ia=function(e,t,n,r,i,o){var a=lo(n),s=Ao(e);if(a+t>s.byteLength)throw Jo(Bo);for(var c=Ao(s.buffer).bytes,u=a+s.byteOffset,f=r(+i),d=0;d<t;d++)c[u+d]=f[o?d:t-d-1]};if(uo){var oa=Lo&&Ro.name!==jo;if(f((function(){Ro(1)}))&&f((function(){new Ro(-1)}))&&!f((function(){return new Ro,new Ro(1.5),new Ro(NaN),oa&&!Eo})))oa&&Eo&&Fe(Ro,"name",jo);else{(zo=function(e){return dn(this,Fo),new Ro(lo(e))}).prototype=Fo;for(var aa,sa=Oo(Ro),ca=0;sa.length>ca;)(aa=sa[ca++])in zo||Fe(zo,aa,Ro[aa]);Fo.constructor=zo}rn&&To(Wo)!==Uo&&rn(Wo,Uo);var ua=new Do(new zo(2)),fa=M(Wo.setInt8);ua.setInt8(0,2147483648),ua.setInt8(1,2147483649),!ua.getInt8(0)&&ua.getInt8(1)||en(Wo,{setInt8:function(e,t){fa(this,e,t<<24>>24)},setUint8:function(e,t){fa(this,e,t<<24>>24)}},{unsafe:!0})}else Fo=(zo=function(e){dn(this,Fo);var t=lo(e);Co(this,{bytes:Go(qo(t),0),byteLength:t}),d||(this.byteLength=t)}).prototype,Wo=(Do=function(e,t,n){dn(this,Wo),dn(e,Fo);var r=Ao(e).byteLength,i=pt(t);if(i<0||i>r)throw Jo("Wrong offset");if(i+(n=void 0===n?r-i:mt(n))>r)throw Jo("Wrong length");Co(this,{buffer:e,byteLength:n,byteOffset:i}),d||(this.buffer=e,this.byteLength=n,this.byteOffset=i)}).prototype,d&&(na(zo,"byteLength"),na(Do,"buffer"),na(Do,"byteLength"),na(Do,"byteOffset")),en(Wo,{getInt8:function(e){return ra(this,1,e)[0]<<24>>24},getUint8:function(e){return ra(this,1,e)[0]},getInt16:function(e){var t=ra(this,2,e,arguments.length>1?arguments[1]:void 0);return(t[1]<<8|t[0])<<16>>16},getUint16:function(e){var t=ra(this,2,e,arguments.length>1?arguments[1]:void 0);return t[1]<<8|t[0]},getInt32:function(e){return Zo(ra(this,4,e,arguments.length>1?arguments[1]:void 0))},getUint32:function(e){return Zo(ra(this,4,e,arguments.length>1?arguments[1]:void 0))>>>0},getFloat32:function(e){return $o(ra(this,4,e,arguments.length>1?arguments[1]:void 0),23)},getFloat64:function(e){return $o(ra(this,8,e,arguments.length>1?arguments[1]:void 0),52)},setInt8:function(e,t){ia(this,1,e,Ko,t)},setUint8:function(e,t){ia(this,1,e,Ko,t)},setInt16:function(e,t){ia(this,2,e,Xo,t,arguments.length>2?arguments[2]:void 0)},setUint16:function(e,t){ia(this,2,e,Xo,t,arguments.length>2?arguments[2]:void 0)},setInt32:function(e,t){ia(this,4,e,Yo,t,arguments.length>2?arguments[2]:void 0)},setUint32:function(e,t){ia(this,4,e,Yo,t,arguments.length>2?arguments[2]:void 0)},setFloat32:function(e,t){ia(this,4,e,ea,t,arguments.length>2?arguments[2]:void 0)},setFloat64:function(e,t){ia(this,8,e,ta,t,arguments.length>2?arguments[2]:void 0)}});sn(zo,jo),sn(Do,Vo);var da={ArrayBuffer:zo,DataView:Do},la="ArrayBuffer",pa=da.ArrayBuffer,ha=u.ArrayBuffer;Ft({global:!0,forced:ha!==pa},{ArrayBuffer:pa}),un(la);var ya=da.ArrayBuffer,ga=da.DataView,va=ga.prototype,ma=M(ya.prototype.slice),ba=M(va.getUint8),Sa=M(va.setUint8),wa=f((function(){return!new ya(2).slice(1,void 0).byteLength}));Ft({target:"ArrayBuffer",proto:!0,unsafe:!0,forced:wa},{slice:function(e,t){if(ma&&void 0===t)return ma(Ee(this),e);for(var n=Ee(this).byteLength,r=gt(e,n),i=gt(void 0===t?n:t,n),o=new(Jn(this,ya))(mt(i-r)),a=new ga(this),s=new ga(o),c=0;r<i;)Sa(s,c++,ba(a,r++));return o}});var _a={CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0},ka=Te("span").classList,Ma=ka&&ka.constructor&&ka.constructor.prototype,Ta=Ma===Object.prototype?void 0:Ma,Na=me("species"),Ia=u.Array,xa=function(e,t){return new(function(e){var t;return xi(e)&&(t=e.constructor,(Wn(t)&&(t===Ia||xi(t.prototype))||j(t)&&null===(t=t[Na]))&&(t=void 0)),void 0===t?Ia:t}(e))(0===t?0:t)},Oa=M([].push),Pa=function(e){var t=1==e,n=2==e,r=3==e,i=4==e,o=6==e,a=7==e,s=5==e||o;return function(c,u,f,d){for(var l,p,h=se(c),y=P(h),g=pn(u,f),v=bt(y),m=0,b=d||xa,S=t?b(c,v):n||a?b(c,0):void 0;v>m;m++)if((s||m in y)&&(p=g(l=y[m],m,h),e))if(t)S[m]=p;else if(p)switch(e){case 3:return!0;case 5:return l;case 6:return m;case 2:Oa(S,l)}else switch(e){case 4:return!1;case 7:Oa(S,l)}return o?-1:r||i?i:S}},La={forEach:Pa(0),map:Pa(1),filter:Pa(2),some:Pa(3),every:Pa(4),find:Pa(5),findIndex:Pa(6),filterReject:Pa(7)},Ea=La.forEach,Aa=Dt("forEach")?[].forEach:function(e){return Ea(this,e,arguments.length>1?arguments[1]:void 0)},Ca=function(e){if(e&&e.forEach!==Aa)try{Fe(e,"forEach",Aa)}catch(t){e.forEach=Aa}};for(var ja in _a)_a[ja]&&Ca(u[ja]&&u[ja].prototype);Ca(Ta);var Va=Object.keys||function(e){return Mt(e,Tt)},Ba=f((function(){Va(1)}));Ft({target:"Object",stat:!0,forced:Ba},{keys:function(e){return Va(se(e))}});var Ra=Object.prototype.toString;function za(e){return Ra.call(e).slice(8,-1)}function Fa(e){return"Number"===za(e)}function Da(e){return"Object"===za(e)}function Wa(e){return"function"==typeof e}function Ua(e,t){var n=e.params,r=za(t[0]),i=e.argsSize,o=(e.agrs0Type,e.event,{});if(i>1||1===i&&"Object"!==r)for(var a=Object.keys(n),s=0;s<i;s++)o[a[s]]=t[s];else 1===i&&"Object"===r&&(o=t[0]);return e.params&&Object.keys(n).forEach((function(e){n[e].ifMustNeed;var t=za(o[e]);e in o&&"any"!==n[e].type&&n[e].type.indexOf(t)})),o}function qa(e,t){var n={};return e&&Object.keys(e).forEach((function(r){"boolean"==typeof t[r]?n[r]=t[r]:n[r]=t[r]||e[r].default})),n}var Ja,Ga=d&&!Oe?Object.defineProperties:function(e,t){Ee(e);for(var n,r=A(t),i=Va(t),o=i.length,a=0;o>a;)ze.f(e,n=i[a++],r[n]);return e},Ha={f:Ga},Qa=$e("IE_PROTO"),$a=function(){},Ka=function(e){return"<script>"+e+"</"+"script>"},Xa=function(e){e.write(Ka("")),e.close();var t=e.parentWindow.Object;return e=null,t},Ya=function(){try{Ja=new ActiveXObject("htmlfile")}catch(e){}var e,t;Ya="undefined"!=typeof document?document.domain&&Ja?Xa(Ja):((t=Te("iframe")).style.display="none",Kn.appendChild(t),t.src=String("javascript:"),(e=t.contentWindow.document).open(),e.write(Ka("document.F=Object")),e.close(),e.F):Xa(Ja);for(var n=Tt.length;n--;)delete Ya.prototype[Tt[n]];return Ya()};Ke[Qa]=!0;var Za=Object.create||function(e,t){var n;return null!==e?($a.prototype=Ee(e),n=new $a,$a.prototype=null,n[Qa]=e):n=Ya(),void 0===t?n:Ha.f(n,t)},es=me("unscopables"),ts=Array.prototype;null==ts[es]&&ze.f(ts,es,{configurable:!0,value:Za(null)});var ns,rs,is,os=function(e){ts[es][e]=!0},as=me("iterator"),ss=!1;[].keys&&("next"in(is=[].keys())?(rs=To(To(is)))!==Object.prototype&&(ns=rs):ss=!0);var cs=null==ns||f((function(){var e={};return ns[as].call(e)!==e}));cs&&(ns={}),C(ns[as])||ft(ns,as,(function(){return this}));var us={IteratorPrototype:ns,BUGGY_SAFARI_ITERATORS:ss},fs=us.IteratorPrototype,ds=function(){return this},ls=ut.PROPER,ps=ut.CONFIGURABLE,hs=us.IteratorPrototype,ys=us.BUGGY_SAFARI_ITERATORS,gs=me("iterator"),vs="keys",ms="values",bs="entries",Ss=function(){return this},ws=function(e,t,n,r,i,o,a){!function(e,t,n,r){var i=t+" Iterator";e.prototype=Za(fs,{next:b(+!r,n)}),sn(e,i,!1),hn[i]=ds}(n,t,r);var s,c,u,f=function(e){if(e===i&&g)return g;if(!ys&&e in p)return p[e];switch(e){case vs:case ms:case bs:return function(){return new n(this,e)}}return function(){return new n(this)}},d=t+" Iterator",l=!1,p=e.prototype,y=p[gs]||p["@@iterator"]||i&&p[i],g=!ys&&y||f(i),v="Array"==t&&p.entries||y;if(v&&(s=To(v.call(new e)))!==Object.prototype&&s.next&&(To(s)!==hs&&(rn?rn(s,hs):C(s[gs])||ft(s,gs,Ss)),sn(s,d,!0)),ls&&i==ms&&y&&y.name!==ms&&(ps?Fe(p,"name",ms):(l=!0,g=function(){return h(y,this)})),i)if(c={values:f(ms),keys:o?g:f(vs),entries:f(bs)},a)for(u in c)(ys||l||!(u in p))&&ft(p,u,c[u]);else Ft({target:t,proto:!0,forced:ys||l},c);return p[gs]!==g&&ft(p,gs,g,{name:i}),hn[t]=g,c},_s=ze.f,ks="Array Iterator",Ms=ot.set,Ts=ot.getterFor(ks),Ns=ws(Array,"Array",(function(e,t){Ms(this,{type:ks,target:A(e),index:0,kind:t})}),(function(){var e=Ts(this),t=e.target,n=e.kind,r=e.index++;return!t||r>=t.length?(e.target=void 0,{value:void 0,done:!0}):"keys"==n?{value:r,done:!1}:"values"==n?{value:t[r],done:!1}:{value:[r,t[r]],done:!1}}),"values"),Is=hn.Arguments=hn.Array;if(os("keys"),os("values"),os("entries"),d&&"values"!==Is.name)try{_s(Is,"name",{value:"values"})}catch(e){}var xs=M("".charAt),Os=M("".charCodeAt),Ps=M("".slice),Ls=function(e){return function(t,n){var r,i,o=zi(E(t)),a=pt(n),s=o.length;return a<0||a>=s?e?"":void 0:(r=Os(o,a))<55296||r>56319||a+1===s||(i=Os(o,a+1))<56320||i>57343?e?xs(o,a):r:e?Ps(o,a,a+2):i-56320+(r-55296<<10)+65536}},Es={codeAt:Ls(!1),charAt:Ls(!0)},As=Es.charAt,Cs="String Iterator",js=ot.set,Vs=ot.getterFor(Cs);ws(String,"String",(function(e){js(this,{type:Cs,string:zi(e),index:0})}),(function(){var e,t=Vs(this),n=t.string,r=t.index;return r>=n.length?{value:void 0,done:!0}:(e=As(n,r),t.index+=e.length,{value:e,done:!1})}));var Bs=It.f,Rs="object"==typeof window&&window&&Object.getOwnPropertyNames?Object.getOwnPropertyNames(window):[],zs={f:function(e){return Rs&&"Window"==I(e)?function(e){try{return Bs(e)}catch(e){return xo(Rs)}}(e):Bs(A(e))}},Fs=f((function(){if("function"==typeof ArrayBuffer){var e=new ArrayBuffer(8);Object.isExtensible(e)&&Object.defineProperty(e,"a",{value:8})}})),Ds=Object.isExtensible,Ws=f((function(){Ds(1)}))||Fs?function(e){return!!j(e)&&((!Fs||"ArrayBuffer"!=I(e))&&(!Ds||Ds(e)))}:Ds,Us=!f((function(){return Object.isExtensible(Object.preventExtensions({}))})),qs=o((function(e){var t=ze.f,n=!1,r=pe("meta"),i=0,o=function(e){t(e,r,{value:{objectID:"O"+i++,weakData:{}}})},a=e.exports={enable:function(){a.enable=function(){},n=!0;var e=It.f,t=M([].splice),i={};i[r]=1,e(i).length&&(It.f=function(n){for(var i=e(n),o=0,a=i.length;o<a;o++)if(i[o]===r){t(i,o,1);break}return i},Ft({target:"Object",stat:!0,forced:!0},{getOwnPropertyNames:zs.f}))},fastKey:function(e,t){if(!j(e))return"symbol"==typeof e?e:("string"==typeof e?"S":"P")+e;if(!ue(e,r)){if(!Ws(e))return"F";if(!t)return"E";o(e)}return e[r].objectID},getWeakData:function(e,t){if(!ue(e,r)){if(!Ws(e))return!0;if(!t)return!1;o(e)}return e[r].weakData},onFreeze:function(e){return Us&&n&&Ws(e)&&!ue(e,r)&&o(e),e}};Ke[r]=!0})),Js=function(e,t,n){var r=-1!==e.indexOf("Map"),i=-1!==e.indexOf("Weak"),o=r?"set":"add",a=u[e],s=a&&a.prototype,c=a,d={},l=function(e){var t=M(s[e]);ft(s,e,"add"==e?function(e){return t(this,0===e?0:e),this}:"delete"==e?function(e){return!(i&&!j(e))&&t(this,0===e?0:e)}:"get"==e?function(e){return i&&!j(e)?void 0:t(this,0===e?0:e)}:"has"==e?function(e){return!(i&&!j(e))&&t(this,0===e?0:e)}:function(e,n){return t(this,0===e?0:e,n),this})};if(Rt(e,!C(a)||!(i||s.forEach&&!f((function(){(new a).entries().next()})))))c=n.getConstructor(t,e,r,o),qs.enable();else if(Rt(e,!0)){var p=new c,h=p[o](i?{}:-0,1)!=p,y=f((function(){p.has(1)})),g=On((function(e){new a(e)})),v=!i&&f((function(){for(var e=new a,t=5;t--;)e[o](t,t);return!e.has(-0)}));g||((c=t((function(e,t){dn(e,s);var n=Vi(new a,e,c);return null!=t&&Mn(t,n[o],{that:n,AS_ENTRIES:r}),n}))).prototype=s,s.constructor=c),(y||v)&&(l("delete"),l("has"),r&&l("get")),(v||h)&&l(o),i&&s.clear&&delete s.clear}return d[e]=c,Ft({global:!0,forced:c!=a},d),sn(c,e),i||n.setStrong(c,e,r),c},Gs=qs.getWeakData,Hs=ot.set,Qs=ot.getterFor,$s=La.find,Ks=La.findIndex,Xs=M([].splice),Ys=0,Zs=function(e){return e.frozen||(e.frozen=new ec)},ec=function(){this.entries=[]},tc=function(e,t){return $s(e.entries,(function(e){return e[0]===t}))};ec.prototype={get:function(e){var t=tc(this,e);if(t)return t[1]},has:function(e){return!!tc(this,e)},set:function(e,t){var n=tc(this,e);n?n[1]=t:this.entries.push([e,t])},delete:function(e){var t=Ks(this.entries,(function(t){return t[0]===e}));return~t&&Xs(this.entries,t,1),!!~t}};var nc,rc={getConstructor:function(e,t,n,r){var i=e((function(e,i){dn(e,o),Hs(e,{type:t,id:Ys++,frozen:void 0}),null!=i&&Mn(i,e[r],{that:e,AS_ENTRIES:n})})),o=i.prototype,a=Qs(t),s=function(e,t,n){var r=a(e),i=Gs(Ee(t),!0);return!0===i?Zs(r).set(t,n):i[r.id]=n,e};return en(o,{delete:function(e){var t=a(this);if(!j(e))return!1;var n=Gs(e);return!0===n?Zs(t).delete(e):n&&ue(n,t.id)&&delete n[t.id]},has:function(e){var t=a(this);if(!j(e))return!1;var n=Gs(e);return!0===n?Zs(t).has(e):n&&ue(n,t.id)}}),en(o,n?{get:function(e){var t=a(this);if(j(e)){var n=Gs(e);return!0===n?Zs(t).get(e):n?n[t.id]:void 0}},set:function(e,t){return s(this,e,t)}}:{add:function(e){return s(this,e,!0)}}),i}},ic=ot.enforce,oc=!u.ActiveXObject&&"ActiveXObject"in u,ac=function(e){return function(){return e(this,arguments.length?arguments[0]:void 0)}},sc=Js("WeakMap",ac,rc);if(He&&oc){nc=rc.getConstructor(ac,"WeakMap",!0),qs.enable();var cc=sc.prototype,uc=M(cc.delete),fc=M(cc.has),dc=M(cc.get),lc=M(cc.set);en(cc,{delete:function(e){if(j(e)&&!Ws(e)){var t=ic(this);return t.frozen||(t.frozen=new nc),uc(this,e)||t.frozen.delete(e)}return uc(this,e)},has:function(e){if(j(e)&&!Ws(e)){var t=ic(this);return t.frozen||(t.frozen=new nc),fc(this,e)||t.frozen.has(e)}return fc(this,e)},get:function(e){if(j(e)&&!Ws(e)){var t=ic(this);return t.frozen||(t.frozen=new nc),fc(this,e)?dc(this,e):t.frozen.get(e)}return dc(this,e)},set:function(e,t){if(j(e)&&!Ws(e)){var n=ic(this);n.frozen||(n.frozen=new nc),fc(this,e)?lc(this,e,t):n.frozen.set(e,t)}else lc(this,e,t);return this}})}var pc=me("iterator"),hc=me("toStringTag"),yc=Ns.values,gc=function(e,t){if(e){if(e[pc]!==yc)try{Fe(e,pc,yc)}catch(t){e[pc]=yc}if(e[hc]||Fe(e,hc,t),_a[t])for(var n in Ns)if(e[n]!==Ns[n])try{Fe(e,n,Ns[n])}catch(t){e[n]=Ns[n]}}};for(var vc in _a)gc(u[vc]&&u[vc].prototype,vc);gc(Ta,"DOMTokenList");var mc=me("isConcatSpreadable"),bc=9007199254740991,Sc="Maximum allowed index exceeded",wc=u.TypeError,_c=q>=51||!f((function(){var e=[];return e[mc]=!1,e.concat()[0]!==e})),kc=Li("concat"),Mc=function(e){if(!j(e))return!1;var t=e[mc];return void 0!==t?!!t:xi(e)};Ft({target:"Array",proto:!0,forced:!_c||!kc},{concat:function(e){var t,n,r,i,o,a=se(this),s=xa(a,0),c=0;for(t=-1,r=arguments.length;t<r;t++)if(Mc(o=-1===t?a:arguments[t])){if(c+(i=bt(o))>bc)throw wc(Sc);for(n=0;n<i;n++,c++)n in o&&Oi(s,c,o[n])}else{if(c>=bc)throw wc(Sc);Oi(s,c++,o)}return s.length=c,s}});var Tc=o((function(e,t){!function(t){var n=Object.hasOwnProperty,r=Array.isArray?Array.isArray:function(e){return"[object Array]"===Object.prototype.toString.call(e)},i="object"==typeof process&&"function"==typeof process.nextTick,o="function"==typeof Symbol,a="object"==typeof Reflect,s="function"==typeof setImmediate?setImmediate:setTimeout,c=o?a&&"function"==typeof Reflect.ownKeys?Reflect.ownKeys:function(e){var t=Object.getOwnPropertyNames(e);return t.push.apply(t,Object.getOwnPropertySymbols(e)),t}:Object.keys;function u(){this._events={},this._conf&&f.call(this,this._conf)}function f(e){e&&(this._conf=e,e.delimiter&&(this.delimiter=e.delimiter),e.maxListeners!==t&&(this._maxListeners=e.maxListeners),e.wildcard&&(this.wildcard=e.wildcard),e.newListener&&(this._newListener=e.newListener),e.removeListener&&(this._removeListener=e.removeListener),e.verboseMemoryLeak&&(this.verboseMemoryLeak=e.verboseMemoryLeak),e.ignoreErrors&&(this.ignoreErrors=e.ignoreErrors),this.wildcard&&(this.listenerTree={}))}function d(e,t){var n="(node) warning: possible EventEmitter memory leak detected. "+e+" listeners added. Use emitter.setMaxListeners() to increase limit.";if(this.verboseMemoryLeak&&(n+=" Event name: "+t+"."),"undefined"!=typeof process&&process.emitWarning){var r=new Error(n);r.name="MaxListenersExceededWarning",r.emitter=this,r.count=e,process.emitWarning(r)}else console.trace}var l=function(e,t,n){var r=arguments.length;switch(r){case 0:return[];case 1:return[e];case 2:return[e,t];case 3:return[e,t,n];default:for(var i=new Array(r);r--;)i[r]=arguments[r];return i}};function p(e,n){for(var r={},i=e.length,o=n?value.length:0,a=0;a<i;a++)r[e[a]]=a<o?n[a]:t;return r}function h(e,t,n){var r,i;if(this._emitter=e,this._target=t,this._listeners={},this._listenersCount=0,(n.on||n.off)&&(r=n.on,i=n.off),t.addEventListener?(r=t.addEventListener,i=t.removeEventListener):t.addListener?(r=t.addListener,i=t.removeListener):t.on&&(r=t.on,i=t.off),!r&&!i)throw Error("target does not implement any known event API");if("function"!=typeof r)throw TypeError("on method must be a function");if("function"!=typeof i)throw TypeError("off method must be a function");this._on=r,this._off=i;var o=e._observers;o?o.push(this):e._observers=[this]}function y(e,r,i,o){var a=Object.assign({},r);if(!e)return a;if("object"!=typeof e)throw TypeError("options must be an object");var s,c,u,f=Object.keys(e),d=f.length;function l(e){throw Error('Invalid "'+s+'" option value'+(e?". Reason: "+e:""))}for(var p=0;p<d;p++){if(s=f[p],!o&&!n.call(r,s))throw Error('Unknown "'+s+'" option');(c=e[s])!==t&&(u=i[s],a[s]=u?u(c,l):c)}return a}function g(e,t){return"function"==typeof e&&e.hasOwnProperty("prototype")||t("value must be a constructor"),e}function v(e){var t="value must be type of "+e.join("|"),n=e.length,r=e[0],i=e[1];return 1===n?function(e,n){if(typeof e===r)return e;n(t)}:2===n?function(e,n){var o=typeof e;if(o===r||o===i)return e;n(t)}:function(r,i){for(var o=typeof r,a=n;a-- >0;)if(o===e[a])return r;i(t)}}Object.assign(h.prototype,{subscribe:function(e,t,n){var r=this,i=this._target,o=this._emitter,a=this._listeners,s=function(){var r=l.apply(null,arguments),a={data:r,name:t,original:e};if(n){var s=n.call(i,a);!1!==s&&o.emit.apply(o,[a.name].concat(r))}else o.emit.apply(o,[t].concat(r))};if(a[e])throw Error("Event '"+e+"' is already listening");this._listenersCount++,o._newListener&&o._removeListener&&!r._onNewListener?(this._onNewListener=function(n){n===t&&null===a[e]&&(a[e]=s,r._on.call(i,e,s))},o.on("newListener",this._onNewListener),this._onRemoveListener=function(n){n===t&&!o.hasListeners(n)&&a[e]&&(a[e]=null,r._off.call(i,e,s))},a[e]=null,o.on("removeListener",this._onRemoveListener)):(a[e]=s,r._on.call(i,e,s))},unsubscribe:function(e){var t,n,r,i=this,o=this._listeners,a=this._emitter,s=this._off,u=this._target;if(e&&"string"!=typeof e)throw TypeError("event must be a string");function f(){i._onNewListener&&(a.off("newListener",i._onNewListener),a.off("removeListener",i._onRemoveListener),i._onNewListener=null,i._onRemoveListener=null);var e=w.call(a,i);a._observers.splice(e,1)}if(e){if(!(t=o[e]))return;s.call(u,e,t),delete o[e],--this._listenersCount||f()}else{for(r=(n=c(o)).length;r-- >0;)e=n[r],s.call(u,e,o[e]);this._listeners={},this._listenersCount=0,f()}}});var m=v(["function"]),b=v(["object","function"]);function S(e,t,n){var r,i,o,a=0,s=new e((function(c,u,f){function d(){i&&(i=null),a&&(clearTimeout(a),a=0)}n=y(n,{timeout:0,overload:!1},{timeout:function(e,t){return("number"!=typeof(e*=1)||e<0||!Number.isFinite(e))&&t("timeout must be a positive number"),e}}),r=!n.overload&&"function"==typeof e.prototype.cancel&&"function"==typeof f;var l=function(e){d(),c(e)},p=function(e){d(),u(e)};r?t(l,p,f):(i=[function(e){p(e||Error("canceled"))}],t(l,p,(function(e){if(o)throw Error("Unable to subscribe on cancel event asynchronously");if("function"!=typeof e)throw TypeError("onCancel callback must be a function");i.push(e)})),o=!0),n.timeout>0&&(a=setTimeout((function(){var e=Error("timeout");e.code="ETIMEDOUT",a=0,s.cancel(e),u(e)}),n.timeout))}));return r||(s.cancel=function(e){if(i){for(var t=i.length,n=1;n<t;n++)i[n](e);i[0](e),i=null}}),s}function w(e){var t=this._observers;if(!t)return-1;for(var n=t.length,r=0;r<n;r++)if(t[r]._target===e)return r;return-1}function _(e,t,n,r,i){if(!n)return null;if(0===r){var o=typeof t;if("string"===o){var a,s,u=0,f=0,d=this.delimiter,l=d.length;if(-1!==(s=t.indexOf(d))){a=new Array(5);do{a[u++]=t.slice(f,s),f=s+l}while(-1!==(s=t.indexOf(d,f)));a[u++]=t.slice(f),t=a,i=u}else t=[t],i=1}else"object"===o?i=t.length:(t=[t],i=1)}var p,h,y,g,v,m,b,S=null,w=t[r],k=t[r+1];if(r===i&&n._listeners)return"function"==typeof n._listeners?(e&&e.push(n._listeners),[n]):(e&&e.push.apply(e,n._listeners),[n]);if("*"===w){for(s=(m=c(n)).length;s-- >0;)"_listeners"!==(p=m[s])&&(b=_(e,t,n[p],r+1,i))&&(S?S.push.apply(S,b):S=b);return S}if("**"===w){for((v=r+1===i||r+2===i&&"*"===k)&&n._listeners&&(S=_(e,t,n,i,i)),s=(m=c(n)).length;s-- >0;)"_listeners"!==(p=m[s])&&("*"===p||"**"===p?(n[p]._listeners&&!v&&(b=_(e,t,n[p],i,i))&&(S?S.push.apply(S,b):S=b),b=_(e,t,n[p],r,i)):b=_(e,t,n[p],p===k?r+2:r,i),b&&(S?S.push.apply(S,b):S=b));return S}if(n[w]&&(S=_(e,t,n[w],r+1,i)),(h=n["*"])&&_(e,t,h,r+1,i),y=n["**"])if(r<i)for(y._listeners&&_(e,t,y,i,i),s=(m=c(y)).length;s-- >0;)"_listeners"!==(p=m[s])&&(p===k?_(e,t,y[p],r+2,i):p===w?_(e,t,y[p],r+1,i):((g={})[p]=y[p],_(e,t,{"**":g},r+1,i)));else y._listeners?_(e,t,y,i,i):y["*"]&&y["*"]._listeners&&_(e,t,y["*"],i,i);return S}function k(e,t,n){var r,i,o=0,a=0,s=this.delimiter,c=s.length;if("string"==typeof e)if(-1!==(r=e.indexOf(s))){i=new Array(5);do{i[o++]=e.slice(a,r),a=r+c}while(-1!==(r=e.indexOf(s,a)));i[o++]=e.slice(a)}else i=[e],o=1;else i=e,o=e.length;if(o>1)for(r=0;r+1<o;r++)if("**"===i[r]&&"**"===i[r+1])return;var u,f=this.listenerTree;for(r=0;r<o;r++)if(f=f[u=i[r]]||(f[u]={}),r===o-1)return f._listeners?("function"==typeof f._listeners&&(f._listeners=[f._listeners]),n?f._listeners.unshift(t):f._listeners.push(t),!f._listeners.warned&&this._maxListeners>0&&f._listeners.length>this._maxListeners&&(f._listeners.warned=!0,d.call(this,f._listeners.length,u))):f._listeners=t,!0;return!0}function M(e,t,n,r){for(var i,o,a,s,u=c(e),f=u.length,d=e._listeners;f-- >0;)i=e[o=u[f]],a="_listeners"===o?n:n?n.concat(o):[o],s=r||"symbol"==typeof o,d&&t.push(s?a:a.join(this.delimiter)),"object"==typeof i&&M.call(this,i,t,a,s);return t}function T(e){for(var t,n,r,i=c(e),o=i.length;o-- >0;)(t=e[n=i[o]])&&(r=!0,"_listeners"===n||T(t)||delete e[n]);return r}function N(e,t,n){this.emitter=e,this.event=t,this.listener=n}function I(e,n,r){if(!0===r)a=!0;else if(!1===r)o=!0;else{if(!r||"object"!=typeof r)throw TypeError("options should be an object or true");var o=r.async,a=r.promisify,c=r.nextTick,u=r.objectify}if(o||c||a){var f=n,d=n._origin||n;if(c&&!i)throw Error("process.nextTick is not supported");a===t&&(a="AsyncFunction"===n.constructor.name),n=function(){var e=arguments,t=this,n=this.event;return a?c?Promise.resolve():new Promise((function(e){s(e)})).then((function(){return t.event=n,f.apply(t,e)})):(c?process.nextTick:s)((function(){t.event=n,f.apply(t,e)}))},n._async=!0,n._origin=d}return[n,u?new N(this,e,n):this]}function x(e){this._events={},this._newListener=!1,this._removeListener=!1,this.verboseMemoryLeak=!1,f.call(this,e)}N.prototype.off=function(){return this.emitter.off(this.event,this.listener),this},x.EventEmitter2=x,x.prototype.listenTo=function(e,n,i){if("object"!=typeof e)throw TypeError("target musts be an object");var o=this;function a(t){if("object"!=typeof t)throw TypeError("events must be an object");var n,r=i.reducers,a=w.call(o,e);n=-1===a?new h(o,e,i):o._observers[a];for(var s,u=c(t),f=u.length,d="function"==typeof r,l=0;l<f;l++)s=u[l],n.subscribe(s,t[s]||s,d?r:r&&r[s])}return i=y(i,{on:t,off:t,reducers:t},{on:m,off:m,reducers:b}),r(n)?a(p(n)):a("string"==typeof n?p(n.split(/\s+/)):n),this},x.prototype.stopListeningTo=function(e,t){var n=this._observers;if(!n)return!1;var r,i=n.length,o=!1;if(e&&"object"!=typeof e)throw TypeError("target should be an object");for(;i-- >0;)r=n[i],e&&r._target!==e||(r.unsubscribe(t),o=!0);return o},x.prototype.delimiter=".",x.prototype.setMaxListeners=function(e){e!==t&&(this._maxListeners=e,this._conf||(this._conf={}),this._conf.maxListeners=e)},x.prototype.getMaxListeners=function(){return this._maxListeners},x.prototype.event="",x.prototype.once=function(e,t,n){return this._once(e,t,!1,n)},x.prototype.prependOnceListener=function(e,t,n){return this._once(e,t,!0,n)},x.prototype._once=function(e,t,n,r){return this._many(e,1,t,n,r)},x.prototype.many=function(e,t,n,r){return this._many(e,t,n,!1,r)},x.prototype.prependMany=function(e,t,n,r){return this._many(e,t,n,!0,r)},x.prototype._many=function(e,t,n,r,i){var o=this;if("function"!=typeof n)throw new Error("many only accepts instances of Function");function a(){return 0==--t&&o.off(e,a),n.apply(this,arguments)}return a._origin=n,this._on(e,a,r,i)},x.prototype.emit=function(){if(!this._events&&!this._all)return!1;this._events||u.call(this);var e,t,n,r,i,a,s=arguments[0],c=this.wildcard;if("newListener"===s&&!this._newListener&&!this._events.newListener)return!1;if(c&&(e=s,"newListener"!==s&&"removeListener"!==s&&"object"==typeof s)){if(n=s.length,o)for(r=0;r<n;r++)if("symbol"==typeof s[r]){a=!0;break}a||(s=s.join(this.delimiter))}var f,d=arguments.length;if(this._all&&this._all.length)for(r=0,n=(f=this._all.slice()).length;r<n;r++)switch(this.event=s,d){case 1:f[r].call(this,s);break;case 2:f[r].call(this,s,arguments[1]);break;case 3:f[r].call(this,s,arguments[1],arguments[2]);break;default:f[r].apply(this,arguments)}if(c)f=[],_.call(this,f,e,this.listenerTree,0,n);else{if("function"==typeof(f=this._events[s])){switch(this.event=s,d){case 1:f.call(this);break;case 2:f.call(this,arguments[1]);break;case 3:f.call(this,arguments[1],arguments[2]);break;default:for(t=new Array(d-1),i=1;i<d;i++)t[i-1]=arguments[i];f.apply(this,t)}return!0}f&&(f=f.slice())}if(f&&f.length){if(d>3)for(t=new Array(d-1),i=1;i<d;i++)t[i-1]=arguments[i];for(r=0,n=f.length;r<n;r++)switch(this.event=s,d){case 1:f[r].call(this);break;case 2:f[r].call(this,arguments[1]);break;case 3:f[r].call(this,arguments[1],arguments[2]);break;default:f[r].apply(this,t)}return!0}if(!this.ignoreErrors&&!this._all&&"error"===s)throw arguments[1]instanceof Error?arguments[1]:new Error("Uncaught, unspecified 'error' event.");return!!this._all},x.prototype.emitAsync=function(){if(!this._events&&!this._all)return!1;this._events||u.call(this);var e,t,n,r,i,a,s=arguments[0],c=this.wildcard;if("newListener"===s&&!this._newListener&&!this._events.newListener)return Promise.resolve([!1]);if(c&&(e=s,"newListener"!==s&&"removeListener"!==s&&"object"==typeof s)){if(r=s.length,o)for(i=0;i<r;i++)if("symbol"==typeof s[i]){t=!0;break}t||(s=s.join(this.delimiter))}var f,d=[],l=arguments.length;if(this._all)for(i=0,r=this._all.length;i<r;i++)switch(this.event=s,l){case 1:d.push(this._all[i].call(this,s));break;case 2:d.push(this._all[i].call(this,s,arguments[1]));break;case 3:d.push(this._all[i].call(this,s,arguments[1],arguments[2]));break;default:d.push(this._all[i].apply(this,arguments))}if(c?(f=[],_.call(this,f,e,this.listenerTree,0)):f=this._events[s],"function"==typeof f)switch(this.event=s,l){case 1:d.push(f.call(this));break;case 2:d.push(f.call(this,arguments[1]));break;case 3:d.push(f.call(this,arguments[1],arguments[2]));break;default:for(n=new Array(l-1),a=1;a<l;a++)n[a-1]=arguments[a];d.push(f.apply(this,n))}else if(f&&f.length){if(f=f.slice(),l>3)for(n=new Array(l-1),a=1;a<l;a++)n[a-1]=arguments[a];for(i=0,r=f.length;i<r;i++)switch(this.event=s,l){case 1:d.push(f[i].call(this));break;case 2:d.push(f[i].call(this,arguments[1]));break;case 3:d.push(f[i].call(this,arguments[1],arguments[2]));break;default:d.push(f[i].apply(this,n))}}else if(!this.ignoreErrors&&!this._all&&"error"===s)return arguments[1]instanceof Error?Promise.reject(arguments[1]):Promise.reject("Uncaught, unspecified 'error' event.");return Promise.all(d)},x.prototype.on=function(e,t,n){return this._on(e,t,!1,n)},x.prototype.prependListener=function(e,t,n){return this._on(e,t,!0,n)},x.prototype.onAny=function(e){return this._onAny(e,!1)},x.prototype.prependAny=function(e){return this._onAny(e,!0)},x.prototype.addListener=x.prototype.on,x.prototype._onAny=function(e,t){if("function"!=typeof e)throw new Error("onAny only accepts instances of Function");return this._all||(this._all=[]),t?this._all.unshift(e):this._all.push(e),this},x.prototype._on=function(e,n,r,i){if("function"==typeof e)return this._onAny(e,n),this;if("function"!=typeof n)throw new Error("on only accepts instances of Function");this._events||u.call(this);var o,a=this;return i!==t&&(n=(o=I.call(this,e,n,i))[0],a=o[1]),this._newListener&&this.emit("newListener",e,n),this.wildcard?(k.call(this,e,n,r),a):(this._events[e]?("function"==typeof this._events[e]&&(this._events[e]=[this._events[e]]),r?this._events[e].unshift(n):this._events[e].push(n),!this._events[e].warned&&this._maxListeners>0&&this._events[e].length>this._maxListeners&&(this._events[e].warned=!0,d.call(this,this._events[e].length,e))):this._events[e]=n,a)},x.prototype.off=function(e,t){if("function"!=typeof t)throw new Error("removeListener only takes instances of Function");var n,i=[];if(this.wildcard){var o="string"==typeof e?e.split(this.delimiter):e.slice();if(!(i=_.call(this,null,o,this.listenerTree,0)))return this}else{if(!this._events[e])return this;n=this._events[e],i.push({_listeners:n})}for(var a=0;a<i.length;a++){var s=i[a];if(n=s._listeners,r(n)){for(var c=-1,u=0,f=n.length;u<f;u++)if(n[u]===t||n[u].listener&&n[u].listener===t||n[u]._origin&&n[u]._origin===t){c=u;break}if(c<0)continue;return this.wildcard?s._listeners.splice(c,1):this._events[e].splice(c,1),0===n.length&&(this.wildcard?delete s._listeners:delete this._events[e]),this._removeListener&&this.emit("removeListener",e,t),this}(n===t||n.listener&&n.listener===t||n._origin&&n._origin===t)&&(this.wildcard?delete s._listeners:delete this._events[e],this._removeListener&&this.emit("removeListener",e,t))}return this.listenerTree&&T(this.listenerTree),this},x.prototype.offAny=function(e){var t,n=0,r=0;if(e&&this._all&&this._all.length>0){for(n=0,r=(t=this._all).length;n<r;n++)if(e===t[n])return t.splice(n,1),this._removeListener&&this.emit("removeListenerAny",e),this}else{if(t=this._all,this._removeListener)for(n=0,r=t.length;n<r;n++)this.emit("removeListenerAny",t[n]);this._all=[]}return this},x.prototype.removeListener=x.prototype.off,x.prototype.removeAllListeners=function(e){if(e===t)return!this._events||u.call(this),this;if(this.wildcard){var n,r=_.call(this,null,e,this.listenerTree,0);if(!r)return this;for(n=0;n<r.length;n++)r[n]._listeners=null;this.listenerTree&&T(this.listenerTree)}else this._events&&(this._events[e]=null);return this},x.prototype.listeners=function(e){var n,r,i,o,a,s=this._events;if(e===t){if(this.wildcard)throw Error("event name required for wildcard emitter");if(!s)return[];for(o=(n=c(s)).length,i=[];o-- >0;)"function"==typeof(r=s[n[o]])?i.push(r):i.push.apply(i,r);return i}if(this.wildcard){if(!(a=this.listenerTree))return[];var u=[],f="string"==typeof e?e.split(this.delimiter):e.slice();return _.call(this,u,f,a,0),u}return s&&(r=s[e])?"function"==typeof r?[r]:r:[]},x.prototype.eventNames=function(e){var t=this._events;return this.wildcard?M.call(this,this.listenerTree,[],null,e):t?c(t):[]},x.prototype.listenerCount=function(e){return this.listeners(e).length},x.prototype.hasListeners=function(e){if(this.wildcard){var n=[],r="string"==typeof e?e.split(this.delimiter):e.slice();return _.call(this,n,r,this.listenerTree,0),n.length>0}var i=this._events,o=this._all;return!!(o&&o.length||i&&(e===t?c(i).length:i[e]))},x.prototype.listenersAny=function(){return this._all?this._all:[]},x.prototype.waitFor=function(e,n){var r=this,i=typeof n;return"number"===i?n={timeout:n}:"function"===i&&(n={filter:n}),S((n=y(n,{timeout:0,filter:t,handleError:!1,Promise:Promise,overload:!1},{filter:m,Promise:g})).Promise,(function(t,i,o){function a(){var o=n.filter;if(!o||o.apply(r,arguments))if(r.off(e,a),n.handleError){var s=arguments[0];s?i(s):t(l.apply(null,arguments).slice(1))}else t(l.apply(null,arguments))}o((function(){r.off(e,a)})),r._on(e,a,!1)}),{timeout:n.timeout,overload:n.overload})};var O=x.prototype;Object.defineProperties(x,{defaultMaxListeners:{get:function(){return O._maxListeners},set:function(e){if("number"!=typeof e||e<0||Number.isNaN(e))throw TypeError("n must be a non-negative number");O._maxListeners=e},enumerable:!0},once:{value:function(e,t,n){return S((n=y(n,{Promise:Promise,timeout:0,overload:!1},{Promise:g})).Promise,(function(n,r,i){var o;if("function"==typeof e.addEventListener)return o=function(){n(l.apply(null,arguments))},i((function(){e.removeEventListener(t,o)})),void e.addEventListener(t,o,{once:!0});var a,s=function(){a&&e.removeListener("error",a),n(l.apply(null,arguments))};"error"!==t&&(a=function(n){e.removeListener(t,s),r(n)},e.once("error",a)),i((function(){a&&e.removeListener("error",a),e.removeListener(t,s)})),e.once(t,s)}),{timeout:n.timeout,overload:n.overload})},writable:!0,configurable:!0}}),Object.defineProperties(O,{_maxListeners:{value:10,writable:!0,configurable:!0},_observers:{value:null,writable:!0,configurable:!0}}),e.exports=x}()})),Nc={f:me},Ic=u,xc=ze.f,Oc=function(e){var t=Ic.Symbol||(Ic.Symbol={});ue(t,e)||xc(t,e,{value:Nc.f(e)})},Pc=La.forEach,Lc=$e("hidden"),Ec="Symbol",Ac=me("toPrimitive"),Cc=ot.set,jc=ot.getterFor(Ec),Vc=Object.prototype,Bc=u.Symbol,Rc=Bc&&Bc.prototype,zc=u.TypeError,Fc=u.QObject,Dc=B("JSON","stringify"),Wc=xe.f,Uc=ze.f,qc=zs.f,Jc=m.f,Gc=M([].push),Hc=oe("symbols"),Qc=oe("op-symbols"),$c=oe("string-to-symbol-registry"),Kc=oe("symbol-to-string-registry"),Xc=oe("wks"),Yc=!Fc||!Fc.prototype||!Fc.prototype.findChild,Zc=d&&f((function(){return 7!=Za(Uc({},"a",{get:function(){return Uc(this,"a",{value:7}).a}})).a}))?function(e,t,n){var r=Wc(Vc,t);r&&delete Vc[t],Uc(e,t,n),r&&e!==Vc&&Uc(Vc,t,r)}:Uc,eu=function(e,t){var n=Hc[e]=Za(Rc);return Cc(n,{type:Ec,tag:e,description:t}),d||(n.description=t),n},tu=function(e,t,n){e===Vc&&tu(Qc,t,n),Ee(e);var r=_e(t);return Ee(n),ue(Hc,r)?(n.enumerable?(ue(e,Lc)&&e[Lc][r]&&(e[Lc][r]=!1),n=Za(n,{enumerable:b(0,!1)})):(ue(e,Lc)||Uc(e,Lc,b(1,{})),e[Lc][r]=!0),Zc(e,r,n)):Uc(e,r,n)},nu=function(e,t){Ee(e);var n=A(t),r=Va(n).concat(au(n));return Pc(r,(function(t){d&&!h(ru,n,t)||tu(e,t,n[t])})),e},ru=function(e){var t=_e(e),n=h(Jc,this,t);return!(this===Vc&&ue(Hc,t)&&!ue(Qc,t))&&(!(n||!ue(this,t)||!ue(Hc,t)||ue(this,Lc)&&this[Lc][t])||n)},iu=function(e,t){var n=A(e),r=_e(t);if(n!==Vc||!ue(Hc,r)||ue(Qc,r)){var i=Wc(n,r);return!i||!ue(Hc,r)||ue(n,Lc)&&n[Lc][r]||(i.enumerable=!0),i}},ou=function(e){var t=qc(A(e)),n=[];return Pc(t,(function(e){ue(Hc,e)||ue(Ke,e)||Gc(n,e)})),n},au=function(e){var t=e===Vc,n=qc(t?Qc:A(e)),r=[];return Pc(n,(function(e){!ue(Hc,e)||t&&!ue(Vc,e)||Gc(r,Hc[e])})),r};if(J||(Bc=function(){if(R(Rc,this))throw zc("Symbol is not a constructor");var e=arguments.length&&void 0!==arguments[0]?zi(arguments[0]):void 0,t=pe(e),n=function(e){this===Vc&&h(n,Qc,e),ue(this,Lc)&&ue(this[Lc],t)&&(this[Lc][t]=!1),Zc(this,t,b(1,e))};return d&&Yc&&Zc(Vc,t,{configurable:!0,set:n}),eu(t,e)},Rc=Bc.prototype,ft(Rc,"toString",(function(){return jc(this).tag})),ft(Bc,"withoutSetter",(function(e){return eu(pe(e),e)})),m.f=ru,ze.f=tu,Ha.f=nu,xe.f=iu,It.f=zs.f=ou,xt.f=au,Nc.f=function(e){return eu(me(e),e)},d&&(Uc(Rc,"description",{configurable:!0,get:function(){return jc(this).description}}),ft(Vc,"propertyIsEnumerable",ru,{unsafe:!0}))),Ft({global:!0,wrap:!0,forced:!J,sham:!J},{Symbol:Bc}),Pc(Va(Xc),(function(e){Oc(e)})),Ft({target:Ec,stat:!0,forced:!J},{for:function(e){var t=zi(e);if(ue($c,t))return $c[t];var n=Bc(t);return $c[t]=n,Kc[n]=t,n},keyFor:function(e){if(!Q(e))throw zc(e+" is not a symbol");if(ue(Kc,e))return Kc[e]},useSetter:function(){Yc=!0},useSimple:function(){Yc=!1}}),Ft({target:"Object",stat:!0,forced:!J,sham:!d},{create:function(e,t){return void 0===t?Za(e):nu(Za(e),t)},defineProperty:tu,defineProperties:nu,getOwnPropertyDescriptor:iu}),Ft({target:"Object",stat:!0,forced:!J},{getOwnPropertyNames:ou,getOwnPropertySymbols:au}),Ft({target:"Object",stat:!0,forced:f((function(){xt.f(1)}))},{getOwnPropertySymbols:function(e){return xt.f(se(e))}}),Dc){var su=!J||f((function(){var e=Bc();return"[null]"!=Dc([e])||"{}"!=Dc({a:e})||"{}"!=Dc(Object(e))}));Ft({target:"JSON",stat:!0,forced:su},{stringify:function(e,t,n){var r=Xn(arguments),i=t;if((j(t)||void 0!==e)&&!Q(e))return xi(t)||(t=function(e,t){if(C(i)&&(t=h(i,this,e,t)),!Q(t))return t}),r[1]=t,$n(Dc,null,r)}})}if(!Rc[Ac]){var cu=Rc.valueOf;ft(Rc,Ac,(function(e){return h(cu,this)}))}sn(Bc,Ec),Ke[Lc]=!0;var uu=ze.f,fu=u.Symbol,du=fu&&fu.prototype;if(d&&C(fu)&&(!("description"in du)||void 0!==fu().description)){var lu={},pu=function(){var e=arguments.length<1||void 0===arguments[0]?void 0:zi(arguments[0]),t=R(du,this)?new fu(e):void 0===e?fu():fu(e);return""===e&&(lu[t]=!0),t};Lt(pu,fu),pu.prototype=du,du.constructor=pu;var hu="Symbol(test)"==String(fu("test")),yu=M(du.toString),gu=M(du.valueOf),vu=/^Symbol\((.*)\)[^)]+$/,mu=M("".replace),bu=M("".slice);uu(du,"description",{configurable:!0,get:function(){var e=gu(this),t=yu(e);if(ue(lu,e))return"";var n=hu?bu(t,7,-1):mu(t,vu,"$1");return""===n?void 0:n}}),Ft({global:!0,forced:!0},{Symbol:pu})}Oc("iterator");var Su={},wu=new Tc.EventEmitter2({maxListeners:20,newListener:!1}),_u=new Tc.EventEmitter2({maxListeners:20,newListener:!1});function ku(e){var t=new WeakMap;return e=e[0].toUpperCase()+e.slice(1),Su[e]||(Su[e]={getGlobalListeners:function(){return wu.listeners(e)},getInternalListeners:function(){return _u.listeners(e)},emit:function(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];_u.emit.apply(_u,[e].concat(t)),wu.emit.apply(wu,[e].concat(t))},emitGlobal:function(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];wu.emit.apply(wu,[e].concat(t))},emitInternal:function(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];_u.emit.apply(_u,[e].concat(t))},internalOnMethod:function(t,n){void 0===n&&(n={}),Wa(t)&&(n.prepend?n.once?_u.prependOnceListener(e,t):_u.prependListener(e,t):n.once?_u.once(e,t):_u.on(e,t))},internalOffMethod:function(t){Wa(t)&&_u.off(e,t)},onMethod:function(n){var r;(r=Wa(n)?n:null)&&(t.set(n,r),wu.on(e,r))},offMethod:function(n){if(!n||Wa(n))if(n){var r=void 0;t.has(n)&&(r=t.get(n),t.delete(n)),wu.off(e,r)}else t=new WeakMap,wu.removeAllListeners(e)}}),Su[e]}function Mu(e){return!!Su[e]}var Tu=new Proxy({},{get:function(e,t){if(t in Yp)return Yp[t];if(t in Ii){var n=Ii[t];return function(){for(var e=[],r=0;r<arguments.length;r++)e[r]=arguments[r];var i=Ua(n,e),o=qa(n.params,i),a=n.isSustain;if("async"===n.type){var s=e[0],c=s||{},u=c.success,f=c.fail,d=c.complete;if(n.usePromise&&!(Wa(u)||Wa(f)||Wa(d)))return new Promise((function(e,n){xu({isSustain:a,event:t,data:o,success:e,fail:n})}));"function"==typeof s?xu({isSustain:a,event:t,data:o},s):xu({isSustain:a,event:t,data:o,success:s&&s.success,fail:s&&s.fail,complete:s&&s.complete})}if("sync"===n.type){var l=Ou({isSustain:a,event:t,data:o});if(n.needReturn)return l}"monitor"===n.type&&Nu(ki(ki({},n),o)),"offMonitor"===n.type&&Iu(ki(ki({},n),o))}}if(t in e)return e[t];throw new Error(t+" method 暂未实现")}}),Nu=function(e){Mu(e.eventManagerName)||didiJsBridge.on({event:e.nativeEvent},(function(t){ku(e.eventManagerName).emit(t.data)})),ku(e.eventManagerName).onMethod(e.callBack)},Iu=function(e){Mu(e.eventManagerName)&&ku(e.eventManagerName).offMethod(e.callBack)},xu=function(t,n){if(t&&t.event){didiJsBridge.invoke({method:t.event,data:t.data||{},isSustain:t.isSustain||!1,callback:(n?function(e){try{(e=e.data).success?n&&n(e.data):n&&n(e.message)}catch(e){throw e}}:"")||function(n){n=n.data;try{n.success?(n.data&&"object"===e(n.data)&&(n.data.errMsg=t.event+":ok"),t.success&&t.success(n.data)):t.fail&&t.fail({errMsg:n.errMsg})}catch(e){throw e}finally{t.complete&&t.complete()}}})}},Ou=function(e){if(e&&e.event)return didiJsBridge.invoke({method:e.event,data:e.data||{}})};didiJsBridge.on({event:"onCloseMiniProgram",isSustain:!0},(function(e){void 0===e&&(e={data:{}});var t=e.data;ku("onCloseMiniProgram").emit(t)}));var Pu=wt.includes;Ft({target:"Array",proto:!0},{includes:function(e){return Pu(this,e,arguments.length>1?arguments[1]:void 0)}}),os("includes");var Lu,Eu,Au=function(){var e=Ee(this),t="";return e.global&&(t+="g"),e.ignoreCase&&(t+="i"),e.multiline&&(t+="m"),e.dotAll&&(t+="s"),e.unicode&&(t+="u"),e.sticky&&(t+="y"),t},Cu=u.RegExp,ju=f((function(){var e=Cu("a","y");return e.lastIndex=2,null!=e.exec("abcd")})),Vu=ju||f((function(){return!Cu("a","y").sticky})),Bu={BROKEN_CARET:ju||f((function(){var e=Cu("^r","gy");return e.lastIndex=2,null!=e.exec("str")})),MISSED_STICKY:Vu,UNSUPPORTED_Y:ju},Ru=u.RegExp,zu=f((function(){var e=Ru(".","s");return!(e.dotAll&&e.exec("\n")&&"s"===e.flags)})),Fu=u.RegExp,Du=f((function(){var e=Fu("(?<a>b)","g");return"b"!==e.exec("b").groups.a||"bc"!=="b".replace(e,"$<a>c")})),Wu=ot.get,Uu=oe("native-string-replace",String.prototype.replace),qu=RegExp.prototype.exec,Ju=qu,Gu=M("".charAt),Hu=M("".indexOf),Qu=M("".replace),$u=M("".slice),Ku=(Eu=/b*/g,h(qu,Lu=/a/,"a"),h(qu,Eu,"a"),0!==Lu.lastIndex||0!==Eu.lastIndex),Xu=Bu.BROKEN_CARET,Yu=void 0!==/()??/.exec("")[1];(Ku||Yu||Xu||zu||Du)&&(Ju=function(e){var t,n,r,i,o,a,s,c=this,u=Wu(c),f=zi(e),d=u.raw;if(d)return d.lastIndex=c.lastIndex,t=h(Ju,d,f),c.lastIndex=d.lastIndex,t;var l=u.groups,p=Xu&&c.sticky,y=h(Au,c),g=c.source,v=0,m=f;if(p&&(y=Qu(y,"y",""),-1===Hu(y,"g")&&(y+="g"),m=$u(f,c.lastIndex),c.lastIndex>0&&(!c.multiline||c.multiline&&"\n"!==Gu(f,c.lastIndex-1))&&(g="(?: "+g+")",m=" "+m,v++),n=new RegExp("^(?:"+g+")",y)),Yu&&(n=new RegExp("^"+g+"$(?!\\s)",y)),Ku&&(r=c.lastIndex),i=h(qu,p?n:c,m),p?i?(i.input=$u(i.input,v),i[0]=$u(i[0],v),i.index=c.lastIndex,c.lastIndex+=i[0].length):c.lastIndex=0:Ku&&i&&(c.lastIndex=c.global?i.index+i[0].length:r),Yu&&i&&i.length>1&&h(Uu,i[0],n,(function(){for(o=1;o<arguments.length-2;o++)void 0===arguments[o]&&(i[o]=void 0)})),i&&l)for(i.groups=a=Za(null),o=0;o<l.length;o++)a[(s=l[o])[0]]=i[s[1]];return i});var Zu=Ju;Ft({target:"RegExp",proto:!0,forced:/./.exec!==Zu},{exec:Zu});var ef=me("species"),tf=RegExp.prototype,nf=function(e,t,n,r){var i=me(e),o=!f((function(){var t={};return t[i]=function(){return 7},7!=""[e](t)})),a=o&&!f((function(){var t=!1,n=/a/;return"split"===e&&((n={}).constructor={},n.constructor[ef]=function(){return n},n.flags="",n[i]=/./[i]),n.exec=function(){return t=!0,null},n[i](""),!t}));if(!o||!a||n){var s=M(/./[i]),c=t(i,""[e],(function(e,t,n,r,i){var a=M(e),c=t.exec;return c===Zu||c===tf.exec?o&&!i?{done:!0,value:s(t,n,r)}:{done:!0,value:a(n,t,r)}:{done:!1}}));ft(String.prototype,e,c[0]),ft(tf,i,c[1])}r&&Fe(tf[i],"sham",!0)},rf=me("match"),of=function(e){var t;return j(e)&&(void 0!==(t=e[rf])?!!t:"RegExp"==I(e))},af=Es.charAt,sf=function(e,t,n){return t+(n?af(e,t).length:1)},cf=u.TypeError,uf=function(e,t){var n=e.exec;if(C(n)){var r=h(n,e,t);return null!==r&&Ee(r),r}if("RegExp"===I(e))return h(Zu,e,t);throw cf("RegExp#exec called on incompatible receiver")},ff=Bu.UNSUPPORTED_Y,df=4294967295,lf=Math.min,pf=[].push,hf=M(/./.exec),yf=M(pf),gf=M("".slice),vf=!f((function(){var e=/(?:)/,t=e.exec;e.exec=function(){return t.apply(this,arguments)};var n="ab".split(e);return 2!==n.length||"a"!==n[0]||"b"!==n[1]}));nf("split",(function(e,t,n){var r;return r="c"=="abbc".split(/(b)*/)[1]||4!="test".split(/(?:)/,-1).length||2!="ab".split(/(?:ab)*/).length||4!=".".split(/(.?)(.?)/).length||".".split(/()()/).length>1||"".split(/.?/).length?function(e,n){var r=zi(E(this)),i=void 0===n?df:n>>>0;if(0===i)return[];if(void 0===e)return[r];if(!of(e))return h(t,r,e,i);for(var o,a,s,c=[],u=(e.ignoreCase?"i":"")+(e.multiline?"m":"")+(e.unicode?"u":"")+(e.sticky?"y":""),f=0,d=new RegExp(e.source,u+"g");(o=h(Zu,d,r))&&!((a=d.lastIndex)>f&&(yf(c,gf(r,f,o.index)),o.length>1&&o.index<r.length&&$n(pf,c,xo(o,1)),s=o[0].length,f=a,c.length>=i));)d.lastIndex===o.index&&d.lastIndex++;return f===r.length?!s&&hf(d,"")||yf(c,""):yf(c,gf(r,f)),c.length>i?xo(c,0,i):c}:"0".split(void 0,0).length?function(e,n){return void 0===e&&0===n?[]:h(t,this,e,n)}:t,[function(t,n){var i=E(this),o=null==t?void 0:Z(t,e);return o?h(o,t,i,n):h(r,zi(i),t,n)},function(e,i){var o=Ee(this),a=zi(e),s=n(r,o,a,i,r!==t);if(s.done)return s.value;var c=Jn(o,RegExp),u=o.unicode,f=(o.ignoreCase?"i":"")+(o.multiline?"m":"")+(o.unicode?"u":"")+(ff?"g":"y"),d=new c(ff?"^(?:"+o.source+")":o,f),l=void 0===i?df:i>>>0;if(0===l)return[];if(0===a.length)return null===uf(d,a)?[a]:[];for(var p=0,h=0,y=[];h<a.length;){d.lastIndex=ff?0:h;var g,v=uf(d,ff?gf(a,h):a);if(null===v||(g=lf(mt(d.lastIndex+(ff?h:0)),a.length))===p)h=sf(a,h,u);else{if(yf(y,gf(a,p,h)),y.length===l)return y;for(var m=1;m<=v.length-1;m++)if(yf(y,v[m]),y.length===l)return y;h=p=g}}return yf(y,gf(a,p)),y}]}),!vf,ff);var mf=Li("splice"),bf=u.TypeError,Sf=Math.max,wf=Math.min,_f=9007199254740991,kf="Maximum allowed length exceeded";Ft({target:"Array",proto:!0,forced:!mf},{splice:function(e,t){var n,r,i,o,a,s,c=se(this),u=bt(c),f=gt(e,u),d=arguments.length;if(0===d?n=r=0:1===d?(n=0,r=u-f):(n=d-2,r=wf(Sf(pt(t),0),u-f)),u+n-r>_f)throw bf(kf);for(i=xa(c,r),o=0;o<r;o++)(a=f+o)in c&&Oi(i,o,c[a]);if(i.length=r,n<r){for(o=f;o<u-r;o++)s=o+n,(a=o+r)in c?c[s]=c[a]:delete c[s];for(o=u;o>u-r+n;o--)delete c[o-1]}else if(n>r)for(o=u-r;o>f;o--)s=o+n-1,(a=o+r-1)in c?c[s]=c[a]:delete c[s];for(o=0;o<n;o++)c[o+f]=arguments[o+2];return c.length=u-r+n,i}});var Mf=ze.f,Tf=qs.fastKey,Nf=ot.set,If=ot.getterFor,xf={getConstructor:function(e,t,n,r){var i=e((function(e,i){dn(e,o),Nf(e,{type:t,index:Za(null),first:void 0,last:void 0,size:0}),d||(e.size=0),null!=i&&Mn(i,e[r],{that:e,AS_ENTRIES:n})})),o=i.prototype,a=If(t),s=function(e,t,n){var r,i,o=a(e),s=c(e,t);return s?s.value=n:(o.last=s={index:i=Tf(t,!0),key:t,value:n,previous:r=o.last,next:void 0,removed:!1},o.first||(o.first=s),r&&(r.next=s),d?o.size++:e.size++,"F"!==i&&(o.index[i]=s)),e},c=function(e,t){var n,r=a(e),i=Tf(t);if("F"!==i)return r.index[i];for(n=r.first;n;n=n.next)if(n.key==t)return n};return en(o,{clear:function(){for(var e=a(this),t=e.index,n=e.first;n;)n.removed=!0,n.previous&&(n.previous=n.previous.next=void 0),delete t[n.index],n=n.next;e.first=e.last=void 0,d?e.size=0:this.size=0},delete:function(e){var t=this,n=a(t),r=c(t,e);if(r){var i=r.next,o=r.previous;delete n.index[r.index],r.removed=!0,o&&(o.next=i),i&&(i.previous=o),n.first==r&&(n.first=i),n.last==r&&(n.last=o),d?n.size--:t.size--}return!!r},forEach:function(e){for(var t,n=a(this),r=pn(e,arguments.length>1?arguments[1]:void 0);t=t?t.next:n.first;)for(r(t.value,t.key,this);t&&t.removed;)t=t.previous},has:function(e){return!!c(this,e)}}),en(o,n?{get:function(e){var t=c(this,e);return t&&t.value},set:function(e,t){return s(this,0===e?0:e,t)}}:{add:function(e){return s(this,e=0===e?0:e,e)}}),d&&Mf(o,"size",{get:function(){return a(this).size}}),i},setStrong:function(e,t,n){var r=t+" Iterator",i=If(t),o=If(r);ws(e,t,(function(e,t){Nf(this,{type:r,target:e,state:i(e),kind:t,last:void 0})}),(function(){for(var e=o(this),t=e.kind,n=e.last;n&&n.removed;)n=n.previous;return e.target&&(e.last=n=n?n.next:e.state.first)?"keys"==t?{value:n.key,done:!1}:"values"==t?{value:n.value,done:!1}:{value:[n.key,n.value],done:!1}:(e.target=void 0,{value:void 0,done:!0})}),n?"entries":"values",!n,!0),un(t)}};Js("Set",(function(e){return function(){return e(this,arguments.length?arguments[0]:void 0)}}),xf);var Of=La.map,Pf=Li("map");Ft({target:"Array",proto:!0,forced:!Pf},{map:function(e){return Of(this,e,arguments.length>1?arguments[1]:void 0)}});var Lf=!!Zt&&f((function(){Zt.prototype.finally.call({then:function(){}},(function(){}))}));if(Ft({target:"Promise",proto:!0,real:!0,forced:Lf},{finally:function(e){var t=Jn(this,B("Promise")),n=C(e);return this.then(n?function(n){return Rr(t,e()).then((function(){return n}))}:e,n?function(n){return Rr(t,e()).then((function(){throw n}))}:e)}}),C(Zt)){var Ef=B("Promise").prototype.finally;Zt.prototype.finally!==Ef&&ft(Zt.prototype,"finally",Ef,{unsafe:!0})}var Af=function(){function e(t){this._promise=t,this.taskIds=[],null!==e.currentTask&&(e.currentTask.destroy(),e.currentTask=null),e.setCurrentTask(this),this.status=2,this.event=exparser.EventBus.create("App Route Callback")}return e.setCurrentTask=function(t){e.currentTask=t},e.getCurrentTask=function(){return e.currentTask},e.prototype.addTask=function(e){var t=this.event.add(e);this.taskIds.push(t)},e.prototype.clearTask=function(){for(var e=0,t=this.taskIds;e<t.length;e++){var n=t[e];this.event.remove(n)}this.taskIds.length=0},e.prototype.resolve=function(){this.status=0,this.event.call(void 0,[])},e.prototype.reject=function(){this.status=1},e.prototype.destroy=function(){var t=this;e.currentTask===this&&(e.currentTask=null),this.clearTask(),this.event=null,"Promise"===za(this._promise)?Promise.race([Promise.resolve(),this._promise]).catch((function(e){})).finally((function(){return t._promise=null})):this._promise=null},Object.defineProperty(e.prototype,"resolved",{get:function(){return 0===this.status},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"rejected",{get:function(){return 1===this.status},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"pending",{get:function(){return 2===this.status},enumerable:!1,configurable:!0}),e.currentTask=null,e}(),Cf=!1,jf="custom-tab-bar/index";function Vf(e,t,n){if(void 0===n&&(n=!1),n&&(t=function(e){if("string"!=typeof e)return e;var t=e.split("?"),n=t[0],r=t[1];return n+=".wxml",void 0!==r?n+"?"+r:n}(t)),0===t.indexOf("/"))return t.substr(1);if(0===t.indexOf("./"))return Vf(e,t.substr(2));for(var r=t.split("/"),i=r.length,o=0;o<i&&".."===r[o];)o+=1;r.splice(0,o);var a=0<e.length?e.split("/"):[];return o>a.length-1?r.join("/"):(a.splice(a.length-o-1,o+1),a.concat(r).join("/"))}function Bf(e){if(__routePackages__){if(Object.prototype.hasOwnProperty.call(__routePackages__,e))return __routePackages__[e];throw new Error("getPackageNameByRoute 未找到对应路由: "+e)}throw new Error("__routePackages__ not define.")}var Rf=new Set;function zf(e){return Rf.has(e)}function Ff(e,t){t?Rf.add(e):Rf.has(e)&&Rf.delete(e)}var Df=function(e,t){return Mi(this,void 0,void 0,(function(){var n;return Ti(this,(function(r){switch(r.label){case 0:return!1!==zf(e)?[3,2]:[4,new Promise((function(t,n){didiJsBridge.invoke({method:"loadJSFileToDataThread",data:{package:e},callback:function(r){r&&r.data&&r.data.success?(Ff(e,!0),t()):n(r.data.errMsg||"loadJSFileToDataThread failed ("+e+").")}})}))];case 1:r.sent(),r.label=2;case 2:return __define__(e),(n=new Set).add(t),Wf(t,n),function(e){if(!__ddConfig.tabBar||!0!==__ddConfig.tabBar.custom)return;!Cf&&function(e){var t=__ddConfig.tabBar&&__ddConfig.tabBar.list;if(t instanceof Array&&(t=t.map((function(e){return e&&e.pagePath}))).indexOf(e)>=0)return!0;return!1}(e)&&(__ddRoute=jf,__ddRouteBegin=!0,__ddAppCurrentFile__=jf+".js",require(jf+".js"),Cf=!0)}(t),globalThis._=void 0,[2,e]}}))}))};var Wf=function t(n,r){var i=__ddAppCode__[n+".json"],o=__ddConfig.isLazyLoad;if("object"===e(i)&&i.usingComponents){var a=i.usingComponents,s=i.componentPlaceholder||[];Object.keys(a).forEach((function(e){if(!o||o&&!s[e]){var i=Vf(n,a[e]);r.has(i)||(r.add(i),t(i,r))}}))}__ddRoute=n,__ddRouteBegin=!0,__ddAppCurrentFile__=n+".js",require(n+".js")};var Uf=!1;function qf(e,t,n){if(void 0===n&&(n=!1),n||!Uf||globalThis.isBrowser){var r=Vf(__appServiceEngine__.getCurrentRoute(),e.split("?")[0]),i=Bf(r);Uf=!0,function(e){return new Promise((function(t,n){didiJsBridge.invoke({method:"loadSubPackage",data:{package:e},callback:function(e){isDevTools&&"devtools"===__ddConfig.platform&&e&&t(),e&&e.data&&e.data.success?t():n(e.data.errMsg)}})}))}(i).then((function(){var e=new Af;t(i),Df(i,r).then((function(){return e.resolve()})).catch((function(t){e.reject(),Reporter.errorReport({key:"service-error",type:"evaluateLogic",error:"[service-error]: evaluateLogic error: "+t}),Reporter.ravenReport("pub_saga_error_message_bt",{key:"service-error",type:"evaluateLogic",error:"[service-error]: evaluateLogic error: "+t,fail:function(e){}})})).finally((function(){e.clearTask(),Uf=!1}))})).catch((function(e){Uf=!1,Reporter.errorReport({key:"service-error",type:"loadSubpackageError",error:"[service-error]: load Subpackage error "+e}),Reporter.ravenReport("pub_saga_error_message_bt",{key:"service-error",type:"loadSubpackageError",error:"[service-error]: load Subpackage error "+e,fail:function(e){}})}))}}var Jf=function(e){var t=e||{},n=t.delta,r=void 0===n?1:n,i=t.success,o=t.fail,a=t.complete;didiJsBridge.invoke({method:"navigateBack",data:{delta:r,openType:"navigateBack",stackId:currentStackId},callback:function(e){e&&e.data&&e.data.success?i&&i():o&&o(),a&&a();var t=+(e.data&&e.data.webViewId);ku("AppRoute").emit({openType:"navigateBack",webViewId:t})}})};function Gf(){if(window.isBrowser)return{query:{}};var e=didiJsBridge.invoke({method:"getLaunchOptionsSync",data:{}});try{e="string"==typeof e?JSON.parse(e):e}catch(e){}return e||{}}function Hf(){if(window.isBrowser)return{query:{}};var e=didiJsBridge.invoke({method:"getEnterOptionsSync",data:{stackId:currentStackId}});try{e="string"==typeof e?JSON.parse(e):e}catch(e){}return e||{}}didiJsBridge.on({event:"navigateBackNative"},(function(e){var t=+e.webViewId;ku("AppRoute").emit({openType:"navigateBack",webViewId:t})}));var Qf=Math.floor,$f=M("".charAt),Kf=M("".replace),Xf=M("".slice),Yf=/\$([$&'`]|\d{1,2}|<[^>]*>)/g,Zf=/\$([$&'`]|\d{1,2})/g,ed=function(e,t,n,r,i,o){var a=n+e.length,s=r.length,c=Zf;return void 0!==i&&(i=se(i),c=Yf),Kf(o,c,(function(o,c){var u;switch($f(c,0)){case"$":return"$";case"&":return e;case"`":return Xf(t,0,n);case"'":return Xf(t,a);case"<":u=i[Xf(c,1,-1)];break;default:var f=+c;if(0===f)return o;if(f>s){var d=Qf(f/10);return 0===d?o:d<=s?void 0===r[d-1]?$f(c,1):r[d-1]+$f(c,1):o}u=r[f-1]}return void 0===u?"":u}))},td=me("replace"),nd=Math.max,rd=Math.min,id=M([].concat),od=M([].push),ad=M("".indexOf),sd=M("".slice),cd="$0"==="a".replace(/./,"$0"),ud=!!/./[td]&&""===/./[td]("a","$0");nf("replace",(function(e,t,n){var r=ud?"$":"$0";return[function(e,n){var r=E(this),i=null==e?void 0:Z(e,td);return i?h(i,e,r,n):h(t,zi(r),e,n)},function(e,i){var o=Ee(this),a=zi(e);if("string"==typeof i&&-1===ad(i,r)&&-1===ad(i,"$<")){var s=n(t,o,a,i);if(s.done)return s.value}var c=C(i);c||(i=zi(i));var u=o.global;if(u){var f=o.unicode;o.lastIndex=0}for(var d=[];;){var l=uf(o,a);if(null===l)break;if(od(d,l),!u)break;""===zi(l[0])&&(o.lastIndex=sf(a,mt(o.lastIndex),f))}for(var p,h="",y=0,g=0;g<d.length;g++){for(var v=zi((l=d[g])[0]),m=nd(rd(pt(l.index),a.length),0),b=[],S=1;S<l.length;S++)od(b,void 0===(p=l[S])?p:String(p));var w=l.groups;if(c){var _=id([v],b,m,a);void 0!==w&&od(_,w);var k=zi($n(i,void 0,_))}else k=ed(v,a,m,b,w,i);m>=y&&(h+=sd(a,y,m)+k,y=m+v.length)}return h+sd(a,y)}]}),!!f((function(){var e=/./;return e.exec=function(){var e=[];return e.groups={a:"7"},e},"7"!=="".replace(e,"$<a>")}))||!cd||ud);var fd={lastRoute:"",lastOpenType:"",query:{},runningStatus:"active",navigatorLock:!1,openUrlLock:!1,possessingBackgroundAudioPlayer:!1,webviewEventCallback:null,hanged:!1,appStatus:0,navigationBarTitleMap:{},currentWebviewId:void 0,lastRawQuery:null},ld=function(e,t){var n=e.data;void 0===t&&(t=0),yd.handleRewriteRoute(n)&&("appLaunch"!==n.openType&&"autoReLaunch"!==n.openType&&(n.path=function(e){return"string"==typeof e?-1!==e.indexOf("?")?e.replace(/\.html\?/,"?"):e.replace(/\.html$/,""):e}(n.path),n.webViewId=void 0!==n.webViewId?n.webViewId:t,fd.lastRoute=n.path||"",fd.lastRawQuery=n.query&&JSON.parse(JSON.stringify(n.query))||{},fd.lastOpenType=n.openType),fd.query=n.query,fd.currentWebviewId=n.webViewId,didiJsBridge.publish({event:"onAppRoute",data:{},webViewId:n.webViewId}),ku("AppRoute").emit(n))},pd=ku("AppRoute").internalOnMethod,hd=ku("AppRoute").internalOffMethod;didiJsBridge.on({event:"switchTabNotification"},(function(e){void 0===e&&(e={data:{toRoute:"",toWebViewId:"",query:{}}});var t=e.data,n=t.toRoute;0===n.indexOf("plugin://imPlugin")&&(n="__dimina__/empty/empty");var r=t.toIndex;t.fromNative&&__ddConfig&&__ddConfig.tabBar&&__ddConfig.tabBar.list&&__ddConfig.tabBar.list[r]&&tabBarTapList.push({index:r,pagePath:(__ddConfig.tabBar.list[r].pagePath||"").replace(/\.html$/,""),text:__ddConfig.tabBar.list[r].text}),ld({data:{openType:"switchTab",path:n,webViewId:t.toWebViewId,query:t.query}})}));var yd={launch:function(e,t){qf(e.url,(function(n){!function(e,t){didiJsBridge.invoke({method:"launch",data:{url:e.url,openType:e.openType,query:e.query,package:e.package,stackId:t}})}(ki(ki({},e),{package:n}),t)}),!0)},reLaunch:function(e){qf(e.url,(function(t){!function(e){var t=e.url,n=e.success,r=e.fail,i=e.complete;didiJsBridge.invoke({method:"reLaunch",data:{url:Vf(__appServiceEngine__.getCurrentRoute(),t),openType:"reLaunch",package:e.package,stackId:currentStackId},callback:function(e){e&&e.data&&e.data.success?n&&n():r&&r(),i&&i()}})}(ki(ki({},e),{package:t}))}))},navigateTo:function(e){qf(e.url,(function(t){!function(e){var t=e.url,n=e.success,r=e.fail,i=e.complete;didiJsBridge.invoke({method:"navigateTo",data:{url:Vf(__appServiceEngine__.getCurrentRoute(),t),openType:"navigateTo",package:e.package,stackId:currentStackId},callback:function(e){e&&e.data&&e.data.success?n&&n():r&&r(),i&&i()}})}(ki(ki({},e),{package:t}))}))},redirectTo:function(e){qf(e.url,(function(t){!function(e){var t=e.url,n=e.success,r=e.fail,i=e.complete;didiJsBridge.invoke({method:"redirectTo",data:{url:Vf(__appServiceEngine__.getCurrentRoute(),t),openType:"redirectTo",package:e.package,stackId:currentStackId},callback:function(e){e&&e.data&&e.data.success?n&&n():r&&r(),i&&i()}})}(ki(ki({},e),{package:t}))}))},handleRewriteRoute:function(e){if(["dismissPip","navigateBack"].includes(e.openType))return!1;if(!e.notFound)return!0;if(/^[-_+a-z]+:\/\//i.test(e.rawPath))try{return didiJsBridge.invoke({method:"rewriteRoute",data:{},webViewId:"",invokeId:""}),!0}catch(e){return!1}return!1},navigateBack:Jf,switchTab:function(e){qf(e.url,(function(t){!function(e){var t=e.url,n=e.success,r=e.fail;didiJsBridge.invoke({method:"switchTab",data:{url:t,openType:"switchTab",package:e.package,stackId:currentStackId},callback:function(e){e&&e.data&&e.data.success?n&&n():r&&r()}})}(ki(ki({},e),{package:t}))}))},navigateToMiniProgram:function(e){if(!e.appId)return e.fail&&e.fail("缺少appId"),void(e.complete&&e.complete());xu({event:"navigateToMiniProgram",data:{appId:e.appId,path:e.path,extraData:e.extraData,envVersion:e.envVersion||"release"},success:e.success,fail:e.fail,complete:e.complete})},navigateToDimina:function(e){if(!e.appId)return e.fail&&e.fail("缺少appId"),void(e.complete&&e.complete());xu({event:"navigateToDimina",data:{appId:e.appId,path:e.path,extraData:e.extraData,remoteUrl:e.remoteUrl||"",hasCapsuleButton:e.hasCapsuleButton||!1},success:e.success,fail:e.fail,complete:e.complete})}};didiJsBridge.subscribe({event:"H5navigateTo"},(function(e){!e||e.data,yd.navigateTo(e.data.params)})),didiJsBridge.subscribe({event:"H5navigateBack"},(function(e){!e||e.data,yd.navigateBack(e.data.params)})),didiJsBridge.subscribe({event:"H5redirectTo"},(function(e){!e||e.data,yd.redirectTo(e.data.params)})),didiJsBridge.subscribe({event:"H5switchTab"},(function(e){!e||e.data,yd.switchTab(e.data.params)})),didiJsBridge.subscribe({event:"H5reLaunch"},(function(e){!e||e.data,yd.reLaunch(e.data.params)})),didiJsBridge.subscribe({event:"H5goSuperAppTab"},(function(){gd()})),didiJsBridge.subscribe({event:"H5openLocation"},(function(e){var t;void 0===(t=e.data)&&(t={latitude:0,longitude:0}),xu({event:"openLocation",data:{latitude:t.latitude,longitude:t.longitude,scale:t.scale||18,name:t.name,address:t.address},success:t.success,fail:t.fail,complete:t.complete})}));var gd=function(){var e,t,n,r=(Hf().query||{}).fromDidiTabbar||!1;"string"==typeof r&&(r="true"===r),r?(void 0===n&&(n={}),xu({event:"closeDimina",data:{},success:n.success,fail:n.fail,complete:n.complete})):(e=!1,(t=__appServiceEngine__.getCurrentPagesByDomain(""))&&t.length&&t[0].route.indexOf("pages/index/index")>-1&&(e=!0),Jf(e?{delta:10}:{delta:10,success:function(){yd.redirectTo({url:"/pages/index/index"})}}))},vd=Gi.trim,md=u.parseInt,bd=u.Symbol,Sd=bd&&bd.iterator,wd=/^[+-]?0x/i,_d=M(wd.exec),kd=8!==md(Fi+"08")||22!==md(Fi+"0x16")||Sd&&!f((function(){md(Object(Sd))}))?function(e,t){var n=vd(zi(e));return md(n,t>>>0||(_d(wd,n)?16:10))}:md;Ft({global:!0,forced:parseInt!=kd},{parseInt:kd});var Md=ut.PROPER,Td="toString",Nd=RegExp.prototype,Id=Nd.toString,xd=M(Au),Od=f((function(){return"/a/b"!=Id.call({source:"a",flags:"b"})})),Pd=Md&&Id.name!=Td;(Od||Pd)&&ft(RegExp.prototype,Td,(function(){var e=Ee(this),t=zi(e.source),n=e.flags;return"/"+t+"/"+zi(void 0===n&&R(Nd,e)&&!("flags"in Nd)?xd(e):n)}),{unsafe:!0});var Ld=Gi.trim,Ed=M("".charAt),Ad=u.parseFloat,Cd=u.Symbol,jd=Cd&&Cd.iterator,Vd=1/Ad(Fi+"-0")!=-1/0||jd&&!f((function(){Ad(Object(jd))}))?function(e){var t=Ld(zi(e)),n=Ad(t);return 0===n&&"-"==Ed(t,0)?-0:n}:Ad;Ft({global:!0,forced:parseFloat!=Vd},{parseFloat:Vd});var Bd,Rd=u.TypeError,zd=function(e){if(of(e))throw Rd("The method doesn't accept regular expressions");return e},Fd=me("match"),Dd=xe.f,Wd=M("".endsWith),Ud=M("".slice),qd=Math.min,Jd=function(e){var t=/./;try{"/./"[e](t)}catch(n){try{return t[Fd]=!1,"/./"[e](t)}catch(e){}}return!1}("endsWith"),Gd=!(Jd||(Bd=Dd(String.prototype,"endsWith"),!Bd||Bd.writable));Ft({target:"String",proto:!0,forced:!Gd&&!Jd},{endsWith:function(e){var t=zi(E(this));zd(e);var n=arguments.length>1?arguments[1]:void 0,r=t.length,i=void 0===n?r:qd(mt(n),r),o=zi(e);return Wd?Wd(t,o,i):Ud(t,i-o.length,i)===o}});var Hd,Qd={aliceblue:"#f0f8ff",antiquewhite:"#faebd7",aqua:"#00ffff",aquamarine:"#7fffd4",azure:"#f0ffff",beige:"#f5f5dc",bisque:"#ffe4c4",black:"#000000",blanchedalmond:"#ffebcd",blue:"#0000ff",blueviolet:"#8a2be2",brown:"#a52a2a",burlywood:"#deb887",cadetblue:"#5f9ea0",chartreuse:"#7fff00",chocolate:"#d2691e",coral:"#ff7f50",cornflowerblue:"#6495ed",cornsilk:"#fff8dc",crimson:"#dc143c",cyan:"#00ffff",darkblue:"#00008b",darkcyan:"#008b8b",darkgoldenrod:"#b8860b",darkgray:"#a9a9a9",darkgrey:"#a9a9a9",darkgreen:"#006400",darkkhaki:"#bdb76b",darkmagenta:"#8b008b",darkolivegreen:"#556b2f",darkorange:"#ff8c00",darkorchid:"#9932cc",darkred:"#8b0000",darksalmon:"#e9967a",darkseagreen:"#8fbc8f",darkslateblue:"#483d8b",darkslategray:"#2f4f4f",darkslategrey:"#2f4f4f",darkturquoise:"#00ced1",darkviolet:"#9400d3",deeppink:"#ff1493",deepskyblue:"#00bfff",dimgray:"#696969",dimgrey:"#696969",dodgerblue:"#1e90ff",firebrick:"#b22222",floralwhite:"#fffaf0",forestgreen:"#228b22",fuchsia:"#ff00ff",gainsboro:"#dcdcdc",ghostwhite:"#f8f8ff",gold:"#ffd700",goldenrod:"#daa520",gray:"#808080",grey:"#808080",green:"#008000",greenyellow:"#adff2f",honeydew:"#f0fff0",hotpink:"#ff69b4",indianred:"#cd5c5c",indigo:"#4b0082",ivory:"#fffff0",khaki:"#f0e68c",lavender:"#e6e6fa",lavenderblush:"#fff0f5",lawngreen:"#7cfc00",lemonchiffon:"#fffacd",lightblue:"#add8e6",lightcoral:"#f08080",lightcyan:"#e0ffff",lightgoldenrodyellow:"#fafad2",lightgray:"#d3d3d3",lightgrey:"#d3d3d3",lightgreen:"#90ee90",lightpink:"#ffb6c1",lightsalmon:"#ffa07a",lightseagreen:"#20b2aa",lightskyblue:"#87cefa",lightslategray:"#778899",lightslategrey:"#778899",lightsteelblue:"#b0c4de",lightyellow:"#ffffe0",lime:"#00ff00",limegreen:"#32cd32",linen:"#faf0e6",magenta:"#ff00ff",maroon:"#800000",mediumaquamarine:"#66cdaa",mediumblue:"#0000cd",mediumorchid:"#ba55d3",mediumpurple:"#9370db",mediumseagreen:"#3cb371",mediumslateblue:"#7b68ee",mediumspringgreen:"#00fa9a",mediumturquoise:"#48d1cc",mediumvioletred:"#c71585",midnightblue:"#191970",mintcream:"#f5fffa",mistyrose:"#ffe4e1",moccasin:"#ffe4b5",navajowhite:"#ffdead",navy:"#000080",oldlace:"#fdf5e6",olive:"#808000",olivedrab:"#6b8e23",orange:"#ffa500",orangered:"#ff4500",orchid:"#da70d6",palegoldenrod:"#eee8aa",palegreen:"#98fb98",paleturquoise:"#afeeee",palevioletred:"#db7093",papayawhip:"#ffefd5",peachpuff:"#ffdab9",peru:"#cd853f",pink:"#ffc0cb",plum:"#dda0dd",powderblue:"#b0e0e6",purple:"#800080",rebeccapurple:"#663399",red:"#ff0000",rosybrown:"#bc8f8f",royalblue:"#4169e1",saddlebrown:"#8b4513",salmon:"#fa8072",sandybrown:"#f4a460",seagreen:"#2e8b57",seashell:"#fff5ee",sienna:"#a0522d",silver:"#c0c0c0",skyblue:"#87ceeb",slateblue:"#6a5acd",slategray:"#708090",slategrey:"#708090",snow:"#fffafa",springgreen:"#00ff7f",steelblue:"#4682b4",tan:"#d2b48c",teal:"#008080",thistle:"#d8bfd8",tomato:"#ff6347",turquoise:"#40e0d0",violet:"#ee82ee",wheat:"#f5deb3",white:"#ffffff",whitesmoke:"#f5f5f5",yellow:"#ffff00",yellowgreen:"#9acd32",transparent:"#00000000"};function $d(e,t,n,r){void 0===n&&(n=""),void 0===r&&(r="");var i="canvas_"+e+"_"+t+"_"+n+"_";return r&&r!==__virtualDOM__.getRootNodeId(e)&&(i+=r),i}function Kd(e,t,n){return void 0===n&&(n={}),Ou({event:t+"Canvas",data:ki({canvasId:e},n)})}function Xd(e){return parseInt(e,16)}function Yd(e){var t=Number(Math.min(Hd.MAX_COLOR_VALUE,Math.max(Math.round(parseFloat(e)),Hd.MIN_COLOR_VALUE))).toString(16);return 1===t.length&&(t="0"+t),t}function Zd(e){return Math.min(Hd.MAX_COLOR_VALUE,Math.max(parseFloat(e),Hd.MIN_COLOR_VALUE))}function el(e){var t=e.slice(0,3).map((function(e){return""+Math.round(e)}));if(4===e.length){var n=e[3].toFixed(3).replace(/0+$/g,"");n.endsWith(".")&&(n="0"),t.push(n)}return t}!function(e){e[e.MAX_COLOR_VALUE=255]="MAX_COLOR_VALUE",e[e.MIN_COLOR_VALUE=0]="MIN_COLOR_VALUE"}(Hd||(Hd={}));var tl={};ku("skiaCanvasLoadFontFace");function nl(e,t){t?tl[e]&&delete tl[e].nodeId:delete tl[e]}var rl={},il=1;didiJsBridge.subscribe({event:"pageScrollDone"},(function(e){var t=e.data,n=void 0===t?{}:t;if(n.callBackId>0&&rl[n.callBackId]){var r=rl[n.callBackId];delete rl[n.callBackId],n.success?"function"==typeof r.success&&r.success():"function"==typeof r.fail&&r.fail(),"function"==typeof r.complete&&r.complete()}}));var ol,al=La.filter,sl=Li("filter");Ft({target:"Array",proto:!0,forced:!sl},{filter:function(e){return al(this,e,arguments.length>1?arguments[1]:void 0)}});var cl=function(){function e(){this.entryList=new fl}return e.prototype.createObserver=function(e){var t=this,n=new ul(e);return didiJsBridge.on({event:"performanceEntries",isSustain:!0},(function(e){var r,i;if(e){var o=(null===(r=null==e?void 0:e.data)||void 0===r?void 0:r.entryList)&&JSON.parse(null===(i=null==e?void 0:e.data)||void 0===i?void 0:i.entryList)||[];o&&(t.entryList.push(o),n.notify(o))}})),n},e.prototype.getEntries=function(){return this.entryList.getEntries()},e.prototype.getEntriesByName=function(e,t){return this.entryList.getEntriesByName(e,t)},e.prototype.getEntriesByType=function(e){return this.entryList.getEntriesByType(e)},e.prototype.setBufferSize=function(){},e}(),ul=function(){function e(e){this.entryTypes=[],this.callback=e}return e.prototype.observe=function(e){this.connected=!0,this.entryTypes=e.entryTypes},e.prototype.notify=function(e){var t=this;if(this.connected){var n=new fl;n.push(e.filter((function(e){var n=!1;return t.entryTypes&&t.entryTypes.length>0&&t.entryTypes.forEach((function(t){e.entryType===t&&(n=!0)})),n}))),this.callback(n)}},e.prototype.disconnect=function(){this.connected=!1},e}(),fl=function(){function e(){this._list=[]}return e.prototype.push=function(e){this._list=this._list.concat(e)},e.prototype.getEntriesByName=function(e,t){return this._entryFilter(e,t)},e.prototype.getEntriesByType=function(e){return this._entryFilter(null,e)},e.prototype._entryFilter=function(e,t){return this._list.filter((function(n){return(!e||e===n.name)&&(!t||t===n.entryType)}))},e.prototype.getEntries=function(){return this._list},e}();function dl(e,t){for(var n=e.split("."),r=t.split("."),i=Math.max(n.length,r.length);n.length<i;)n.push("0");for(;r.length<i;)r.push("0");for(var o=0;o<i;o++){var a=parseInt(n[o]),s=parseInt(r[o]);if(a>s)return 1;if(a<s)return-1}return 0}var ll,pl,hl={"image.webp":{version:"1.4.0",dmVersion:"1.0.0"},view:{version:"1.0.0",dmVersion:"1.0.0"},text:{version:"1.0.0",dmVersion:"1.0.0"},image:{version:"1.0.0",dmVersion:"1.0.0"},label:{version:"1.0.0",dmVersion:"1.0.0"},input:{version:"1.0.0",dmVersion:"1.0.0"},textarea:{version:"1.0.0",dmVersion:"1.0.0"},form:{version:"1.0.0",dmVersion:"1.0.0"},button:{version:"1.0.0",dmVersion:"1.0.0"},"rich-text":{version:"1.0.0",dmVersion:"1.0.0"},swiper:{version:"1.0.0",dmVersion:"1.0.0"},picker:{version:"1.0.0",dmVersion:"1.0.0"},"swiper-item":{version:"1.0.0",dmVersion:"1.0.0"},navigator:{version:"1.0.0",dmVersion:"1.0.0"},radio:{version:"1.0.0",dmVersion:"1.0.0"},"radio-group":{version:"1.0.0",dmVersion:"1.0.0"},switch:{version:"1.0.0",dmVersion:"1.0.0"},slider:{version:"1.0.0",dmVersion:"1.0.0"},"scroll-view":{version:"1.0.0",dmVersion:"1.0.0"},map:{version:"1.0.0",dmVersion:"1.0.0"},"functional-map":{version:"1.0.0",dmVersion:"1.0.0"},"global-map":{version:"2.23.0",dmVersion:"1.22.0"},"cover-view":{version:"1.0.0",dmVersion:"1.0.0"},checkbox:{version:"1.0.0",dmVersion:"1.0.0"},"checkbox-group":{version:"1.0.0",dmVersion:"1.0.0"},"web-view":{version:"1.0.0",dmVersion:"1.0.0"},"movable-area":{version:"1.0.0",dmVersion:"1.0.0"},"movable-view":{version:"1.0.0",dmVersion:"1.0.0"},nextTick:{version:"1.0.0",dmVersion:"1.0.0"},createAnimation:{version:"1.0.0",dmVersion:"1.0.0"},createSelectorQuery:{version:"1.0.0",dmVersion:"1.0.0"},createIntersectionObserver:{version:"1.0.0",dmVersion:"1.0.0"},createMediaQueryObserver:{version:"1.0.0",dmVersion:"1.0.0"},onAppHide:{version:"1.0.0",dmVersion:"1.0.0"},startPullDownRefresh:{version:"1.0.0",dmVersion:"1.0.0"},stopPullDownRefresh:{version:"1.0.0",dmVersion:"1.0.0"},enablePullDownRefresh:{version:"1.0.0",dmVersion:"1.0.0"},disablePullDownRefresh:{version:"1.0.0",dmVersion:"1.0.0"},navigateTo:{version:"1.0.0",dmVersion:"1.0.0"},redirectTo:{version:"1.0.0",dmVersion:"1.0.0"},navigateBack:{version:"1.0.0",dmVersion:"1.0.0"},switchTab:{version:"1.0.0",dmVersion:"1.0.0"},reLaunch:{version:"1.0.0",dmVersion:"1.0.0"},launch:{version:"1.0.0",dmVersion:"1.0.0"},getRealRoute:{version:"1.0.0",dmVersion:"1.0.0"},getLocalFilePath:{version:"1.0.0",dmVersion:"1.0.0"},getStorageSync:{version:"1.0.0",dmVersion:"1.0.0"},setStorageSync:{version:"1.0.0",dmVersion:"1.0.0"},removeStorageSync:{version:"1.0.0",dmVersion:"1.0.0"},removeStorage:{version:"1.0.0",dmVersion:"1.0.0"},getStorageInfo:{version:"1.0.0",dmVersion:"1.0.0"},setStorage:{version:"1.0.0",dmVersion:"1.0.0"},clearStorage:{version:"1.0.0",dmVersion:"1.0.0"},setBackgroundFetchToken:{version:"1.12.0",dmVersion:"1.3.0"},getBackgroundFetchData:{version:"1.12.0",dmVersion:"1.3.0"},showLoading:{version:"1.0.0",dmVersion:"1.0.0"},hideLoading:{version:"1.0.0",dmVersion:"1.0.0"},showToast:{version:"1.0.0",dmVersion:"1.0.0"},showModal:{version:"1.0.0",dmVersion:"1.0.0"},getImageInfo:{version:"1.0.0",dmVersion:"1.0.0"},getSystemInfo:{version:"1.0.0",dmVersion:"1.0.0"},getSystemInfoSync:{version:"1.0.0",dmVersion:"1.0.0"},getSystemSetting:{version:"2.8.0",dmVersion:"1.7.0"},setNavigationBarTitle:{version:"1.0.0",dmVersion:"1.0.0"},saveImageToPhotosAlbum:{version:"1.0.0",dmVersion:"1.0.0"},request:{version:"1.0.0",dmVersion:"1.0.0"},RequestTask:{version:"2.9.0",dmVersion:"1.7.6"},getLocation:{version:"1.0.0",dmVersion:"1.0.0"},getLaunchOptionsSync:{version:"1.0.0",dmVersion:"1.0.0"},chooseImage:{version:"1.0.0",dmVersion:"1.0.0"},scanCode:{version:"1.0.0",dmVersion:"1.0.0"},makePhoneCall:{version:"1.0.0",dmVersion:"1.0.0"},getSavedFileInfo:{version:"1.0.0",dmVersion:"1.0.0"},downloadFile:{version:"1.0.0",dmVersion:"1.0.0"},DownloadTask:{version:"2.11.0",dmVersion:"1.7.6"},getFileInfo:{version:"1.0.0",dmVersion:"1.0.0"},saveFile:{version:"1.0.0",dmVersion:"1.0.0"},removeSavedFile:{version:"1.0.0",dmVersion:"1.0.0"},uploadFile:{version:"1.0.0",dmVersion:"1.0.0"},UploadTask:{version:"2.9.0",dmVersion:"1.7.6"},setClipboardData:{version:"1.0.0",dmVersion:"1.0.0"},getClipboardData:{version:"1.0.0",dmVersion:"1.0.0"},getFileSystemManager:{version:"1.0.0",dmVersion:"1.0.0"},onAppRoute:{version:"1.0.0",dmVersion:"1.0.0"},canIUse:{version:"1.0.0",dmVersion:"1.0.0"},checkBridgeExist:{version:"1.0.0",dmVersion:"1.0.0"},getUpdateManager:{version:"1.0.0",dmVersion:"1.0.0"},reportEvent:{version:"11.0.0",dmVersion:"11.0.0"},reportAnalytics:{version:"1.0.0",dmVersion:"1.0.0"},navigateToMiniProgram:{version:"1.0.0",dmVersion:"1.0.0"},authorize:{version:"1.14.0",dmVersion:"1.3.0"},openSetting:{version:"1.0.0",dmVersion:"1.0.0"},getSetting:{version:"1.0.0",dmVersion:"1.0.0"},setNavigationBarColor:{version:"1.0.0",dmVersion:"1.0.0"},customShare:{version:"1.0.0",dmVersion:"1.0.0"},showShareEntrance:{version:"1.0.0",dmVersion:"1.0.0"},hideShareEntrance:{version:"1.0.0",dmVersion:"1.0.0"},shareWeixinAppmsg:{version:"1.0.0",dmVersion:"1.0.0"},shareWeixinTimeline:{version:"1.0.0",dmVersion:"1.0.0"},shareMessage:{version:"1.0.0",dmVersion:"1.0.0"},getMenuButtonBoundingClientRect:{version:"1.0.0",dmVersion:"1.0.0"},pageScrollTo:{version:"1.0.0",dmVersion:"1.0.0"},previewImage:{version:"1.0.0",dmVersion:"1.0.0"},requestPayment:{version:"1.0.0",dmVersion:"1.0.0"},extBridge:{version:"1.0.0",dmVersion:"1.0.0"},setTabBarBadge:{version:"1.0.0",dmVersion:"1.0.0"},openLocation:{version:"1.0.0",dmVersion:"1.0.0"},showCapsuleButton:{version:"1.0.0",dmVersion:"1.0.0"},hideCapsuleButton:{version:"1.0.0",dmVersion:"1.0.0"},triggerGC:{version:"1.0.0",dmVersion:"1.0.0"},vibrateShort:{version:"1.0.0",dmVersion:"1.0.0"},vibrateLong:{version:"2.8.0",dmVersion:"1.7.0"},onMemoryWarning:{version:"1.0.0",dmVersion:"1.0.0"},offMemoryWarning:{version:"1.0.0",dmVersion:"1.0.0"},closeDimina:{version:"1.0.0",dmVersion:"1.0.0"},getNetworkType:{version:"1.0.0",dmVersion:"1.0.0"},onNetworkStatusChange:{version:"1.0.0",dmVersion:"1.0.0"},offNetworkStatusChange:{version:"1.0.0",dmVersion:"1.0.0"},loginNotifition:{version:"1.0.0",dmVersion:"1.0.0"},logout:{version:"1.0.0",dmVersion:"1.0.0"},login:{version:"1.0.0",dmVersion:"1.0.0"},passportLogin:{version:"1.0.0",dmVersion:"1.0.0"},businessAuthorize:{version:"2.1.0",dmVersion:"1.4.0"},onUnhandledRejection:{version:"1.0.0",dmVersion:"1.4.3"},offUnhandledRejection:{version:"1.0.0",dmVersion:"1.4.3"},setScreenBrightness:{version:"2.8.0",dmVersion:"1.7.0"},setKeepScreenOn:{version:"2.8.0",dmVersion:"1.7.0"},onUserCaptureScreen:{version:"2.8.0",dmVersion:"1.7.0"},offUserCaptureScreen:{version:"2.8.0",dmVersion:"1.7.0"},getScreenBrightness:{version:"2.8.0",dmVersion:"1.7.0"},startRecord:{version:"2.8.0",dmVersion:"1.7.0"},stopRecord:{version:"2.8.0",dmVersion:"1.7.0"},startWifi:{version:"2.8.0",dmVersion:"1.7.0"},stopWifi:{version:"2.8.0",dmVersion:"1.7.0"},getWifiList:{version:"2.8.0",dmVersion:"1.7.0"},onGetWifiList:{version:"2.8.0",dmVersion:"1.7.0"},offGetWifiList:{version:"2.8.0",dmVersion:"1.7.0"},getConnectedWifi:{version:"2.8.0",dmVersion:"1.7.0"},onWifiConnected:{version:"2.8.0",dmVersion:"1.7.0"},offWifiConnected:{version:"2.8.0",dmVersion:"1.7.0"},showActionSheet:{version:"2.8.0",dmVersion:"1.7.0"},enableAlertBeforeUnload:{version:"2.8.0",dmVersion:"1.7.0"},disableAlertBeforeUnload:{version:"2.8.0",dmVersion:"1.7.0"},getAccountInfoSync:{version:"2.6.0",dmVersion:"1.6.0"},chooseContact:{version:"2.11.0",dmVersion:"1.8.0"},addPhoneContact:{version:"2.11.0",dmVersion:"1.8.0"},chooseVideo:{version:"2.13.0",dmVersion:"1.9.0"},getVideoInfo:{version:"2.13.0",dmVersion:"1.9.0"},saveVideoToPhotosAlbum:{version:"2.13.0",dmVersion:"1.9.0"},chooseMedia:{version:"2.13.0",dmVersion:"1.9.0"},compressVideo:{version:"2.13.0",dmVersion:"1.9.0"},showTabBar:{version:"2.8.0",dmVersion:"1.6.2"},hideTabBar:{version:"2.8.0",dmVersion:"1.6.2"},setTabBarStyle:{version:"10000.0.0",dmVersion:"10000.0.0"},getPerformance:{version:"2.11.0",dmVersion:"1.8.0"},choosePoi:{version:"3.0.0",dmVersion:"1.8.0"},chooseLocation:{version:"3.0.0",dmVersion:"1.8.0"},shareQqAppmsg:{version:"10000.0.0",dmVersion:"10000.0.0"},shareQzone:{version:"10000.0.0",dmVersion:"10000.0.0"},shareAlipayFriend:{version:"10000.0.0",dmVersion:"10000.0.0"},shareAlipayLife:{version:"10000.0.0",dmVersion:"10000.0.0"},shareSinaWeibo:{version:"10000.0.0",dmVersion:"10000.0.0"},requestSubscribeMessage:{version:"10000.0.0",dmVersion:"10000.0.0"},getRealtimeLogManager:{version:"10000.0.0",dmVersion:"10000.0.0"},openBusinessView:{version:"10000.0.0",dmVersion:"10000.0.0"},registerLocalNotify:{version:"2.13.0",dmVersion:"1.9.0"},checkLocalNotify:{version:"2.13.0",dmVersion:"1.9.0"},removeLocalNotify:{version:"2.13.0",dmVersion:"1.9.0"},reportUncaughtError:{version:"2.21.0",dmVersion:"1.14.0"},loginAndShowLegalDialog:{version:"2.23.0",dmVersion:"1.18.0"},getLoginLegalInfo:{version:"2.23.0",dmVersion:"1.18.0"}},yl=function(e){if(!hl[e])return!1;if(!ll||!pl){var t=dd.getSystemInfoSync();ll=(null==t?void 0:t.SDKVersion)||"10.0.0",pl=(null==t?void 0:t.jssdkVersion)||"10.0.0"}var n=dl(ll,hl[e].version),r=dl(pl,hl[e].dmVersion);return n>=0&&r>=0},gl=function(t,n){var r={};if(t){if(n)for(var i in n){var o=n[i];void 0===o||!o&&void 0!==o&&0!==o||(r[i]=n[i]),"object"===e(o)&&(r[i]=JSON.stringify(n[i]))}xu({event:"reportAnalytics",data:{eventName:""+t,data:ki({},r)},success:n&&n.success,fail:n&&n.fail,complete:n&&n.complete})}},vl=function(e,t){e&&xu({event:"traceServiceCoreDotting",data:{eventName:""+e,data:ki({},t)}})},ml=function(e,t){if(void 0===t&&(t=!1),vl("app_error",{info:e,isError:!0}),wl("tech_saga_app_err",{err_info:e,err_type:1}),!t){var n=__appServiceEngine__.getApp();n&&n.onError&&n.onError(e)}},bl=[],Sl=0;function wl(e,t){"reportMiniProgram"!==t.apiName&&xu({event:"reportMiniProgram",data:{eventName:""+e,data:ki({},t)}})}var _l=function(e){xu({event:"fileSystemReadFile",data:{filePath:e.filePath,encoding:e.encoding},success:e.success,fail:e.fail,complete:e.complete})},kl=function(e,t){return Ou({event:"fileSystemReadFileSync",data:{filePath:e,encoding:t}}).data},Ml=function(e){xu({event:"fileSystemWriteFile",data:{filePath:e.filePath,data:e.data,encoding:e.encoding},success:e.success,fail:e.fail,complete:e.complete})},Tl=function(e,t,n){return Ou({event:"fileSystemWriteFileSync",data:{filePath:e,data:t,encoding:n}}).data},Nl=null,Il=[],xl=null;function Ol(){var e=Il;Il=[],xl=null;for(var t=0;t<e.length;t++)e[t]()}var Pl=u.TypeError,Ll=function(e){return function(t,n,r,i){Y(n);var o=se(t),a=P(o),s=bt(o),c=e?s-1:0,u=e?-1:1;if(r<2)for(;;){if(c in a){i=a[c],c+=u;break}if(c+=u,e?c<0:s<=c)throw Pl("Reduce of empty array with no initial value")}for(;e?c>=0:s>c;c+=u)c in a&&(i=n(i,a[c],c,o));return i}},El={left:Ll(!1),right:Ll(!0)}.left,Al=Dt("reduce");Ft({target:"Array",proto:!0,forced:!Al||!tr&&q>79&&q<83},{reduce:function(e){var t=arguments.length;return El(this,e,t,t>1?arguments[1]:void 0)}});var Cl=function(){function e(e){void 0===e&&(e={}),this.actions=[],this.currentTransform={},this.currentStepAnimates=[],this.option={transition:{duration:void 0!==e.duration?e.duration:400,timingFunction:void 0!==e.timingFunction?e.timingFunction:"linear",delay:void 0!==e.delay?e.delay:0},transformOrigin:e.transformOrigin||"50% 50% 0"}}return e.prototype.export=function(){var e=this.actions;return this.actions=[],{actions:e}},e.prototype.step=function(e){void 0===e&&(e={});for(var t=this,n=0,r=this.currentStepAnimates;n<r.length;n++){var i=r[n];"style"===i.type?this.currentTransform[i.type+"."+i.args[0]]=i:this.currentTransform[i.type]=i}return this.actions.push({animates:Object.keys(this.currentTransform).reduce((function(e,n){return[].concat.apply([],function(){for(var e=0,t=0,n=arguments.length;t<n;t++)e+=arguments[t].length;var r=Array(e),i=0;for(t=0;t<n;t++)for(var o=arguments[t],a=0,s=o.length;a<s;a++,i++)r[i]=o[a];return r}(e,[[t.currentTransform[n]]]))}),[]),option:{transformOrigin:void 0!==e.transformOrigin?e.transformOrigin:this.option.transformOrigin,transition:{duration:void 0!==e.duration?e.duration:this.option.transition.duration,timingFunction:void 0!==e.timingFunction?e.timingFunction:this.option.transition.timingFunction,delay:void 0!==e.delay?e.delay:this.option.transition.delay}}}),this.currentStepAnimates=[],this},e.prototype.matrix=function(e,t,n,r,i,o){return void 0===e&&(e=1),void 0===t&&(t=0),void 0===n&&(n=0),void 0===r&&(r=1),void 0===i&&(i=1),void 0===o&&(o=1),this.currentStepAnimates.push({type:"matrix",args:[e,t,n,r,i,o]}),this},e.prototype.matrix3d=function(e,t,n,r,i,o,a,s,c,u,f,d,l,p,h,y){return void 0===e&&(e=1),void 0===t&&(t=0),void 0===n&&(n=0),void 0===r&&(r=0),void 0===i&&(i=0),void 0===o&&(o=1),void 0===a&&(a=0),void 0===s&&(s=0),void 0===c&&(c=0),void 0===u&&(u=0),void 0===f&&(f=1),void 0===d&&(d=0),void 0===l&&(l=0),void 0===p&&(p=0),void 0===h&&(h=0),void 0===y&&(y=1),this.currentStepAnimates.push({type:"matrix3d",args:[e,t,n,r,i,o,a,s,c,u,f,d,l,p,h,y]}),this},e.prototype.rotate=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"rotate",args:[e]}),this},e.prototype.rotate3d=function(e,t,n,r){return void 0===e&&(e=0),void 0===t&&(t=0),void 0===n&&(n=0),void 0===r&&(r=0),this.currentStepAnimates.push({type:"rotate3d",args:[e,t,n,r]}),this},e.prototype.rotateX=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"rotateX",args:[e]}),this},e.prototype.rotateY=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"rotateY",args:[e]}),this},e.prototype.rotateZ=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"rotateZ",args:[e]}),this},e.prototype.scale=function(e,t){return void 0===e&&(e=1),void 0===t&&(t=1),this.currentStepAnimates.push({type:"scale",args:[e,t]}),this},e.prototype.scale3d=function(e,t,n){return void 0===e&&(e=1),void 0===t&&(t=1),void 0===n&&(n=1),this.currentStepAnimates.push({type:"scale3d",args:[e,t,n]}),this},e.prototype.scaleX=function(e){return void 0===e&&(e=1),this.currentStepAnimates.push({type:"scaleX",args:[e]}),this},e.prototype.scaleY=function(e){return void 0===e&&(e=1),this.currentStepAnimates.push({type:"scaleY",args:[e]}),this},e.prototype.scaleZ=function(e){return void 0===e&&(e=1),this.currentStepAnimates.push({type:"scaleZ",args:[e]}),this},e.prototype.skew=function(e,t){return void 0===e&&(e=0),void 0===t&&(t=0),this.currentStepAnimates.push({type:"skew",args:[e,t]}),this},e.prototype.skewX=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"skewX",args:[e]}),this},e.prototype.skewY=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"skewY",args:[e]}),this},e.prototype.translate=function(e,t){return void 0===e&&(e=0),void 0===t&&(t=0),this.currentStepAnimates.push({type:"translate",args:[e,t]}),this},e.prototype.translate3d=function(e,t,n){return void 0===e&&(e=0),void 0===t&&(t=0),void 0===n&&(n=0),this.currentStepAnimates.push({type:"translate3d",args:[e,t,n]}),this},e.prototype.translateX=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"translateX",args:[e]}),this},e.prototype.translateY=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"translateY",args:[e]}),this},e.prototype.translateZ=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"translateZ",args:[e]}),this},e.prototype.opacity=function(e){return this.currentStepAnimates.push({type:"style",args:["opacity",e]}),this},e.prototype.backgroundColor=function(e){return this.currentStepAnimates.push({type:"style",args:["background-color",e]}),this},e.prototype.width=function(e){return Fa(e)&&(e+="px"),this.currentStepAnimates.push({type:"style",args:["width",e]}),this},e.prototype.height=function(e){return Fa(e)&&(e+="px"),this.currentStepAnimates.push({type:"style",args:["height",e]}),this},e.prototype.left=function(e){return Fa(e)&&(e+="px"),this.currentStepAnimates.push({type:"style",args:["left",e]}),this},e.prototype.right=function(e){return Fa(e)&&(e+="px"),this.currentStepAnimates.push({type:"style",args:["right",e]}),this},e.prototype.top=function(e){return Fa(e)&&(e+="px"),this.currentStepAnimates.push({type:"style",args:["top",e]}),this},e.prototype.bottom=function(e){return Fa(e)&&(e+="px"),this.currentStepAnimates.push({type:"style",args:["bottom",e]}),this},e}();var jl=function(){function e(e,t,n,r){this._selectorQuery=e,this._component=t,this._selector=n,this._single=r}return e.prototype.fields=function(e,t){return this._selectorQuery._push(this._selector,this._component,this._single,e,t),this._selectorQuery},e.prototype.boundingClientRect=function(e){return this.fields({id:!0,dataset:!0,rect:!0,size:!0},e)},e.prototype.scrollOffset=function(e){return this.fields({id:!0,dataset:!0,scrollOffset:!0},e)},e.prototype.context=function(e){return this.fields({context:!0},e)},e.prototype.node=function(e){return this.fields({node:!0},e)},e}(),Vl=function(){function e(){this.width=0,this.height=0,this.src="",this.path=null,this.onload=void 0,this.onerror=void 0,this._onload=void 0,this._onerror=void 0,this._complete=!1,this._status=null,this._sendTime=null,Object.defineProperty(this,"onload",{set:function(e){e&&"function"==typeof e?(this._onload=e,this._complete&&this._status&&(this._complete=!1,e())):this._onload=void 0},get:function(){return this._onload}}),Object.defineProperty(this,"onerror",{set:function(e){e&&"function"==typeof e?(this._onerror=e,this._complete&&!1===this._status&&(this._complete=!1,e())):this._onerror=void 0},get:function(){return this._onerror}}),Object.defineProperty(this,"src",{set:function(e){this._src=e,this.checkImageValid(e,""+Date.now())},get:function(){return this._src}})}return e.prototype.checkImageValid=function(e,t){var n=this;this._complete=!1,this._status=null,this._sendTime=t,xu({event:"getImageInfo",data:{src:e}},(function(e){n._sendTime===t&&(n._complete=!0,n.dealCheckResult(e))}))},e.prototype.dealCheckResult=function(e){var t=e.width,n=e.height,r=e.path,i=!!t&&!!n&&!!r;this._status=i,this.width=t||0,this.height=n||0,this.path=r||null,i&&this._onload?this._onload():!i&&this._onerror&&this._onerror()},e}(),Bl=["shadowBlur","shadowOffsetX","shadowOffsetY","lineCap","lineJoin","lineWidth","miterLimit","font","textAlign","textBaseline","direction"],Rl=["fillStyle","strokeStyle","shadowColor"],zl=[{key:"clearRect",params:["x","y","width","height"],extParams:[]},{key:"fillRect",params:["x","y","width","height"],extParams:[]},{key:"strokeRect",params:["x","y","width","height"],extParams:[]},{key:"fillText",params:["text","x","y"],extParams:["maxWidth"]},{key:"strokeText",params:["text","x","y"],extParams:["maxWidth"]},{key:"measureText",params:["text"],extParams:[]},{key:"beginPath",params:[],extParams:[]},{key:"closePath",params:[],extParams:[]},{key:"moveTo",params:["x","y"],extParams:[]},{key:"lineTo",params:["x","y"],extParams:[]},{key:"bezierCurveTo",params:["cp1x","cp1y","cp2x","cp2y","x","y"],extParams:[]},{key:"quadraticCurveTo",params:["cpx","cpy","x","y"],extParams:[]},{key:"arc",params:["x","y","radius","startAngle","endAngle"],extParams:["anticlockwise"]},{key:"rect",params:["x","y","width","height"],extParams:[]},{key:"fill",params:[],extParams:[]},{key:"stroke",params:[],extParams:[]},{key:"clip",params:[],extParams:[]},{key:"rotate",params:["angle"],extParams:[]},{key:"scale",params:["x","y"],extParams:[]},{key:"translate",params:["x","y"],extParams:[]},{key:"transform",params:["a","b","c","d","e","f"],extParams:[]},{key:"setTransform",params:["a","b","c","d","e","f"],extParams:[]},{key:"save",params:[],extParams:[]},{key:"restore",params:[],extParams:[]}],Fl=function(){function e(e){var t=this;this.viewId=e,Bl.forEach((function(e){Object.defineProperty(t,e,{set:function(n){var r;Kd(t.viewId,e,((r={})[e]=n,r))},get:function(){return Kd(t.viewId,e)}})})),Rl.forEach((function(e){Object.defineProperty(t,"_"+e,{value:"#000000",writable:!0}),Object.defineProperty(t,e,{set:function(n){var r,i=function(e){if("string"==typeof e){if(e=e.toLowerCase().replace(/\s+/g,""),/^#([0-9|a-f]{6})$/.test(e))return e;if(/^#([0-9|a-f]{8})$/.test(e))return"ff"===e.slice(7)?e.slice(0,7):el([Xd(e.slice(1,3)),Xd(e.slice(3,5)),Xd(e.slice(5,7)),Xd(e.slice(7))/Hd.MAX_COLOR_VALUE]);if(/^#([0-9|a-f]{3,4})$/.test(e)){var t=e.slice(1,2),n=e.slice(2,3),r=e.slice(3,4),i=void 0;return 4===e.length||"f"===(i=e.slice(4))?"#"+t+t+n+n+r+r:el([Xd(t+t),Xd(n+n),Xd(r+r),Xd(i+i)/Hd.MAX_COLOR_VALUE])}if(/^rgb[a]?\(((-|\+?)\d+(\.\d+)?,){2,3}(-|\+?)\d+(\.\d+)?\)$/.test(e)){var o=e.split(",");return t=o[0].split("(")[1],n=o[1],r=o[2],"rgba"===e.slice(0,4)&&o[3]&&(i=Zd(o[3].split(")")[0]))<1?el([Zd(t),Zd(n),Zd(r),i]):"#"+Yd(t)+Yd(n)+Yd(r)}if(Qd[e])return Qd[e]}return null}(n);i&&(Array.isArray(i)?(t["_"+e]="rgba("+i.join(", ")+")",i="#"+Yd(""+parseFloat(i[3])*Hd.MAX_COLOR_VALUE)+Yd(i[0])+Yd(i[1])+Yd(i[2])):t["_"+e]=i,Kd(t.viewId,e,((r={})[e]=i,r)))},get:function(){return t["_"+e]}})})),zl.forEach((function(e){var n=e.key,r=e.params,i=e.extParams;t[n]=function(){for(var e=[],o=0;o<arguments.length;o++)e[o]=arguments[o];var a={},s=e.length,c=r.length;if(s<c)throw new TypeError("Failed to execute '"+n+"' on 'CanvasRenderingContext2D': "+r.length+" arguments required, but only "+e.length+" present.");for(var u=i.length,f=0;f<c;f++)a[r[f]]=e[f];if(s>c)for(f=0;f<u;f++)a[i[f]]=e[f+c];return Kd(t.viewId,n,a)}}))}return e.prototype.drawImage=function(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];if(!(e instanceof Vl))throw new TypeError("Failed to execute 'drawImage' on 'CanvasRenderingContext2D': image must be created by canvas.");if(![2,4,8].includes(t.length))throw new TypeError("Failed to execute 'drawImage' on 'CanvasRenderingContext2D': Overload resolution failed.");if(e.path){var r={src:e.path},i=void 0,o=void 0,a=void 0,s=void 0;2===t.length||4===t.length?(i=t[0],o=t[1],a=t[2]||null,s=t[3]||null):(r.sx=t[0],r.sy=t[1],r.sWidth=t[2],r.sHeight=t[3],i=t[4],o=t[5],a=t[6],s=t[7]),r.dx=i,r.dy=o,a&&(r.dWidth=a,r.dHeight=s),Kd(this.viewId,"drawImage",r)}},e}(),Dl=function(){function e(e,t){var n=this;this._width=300,this._height=150,this._webViewId=e,this._nodeId=t,this.canvasRef=null,Object.defineProperty(this,"width",{get:function(){return n._width},set:function(e){e=Wl(e),n._width=e,Kd(n._nodeId,"width",{width:e})}}),Object.defineProperty(this,"height",{get:function(){return n._height},set:function(e){e=Wl(e),n._height=e,Kd(n._nodeId,"height",{height:e})}})}return e.prototype.getContext=function(e){if(!this.canvasRef&&"2d"===e){var t=Kd(this._nodeId,"getContext",{type:"2d"});if(!(null==t?void 0:t.canvasId))return null;this.canvasRef=new Fl(this._nodeId)}return this.canvasRef},e.prototype.createImage=function(){return new Vl},e.prototype.createImageData=function(){},e.prototype.createPath2D=function(){},e.prototype.requestAnimationFrame=function(){},e.prototype.cancelAnimationFrame=function(){},e.prototype.toDataURL=function(e,t){return void 0===e&&(e="image/png"),Kd(this._nodeId,"toDataURL",{type:e,encoderOptions:t})},e}();function Wl(e){try{var t=Math.abs(parseInt(e));return isNaN(t)?0:t}catch(e){return 0}}Js("Map",(function(e){return function(){return e(this,arguments.length?arguments[0]:void 0)}}),xf);var Ul=function(){function e(e){this.lottieId="",this.src="",this._onDataReady=void 0,this._onDataFailed=void 0,this._complete=!1,this._status=null,this._sendTime=null,this.onCompletionCallbackLottie=null,this.lottieId=e,Object.defineProperty(this,"src",{set:function(e){this._src=e,this.srcLottie(e,""+Date.now())},get:function(){return this._src}})}return e.prototype.onDataReady=function(e){e&&"function"==typeof e?(this._onDataReady=e,this._complete&&this._status&&(this._complete=!1,e())):this._onDataReady=void 0},e.prototype.onDataFailed=function(e){e&&"function"==typeof e?(this._onDataFailed=e,this._complete&&!1===this._status&&(this._complete=!1,e())):this._onDataFailed=void 0},e.prototype.srcLottie=function(e,t){var n=this;this._complete=!1,this._status=null,this._sendTime=t,xu({event:"srcLottie",data:{src:e,lottieId:this.lottieId},success:function(){n._sendTime===t&&(n._complete=!0,n._status=!0,n._onDataReady&&n._onDataReady())},fail:function(e){n._sendTime===t&&(n._complete=!0,n._status=!1,n._onDataFailed&&n._onDataFailed(e.data))}})},e.prototype.setLoopLottie=function(e){xu({event:"setLoopLottie",data:{isLoop:e,lottieId:this.lottieId}})},e.prototype.playAnimationLottie=function(){xu({event:"playAnimationLottie",data:{lottieId:this.lottieId}})},e.prototype.cancelAnimationLottie=function(){xu({event:"cancelAnimationLottie",data:{lottieId:this.lottieId}})},e.prototype.setOnCompletionCallbackLottie=function(e){var t=this;this.onCompletionCallbackLottie&&didiJsBridge.off({event:"onCompletionCallbackLottie",callback:this.onCompletionCallbackLottie}),"function"==typeof e&&(this.onCompletionCallbackLottie=function(n){var r;(null===(r=n.data)||void 0===r?void 0:r.lottieId)===t.lottieId&&e()},didiJsBridge.on({event:"onCompletionCallbackLottie",callback:this.onCompletionCallbackLottie}))},e}(),ql=new Map;function Jl(e,t,n,r){if(e)if(Array.isArray(e))e.forEach((function(e){return Jl(e,t,n)}));else{var i=e.nodeIs;if(i){var o=e.nodeId;"dd-canvas"===i&&o?e.node=function(e,t){if("2d"===t){var n=function(e,t){var n,r=$d(e,t);return(null===(n=tl[e])||void 0===n?void 0:n[r])||null}(fd.currentWebviewId,e);return n||(n=new Dl(fd.currentWebviewId,e),function(e,t,n){var r=$d(e,t);tl[e]?tl[e][r]=n:tl[e]={id:n}}(fd.currentWebviewId,e,n),n)}}(o,e.nodeCanvasType):"dd-lottie"===i&&o&&(e.node=(a=o,ql.has(a)||ql.set(a,new Ul(a)),ql.get(a))),delete e.nodeIs,delete e.nodeId,delete e.nodeCanvasType,e.node&&"function"==typeof e.node._onReady&&n.push(new Promise((function(t){return e.node._onReady(t)})))}}var a}var Gl={},Hl={};function Ql(e,t){return Gl[t]||(Gl[t]=function(e){return function(){function t(e){if(e&&e.page)this._component=this._defaultComponent=e.page,this._webViewId=this._defaultComponent.__ddWebViewId__;else{var t=__appServiceEngine__.getCurrentPagesByDomain("");this._defaultComponent=t[t.length-1],this._component=null,this._webViewId=null}this._queue=[],this._queueCb=[]}return t.prototype.in=function(e){return null===this._webViewId?(this._webViewId=e.__ddWebViewId__,this._component=e):this._webViewId!==e.__ddWebViewId__||(this._component=e),this},t.prototype.select=function(e){return new jl(this,this._component,e,!0)},t.prototype.selectAll=function(e){return new jl(this,this._component,e,!1)},t.prototype.selectViewport=function(){return new jl(this,0,"",!0)},t.prototype._push=function(t,n,r,i,o){null===this._webViewId&&(this._webViewId=this._defaultComponent?this._defaultComponent.__ddWebViewId__:void 0);var a=e?"":__virtualDOM__.getRootNodeId(this._webViewId),s=null!=n?0===n?0:n.__ddExparserNodeId__:a;this._queue.push({component:s,selector:t,single:r,fields:i}),this._queueCb.push(o||null)},t.prototype.exec=function(t){var n=this,r=this,i=this._webViewId,o={pluginId:e,queue:this._queue},a=function(e){return Mi(n,void 0,void 0,(function(){var n,i,o,a=this;return Ti(this,(function(s){switch(s.label){case 0:return n=this._queueCb,i=[],o=[],e.forEach((function(e,t){Jl(e,a._component,o),Wa(n[t])&&i.push((function(){n[t].call(r,e)}))})),Wa(t)&&i.push((function(){t.call(r,e)})),o.length?[4,Promise.all(o)]:[3,2];case 1:s.sent(),s.label=2;case 2:return i.forEach((function(e){return e()})),[2]}}))}))};if(null!=i)var s=__virtualDOM__.requestViewInfo("selectorQuery",o,i,(function(e){a&&(__virtualDOM__.endViewInfoCallback(i,s),a&&a(e))}))},t}()}(t)),new Gl[t](e)}function $l(e,t,n){return Hl[n]||(Hl[n]=function(e){return function(){function t(e,t){if(this._component=e,this._options=t,this._relativeInfo=[],this._observerId=null,this._disconnected=!1,this._component)this._webViewId=this._component.__ddWebViewId__;else{var n=__appServiceEngine__.getCurrentPagesByDomain("");n.length&&(this._webViewId=n[n.length-1].__ddWebViewId__)}}return t.requestViewInfo=function(e,t,n){var r=__virtualDOM__.requestViewInfo("intersection",t,e,(function(t){t.reqEnd&&__virtualDOM__.endViewInfoCallback(e,r),n&&!t.reqEnd&&n(t)}))},t.prototype.relativeTo=function(e,t){if(null!==this._observerId)throw new Error('Relative nodes cannot be added after "observe" call in IntersectionObserver');return this._relativeInfo.push({selector:e,margins:t}),this},t.prototype.relativeToViewport=function(e){if(null!==this._observerId)throw new Error('Relative nodes cannot be added after "observe" call in IntersectionObserver');return this._relativeInfo.push({selector:null,margins:e}),this},t.prototype.observe=function(n,r){var i=this;if(null!==this._observerId)throw new Error('"observe" call can be only called once in IntersectionObserver');this._observerId="";var o=this._component;t.requestViewInfo(this._webViewId,{type:"addIntersectionObserver",pluginId:e,nodeId:o?o.__ddExparserNodeId__:__virtualDOM__.getRootNodeId(this._webViewId),targetSelector:n,relativeInfo:this._relativeInfo,options:this._options},(function(e){i._disconnected||(e.observerId&&(i._observerId=e.observerId),e.info&&r.call(i,e.info))}))},t.prototype.disconnect=function(){t.requestViewInfo(this._webViewId,{type:"removeIntersectionObserver",observerId:this._observerId}),this._disconnected=!0},t}()}(n)),new Hl[n](e,t)}var Kl=ku("AppHide").internalOnMethod;ku("AppHide").internalOffMethod;function Xl(e,t,n){var r={event:e,data:t,webViewId:n};didiJsBridge.publish(r)}function Yl(e,t){didiJsBridge.subscribe({event:e},(function(e){var n=e.data,r=void 0===n?{}:n,i=e.webViewId;Wa(t)&&t(r,i)}))}var Zl=!1;var ep=new Tc.EventEmitter2;didiJsBridge.on({event:"onUpdateStatusChange"},(function(e){var t=e&&e.data&&e.data.event||"";ep.emit(t,e)}));var tp,np,rp=null,ip=[];function op(){ip.forEach((function(e){"function"==typeof e&&e(tp)})),ip.length=0}ep.on("updating",(function(){tp={hasUpdate:!0},op()})),ep.on("noupdate",(function(){tp={hasUpdate:!1},op()}));var ap,sp=[],cp=!1;ep.on("updateready",(function(e){cp=!0,np={strategy:e.data.strategy},sp.forEach((function(e){"function"==typeof e&&e(np)})),sp.length=0}));var up=[];ep.on("updatefail",(function(){ap={},up.forEach((function(e){"function"==typeof e&&e(ap)})),up.length=0}));var fp,dp={src:"",startTime:0,paused:!0,currentTime:0,duration:0,obeyMuteSwitch:!0,volume:1,autoplay:!1,loop:!1,buffered:0,referrerPolicy:""},lp=new Map,pp=function(){function e(e){this.src=e.src,this.startTime=e.startTime,this.paused=e.paused,this.currentTime=e.currentTime,this.duration=e.duration,this.obeyMuteSwitch=e.obeyMuteSwitch,this.volume=e.volume,this.autoplay=e.autoplay,this.loop=e.loop,this.buffered=e.buffered,this.referrerPolicy=e.referrerPolicy}return e.prototype.play=function(){xu({event:"audioInstancePlay",data:{audioId:fp,src:this.src,paused:!1,startTime:this.startTime,currentTime:this.currentTime,duration:this.duration,obeyMuteSwitch:this.obeyMuteSwitch,volume:this.volume,autoplay:this.autoplay,loop:this.loop,buffered:this.buffered}})},e.prototype.stop=function(){xu({event:"audioInstanceStop",data:{audioId:fp,src:this.src,paused:this.paused,startTime:this.startTime,currentTime:this.currentTime,duration:this.duration,obeyMuteSwitch:this.obeyMuteSwitch,volume:this.volume,autoplay:this.autoplay,loop:this.loop,buffered:this.buffered}})},e.prototype.destroy=function(){lp.clear()},e.prototype.onPlay=function(e){this.onPlayFuncs=e},e.prototype.onStop=function(e){this.onStopFuncs=e},e.prototype.onEnded=function(e){this.onEndedFuncs=e},e}();didiJsBridge.on({event:"audioInstanceStateChanged"},(function(e){var t=e.data,n=t.audioId,r=t.emitFunctionName,i=lp.get(n);try{i&&"function"==typeof i[r+"Funcs"]&&i[r+"Funcs"]()}catch(e){}}));var hp=new Map;didiJsBridge.on({event:"bindanimationend",callback:function(e){var t=e.data||{},n="string"==typeof t?JSON.parse(t):t,r=n.markerId&&hp.get(n.markerId);r&&"function"==typeof r&&r(n)}});var yp=function(){function e(e,t){this.mapId=e,this.that=t}return e.prototype.addArc=function(e){void 0===e&&(e={}),e.mapId=this.mapId,xu({event:"addArc",data:e,success:e.success,fail:e.fail,complete:e.complete})},e.prototype.removeArc=function(e){void 0===e&&(e={}),e.mapId=this.mapId,xu({event:"removeArc",data:e,success:e.success,fail:e.fail,complete:e.complete})},e.prototype.setCenterOffset=function(e){void 0===e&&(e={}),e.mapId=this.mapId,xu({event:"setCenterOffset",data:e,success:e.success,fail:e.fail,complete:e.complete})},e.prototype.includePoints=function(e){void 0===e&&(e={}),e.mapId=this.mapId,xu({event:"includePoints",data:e,success:e.success,fail:e.fail,complete:e.complete})},e.prototype.getCenterLocation=function(e){void 0===e&&(e={}),e.mapId=this.mapId,xu({event:"getCenterLocation",data:e,success:e.success,fail:e.fail,complete:e.complete})},e.prototype.moveToLocation=function(e){void 0===e&&(e={}),e.mapId=this.mapId,xu({event:"moveToLocation",data:e,success:e.success,fail:e.fail,complete:e.complete})},e.prototype.translateMarker=function(e){void 0===e&&(e={}),e.mapId=this.mapId,xu({event:"translateMarker",data:e,success:e.success,fail:e.fail,complete:e.complete});var t=e.animationEnd;t&&"function"==typeof t&&hp.set(e.markerId,t)},e.prototype.getScale=function(e){void 0===e&&(e={}),e.mapId=this.mapId,xu({event:"getScale",data:e,success:e.success,fail:e.fail,complete:e.complete})},e.prototype.openMapApp=function(e){void 0===e&&(e={}),e.mapId=this.mapId,xu({event:"openMapApp",data:e,success:e.success,fail:e.fail,complete:e.complete})},e}();var gp=function(){function t(){}return t.prototype.takePhoto=function(e){var t=e.quality,n=void 0===t?"normal":t,r=e.success,i=e.fail,o=e.complete;xu({event:"takePhotoCamera",data:{quality:n},success:r,fail:i,complete:o})},t.prototype.setZoom=function(t){var n=t.zoom,r=t.success,i=t.fail,o=t.complete;if("number"!=typeof n)throw new Error("CameraContext.setZoom:fail parameter error: parameter.zoom should be Number instead of "+e(n)+";");xu({event:"setZoomCamera",data:{zoom:n},success:r,fail:i,complete:o})},t.prototype.startRecord=function(e){var t=e.success,n=e.fail,r=e.complete;xu({event:"startRecordCamera",success:t,fail:n,complete:r})},t.prototype.stopRecord=function(e){var t=e.compressed,n=void 0!==t&&t,r=e.success,i=e.fail,o=e.complete;xu({event:"stopRecordCamera",data:{compressed:n},success:r,fail:i,complete:o})},t}();var vp="";function mp(e){return e||null}function bp(e,t,n,r){var i=["then","catch","always"].reduce((function(e,t){return e[t]=function(n){return e[t]=n,e},e}),{}),o=new XMLHttpRequest,a=function(e,t,n){if("get"!==n.toLowerCase()||!t)return e;var r=function(e){return wp(e)?_p(e):e}(t),i=e.indexOf("?")>-1?"&":"?";return e+i+r}(t,n,e);return o.open(e,a,!0),o.withCredentials=r.hasOwnProperty("withCredentials"),function(e,t,n){(function(e){return Object.keys(e).some((function(e){return"content-type"===e.toLowerCase()}))})(t=t||{})||(t["Content-Type"]=wp(n)?"application/json":"application/x-www-form-urlencoded");if("application/x-www-form-urlencoded"===t["Content-Type"]||"application/x-www-form-urlencoded"===t["content-type"]){if(wp(n)){for(var r in n)vp=vp+r+"="+n[r]+"&";vp=vp.substr(0,vp.length-1)}}else vp=wp(n)?JSON.stringify(n):n;Object.keys(t).forEach((function(n){t[n]&&e.setRequestHeader(n,t[n])}))}(o,r.headers,n),o.addEventListener("readystatechange",function(e,t){return function n(){t.readyState===t.DONE&&(t.removeEventListener("readystatechange",n,!1),e.always.apply(e,Sp(t)),t.status>=200&&t.status<300?e.then.apply(e,Sp(t)):e.catch.apply(e,Sp(t)))}}(i,o),!1),o.send(vp),i.abort=function(){return o.abort()},i}function Sp(e){var t;try{t=JSON.parse(e.responseText)}catch(n){t=e.responseText}return[t,e]}function wp(e){return"[object Object]"===Object.prototype.toString.call(e)}function _p(t,n){return Object.keys(t).map((function(r){if(t.hasOwnProperty(r)&&void 0!==t[r]){var i=t[r];return r=n?n+"["+r+"]":r,null!==i&&"object"===e(i)?_p(i,r):kp(r)+"="+kp(i)}})).filter(Boolean).join("&")}function kp(e){return encodeURIComponent(e)}function Mp(e,t){this.eventMap=new Map,this.callbackMap=new WeakMap,this.originalCallbackMap=new WeakMap,this.type=e,this.surround=t,this.on=function(e,t){var n,r;Wa(t)&&(n=t,this.surround&&(r=t,"at"+this.type+e+"callback function",n=function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];try{return r.apply(void 0,e)}catch(e){return}},this.callbackMap.set(t,n),this.originalCallbackMap.set(n,t),this.eventMap.has(e)?this.eventMap.get(e).add(n):this.eventMap.set(e,new Set([n]))))},this.off=function(e,t){var n,r=this,i=this.eventMap.get(e);i&&("function"!=typeof t?(i.forEach((function(e){var t=r.originalCallbackMap.get(e);r.callbackMap.delete(t),r.originalCallbackMap.delete(e)})),i.clear()):this.surround?(n=this.callbackMap.get(t),i.delete(n),this.callbackMap.delete(t),this.originalCallbackMap.delete(n)):i.delete(t))},this.emit=function(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];this.eventMap.has(e)&&new Set(this.eventMap.get(e)).forEach((function(e){return e.apply(void 0,t)}))},this.removeAllListeners=function(e){this.off(e)}}var Tp="pending",Np="then",Ip="catch",xp=function(){function e(e){if(this._status=Tp,this._return=void 0,this._processors=[],"function"!=typeof e)throw new TypeError("Promise resolver is not a function");var t=this;try{e((function(e){t._status===Tp&&(t._status=Np,t._return=e,t._consume())}),(function(e){t._status===Tp&&(t._status=Ip,t._return=e,t._consume())}))}catch(e){}}return e.prototype._consume=function(){if(this._status!==Tp){for(var e=this._processors.shift();e&&e.type!==this._status;)e=this._processors.shift();if(e)try{this._return=e.func(this._return),this._status=Np}catch(e){this._return=e,this._status=Ip}finally{this._consume()}}},e.prototype.then=function(e){return this._processors.push({func:e,type:Np}),this._consume(),this},e.prototype.catch=function(e){return this._processors.push({func:e,type:Ip}),this._consume(),this},e.prototype.resolve=function(t){return new e((function(e){return e(t)}))},e.prototype.reject=function(t){return new e((function(){throw t}))},e}(),Op={currentTaskCount:0,maxTaskCount:10,taskQueue:[],functionName:"",taskIdMap:{}},Pp={};function Lp(e,n){var r=Pp[e]?Pp[e]:Op;didiJsBridge.on({event:"on"+e+"TaskStateChange"},(function(t){!function(e,t){var n=e.taskId,r=e.state,i=e.data;Vp.emit(""+t+n+r,i),("success"===r||"fail"===r)&&(Vp.emit(""+t+n+"complete",i),--Pp[t].currentTaskCount,Pp[t].taskQueue.length>0&&Pp[t].taskQueue.shift().item.createTask(),delete Pp[t].taskIdMap[""+t+n])}(t&&t.data,e)})),Pp[e]=t(r,n)}Lp("Request",{maxTaskCount:10,functionName:"request"}),Lp("Download",{maxTaskCount:10,functionName:"downloadFile"}),Lp("Upload",{maxTaskCount:10,functionName:"uploadFile"});var Ep=new WeakMap,Ap=new WeakMap,Cp=new WeakMap,jp=0,Vp=new Mp("netWork",!0),Bp=function(){function e(e){var t=this,n=e.taskType;++jp,Pp[n].taskIdMap[""+n+jp]=this,Ap.set(this,n),Cp.set(this,e),this.promise=new xp((function(e,n){t.resolve=e,t.reject=n})),Pp[n].currentTaskCount>=Pp[n].maxTaskCount?Pp[n].taskQueue.push({id:""+n+jp,item:this}):this.createTask()}return e.prototype.createTask=function(){var e,t=this,n=Cp.get(this),r=Ap.get(this),i={url:n.url,data:n.data,dataString:(e=n.data,["Object","Array"].includes(Object.prototype.toString.call(e).slice(8,-1))?JSON.stringify(n.data):""),header:n.header,dataType:n.dataType,responseType:n.responseType,method:n.method,timeout:n.timeout,filePath:n.filePath,formData:n.formData,name:n.name};"Request"===r&&(i.dataType||(i.dataType="json"),i.responseType||(i.responseType="text"),i.method||(i.method="GET"));var o=""+r+jp;xu({event:"create"+r+"Task",data:{taskId:o,options:i},success:function(){Ep.set(t,""+o),Pp[r].taskIdMap[o].resolve()},fail:function(e){Pp[r].taskIdMap[o].reject(e)}}),this.promise.then((function(){t.createTaskSuccess()})).catch((function(e){t.createTaskFail(e)}))},e.prototype.createTaskSuccess=function(){var e=Ap.get(this),t=Ep.get(this),n=Cp.get(this);Vp.on(""+e+t+"success",(function(e){n&&n.success&&"function"==typeof n.success&&n.success(e)})),Vp.on(""+e+t+"fail",(function(e){n&&n.fail&&"function"==typeof n.fail&&n.fail(e)})),Vp.on(""+e+t+"complete",(function(e){n&&n.complete&&"function"==typeof n.complete&&n.complete(e)}))},e.prototype.createTaskFail=function(e){var t=Cp.get(this);t&&t.fail&&"function"==typeof t.fail&&t.fail(e),t&&t.complete&&"function"==typeof t.complete&&t.complete(e)},e.prototype.abort=function(){var e=this;this.promise.then((function(){var t=Ap.get(e);xu({event:"operate"+t+"Task",data:{operationType:"abort",taskId:Ep.get(e),extra:{}},success:function(){},fail:function(e){}})}))},e.prototype.onProgressUpdate=function(e){var t=this;Ep.get(this)?Vp.on(""+Ap.get(this)+Ep.get(this)+"progressUpdate",e):this.promise.then((function(){Vp.on(""+Ap.get(t)+Ep.get(t)+"progressUpdate",e)}))},e.prototype.offProgressUpdate=function(e){Vp.off(""+Ap.get(this)+Ep.get(this)+"progressUpdate",e)},e}();var Rp,zp={type:"async",event:"downloadFile",argsSize:1,agrs0Type:"Object",params:{url:{type:["String"],ifMustNeed:!0,default:"",desc:"下载资源的url"},header:{type:["Object"],ifMustNeed:!1,default:{},desc:"HTTP 请求的 Header，Header 中不能设置 Referer"},timeout:{type:["Number"],ifMustNeed:!1,default:"",desc:"超时时间，单位为毫秒"},filePath:{type:["String"],ifMustNeed:!1,default:"",desc:"指定文件下载后存储的路径 (本地路径)"}}},Fp={type:"async",event:"uploadFile",argsSize:1,agrs0Type:"Object",params:{url:{type:["String"],ifMustNeed:!0,default:"",desc:"开发者服务器地址"},filePath:{type:["String"],ifMustNeed:!0,default:"",desc:"要上传文件资源的路径 (本地路径)"},name:{type:["String"],ifMustNeed:!0,default:"",desc:"文件对应的 key，开发者在服务端可以通过这个 key 获取文件的二进制内容"},header:{type:["Object"],ifMustNeed:!1,default:{},desc:"HTTP 请求 Header，Header 中不能设置 Referer"},formData:{type:["Object"],ifMustNeed:!1,default:{},desc:"HTTP 请求中其他额外的 form data"},timeout:{type:["Number"],ifMustNeed:!1,default:"",desc:"超时时间，单位为毫秒"}}},Dp=function(e){if(void 0===e&&(e={url:""}),window.isBrowser){var t=(n={method:e.method||"GET",data:e.data,url:e.url,headers:e.header,timeout:e.timeout,dataType:e.dataType||"json",responseType:e.responseType||"text"},vp="",(n=n||{}).baseUrl=n.baseUrl||"",n.method&&n.url?bp(n.method,n.baseUrl+n.url,mp(n.data),n):["get","post","put","delete"].reduce((function(e,t){return e[t]=function(e,r){return bp(t,n.baseUrl+e,mp(r),n)},e}),{}));t.then((function(t){e.success({data:t})}))}else{var n;xu({event:"request",data:{url:e.url,data:e.data,header:e.header,timeout:e.timeout,method:e.method||"GET",dataType:e.dataType||"json",responseType:e.responseType||"text"},success:e.success,fail:e.fail,complete:e.complete})}},Wp="2.11.0",Up=new Mp("socket-task",!0),qp=0,Jp=new WeakMap,Gp={};didiJsBridge.on({event:"onSocketStateChange"},(function(e){var t=e.data,n=t.state,r=t.taskId,i=t.data;"open"===n&&(Qp.currentTaskCount++,Gp[r].readyState=1),Up.emit(""+r+n,i),"close"===n&&(Qp.currentTaskCount--,Gp[r].readyState=3,Up.removeAllListeners(r+"open"),Up.removeAllListeners(r+"close"),Up.removeAllListeners(r+"message"),Up.removeAllListeners(r+"error"))}));var Hp=new WeakMap,Qp=function(){function e(){}return e.connectSocket=function(t){if(t&&t.url&&(r=t.url,/^(ws|wss):\/\/.*/i.test(r))){t.header&&"[Object object]"===Object.prototype.toString.call(t.header)||delete t.header,0===t.timeout&&delete t.timeout;try{var n=new $p(t);return n&&3!==n.readyState&&Hp.set(e.currentTask,n),n}catch(e){}}var r},e.closeSocket=function(){var t=Hp.get(e.currentTask);t&&3!==t.readyState&&t.close()},e.sendSocketMessage=function(t){Hp.get(e.currentTask).send(t)},e.onSocketOpen=function(t){t||(t=function(){});var n=Hp.get(e.currentTask);Up.on(n.taskId+"open",t)},e.onSocketClose=function(t){t||(t=function(){});var n=Hp.get(e.currentTask);Up.on(n.taskId+"close",t)},e.onSocketMessage=function(t){t||(t=function(){});var n=Hp.get(e.currentTask);Up.on(n.taskId+"message",t)},e.onSocketError=function(t){t||(t=function(){});var n=Hp.get(e.currentTask);Up.on(n.taskId+"error",t)},e.currentTask={},e.currentTaskCount=0,e}(),$p=function(){function e(e){this.readyState=0;var t="web-socket"+qp++;Jp.set(this,t),Gp[t]=this,Qp.currentTaskCount>=2?e.fail({errMsg:"exceed max task count"}):xu({event:"createSocketTask",data:{taskId:t,options:{url:e.url,header:e.header,protocols:e.protocols,tcpNoDelay:e.tcpNoDelay,perMessageDeflate:e.perMessageDeflate,timeout:e.timeout}},success:function(n){Da(n)||(n={errMsg:"operateSocketTask:ok"}),n.errMsg=n.errMsg.replace("createSocketTask","connectSocket"),n.socketTaskId=t,e.success&&e.success(n)},fail:function(t){e.fail&&e.fail(t)},complete:function(){e.complete&&e.complete()}})}return e.prototype.close=function(e){var t=this;this.readyState>1||(e&&e.code&&(1e3!==e.code||e.code>=3e3&&e.code<=4999)?e&&e.fail&&e.fail({errMsg:"closeSocket:fail Failed to execute 'close' on 'WebSocket': The code must be either 1000, or between 3000 and 4999. "+e.code+" is neither."}):(this.readyState=2,xu({event:"operateSocketTask",data:{operationType:"close",taskId:Jp.get(this),extra:{code:e.code||1e3,reason:e.reason}},success:function(n){Da(n)||(n={errMsg:"operateSocketTask:ok"}),Qp.currentTaskCount--,t.readyState=3,n.errMsg=n.errMsg.replace("operateSocketTask","closeSocket"),e.success&&e.success(n)},fail:function(t){e.fail&&e.fail(t)},complete:function(){e.complete&&e.complete()}})))},e.prototype.send=function(e){if(1===this.readyState)xu({event:"operateSocketTask",data:{operationType:"send",taskId:Jp.get(this),extra:{data:e.data||""}},success:function(t){Da(t)||(t={errMsg:"operateSocketTask:ok"}),t.errMsg=t.errMsg.replace("operateSocketTask","sendSocketMessage"),e.success&&e.success(t)},fail:function(t){e.fail&&e.fail(t)}});else{if(!e.fail)throw new Error("SocketTask.send:fail SocketTask.readyState is not OPEN");e.fail({errMsg:"SocketTask.send:fail SocketTask.readyState is not OPEN"})}},e.prototype.onClose=function(e){var t=this;e||(e=function(){});var n=Jp.get(this);Up.on(n+"close",(function(){t.readyState=3,e()}))},e.prototype.onError=function(e){e||(e=function(){});var t=Jp.get(this);Up.on(t+"error",e)},e.prototype.onMessage=function(e){e||(e=function(){});var t=Jp.get(this);Up.on(t+"message",e)},e.prototype.onOpen=function(e){e||(e=function(){});var t=Jp.get(this);Up.on(t+"open",e)},e}();var Kp,Xp,Yp={downloadFile:function(e){void 0===e&&(e={url:""});var t=Ua(zp,[e]);if(dl((null==(Rp=Rp||dd.getSystemInfoSync())?void 0:Rp.SDKVersion)||"10.0.0",Wp)>=0)return new Bp(ki({taskType:"Download"},t));!function(e){xu({event:"downloadFile",data:{url:e.url,header:e.header,timeout:e.timeout,filePath:e.filePath},success:e.success,fail:e.fail,complete:e.complete})}(t)},request:function(e){if(void 0===e&&(e={url:""}),dl((null==(Rp=Rp||dd.getSystemInfoSync())?void 0:Rp.SDKVersion)||"10.0.0",Wp)>=0)return new Bp(ki({taskType:"Request"},e));Dp(e)},uploadFile:function(e){var t=Ua(Fp,[e]);if(dl((null==(Rp=Rp||dd.getSystemInfoSync())?void 0:Rp.SDKVersion)||"10.0.0",Wp)>=0)return new Bp(ki({taskType:"Upload"},t));!function(e){xu({event:"uploadFile",data:{url:e.url,filePath:e.filePath,name:e.name,header:e.header,formData:e.formData,timeout:e.timeout},success:e.success,fail:e.fail,complete:e.complete})}(t)},connectSocket:function(e){return Qp.connectSocket(e)},onSocketOpen:function(e){Qp.onSocketOpen(e)},closeSocket:function(){Qp.closeSocket()},sendSocketMessage:function(e){Qp.sendSocketMessage(e)},onSocketClose:function(e){Qp.onSocketClose(e)},onSocketMessage:function(e){Qp.onSocketMessage(e)},onSocketError:function(e){Qp.onSocketError(e)},nextTick:function(e){Wa(e)&&(Il.push(e),xl||(xl=setTimeout(Ol,0)))},createAnimation:function(e){return void 0===e&&(e={}),new Cl(e)},createSelectorQuery:function(e){return Ql(e,"")},createIntersectionObserver:function(e,t){return $l(e,t,"")},createMediaQueryObserver:function(){return null},getLaunchOptionsSync:Gf,getEnterOptionsSync:Hf,onAppHide:Kl,navigateTo:yd.navigateTo,redirectTo:yd.redirectTo,navigateBack:yd.navigateBack,switchTab:yd.switchTab,reLaunch:yd.reLaunch,launch:yd.launch,getRealRoute:Vf,getLocalFilePath:function(e,t){return new Promise((function(n,r){didiJsBridge.invoke({method:"getLocalFilePath",data:{package:e,path:t},callback:function(i){i&&i.data&&i.data.success?n(i.data.data.path):r(i.data.errMsg||"getLocalFilePath failed ("+e+" - "+t+").")}})}))},getFileSystemManager:function(){return{readFile:_l,readFileSync:kl,writeFileSync:Tl,writeFile:Ml}},onAppRoute:pd,canIUse:yl,getUpdateManager:function(){return rp||(rp={onCheckForUpdate:function(e){tp?"function"==typeof e&&e(tp):ip.push(e)},onUpdateReady:function(e){cp?"function"==typeof e&&e(np):sp.push(e)},onUpdateFailed:function(e){ap?"function"==typeof e&&e(ap):up.push(e)},applyUpdate:function(){cp&&xu({event:"applyUpdate"})}})},getRealtimeLogManager:function(){return{info:function(){},warn:function(){},error:function(){},setFilterMsg:function(){},addFilterMsg:function(){},in:function(){}}},openBusinessView:function(){return!1},reportAnalytics:function(e,t){gl(e,t)},navigateToMiniProgram:yd.navigateToMiniProgram,navigateToDimina:yd.navigateToDimina,requestSubscribeMessage:function(e){return e.sucssess&&e.success(),{}},loginNotifition:function(e){didiJsBridge.on({event:"loginNotifition"},(function(t){e&&e(t.data||{})}))},shareQqAppmsg:function(e){xu({event:"shareQqAppmsg",data:{type:e.type||"text",icon:e.icon,image:e.image,url:e.url,title:e.title,content:e.content,ext:e.ext},success:e.success,fail:e.fail,complete:e.complete})},shareQzone:function(e){xu({event:"shareQzone",data:{type:e.type||"text",icon:e.icon,image:e.image,url:e.url,title:e.title,content:e.content,ext:e.ext},success:e.success,fail:e.fail,complete:e.complete})},shareAlipayFriend:function(e){xu({event:"shareAlipayFriend",data:{type:e.type||"text",icon:e.icon,image:e.image,url:e.url,title:e.title,content:e.content,ext:e.ext},success:e.success,fail:e.fail,complete:e.complete})},shareAlipayLife:function(e){xu({event:"shareAlipayLife",data:{type:e.type||"text",icon:e.icon,image:e.image,url:e.url,title:e.title,content:e.content,ext:e.ext},success:e.success,fail:e.fail,complete:e.complete})},shareSinaWeibo:function(e){xu({event:"shareSinaWeibo",data:{type:e.type||"text",icon:e.icon,image:e.image,url:e.url,title:e.title,content:e.content,ext:e.ext},success:e.success,fail:e.fail,complete:e.complete})},getPerformance:function(){return ol||(ol=new cl),ol},pageScrollTo:function(e){var t=__appServiceEngine__.getCurrentPagesByDomain(""),n=t[t.length-1].__ddWebViewId__;e.page&&(e.page.__ddWebViewId__||e.page.__wxWebviewId__)&&(n=e.page.__ddWebViewId__||e.page.__wxWebviewId__);var r={};for(var i in e)"function"==typeof e[i]&&(r[i]=e[i],delete e[i]);e.callBackId=il,rl[il]=r,il++,didiJsBridge.publish({event:"pageScrollTo",data:e,webViewId:n})},requestPayment:function(e){if(!e.isTrip&&!e.outTradeId)return e.fail&&e.fail("缺少outTradeId"),void(e.complete&&e.complete());for(var t={},n=0,r=["isNewPayView","isTrip","oid","sid","bid","appId","domain","isOnline","mOfflineURL","outToken","ext_info","bizContent","sign","signType","terminalId","orderId","isFastPay"];n<r.length;n++){var i=r[n];void 0!==e[i]&&(t[i]=e[i])}xu({event:"requestPayment",data:ki({outTradeId:e.outTradeId},t),success:e.success,fail:e.fail,complete:e.complete})},skiaCanvasRemove:nl,extBridge:function(e,t){e&&e.event&&e.module&&didiJsBridge.invoke({module:e.module,method:e.event,data:e.data||{},isSustain:e.isSustain||!1,callback:t||function(t){(t=t.data).success?e.success&&e.success(t.data):e.fail&&e.fail({errMsg:t.errMsg}),e.complete&&e.complete()}})},extOnBridge:function(e){var t=e.event,n=e.module,r=e.callBack;if(n&&"DMServiceBridgeModule"!==n&&t&&r){var i=n+"_"+t;Nu({eventManagerName:i,nativeEvent:i,callBack:r})}},extOffBridge:function(e){var t=e.event,n=e.module,r=e.callBack;if(n&&"DMServiceBridgeModule"!==n&&t){var i=n+"_"+t;Iu({eventManagerName:i,nativeEvent:i,callBack:r})}},triggerGC:function(){if(!Zl){Zl=!0;for(var e={},t=0;t<1e5;t++)e[t]=[];e=null,new Promise((function(e){e(!0)})).then((function(){})).catch((function(){})).finally((function(){return Zl&&(Zl=!1)}))}},goSuperAppTab:gd,onCloseMiniProgram:function(e){ku("onCloseMiniProgram").internalOnMethod(e)},exitMiniProgram:function(e){void 0===e&&(e={}),xu({event:"exitMiniProgram",data:{},success:e.success,fail:e.fail,complete:e.complete})},createInnerAudioContext:function(){var e=new pp(dp);fp=Number(Math.random().toString().substr(3,13)+Date.now()).toString(36);var t=new Proxy(e,{get:function(e,t){return e[t]},set:function(e,t,n){var r;return xu({event:"updateAudioInstanceState",data:(r={audioId:fp},r[t]=n,r)}),e[t]=n,!0}});return lp.set(fp,t),t},createMapContext:function(e,t){return new yp(e,t)},createCameraContext:function(){return new gp},emitUnhandledRejection:function(e){Nl||(Nl=ku("unhandledRejection")),Nl&&Nl.emit(e);var t=e.reason;if(t instanceof Error)__appServiceSDK__.reportUncaughtError({info:"Uncaught (in promise) "+t.toString(),stack:t.stack,isPromise:!0}),(n=__appServiceEngine__.getApp())&&n.onUnhandledRejection&&n.onUnhandledRejection(e);else if("string"==typeof t&&t.length>0){var n;__appServiceSDK__.reportUncaughtError({info:"Uncaught (in promise) "+t,isPromise:!0}),(n=__appServiceEngine__.getApp())&&n.onUnhandledRejection&&n.onUnhandledRejection(e)}},onUnhandledRejection:function(e){Nl||(Nl=ku("unhandledRejection")),Nl.onMethod(e)},offUnhandledRejection:function(e){Nl&&Nl.offMethod(e)},reportEvent:function(e){didiJsBridge.invoke({method:"reportEvent",data:ki({},e)})}},Zp={openSetting:function(e){void 0===e&&(e={}),xu({event:"openSetting",data:{},success:e&&e.success,fail:e&&e.fail,complete:e&&e.complete})},showToast:function(e){xu({event:"showToast",data:{title:e.title,icon:e.icon,image:e.image,duration:e.duration||1500,mask:e.mask||!1},success:e.success,fail:e.fail,complete:e.complete})},hideToast:function(e){void 0===e&&(e={}),xu({event:"hideToast",data:{},success:e.success,fail:e.fail,complete:e.complete})},showModal:function(e){window.isBrowser?window.confirm(e.content)?e.success({confirm:!0}):e.fail({confirm:!1}):xu({event:"showModal",data:{title:e.title,content:e.content,showCancel:void 0===e.showCancel||e.showCancel,cancelText:e.cancelText||"取消",cancelColor:e.cancelColor||"#000000",confirmText:e.confirmText||"确定",confirmColor:e.confirmColor||"#576B95"},success:e.success,fail:e.fail,complete:e.complete})},navigateTo:yd.navigateTo,redirectTo:yd.redirectTo,navigateBack:yd.navigateBack,switchTab:yd.switchTab,reLaunch:yd.reLaunch};Yl("invokeAppServiceMethod",(function(e){e.name in Zp&&Zp[e.name].apply(void 0,e.args)})),Yl("skiaCanvasRemove",(function(e){var t=e.viewId;nl(e.webViewId,t)})),Kp="noTargetApiCall",Xp=function(e){var t=e||{},n=t.module,i=void 0===n?"未知模块":n,o=t.method,a="Native模块"+i+"里没有"+(void 0===o?"未知api":o)+"此Api，请联系Native同学查看";r&&r.vConsoleLog&&r.vConsoleLog(3,a)},didiJsBridge.on({event:Kp},(function(e){var t=e.data,n=void 0===t?{}:t,r=e.webViewId;Wa(Xp)&&Xp(n,r)}));var eh={vdSync:function(e,t){Xl("vdSync",{data:e,webViewId:t},t)},vdSyncBatch:function(e,t){Xl("vdSyncBatch",{data:e,webViewId:t},t)},onVdSync:function(e){Yl("vdSync",(function(t){var n=t.data,r=t.webViewId;e(n,r)}))},onVdSyncBatch:function(e){Yl("vdSyncBatch",(function(t){var n=t.data,r=t.webViewId;e(n,r)}))}};var th=ku("onAppRouteDone").internalOnMethod,nh=ku("onAppRouteDone").internalOffMethod,rh=0,ih=[];pd((function e(t){var n={};"appLaunch"===t.openType&&(n=Gf(),ku("onAppShow").emitInternal(n),hd(e))}));var oh=ku("AppEnterForeground"),ah=ku("onAppShow");didiJsBridge.on({event:"onAppEnterForeground"},(function(e){ah.emit(e)})),didiJsBridge.subscribe({event:"onPageReload"},(function(e){void 0===e&&(e={data:{path:"",webViewId:-1,query:{}}});var t=e.data;ku("onPageReload").emit({path:t.path,webViewId:t.webViewId,query:t.query})})),didiJsBridge.on({event:"onPullDownRefresh"},(function(){ku("onPullDownRefresh").emit()}));var sh=ku("onPullDownRefresh").internalOnMethod,ch=ku("onPullDownRefresh").internalOffMethod,uh={proxySDK:Tu,dd:Yp,_createSelectorQuery:Ql,_createIntersectionObserver:$l,_virtualDOMTunnel:eh,_getPackageDirByRoute:Bf,getLaunchOptionsSync:Gf,getEnterOptionsSync:Hf,pluginInfos:{},onAppRouteDone:th,offAppRouteDone:nh,invokeWebviewMethod:function(e,t,n,r){void 0===t&&(t={});var i=rh++;ih[i]=r,Xl&&Xl("invokeWebviewMethod",{name:e,args:t,callbackId:i},void 0===n?fd.currentWebviewId:n),Yl&&Yl("callbackWebviewMethod",(function(e){var t=e.callbackId;r=ih[t],delete ih[t],r&&r(e.res)}))},onAppRoute:pd,onAppRouteInit:ld,offAppRoute:hd,onAppShow:ku("onAppShow").onMethod,onAppEnterForeground:function(){return oh.internalOnMethod},emitIsloatedAppShow:function(e){!function(e){ku("onAppShow").emitGlobal(e)}(e)},onAppHide:Kl,traceEvent:function(e){didiJsBridge.invoke({method:"traceEvent",data:ki({},e)})},onAppEnterBackground:function(){didiJsBridge.on({event:"onAppEnterBackground"},(function(){ku("AppHide").emit()}))},onCallMethodFromWxs:function(e){Yl("vdCallComponentMethodForWxs",e)},onPageReload:ku("onPageReload").internalOnMethod,offPageReload:ku("onPageReload").internalOffMethod,onPullDownRefresh:sh,offPullDownRefresh:ch,installPackageByRoute:qf,RouteTask:Af,getPackageLoadStatus:zf,setPackageLoadStatus:Ff,requireByRoute:Wf,traceBeginEvent:function(e,t){if(e&&t)try{var n={category:e,name:t,timeStamp:(new Date).getTime()};if(bl.length>=1){var r=bl.length-1;Sl=(new Date).getTime()-bl[r].timeStamp}bl.push(n)}catch(e){}},traceEndEvent:function(){if(bl&&bl.length)try{var e=bl.pop(),t=(new Date).getTime(),n=t-e.timeStamp,r=bl[bl.length-1];gl(("pub_saga_"+e.category+"_"+e.name+"_bt").toLowerCase(),{start_time:e.timeStamp,end_time:t,take_up_time:n,take_begin_time:Sl,take_before_name:r.name,take_before_category:r.category})}catch(e){}},reportNative:gl,traceCoreDotting:vl,reportToMiniBackend:wl,reportUncaughtError:function(e){if(e){var t=(e.info||"")+"\n"+(e.stack||"");if(yl("reportUncaughtError")){var n=__appServiceEngine__.getApp();return xu({event:"reportUncaughtError",data:ki(ki({},e),{appId:null==n?void 0:n.__appId__})}),void(e.isPromise||e.disableAppError||n&&n.onError&&n.onError(t))}ml(t,e.isPromise)}}};return uh}();

var dd = __appServiceSDK__.dd;

var exparser=function(){"use strict";var e="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function t(e,t,r){return e(r={path:t,exports:{},require:function(e,t){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==t&&r.path)}},r.exports),r.exports}var r,n,i=function(e){return e&&e.Math==Math&&e},o=i("object"==typeof globalThis&&globalThis)||i("object"==typeof window&&window)||i("object"==typeof self&&self)||i("object"==typeof e&&e)||function(){return this}()||Function("return this")(),a=function(e){try{return!!e()}catch(e){return!0}},s=!a((function(){var e=function(){}.bind();return"function"!=typeof e||e.hasOwnProperty("prototype")})),l=Function.prototype,u=l.bind,c=l.call,d=s&&u.bind(c,c),f=s?function(e){return e&&d(e)}:function(e){return e&&function(){return c.apply(e,arguments)}},_=f({}.toString),p=f("".slice),h=function(e){return p(_(e),8,-1)},v=o.Object,m=f("".split),g=a((function(){return!v("z").propertyIsEnumerable(0)}))?function(e){return"String"==h(e)?m(e,""):v(e)}:v,y=o.TypeError,b=function(e){if(null==e)throw y("Can't call method on "+e);return e},E=function(e){return g(b(e))},w=Object.defineProperty,O=function(e,t){try{w(o,e,{value:t,configurable:!0,writable:!0})}catch(r){o[e]=t}return t},A="__core-js_shared__",C=o[A]||O(A,{}),S=t((function(e){(e.exports=function(e,t){return C[e]||(C[e]=void 0!==t?t:{})})("versions",[]).push({version:"3.21.1",mode:"global",copyright:"© 2014-2022 Denis Pushkarev (zloirock.ru)",license:"https://github.com/zloirock/core-js/blob/v3.21.1/LICENSE",source:"https://github.com/zloirock/core-js"})})),T=o.Object,N=function(e){return T(b(e))},x=f({}.hasOwnProperty),I=Object.hasOwn||function(e,t){return x(N(e),t)},R=0,L=Math.random(),M=f(1..toString),k=function(e){return"Symbol("+(void 0===e?"":e)+")_"+M(++R+L,36)},P=function(e){return"function"==typeof e},j=function(e){return P(e)?e:void 0},D=function(e,t){return arguments.length<2?j(o[e]):o[e]&&o[e][t]},B=D("navigator","userAgent")||"",F=o.process,U=o.Deno,G=F&&F.versions||U&&U.version,H=G&&G.v8;H&&(n=(r=H.split("."))[0]>0&&r[0]<4?1:+(r[0]+r[1])),!n&&B&&(!(r=B.match(/Edge\/(\d+)/))||r[1]>=74)&&(r=B.match(/Chrome\/(\d+)/))&&(n=+r[1]);var V,z=n,$=!!Object.getOwnPropertySymbols&&!a((function(){var e=Symbol();return!String(e)||!(Object(e)instanceof Symbol)||!Symbol.sham&&z&&z<41})),Y=$&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,W=S("wks"),Z=o.Symbol,J=Z&&Z.for,K=Y?Z:Z&&Z.withoutSetter||k,q=function(e){if(!I(W,e)||!$&&"string"!=typeof W[e]){var t="Symbol."+e;$&&I(Z,e)?W[e]=Z[e]:W[e]=Y&&J?J(t):K(t)}return W[e]},X=function(e){return"object"==typeof e?null!==e:P(e)},Q=o.String,ee=o.TypeError,te=function(e){if(X(e))return e;throw ee(Q(e)+" is not an object")},re=!a((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),ne=re&&a((function(){return 42!=Object.defineProperty((function(){}),"prototype",{value:42,writable:!1}).prototype})),ie=o.document,oe=X(ie)&&X(ie.createElement),ae=function(e){return oe?ie.createElement(e):{}},se=!re&&!a((function(){return 7!=Object.defineProperty(ae("div"),"a",{get:function(){return 7}}).a})),le=Function.prototype.call,ue=s?le.bind(le):function(){return le.apply(le,arguments)},ce=f({}.isPrototypeOf),de=o.Object,fe=Y?function(e){return"symbol"==typeof e}:function(e){var t=D("Symbol");return P(t)&&ce(t.prototype,de(e))},_e=o.String,pe=function(e){try{return _e(e)}catch(e){return"Object"}},he=o.TypeError,ve=function(e){if(P(e))return e;throw he(pe(e)+" is not a function")},me=function(e,t){var r=e[t];return null==r?void 0:ve(r)},ge=o.TypeError,ye=o.TypeError,be=q("toPrimitive"),Ee=function(e,t){if(!X(e)||fe(e))return e;var r,n=me(e,be);if(n){if(void 0===t&&(t="default"),r=ue(n,e,t),!X(r)||fe(r))return r;throw ye("Can't convert object to primitive value")}return void 0===t&&(t="number"),function(e,t){var r,n;if("string"===t&&P(r=e.toString)&&!X(n=ue(r,e)))return n;if(P(r=e.valueOf)&&!X(n=ue(r,e)))return n;if("string"!==t&&P(r=e.toString)&&!X(n=ue(r,e)))return n;throw ge("Can't convert object to primitive value")}(e,t)},we=function(e){var t=Ee(e,"string");return fe(t)?t:t+""},Oe=o.TypeError,Ae=Object.defineProperty,Ce=Object.getOwnPropertyDescriptor,Se="enumerable",Te="configurable",Ne="writable",xe=re?ne?function(e,t,r){if(te(e),t=we(t),te(r),"function"==typeof e&&"prototype"===t&&"value"in r&&Ne in r&&!r.writable){var n=Ce(e,t);n&&n.writable&&(e[t]=r.value,r={configurable:Te in r?r.configurable:n.configurable,enumerable:Se in r?r.enumerable:n.enumerable,writable:!1})}return Ae(e,t,r)}:Ae:function(e,t,r){if(te(e),t=we(t),te(r),se)try{return Ae(e,t,r)}catch(e){}if("get"in r||"set"in r)throw Oe("Accessors not supported");return"value"in r&&(e[t]=r.value),e},Ie={f:xe},Re=Math.ceil,Le=Math.floor,Me=function(e){var t=+e;return t!=t||0===t?0:(t>0?Le:Re)(t)},ke=Math.max,Pe=Math.min,je=function(e,t){var r=Me(e);return r<0?ke(r+t,0):Pe(r,t)},De=Math.min,Be=function(e){return e>0?De(Me(e),9007199254740991):0},Fe=function(e){return Be(e.length)},Ue=function(e){return function(t,r,n){var i,o=E(t),a=Fe(o),s=je(n,a);if(e&&r!=r){for(;a>s;)if((i=o[s++])!=i)return!0}else for(;a>s;s++)if((e||s in o)&&o[s]===r)return e||s||0;return!e&&-1}},Ge={includes:Ue(!0),indexOf:Ue(!1)},He={},Ve=Ge.indexOf,ze=f([].push),$e=function(e,t){var r,n=E(e),i=0,o=[];for(r in n)!I(He,r)&&I(n,r)&&ze(o,r);for(;t.length>i;)I(n,r=t[i++])&&(~Ve(o,r)||ze(o,r));return o},Ye=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],We=Object.keys||function(e){return $e(e,Ye)},Ze=re&&!ne?Object.defineProperties:function(e,t){te(e);for(var r,n=E(t),i=We(t),o=i.length,a=0;o>a;)Ie.f(e,r=i[a++],n[r]);return e},Je={f:Ze},Ke=D("document","documentElement"),qe=S("keys"),Xe=function(e){return qe[e]||(qe[e]=k(e))},Qe=Xe("IE_PROTO"),et=function(){},tt=function(e){return"<script>"+e+"</"+"script>"},rt=function(e){e.write(tt("")),e.close();var t=e.parentWindow.Object;return e=null,t},nt=function(){try{V=new ActiveXObject("htmlfile")}catch(e){}var e,t;nt="undefined"!=typeof document?document.domain&&V?rt(V):((t=ae("iframe")).style.display="none",Ke.appendChild(t),t.src=String("javascript:"),(e=t.contentWindow.document).open(),e.write(tt("document.F=Object")),e.close(),e.F):rt(V);for(var r=Ye.length;r--;)delete nt.prototype[Ye[r]];return nt()};He[Qe]=!0;var it=Object.create||function(e,t){var r;return null!==e?(et.prototype=te(e),r=new et,et.prototype=null,r[Qe]=e):r=nt(),void 0===t?r:Je.f(r,t)},ot=q("unscopables"),at=Array.prototype;null==at[ot]&&Ie.f(at,ot,{configurable:!0,value:it(null)});var st=function(e){at[ot][e]=!0},lt={},ut=f(Function.toString);P(C.inspectSource)||(C.inspectSource=function(e){return ut(e)});var ct,dt,ft,_t=C.inspectSource,pt=o.WeakMap,ht=P(pt)&&/native code/.test(_t(pt)),vt=function(e,t){return{enumerable:!(1&e),configurable:!(2&e),writable:!(4&e),value:t}},mt=re?function(e,t,r){return Ie.f(e,t,vt(1,r))}:function(e,t,r){return e[t]=r,e},gt="Object already initialized",yt=o.TypeError,bt=o.WeakMap;if(ht||C.state){var Et=C.state||(C.state=new bt),wt=f(Et.get),Ot=f(Et.has),At=f(Et.set);ct=function(e,t){if(Ot(Et,e))throw new yt(gt);return t.facade=e,At(Et,e,t),t},dt=function(e){return wt(Et,e)||{}},ft=function(e){return Ot(Et,e)}}else{var Ct=Xe("state");He[Ct]=!0,ct=function(e,t){if(I(e,Ct))throw new yt(gt);return t.facade=e,mt(e,Ct,t),t},dt=function(e){return I(e,Ct)?e[Ct]:{}},ft=function(e){return I(e,Ct)}}var St,Tt,Nt,xt={set:ct,get:dt,has:ft,enforce:function(e){return ft(e)?dt(e):ct(e,{})},getterFor:function(e){return function(t){var r;if(!X(t)||(r=dt(t)).type!==e)throw yt("Incompatible receiver, "+e+" required");return r}}},It={}.propertyIsEnumerable,Rt=Object.getOwnPropertyDescriptor,Lt={f:Rt&&!It.call({1:2},1)?function(e){var t=Rt(this,e);return!!t&&t.enumerable}:It},Mt=Object.getOwnPropertyDescriptor,kt=re?Mt:function(e,t){if(e=E(e),t=we(t),se)try{return Mt(e,t)}catch(e){}if(I(e,t))return vt(!ue(Lt.f,e,t),e[t])},Pt={f:kt},jt=Function.prototype,Dt=re&&Object.getOwnPropertyDescriptor,Bt=I(jt,"name"),Ft={EXISTS:Bt,PROPER:Bt&&"something"===function(){}.name,CONFIGURABLE:Bt&&(!re||re&&Dt(jt,"name").configurable)},Ut=t((function(e){var t=Ft.CONFIGURABLE,r=xt.get,n=xt.enforce,i=String(String).split("String");(e.exports=function(e,r,a,s){var l,u=!!s&&!!s.unsafe,c=!!s&&!!s.enumerable,d=!!s&&!!s.noTargetGet,f=s&&void 0!==s.name?s.name:r;P(a)&&("Symbol("===String(f).slice(0,7)&&(f="["+String(f).replace(/^Symbol\(([^)]*)\)/,"$1")+"]"),(!I(a,"name")||t&&a.name!==f)&&mt(a,"name",f),(l=n(a)).source||(l.source=i.join("string"==typeof f?f:""))),e!==o?(u?!d&&e[r]&&(c=!0):delete e[r],c?e[r]=a:mt(e,r,a)):c?e[r]=a:O(r,a)})(Function.prototype,"toString",(function(){return P(this)&&r(this).source||_t(this)}))})),Gt=Ye.concat("length","prototype"),Ht=Object.getOwnPropertyNames||function(e){return $e(e,Gt)},Vt={f:Ht},zt={f:Object.getOwnPropertySymbols},$t=f([].concat),Yt=D("Reflect","ownKeys")||function(e){var t=Vt.f(te(e)),r=zt.f;return r?$t(t,r(e)):t},Wt=function(e,t,r){for(var n=Yt(t),i=Ie.f,o=Pt.f,a=0;a<n.length;a++){var s=n[a];I(e,s)||r&&I(r,s)||i(e,s,o(t,s))}},Zt=/#|\.prototype\./,Jt=function(e,t){var r=qt[Kt(e)];return r==Qt||r!=Xt&&(P(t)?a(t):!!t)},Kt=Jt.normalize=function(e){return String(e).replace(Zt,".").toLowerCase()},qt=Jt.data={},Xt=Jt.NATIVE="N",Qt=Jt.POLYFILL="P",er=Jt,tr=Pt.f,rr=function(e,t){var r,n,i,a,s,l=e.target,u=e.global,c=e.stat;if(r=u?o:c?o[l]||O(l,{}):(o[l]||{}).prototype)for(n in t){if(a=t[n],i=e.noTargetGet?(s=tr(r,n))&&s.value:r[n],!er(u?n:l+(c?".":"#")+n,e.forced)&&void 0!==i){if(typeof a==typeof i)continue;Wt(a,i)}(e.sham||i&&i.sham)&&mt(a,"sham",!0),Ut(r,n,a,e)}},nr=!a((function(){function e(){}return e.prototype.constructor=null,Object.getPrototypeOf(new e)!==e.prototype})),ir=Xe("IE_PROTO"),or=o.Object,ar=or.prototype,sr=nr?or.getPrototypeOf:function(e){var t=N(e);if(I(t,ir))return t[ir];var r=t.constructor;return P(r)&&t instanceof r?r.prototype:t instanceof or?ar:null},lr=q("iterator"),ur=!1;[].keys&&("next"in(Nt=[].keys())?(Tt=sr(sr(Nt)))!==Object.prototype&&(St=Tt):ur=!0);var cr=null==St||a((function(){var e={};return St[lr].call(e)!==e}));cr&&(St={}),P(St[lr])||Ut(St,lr,(function(){return this}));var dr={IteratorPrototype:St,BUGGY_SAFARI_ITERATORS:ur},fr=Ie.f,_r=q("toStringTag"),pr=function(e,t,r){e&&!r&&(e=e.prototype),e&&!I(e,_r)&&fr(e,_r,{configurable:!0,value:t})},hr=dr.IteratorPrototype,vr=function(){return this},mr=o.String,gr=o.TypeError,yr=Object.setPrototypeOf||("__proto__"in{}?function(){var e,t=!1,r={};try{(e=f(Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set))(r,[]),t=r instanceof Array}catch(e){}return function(r,n){return te(r),function(e){if("object"==typeof e||P(e))return e;throw gr("Can't set "+mr(e)+" as a prototype")}(n),t?e(r,n):r.__proto__=n,r}}():void 0),br=Ft.PROPER,Er=Ft.CONFIGURABLE,wr=dr.IteratorPrototype,Or=dr.BUGGY_SAFARI_ITERATORS,Ar=q("iterator"),Cr="keys",Sr="values",Tr="entries",Nr=function(){return this},xr=function(e,t,r,n,i,o,a){!function(e,t,r,n){var i=t+" Iterator";e.prototype=it(hr,{next:vt(+!n,r)}),pr(e,i,!1),lt[i]=vr}(r,t,n);var s,l,u,c=function(e){if(e===i&&h)return h;if(!Or&&e in _)return _[e];switch(e){case Cr:case Sr:case Tr:return function(){return new r(this,e)}}return function(){return new r(this)}},d=t+" Iterator",f=!1,_=e.prototype,p=_[Ar]||_["@@iterator"]||i&&_[i],h=!Or&&p||c(i),v="Array"==t&&_.entries||p;if(v&&(s=sr(v.call(new e)))!==Object.prototype&&s.next&&(sr(s)!==wr&&(yr?yr(s,wr):P(s[Ar])||Ut(s,Ar,Nr)),pr(s,d,!0)),br&&i==Sr&&p&&p.name!==Sr&&(Er?mt(_,"name",Sr):(f=!0,h=function(){return ue(p,this)})),i)if(l={values:c(Sr),keys:o?h:c(Cr),entries:c(Tr)},a)for(u in l)(Or||f||!(u in _))&&Ut(_,u,l[u]);else rr({target:t,proto:!0,forced:Or||f},l);return _[Ar]!==h&&Ut(_,Ar,h,{name:i}),lt[t]=h,l},Ir=Ie.f,Rr="Array Iterator",Lr=xt.set,Mr=xt.getterFor(Rr),kr=xr(Array,"Array",(function(e,t){Lr(this,{type:Rr,target:E(e),index:0,kind:t})}),(function(){var e=Mr(this),t=e.target,r=e.kind,n=e.index++;return!t||n>=t.length?(e.target=void 0,{value:void 0,done:!0}):"keys"==r?{value:n,done:!1}:"values"==r?{value:t[n],done:!1}:{value:[n,t[n]],done:!1}}),"values"),Pr=lt.Arguments=lt.Array;if(st("keys"),st("values"),st("entries"),re&&"values"!==Pr.name)try{Ir(Pr,"name",{value:"values"})}catch(e){}var jr="undefined"!=typeof ArrayBuffer&&"undefined"!=typeof DataView,Dr=function(e,t,r){for(var n in t)Ut(e,n,t[n],r);return e},Br=o.TypeError,Fr=function(e,t){if(ce(t,e))return e;throw Br("Incorrect invocation")},Ur=o.RangeError,Gr=function(e){if(void 0===e)return 0;var t=Me(e),r=Be(t);if(t!==r)throw Ur("Wrong length or index");return r},Hr=o.Array,Vr=Math.abs,zr=Math.pow,$r=Math.floor,Yr=Math.log,Wr=Math.LN2,Zr=function(e,t,r){var n,i,o,a=Hr(r),s=8*r-t-1,l=(1<<s)-1,u=l>>1,c=23===t?zr(2,-24)-zr(2,-77):0,d=e<0||0===e&&1/e<0?1:0,f=0;for((e=Vr(e))!=e||e===1/0?(i=e!=e?1:0,n=l):(n=$r(Yr(e)/Wr),e*(o=zr(2,-n))<1&&(n--,o*=2),(e+=n+u>=1?c/o:c*zr(2,1-u))*o>=2&&(n++,o/=2),n+u>=l?(i=0,n=l):n+u>=1?(i=(e*o-1)*zr(2,t),n+=u):(i=e*zr(2,u-1)*zr(2,t),n=0));t>=8;)a[f++]=255&i,i/=256,t-=8;for(n=n<<t|i,s+=t;s>0;)a[f++]=255&n,n/=256,s-=8;return a[--f]|=128*d,a},Jr=function(e,t){var r,n=e.length,i=8*n-t-1,o=(1<<i)-1,a=o>>1,s=i-7,l=n-1,u=e[l--],c=127&u;for(u>>=7;s>0;)c=256*c+e[l--],s-=8;for(r=c&(1<<-s)-1,c>>=-s,s+=t;s>0;)r=256*r+e[l--],s-=8;if(0===c)c=1-a;else{if(c===o)return r?NaN:u?-1/0:1/0;r+=zr(2,t),c-=a}return(u?-1:1)*r*zr(2,c-t)},Kr=function(e){for(var t=N(this),r=Fe(t),n=arguments.length,i=je(n>1?arguments[1]:void 0,r),o=n>2?arguments[2]:void 0,a=void 0===o?r:je(o,r);a>i;)t[i++]=e;return t},qr=function(e,t,r){var n=we(t);n in e?Ie.f(e,n,vt(0,r)):e[n]=r},Xr=o.Array,Qr=Math.max,en=function(e,t,r){for(var n=Fe(e),i=je(t,n),o=je(void 0===r?n:r,n),a=Xr(Qr(o-i,0)),s=0;i<o;i++,s++)qr(a,s,e[i]);return a.length=s,a},tn=Vt.f,rn=Ie.f,nn=Ft.PROPER,on=Ft.CONFIGURABLE,an=xt.get,sn=xt.set,ln="ArrayBuffer",un="DataView",cn="Wrong index",dn=o.ArrayBuffer,fn=dn,_n=fn&&fn.prototype,pn=o.DataView,hn=pn&&pn.prototype,vn=Object.prototype,mn=o.Array,gn=o.RangeError,yn=f(Kr),bn=f([].reverse),En=Zr,wn=Jr,On=function(e){return[255&e]},An=function(e){return[255&e,e>>8&255]},Cn=function(e){return[255&e,e>>8&255,e>>16&255,e>>24&255]},Sn=function(e){return e[3]<<24|e[2]<<16|e[1]<<8|e[0]},Tn=function(e){return En(e,23,4)},Nn=function(e){return En(e,52,8)},xn=function(e,t){rn(e.prototype,t,{get:function(){return an(this)[t]}})},In=function(e,t,r,n){var i=Gr(r),o=an(e);if(i+t>o.byteLength)throw gn(cn);var a=an(o.buffer).bytes,s=i+o.byteOffset,l=en(a,s,s+t);return n?l:bn(l)},Rn=function(e,t,r,n,i,o){var a=Gr(r),s=an(e);if(a+t>s.byteLength)throw gn(cn);for(var l=an(s.buffer).bytes,u=a+s.byteOffset,c=n(+i),d=0;d<t;d++)l[u+d]=c[o?d:t-d-1]};if(jr){var Ln=nn&&dn.name!==ln;if(a((function(){dn(1)}))&&a((function(){new dn(-1)}))&&!a((function(){return new dn,new dn(1.5),new dn(NaN),Ln&&!on})))Ln&&on&&mt(dn,"name",ln);else{(fn=function(e){return Fr(this,_n),new dn(Gr(e))}).prototype=_n;for(var Mn,kn=tn(dn),Pn=0;kn.length>Pn;)(Mn=kn[Pn++])in fn||mt(fn,Mn,dn[Mn]);_n.constructor=fn}yr&&sr(hn)!==vn&&yr(hn,vn);var jn=new pn(new fn(2)),Dn=f(hn.setInt8);jn.setInt8(0,2147483648),jn.setInt8(1,2147483649),!jn.getInt8(0)&&jn.getInt8(1)||Dr(hn,{setInt8:function(e,t){Dn(this,e,t<<24>>24)},setUint8:function(e,t){Dn(this,e,t<<24>>24)}},{unsafe:!0})}else _n=(fn=function(e){Fr(this,_n);var t=Gr(e);sn(this,{bytes:yn(mn(t),0),byteLength:t}),re||(this.byteLength=t)}).prototype,hn=(pn=function(e,t,r){Fr(this,hn),Fr(e,_n);var n=an(e).byteLength,i=Me(t);if(i<0||i>n)throw gn("Wrong offset");if(i+(r=void 0===r?n-i:Be(r))>n)throw gn("Wrong length");sn(this,{buffer:e,byteLength:r,byteOffset:i}),re||(this.buffer=e,this.byteLength=r,this.byteOffset=i)}).prototype,re&&(xn(fn,"byteLength"),xn(pn,"buffer"),xn(pn,"byteLength"),xn(pn,"byteOffset")),Dr(hn,{getInt8:function(e){return In(this,1,e)[0]<<24>>24},getUint8:function(e){return In(this,1,e)[0]},getInt16:function(e){var t=In(this,2,e,arguments.length>1?arguments[1]:void 0);return(t[1]<<8|t[0])<<16>>16},getUint16:function(e){var t=In(this,2,e,arguments.length>1?arguments[1]:void 0);return t[1]<<8|t[0]},getInt32:function(e){return Sn(In(this,4,e,arguments.length>1?arguments[1]:void 0))},getUint32:function(e){return Sn(In(this,4,e,arguments.length>1?arguments[1]:void 0))>>>0},getFloat32:function(e){return wn(In(this,4,e,arguments.length>1?arguments[1]:void 0),23)},getFloat64:function(e){return wn(In(this,8,e,arguments.length>1?arguments[1]:void 0),52)},setInt8:function(e,t){Rn(this,1,e,On,t)},setUint8:function(e,t){Rn(this,1,e,On,t)},setInt16:function(e,t){Rn(this,2,e,An,t,arguments.length>2?arguments[2]:void 0)},setUint16:function(e,t){Rn(this,2,e,An,t,arguments.length>2?arguments[2]:void 0)},setInt32:function(e,t){Rn(this,4,e,Cn,t,arguments.length>2?arguments[2]:void 0)},setUint32:function(e,t){Rn(this,4,e,Cn,t,arguments.length>2?arguments[2]:void 0)},setFloat32:function(e,t){Rn(this,4,e,Tn,t,arguments.length>2?arguments[2]:void 0)},setFloat64:function(e,t){Rn(this,8,e,Nn,t,arguments.length>2?arguments[2]:void 0)}});pr(fn,ln),pr(pn,un);var Bn={ArrayBuffer:fn,DataView:pn},Fn={};Fn[q("toStringTag")]="z";var Un="[object z]"===String(Fn),Gn=q("toStringTag"),Hn=o.Object,Vn="Arguments"==h(function(){return arguments}()),zn=Un?h:function(e){var t,r,n;return void 0===e?"Undefined":null===e?"Null":"string"==typeof(r=function(e,t){try{return e[t]}catch(e){}}(t=Hn(e),Gn))?r:Vn?h(t):"Object"==(n=h(t))&&P(t.callee)?"Arguments":n},$n=function(){},Yn=[],Wn=D("Reflect","construct"),Zn=/^\s*(?:class|function)\b/,Jn=f(Zn.exec),Kn=!Zn.exec($n),qn=function(e){if(!P(e))return!1;try{return Wn($n,Yn,e),!0}catch(e){return!1}},Xn=function(e){if(!P(e))return!1;switch(zn(e)){case"AsyncFunction":case"GeneratorFunction":case"AsyncGeneratorFunction":return!1}try{return Kn||!!Jn(Zn,_t(e))}catch(e){return!0}};Xn.sham=!0;var Qn=!Wn||a((function(){var e;return qn(qn.call)||!qn(Object)||!qn((function(){e=!0}))||e}))?Xn:qn,ei=o.TypeError,ti=function(e){if(Qn(e))return e;throw ei(pe(e)+" is not a constructor")},ri=q("species"),ni=function(e,t){var r,n=te(e).constructor;return void 0===n||null==(r=te(n)[ri])?t:ti(r)},ii=Bn.ArrayBuffer,oi=Bn.DataView,ai=oi.prototype,si=f(ii.prototype.slice),li=f(ai.getUint8),ui=f(ai.setUint8),ci=a((function(){return!new ii(2).slice(1,void 0).byteLength}));rr({target:"ArrayBuffer",proto:!0,unsafe:!0,forced:ci},{slice:function(e,t){if(si&&void 0===t)return si(te(this),e);for(var r=te(this).byteLength,n=je(e,r),i=je(void 0===t?r:t,r),o=new(ni(this,ii))(Be(i-n)),a=new oi(this),s=new oi(o),l=0;n<i;)ui(s,l++,li(a,n++));return o}});var di=Un?{}.toString:function(){return"[object "+zn(this)+"]"};Un||Ut(Object.prototype,"toString",di,{unsafe:!0});var fi=q("iterator"),_i=!1;try{var pi=0,hi={next:function(){return{done:!!pi++}},return:function(){_i=!0}};hi[fi]=function(){return this},Array.from(hi,(function(){throw 2}))}catch(e){}var vi,mi,gi,yi=function(e,t){if(!t&&!_i)return!1;var r=!1;try{var n={};n[fi]=function(){return{next:function(){return{done:r=!0}}}},e(n)}catch(e){}return r},bi=Ie.f,Ei=o.Int8Array,wi=Ei&&Ei.prototype,Oi=o.Uint8ClampedArray,Ai=Oi&&Oi.prototype,Ci=Ei&&sr(Ei),Si=wi&&sr(wi),Ti=Object.prototype,Ni=o.TypeError,xi=q("toStringTag"),Ii=k("TYPED_ARRAY_TAG"),Ri=k("TYPED_ARRAY_CONSTRUCTOR"),Li=jr&&!!yr&&"Opera"!==zn(o.opera),Mi=!1,ki={Int8Array:1,Uint8Array:1,Uint8ClampedArray:1,Int16Array:2,Uint16Array:2,Int32Array:4,Uint32Array:4,Float32Array:4,Float64Array:8},Pi={BigInt64Array:8,BigUint64Array:8},ji=function(e){if(!X(e))return!1;var t=zn(e);return I(ki,t)||I(Pi,t)};for(vi in ki)(gi=(mi=o[vi])&&mi.prototype)?mt(gi,Ri,mi):Li=!1;for(vi in Pi)(gi=(mi=o[vi])&&mi.prototype)&&mt(gi,Ri,mi);if((!Li||!P(Ci)||Ci===Function.prototype)&&(Ci=function(){throw Ni("Incorrect invocation")},Li))for(vi in ki)o[vi]&&yr(o[vi],Ci);if((!Li||!Si||Si===Ti)&&(Si=Ci.prototype,Li))for(vi in ki)o[vi]&&yr(o[vi].prototype,Si);if(Li&&sr(Ai)!==Si&&yr(Ai,Si),re&&!I(Si,xi))for(vi in Mi=!0,bi(Si,xi,{get:function(){return X(this)?this[Ii]:void 0}}),ki)o[vi]&&mt(o[vi],Ii,vi);var Di={NATIVE_ARRAY_BUFFER_VIEWS:Li,TYPED_ARRAY_CONSTRUCTOR:Ri,TYPED_ARRAY_TAG:Mi&&Ii,aTypedArray:function(e){if(ji(e))return e;throw Ni("Target is not a typed array")},aTypedArrayConstructor:function(e){if(P(e)&&(!yr||ce(Ci,e)))return e;throw Ni(pe(e)+" is not a typed array constructor")},exportTypedArrayMethod:function(e,t,r,n){if(re){if(r)for(var i in ki){var a=o[i];if(a&&I(a.prototype,e))try{delete a.prototype[e]}catch(r){try{a.prototype[e]=t}catch(e){}}}Si[e]&&!r||Ut(Si,e,r?t:Li&&wi[e]||t,n)}},exportTypedArrayStaticMethod:function(e,t,r){var n,i;if(re){if(yr){if(r)for(n in ki)if((i=o[n])&&I(i,e))try{delete i[e]}catch(e){}if(Ci[e]&&!r)return;try{return Ut(Ci,e,r?t:Li&&Ci[e]||t)}catch(e){}}for(n in ki)!(i=o[n])||i[e]&&!r||Ut(i,e,t)}},isView:function(e){if(!X(e))return!1;var t=zn(e);return"DataView"===t||I(ki,t)||I(Pi,t)},isTypedArray:ji,TypedArray:Ci,TypedArrayPrototype:Si},Bi=Di.NATIVE_ARRAY_BUFFER_VIEWS,Fi=o.ArrayBuffer,Ui=o.Int8Array,Gi=!Bi||!a((function(){Ui(1)}))||!a((function(){new Ui(-1)}))||!yi((function(e){new Ui,new Ui(null),new Ui(1.5),new Ui(e)}),!0)||a((function(){return 1!==new Ui(new Fi(2),1,void 0).length})),Hi=Math.floor,Vi=Number.isInteger||function(e){return!X(e)&&isFinite(e)&&Hi(e)===e},zi=o.RangeError,$i=o.RangeError,Yi=function(e,t){var r=function(e){var t=Me(e);if(t<0)throw zi("The argument can't be less than 0");return t}(e);if(r%t)throw $i("Wrong offset");return r},Wi=f(f.bind),Zi=function(e,t){return ve(e),void 0===t?e:s?Wi(e,t):function(){return e.apply(t,arguments)}},Ji=q("iterator"),Ki=function(e){if(null!=e)return me(e,Ji)||me(e,"@@iterator")||lt[zn(e)]},qi=o.TypeError,Xi=function(e,t){var r=arguments.length<2?Ki(e):t;if(ve(r))return te(ue(r,e));throw qi(pe(e)+" is not iterable")},Qi=q("iterator"),eo=Array.prototype,to=function(e){return void 0!==e&&(lt.Array===e||eo[Qi]===e)},ro=Di.aTypedArrayConstructor,no=function(e){var t,r,n,i,o,a,s=ti(this),l=N(e),u=arguments.length,c=u>1?arguments[1]:void 0,d=void 0!==c,f=Ki(l);if(f&&!to(f))for(a=(o=Xi(l,f)).next,l=[];!(i=ue(a,o)).done;)l.push(i.value);for(d&&u>2&&(c=Zi(c,arguments[2])),r=Fe(l),n=new(ro(s))(r),t=0;r>t;t++)n[t]=d?c(l[t],t):l[t];return n},io=Array.isArray||function(e){return"Array"==h(e)},oo=q("species"),ao=o.Array,so=function(e,t){return new(function(e){var t;return io(e)&&(t=e.constructor,(Qn(t)&&(t===ao||io(t.prototype))||X(t)&&null===(t=t[oo]))&&(t=void 0)),void 0===t?ao:t}(e))(0===t?0:t)},lo=f([].push),uo=function(e){var t=1==e,r=2==e,n=3==e,i=4==e,o=6==e,a=7==e,s=5==e||o;return function(l,u,c,d){for(var f,_,p=N(l),h=g(p),v=Zi(u,c),m=Fe(h),y=0,b=d||so,E=t?b(l,m):r||a?b(l,0):void 0;m>y;y++)if((s||y in h)&&(_=v(f=h[y],y,p),e))if(t)E[y]=_;else if(_)switch(e){case 3:return!0;case 5:return f;case 6:return y;case 2:lo(E,f)}else switch(e){case 4:return!1;case 7:lo(E,f)}return o?-1:n||i?i:E}},co={forEach:uo(0),map:uo(1),filter:uo(2),some:uo(3),every:uo(4),find:uo(5),findIndex:uo(6),filterReject:uo(7)},fo=q("species"),_o=function(e){var t=D(e),r=Ie.f;re&&t&&!t[fo]&&r(t,fo,{configurable:!0,get:function(){return this}})},po=function(e,t,r){var n,i;return yr&&P(n=t.constructor)&&n!==r&&X(i=n.prototype)&&i!==r.prototype&&yr(e,i),e},ho=t((function(e){var t=Vt.f,r=co.forEach,n=xt.get,i=xt.set,a=Ie.f,s=Pt.f,l=Math.round,u=o.RangeError,c=Bn.ArrayBuffer,d=c.prototype,f=Bn.DataView,_=Di.NATIVE_ARRAY_BUFFER_VIEWS,p=Di.TYPED_ARRAY_CONSTRUCTOR,h=Di.TYPED_ARRAY_TAG,v=Di.TypedArray,m=Di.TypedArrayPrototype,g=Di.aTypedArrayConstructor,y=Di.isTypedArray,b="BYTES_PER_ELEMENT",E="Wrong length",w=function(e,t){g(e);for(var r=0,n=t.length,i=new e(n);n>r;)i[r]=t[r++];return i},O=function(e,t){a(e,t,{get:function(){return n(this)[t]}})},A=function(e){var t;return ce(d,e)||"ArrayBuffer"==(t=zn(e))||"SharedArrayBuffer"==t},C=function(e,t){return y(e)&&!fe(t)&&t in e&&Vi(+t)&&t>=0},S=function(e,t){return t=we(t),C(e,t)?vt(2,e[t]):s(e,t)},T=function(e,t,r){return t=we(t),!(C(e,t)&&X(r)&&I(r,"value"))||I(r,"get")||I(r,"set")||r.configurable||I(r,"writable")&&!r.writable||I(r,"enumerable")&&!r.enumerable?a(e,t,r):(e[t]=r.value,e)};re?(_||(Pt.f=S,Ie.f=T,O(m,"buffer"),O(m,"byteOffset"),O(m,"byteLength"),O(m,"length")),rr({target:"Object",stat:!0,forced:!_},{getOwnPropertyDescriptor:S,defineProperty:T}),e.exports=function(e,s,d){var g=e.match(/\d+$/)[0]/8,O=e+(d?"Clamped":"")+"Array",C="get"+e,S="set"+e,T=o[O],N=T,x=N&&N.prototype,I={},R=function(e,t){a(e,t,{get:function(){return function(e,t){var r=n(e);return r.view[C](t*g+r.byteOffset,!0)}(this,t)},set:function(e){return function(e,t,r){var i=n(e);d&&(r=(r=l(r))<0?0:r>255?255:255&r),i.view[S](t*g+i.byteOffset,r,!0)}(this,t,e)},enumerable:!0})};_?Gi&&(N=s((function(e,t,r,n){return Fr(e,x),po(X(t)?A(t)?void 0!==n?new T(t,Yi(r,g),n):void 0!==r?new T(t,Yi(r,g)):new T(t):y(t)?w(N,t):ue(no,N,t):new T(Gr(t)),e,N)})),yr&&yr(N,v),r(t(T),(function(e){e in N||mt(N,e,T[e])})),N.prototype=x):(N=s((function(e,t,r,n){Fr(e,x);var o,a,s,l=0,d=0;if(X(t)){if(!A(t))return y(t)?w(N,t):ue(no,N,t);o=t,d=Yi(r,g);var _=t.byteLength;if(void 0===n){if(_%g)throw u(E);if((a=_-d)<0)throw u(E)}else if((a=Be(n)*g)+d>_)throw u(E);s=a/g}else s=Gr(t),o=new c(a=s*g);for(i(e,{buffer:o,byteOffset:d,byteLength:a,length:s,view:new f(o)});l<s;)R(e,l++)})),yr&&yr(N,v),x=N.prototype=it(m)),x.constructor!==N&&mt(x,"constructor",N),mt(x,p,N),h&&mt(x,h,O),I[O]=N,rr({global:!0,forced:N!=T,sham:!_},I),b in N||mt(N,b,g),b in x||mt(x,b,g),_o(O)}):e.exports=function(){}}));ho("Uint16",(function(e){return function(t,r,n){return e(this,t,r,n)}}));var vo=Math.min,mo=[].copyWithin||function(e,t){var r=N(this),n=Fe(r),i=je(e,n),o=je(t,n),a=arguments.length>2?arguments[2]:void 0,s=vo((void 0===a?n:je(a,n))-o,n-i),l=1;for(o<i&&i<o+s&&(l=-1,o+=s-1,i+=s-1);s-- >0;)o in r?r[i]=r[o]:delete r[i],i+=l,o+=l;return r},go=f(mo),yo=Di.aTypedArray;(0,Di.exportTypedArrayMethod)("copyWithin",(function(e,t){return go(yo(this),e,t,arguments.length>2?arguments[2]:void 0)}));var bo=co.every,Eo=Di.aTypedArray;(0,Di.exportTypedArrayMethod)("every",(function(e){return bo(Eo(this),e,arguments.length>1?arguments[1]:void 0)}));var wo=Di.aTypedArray;(0,Di.exportTypedArrayMethod)("fill",(function(e){var t=arguments.length;return ue(Kr,wo(this),e,t>1?arguments[1]:void 0,t>2?arguments[2]:void 0)}));var Oo=Di.TYPED_ARRAY_CONSTRUCTOR,Ao=Di.aTypedArrayConstructor,Co=function(e){return Ao(ni(e,e[Oo]))},So=function(e,t){return function(e,t){for(var r=0,n=Fe(t),i=new e(n);n>r;)i[r]=t[r++];return i}(Co(e),t)},To=co.filter,No=Di.aTypedArray;(0,Di.exportTypedArrayMethod)("filter",(function(e){var t=To(No(this),e,arguments.length>1?arguments[1]:void 0);return So(this,t)}));var xo=co.find,Io=Di.aTypedArray;(0,Di.exportTypedArrayMethod)("find",(function(e){return xo(Io(this),e,arguments.length>1?arguments[1]:void 0)}));var Ro=co.findIndex,Lo=Di.aTypedArray;(0,Di.exportTypedArrayMethod)("findIndex",(function(e){return Ro(Lo(this),e,arguments.length>1?arguments[1]:void 0)}));var Mo=co.forEach,ko=Di.aTypedArray;(0,Di.exportTypedArrayMethod)("forEach",(function(e){Mo(ko(this),e,arguments.length>1?arguments[1]:void 0)}));var Po=Ge.includes,jo=Di.aTypedArray;(0,Di.exportTypedArrayMethod)("includes",(function(e){return Po(jo(this),e,arguments.length>1?arguments[1]:void 0)}));var Do=Ge.indexOf,Bo=Di.aTypedArray;(0,Di.exportTypedArrayMethod)("indexOf",(function(e){return Do(Bo(this),e,arguments.length>1?arguments[1]:void 0)}));var Fo=q("iterator"),Uo=o.Uint8Array,Go=f(kr.values),Ho=f(kr.keys),Vo=f(kr.entries),zo=Di.aTypedArray,$o=Di.exportTypedArrayMethod,Yo=Uo&&Uo.prototype,Wo=!a((function(){Yo[Fo].call([1])})),Zo=!!Yo&&Yo.values&&Yo[Fo]===Yo.values&&"values"===Yo.values.name,Jo=function(){return Go(zo(this))};$o("entries",(function(){return Vo(zo(this))}),Wo),$o("keys",(function(){return Ho(zo(this))}),Wo),$o("values",Jo,Wo||!Zo,{name:"values"}),$o(Fo,Jo,Wo||!Zo,{name:"values"});var Ko=Di.aTypedArray,qo=Di.exportTypedArrayMethod,Xo=f([].join);qo("join",(function(e){return Xo(Ko(this),e)}));var Qo=Function.prototype,ea=Qo.apply,ta=Qo.call,ra="object"==typeof Reflect&&Reflect.apply||(s?ta.bind(ea):function(){return ta.apply(ea,arguments)}),na=function(e,t){var r=[][e];return!!r&&a((function(){r.call(null,t||function(){return 1},1)}))},ia=Math.min,oa=[].lastIndexOf,aa=!!oa&&1/[1].lastIndexOf(1,-0)<0,sa=na("lastIndexOf"),la=aa||!sa?function(e){if(aa)return ra(oa,this,arguments)||0;var t=E(this),r=Fe(t),n=r-1;for(arguments.length>1&&(n=ia(n,Me(arguments[1]))),n<0&&(n=r+n);n>=0;n--)if(n in t&&t[n]===e)return n||0;return-1}:oa,ua=Di.aTypedArray;(0,Di.exportTypedArrayMethod)("lastIndexOf",(function(e){var t=arguments.length;return ra(la,ua(this),t>1?[e,arguments[1]]:[e])}));var ca=co.map,da=Di.aTypedArray;(0,Di.exportTypedArrayMethod)("map",(function(e){return ca(da(this),e,arguments.length>1?arguments[1]:void 0,(function(e,t){return new(Co(e))(t)}))}));var fa=o.TypeError,_a=function(e){return function(t,r,n,i){ve(r);var o=N(t),a=g(o),s=Fe(o),l=e?s-1:0,u=e?-1:1;if(n<2)for(;;){if(l in a){i=a[l],l+=u;break}if(l+=u,e?l<0:s<=l)throw fa("Reduce of empty array with no initial value")}for(;e?l>=0:s>l;l+=u)l in a&&(i=r(i,a[l],l,o));return i}},pa={left:_a(!1),right:_a(!0)},ha=pa.left,va=Di.aTypedArray;(0,Di.exportTypedArrayMethod)("reduce",(function(e){var t=arguments.length;return ha(va(this),e,t,t>1?arguments[1]:void 0)}));var ma=pa.right,ga=Di.aTypedArray;(0,Di.exportTypedArrayMethod)("reduceRight",(function(e){var t=arguments.length;return ma(ga(this),e,t,t>1?arguments[1]:void 0)}));var ya=Di.aTypedArray,ba=Di.exportTypedArrayMethod,Ea=Math.floor;ba("reverse",(function(){for(var e,t=this,r=ya(t).length,n=Ea(r/2),i=0;i<n;)e=t[i],t[i++]=t[--r],t[r]=e;return t}));var wa=f([].slice),Oa=Di.aTypedArray;(0,Di.exportTypedArrayMethod)("slice",(function(e,t){for(var r=wa(Oa(this),e,t),n=Co(this),i=0,o=r.length,a=new n(o);o>i;)a[i]=r[i++];return a}),a((function(){new Int8Array(1).slice()})));var Aa=co.some,Ca=Di.aTypedArray;(0,Di.exportTypedArrayMethod)("some",(function(e){return Aa(Ca(this),e,arguments.length>1?arguments[1]:void 0)}));var Sa=Math.floor,Ta=function(e,t){var r=e.length,n=Sa(r/2);return r<8?Na(e,t):xa(e,Ta(en(e,0,n),t),Ta(en(e,n),t),t)},Na=function(e,t){for(var r,n,i=e.length,o=1;o<i;){for(n=o,r=e[o];n&&t(e[n-1],r)>0;)e[n]=e[--n];n!==o++&&(e[n]=r)}return e},xa=function(e,t,r,n){for(var i=t.length,o=r.length,a=0,s=0;a<i||s<o;)e[a+s]=a<i&&s<o?n(t[a],r[s])<=0?t[a++]:r[s++]:a<i?t[a++]:r[s++];return e},Ia=Ta,Ra=B.match(/firefox\/(\d+)/i),La=!!Ra&&+Ra[1],Ma=/MSIE|Trident/.test(B),ka=B.match(/AppleWebKit\/(\d+)\./),Pa=!!ka&&+ka[1],ja=o.Array,Da=Di.aTypedArray,Ba=Di.exportTypedArrayMethod,Fa=o.Uint16Array,Ua=Fa&&f(Fa.prototype.sort),Ga=!(!Ua||a((function(){Ua(new Fa(2),null)}))&&a((function(){Ua(new Fa(2),{})}))),Ha=!!Ua&&!a((function(){if(z)return z<74;if(La)return La<67;if(Ma)return!0;if(Pa)return Pa<602;var e,t,r=new Fa(516),n=ja(516);for(e=0;e<516;e++)t=e%4,r[e]=515-e,n[e]=e-2*t+3;for(Ua(r,(function(e,t){return(e/4|0)-(t/4|0)})),e=0;e<516;e++)if(r[e]!==n[e])return!0}));Ba("sort",(function(e){return void 0!==e&&ve(e),Ha?Ua(this,e):Ia(Da(this),function(e){return function(t,r){return void 0!==e?+e(t,r)||0:r!=r?-1:t!=t?1:0===t&&0===r?1/t>0&&1/r<0?1:-1:t>r}}(e))}),!Ha||Ga);var Va=o.Int8Array,za=Di.aTypedArray,$a=Di.exportTypedArrayMethod,Ya=[].toLocaleString,Wa=!!Va&&a((function(){Ya.call(new Va(1))}));$a("toLocaleString",(function(){return ra(Ya,Wa?wa(za(this)):za(this),wa(arguments))}),a((function(){return[1,2].toLocaleString()!=new Va([1,2]).toLocaleString()}))||!a((function(){Va.prototype.toLocaleString.call([1,2])})));var Za=Di.exportTypedArrayMethod,Ja=o.Uint8Array,Ka=Ja&&Ja.prototype||{},qa=[].toString,Xa=f([].join);a((function(){qa.call({})}))&&(qa=function(){return Xa(this)});var Qa=Ka.toString!=qa;Za("toString",qa,Qa);var es=q("species"),ts=function(e){return z>=51||!a((function(){var t=[];return(t.constructor={})[es]=function(){return{foo:1}},1!==t[e](Boolean).foo}))},rs=ts("slice"),ns=q("species"),is=o.Array,os=Math.max;rr({target:"Array",proto:!0,forced:!rs},{slice:function(e,t){var r,n,i,o=E(this),a=Fe(o),s=je(e,a),l=je(void 0===t?a:t,a);if(io(o)&&(r=o.constructor,(Qn(r)&&(r===is||io(r.prototype))||X(r)&&null===(r=r[ns]))&&(r=void 0),r===is||void 0===r))return wa(o,s,l);for(n=new(void 0===r?is:r)(os(l-s,0)),i=0;s<l;s++,i++)s in o&&qr(n,i,o[s]);return n.length=i,n}}),ho("Int32",(function(e){return function(t,r,n){return e(this,t,r,n)}}));
/*! *****************************************************************************
	Copyright (c) Microsoft Corporation.

	Permission to use, copy, modify, and/or distribute this software for any
	purpose with or without fee is hereby granted.

	THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
	REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
	AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
	INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
	LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
	OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
	PERFORMANCE OF THIS SOFTWARE.
	***************************************************************************** */
var as=function(e,t){return as=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var r in t)Object.prototype.hasOwnProperty.call(t,r)&&(e[r]=t[r])},as(e,t)};function ss(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function r(){this.constructor=e}as(e,t),e.prototype=null===t?Object.create(t):(r.prototype=t.prototype,new r)}function ls(){for(var e=0,t=0,r=arguments.length;t<r;t++)e+=arguments[t].length;var n=Array(e),i=0;for(t=0;t<r;t++)for(var o=arguments[t],a=0,s=o.length;a<s;a++,i++)n[i]=o[a];return n}var us="ArrayBuffer",cs=Bn.ArrayBuffer,ds=o.ArrayBuffer;rr({global:!0,forced:ds!==cs},{ArrayBuffer:cs}),_o(us),ho("Int8",(function(e){return function(t,r,n){return e(this,t,r,n)}})),ho("Uint8",(function(e){return function(t,r,n){return e(this,t,r,n)}})),ho("Int16",(function(e){return function(t,r,n){return e(this,t,r,n)}})),ho("Uint32",(function(e){return function(t,r,n){return e(this,t,r,n)}})),ho("Float32",(function(e){return function(t,r,n){return e(this,t,r,n)}})),ho("Float64",(function(e){return function(t,r,n){return e(this,t,r,n)}}));var fs,_s,ps,hs,vs,ms,gs,ys,bs,Es,ws=new ArrayBuffer(1114112);fs={Math:Math,Int8Array:Int8Array,Uint8Array:Uint8Array,Int16Array:Int16Array,Uint16Array:Uint16Array,Int32Array:Int32Array,Uint32Array:Uint32Array,Float32Array:Float32Array,Float64Array:Float64Array,NaN:NaN,Infinity:1/0},_s=ws,ps=new fs.Int8Array(_s),new fs.Int16Array(_s),hs=new fs.Int32Array(_s),vs=new fs.Uint8Array(_s),ms=new fs.Uint16Array(_s),gs=new fs.Uint32Array(_s),new fs.Float32Array(_s),new fs.Float64Array(_s),ys=fs.Math.imul,fs.Math.fround,fs.Math.abs,bs=fs.Math.clz32,fs.Math.min,fs.Math.max,fs.Math.floor,fs.Math.ceil,fs.Math.sqrt,fs.NaN,fs.Infinity,Es=1048576;var Os={memory:Object.create(Object.prototype,{grow:{value:Rs},buffer:{get:function(){return _s}}}),rust_calloc:Ts,rust_free:function(e){As(e|=0)},llparser_create:function(e,t,r){return 0|(n=e|=0,i=t|=0,o=r|=0,Es=a=Es-32|0,hs[28+a>>2]=n,hs[24+a>>2]=i,hs[20+a>>2]=o,i=hs[28+(n=a)>>2]?hs[28+a>>2]:256,hs[n+28>>2]=i,i=hs[24+(n=a)>>2]?hs[24+a>>2]:256,hs[n+24>>2]=i,i=hs[20+(n=a)>>2]?hs[20+a>>2]:256,hs[n+20>>2]=i,l=Ts(((((((ys(hs[24+(s=a)>>2],140)+52|0)+ys(hs[20+a>>2],44)|0)+(hs[24+a>>2]<<9)|0)+(hs[24+a>>2]<<9)|0)+ys(hs[20+a>>2],hs[24+a>>2]<<3)|0)+(hs[28+a>>2]<<1)|0)+(hs[28+a>>2]<<3)|0,1),hs[16+s>>2]=l,hs[hs[16+a>>2]+12>>2]=hs[28+a>>2],hs[hs[16+a>>2]+16>>2]=hs[24+a>>2],hs[hs[16+a>>2]+20>>2]=hs[20+a>>2],hs[hs[16+a>>2]+4>>2]=0,hs[hs[16+a>>2]>>2]=0,hs[hs[16+a>>2]+8>>2]=0,hs[12+a>>2]=hs[16+a>>2]+52,hs[hs[16+a>>2]+24>>2]=hs[12+a>>2],hs[12+a>>2]=hs[12+a>>2]+ys(hs[24+a>>2],140),hs[hs[16+a>>2]+28>>2]=hs[12+a>>2],hs[12+a>>2]=hs[12+a>>2]+ys(hs[20+a>>2],44),hs[hs[16+a>>2]+32>>2]=hs[12+a>>2],hs[12+a>>2]=hs[12+a>>2]+(hs[24+a>>2]<<9),hs[hs[16+a>>2]+36>>2]=hs[12+a>>2],hs[12+a>>2]=hs[12+a>>2]+(hs[24+a>>2]<<9),hs[hs[16+a>>2]+40>>2]=hs[12+a>>2],hs[12+a>>2]=hs[12+a>>2]+ys(hs[20+a>>2],hs[24+a>>2]<<3),hs[hs[16+a>>2]+44>>2]=hs[12+a>>2],hs[12+a>>2]=hs[12+a>>2]+(hs[28+a>>2]<<1),hs[hs[16+a>>2]+48>>2]=hs[12+a>>2],Es=32+a|0,hs[16+a>>2]);var n,i,o,a,s,l},llparser_destroy:function(e){var t,r;t=e|=0,Es=r=Es-16|0,hs[12+r>>2]=t,As(hs[12+r>>2]),Es=16+r|0},llparser_create_descriptor:function(e,t){return 0|(r=e|=0,n=t|=0,hs[12+(i=Es-16|0)>>2]=r,hs[8+i>>2]=n,n=hs[hs[12+i>>2]+24>>2],o=hs[12+i>>2],r=hs[o+4>>2],hs[o+4>>2]=r+1,hs[4+i>>2]=n+ys(r,140),hs[hs[4+i>>2]+4>>2]=hs[8+i>>2]?1:0,hs[4+i>>2]);var r,n,i,o},llparser_descriptor_set_all:function(e){var t;e|=0,hs[12+(t=Es-16|0)>>2]=e,hs[hs[12+t>>2]+4>>2]=-1,ps[hs[12+t>>2]+135|0]=1},llparser_descriptor_set_nil:function(e){var t;e|=0,hs[12+(t=Es-16|0)>>2]=e,hs[hs[12+t>>2]+4>>2]=-2,ps[hs[12+t>>2]+8|0]=1},llparser_descriptor_add_char:function(e,t){var r,n,i;r=e|=0,n=t|=0,hs[12+(i=Es-16|0)>>2]=r,hs[8+i>>2]=n,ps[hs[8+i>>2]+(hs[12+i>>2]+8|0)|0]=1},llparser_descriptor_add_range:function(e,t,r){!function(e,t,r){var n;for(hs[12+(n=Es-16|0)>>2]=e,hs[8+n>>2]=t,hs[4+n>>2]=r,hs[n>>2]=hs[8+n>>2];!(hs[n>>2]>hs[4+n>>2]);)ps[hs[n>>2]+(hs[12+n>>2]+8|0)|0]=1,hs[n>>2]=hs[n>>2]+1}(e|=0,t|=0,r|=0)},llparser_descriptor_revert:function(e){!function(e){var t;for(hs[12+(t=Es-16|0)>>2]=e,hs[8+t>>2]=1;!(127<=hs[8+t>>2]);)ps[hs[8+t>>2]+(hs[12+t>>2]+8|0)|0]=1&(0!=vs[hs[8+t>>2]+(hs[12+t>>2]+8|0)|0]^-1),hs[8+t>>2]=hs[8+t>>2]+1}(e|=0)},llparser_add_rule:function(e,t,r,n,i,o,a,s,l,u,c,d){return 0|(f=e|=0,_=t|=0,p=r|=0,h=n|=0,v=i|=0,m=o|=0,g=a|=0,y=s|=0,b=l|=0,E=u|=0,w=c|=0,O=d|=0,Es=A=Es+-64|0,hs[60+A>>2]=f,hs[56+A>>2]=_,hs[52+A>>2]=p,hs[48+A>>2]=h,hs[44+A>>2]=v,hs[40+A>>2]=m,hs[36+A>>2]=g,hs[32+A>>2]=y,hs[28+A>>2]=b,hs[24+A>>2]=E,hs[20+A>>2]=w,hs[16+A>>2]=O,_=hs[hs[60+A>>2]+28>>2],p=hs[60+A>>2],f=hs[p>>2],hs[p>>2]=f+1,hs[12+A>>2]=_+ys(f,44),hs[hs[12+A>>2]>>2]=hs[52+A>>2],hs[hs[12+A>>2]+4>>2]=hs[48+A>>2],0<hs[48+A>>2]&&(hs[hs[12+A>>2]+8>>2]=hs[44+A>>2]),1<hs[48+A>>2]&&(hs[hs[12+A>>2]+12>>2]=hs[40+A>>2]),2<hs[48+A>>2]&&(hs[hs[12+A>>2]+16>>2]=hs[36+A>>2]),3<hs[48+A>>2]&&(hs[hs[12+A>>2]+20>>2]=hs[32+A>>2]),4<hs[48+A>>2]&&(hs[hs[12+A>>2]+24>>2]=hs[28+A>>2]),5<hs[48+A>>2]&&(hs[hs[12+A>>2]+28>>2]=hs[24+A>>2]),6<hs[48+A>>2]&&(hs[hs[12+A>>2]+32>>2]=hs[20+A>>2]),7<hs[48+A>>2]&&(hs[hs[12+A>>2]+36>>2]=hs[16+A>>2]),hs[hs[12+A>>2]+40>>2]=hs[56+A>>2],0<hs[48+A>>2]&&(C=hs[60+A>>2],S=hs[12+A>>2],T=hs[52+A>>2],hs[28+(N=Es-32|0)>>2]=C,hs[24+N>>2]=S,hs[20+N>>2]=T,hs[16+N>>2]=(hs[20+N>>2]-hs[hs[28+N>>2]+24>>2]|0)/140,1==hs[hs[20+N>>2]+4>>2]&&(S=hs[hs[28+N>>2]+40>>2],T=hs[28+N>>2],C=hs[T+8>>2],hs[T+8>>2]=C+1,hs[12+N>>2]=S+(C<<3),hs[hs[12+N>>2]>>2]=hs[24+N>>2],hs[hs[12+N>>2]+4>>2]=hs[hs[20+N>>2]+136>>2],hs[hs[20+N>>2]+136>>2]=hs[12+N>>2])),Es=64+A|0,hs[12+A>>2]);var f,_,p,h,v,m,g,y,b,E,w,O,A,C,S,T,N},llparser_prepare:function(e){!function(e){var t;for(Es=t=Es-32|0,hs[28+t>>2]=e,hs[24+t>>2]=0;!(hs[24+t>>2]>=hs[hs[28+t>>2]+4>>2]);)hs[20+t>>2]=hs[hs[28+t>>2]+24>>2]+ys(hs[24+t>>2],140),1==hs[hs[20+t>>2]+4>>2]&&function e(t,r,n,i,o){var a;if(Es=a=Es-48|0,hs[44+a>>2]=t,hs[40+a>>2]=r,hs[36+a>>2]=n,hs[32+a>>2]=i,hs[28+a>>2]=o,hs[hs[40+a>>2]>>2]!=hs[36+a>>2])for(hs[hs[40+a>>2]>>2]=hs[36+a>>2],hs[24+a>>2]=hs[hs[40+a>>2]+136>>2],hs[20+a>>2]=1&(0!=hs[28+a>>2]^-1^-1);hs[24+a>>2];){for(hs[20+a>>2]||(hs[28+a>>2]=hs[24+a>>2]),hs[16+a>>2]=hs[hs[hs[24+a>>2]>>2]+8>>2],1==hs[hs[16+a>>2]+4>>2]&&e(hs[44+a>>2],hs[16+a>>2],hs[36+a>>2],hs[32+a>>2],hs[28+a>>2]),hs[12+a>>2]=0;!(128<=hs[12+a>>2]);)vs[hs[12+a>>2]+(hs[16+a>>2]+8|0)|0]&&(gs[hs[28+a>>2]>>2]>=gs[hs[32+a>>2]+(hs[12+a>>2]<<2)>>2]&&hs[hs[32+a>>2]+(hs[12+a>>2]<<2)>>2]||(hs[hs[32+a>>2]+(hs[12+a>>2]<<2)>>2]=hs[hs[28+a>>2]>>2])),hs[12+a>>2]=hs[12+a>>2]+1;hs[24+a>>2]=hs[hs[24+a>>2]+4>>2]}Es=48+a|0}(hs[28+t>>2],hs[20+t>>2],hs[20+t>>2],hs[hs[28+t>>2]+32>>2]+(hs[24+t>>2]<<9)|0,0),hs[24+t>>2]=hs[24+t>>2]+1;for(hs[16+t>>2]=0;!(hs[16+t>>2]>=hs[hs[28+t>>2]+4>>2]);)hs[12+t>>2]=hs[hs[28+t>>2]+24>>2]+ys(hs[16+t>>2],140),1==hs[hs[12+t>>2]+4>>2]&&(hs[hs[12+t>>2]>>2]=0,function(e,t,r,n){var i;for(hs[44+(i=Es-48|0)>>2]=e,hs[40+i>>2]=t,hs[36+i>>2]=r,hs[32+i>>2]=n,hs[28+i>>2]=hs[hs[40+i>>2]+136>>2];hs[28+i>>2];){if(hs[24+i>>2]=hs[hs[hs[28+i>>2]>>2]+8>>2],hs[24+i>>2]==hs[40+i>>2])for(hs[20+i>>2]=hs[hs[hs[28+i>>2]>>2]+12>>2],hs[16+i>>2]=0;!(128<=hs[16+i>>2]);){e:{if(1!=hs[hs[20+i>>2]+4>>2]){if(!vs[hs[16+i>>2]+(hs[20+i>>2]+8|0)|0])break e}else if(hs[12+i>>2]=hs[hs[44+i>>2]+32>>2]+((hs[20+i>>2]-hs[hs[44+i>>2]+24>>2]|0)/140<<9),!hs[hs[12+i>>2]+(hs[16+i>>2]<<2)>>2])break e;gs[hs[28+i>>2]>>2]>=gs[hs[32+i>>2]+(hs[16+i>>2]<<2)>>2]&&hs[hs[32+i>>2]+(hs[16+i>>2]<<2)>>2]||(hs[hs[32+i>>2]+(hs[16+i>>2]<<2)>>2]=hs[hs[28+i>>2]>>2])}hs[16+i>>2]=hs[16+i>>2]+1}hs[28+i>>2]=hs[hs[28+i>>2]+4>>2]}}(hs[28+t>>2],hs[12+t>>2],hs[12+t>>2],hs[hs[28+t>>2]+36>>2]+(hs[16+t>>2]<<9)|0)),hs[16+t>>2]=hs[16+t>>2]+1;Es=32+t|0}(e|=0)},llparser_parse:function(e,t){return 0|(r=e|=0,n=t|=0,Es=i=Es-32|0,hs[24+i>>2]=r,hs[20+i>>2]=n,hs[16+i>>2]=0,hs[12+i>>2]=0,a=function e(t,r,n,i,o,a,s){var l,u=0,c=0;Es=l=Es-96|0,hs[88+l>>2]=t,hs[84+l>>2]=r,hs[80+l>>2]=n,hs[76+l>>2]=i,hs[72+l>>2]=o,hs[68+l>>2]=a,hs[64+l>>2]=s,hs[60+l>>2]=ms[hs[80+l>>2]+(hs[hs[76+l>>2]>>2]<<1)>>1],128<=gs[60+l>>2]&&(hs[60+l>>2]=1);e:if(hs[hs[72+l>>2]>>2]>(hs[64+l>>2]-4|0))hs[92+l>>2]=-1;else if(1==hs[hs[84+l>>2]+4>>2])if(hs[56+l>>2]=hs[hs[76+l>>2]>>2],hs[52+l>>2]=hs[hs[72+l>>2]>>2],hs[48+l>>2]=0,hs[44+l>>2]=0,hs[40+l>>2]=hs[hs[88+l>>2]+32>>2]+((hs[84+l>>2]-hs[hs[88+l>>2]+24>>2]|0)/140<<9),hs[36+l>>2]=0,!hs[hs[40+l>>2]+(hs[60+l>>2]<<2)>>2]|gs[60+l>>2]<=0|127<=gs[60+l>>2]?!hs[60+l>>2]|!hs[hs[40+l>>2]+508>>2]?hs[hs[40+l>>2]>>2]&&(hs[36+l>>2]=hs[hs[40+l>>2]>>2]):hs[36+l>>2]=hs[hs[40+l>>2]+508>>2]:hs[36+l>>2]=hs[hs[40+l>>2]+(hs[60+l>>2]<<2)>>2],hs[36+l>>2]){for(hs[68+l>>2]||hs[hs[36+l>>2]+40>>2]||(hs[48+l>>2]=hs[hs[72+l>>2]>>2],t=hs[72+l>>2],hs[t>>2]=hs[t>>2]+2),hs[32+l>>2]=0;hs[32+l>>2]<hs[hs[36+l>>2]+4>>2];){if(hs[28+l>>2]=hs[68+l>>2],hs[68+l>>2]||!hs[hs[36+l>>2]+40>>2]|hs[hs[36+l>>2]+40>>2]==(hs[32+l>>2]+65536|0)||(hs[28+l>>2]=1),c=e(hs[88+(u=l)>>2],hs[(hs[36+l>>2]+8|0)+(hs[32+l>>2]<<2)>>2],hs[80+l>>2],hs[76+l>>2],hs[72+l>>2],hs[28+l>>2],hs[64+l>>2]),hs[u+24>>2]=c,hs[24+l>>2]<0){hs[92+l>>2]=-1;break e}hs[68+l>>2]|hs[hs[36+l>>2]+40>>2]!=(hs[32+l>>2]+65536|0)||(hs[44+l>>2]=hs[24+l>>2]),hs[32+l>>2]=hs[32+l>>2]+1}for(hs[68+l>>2]||(hs[hs[36+l>>2]+40>>2]?1==hs[hs[36+l>>2]+40>>2]&&(r=hs[56+l>>2],n=hs[hs[88+l>>2]+48>>2],i=hs[72+l>>2],t=hs[i>>2],hs[i>>2]=t+1,hs[n+(t<<2)>>2]=r,hs[44+l>>2]=hs[hs[72+l>>2]>>2],r=hs[hs[76+l>>2]>>2],n=hs[hs[88+l>>2]+48>>2],i=hs[72+l>>2],t=hs[i>>2],hs[i>>2]=t+1,hs[n+(t<<2)>>2]=r):(hs[hs[hs[88+l>>2]+48>>2]+(hs[48+l>>2]<<2)>>2]=0-hs[36+l>>2],hs[hs[hs[88+l>>2]+48>>2]+(hs[48+l>>2]+1<<2)>>2]=hs[hs[36+l>>2]+4>>2],hs[44+l>>2]=hs[48+l>>2]+1));;){if(hs[hs[72+l>>2]>>2]>(hs[64+l>>2]-4|0)){hs[92+l>>2]=-1;break e}if(hs[20+l>>2]=hs[hs[88+l>>2]+36>>2]+((hs[84+l>>2]-hs[hs[88+l>>2]+24>>2]|0)/140<<9),hs[16+l>>2]=0,hs[60+l>>2]=ms[hs[80+l>>2]+(hs[hs[76+l>>2]>>2]<<1)>>1],128<=gs[60+l>>2]&&(hs[60+l>>2]=1),!hs[hs[20+l>>2]+(hs[60+l>>2]<<2)>>2]|gs[60+l>>2]<=0|127<=gs[60+l>>2]?!hs[60+l>>2]|!hs[hs[20+l>>2]+508>>2]||(hs[16+l>>2]=hs[hs[20+l>>2]+508>>2]):hs[16+l>>2]=hs[hs[20+l>>2]+(hs[60+l>>2]<<2)>>2],!hs[16+l>>2])break;for(hs[68+l>>2]||(hs[hs[16+l>>2]+40>>2]?65536!=hs[hs[16+l>>2]+40>>2]&&(hs[hs[72+l>>2]>>2]=hs[52+l>>2]):(hs[hs[hs[88+l>>2]+48>>2]+(hs[44+l>>2]<<2)>>2]=(0-hs[hs[hs[88+l>>2]+48>>2]+(hs[44+l>>2]<<2)>>2]|0)-1,hs[48+l>>2]=hs[hs[72+l>>2]>>2],t=hs[72+l>>2],hs[t>>2]=hs[t>>2]+2)),hs[12+l>>2]=1;hs[12+l>>2]<hs[hs[16+l>>2]+4>>2];){if(hs[8+l>>2]=hs[68+l>>2],hs[68+l>>2]||!hs[hs[16+l>>2]+40>>2]|hs[hs[16+l>>2]+40>>2]==(hs[12+l>>2]+65536|0)||(hs[8+l>>2]=1),c=e(hs[88+(u=l)>>2],hs[(hs[16+l>>2]+8|0)+(hs[12+l>>2]<<2)>>2],hs[80+l>>2],hs[76+l>>2],hs[72+l>>2],hs[8+l>>2],hs[64+l>>2]),hs[u+4>>2]=c,hs[4+l>>2]<0){hs[92+l>>2]=-1;break e}hs[68+l>>2]|hs[hs[16+l>>2]+40>>2]!=(hs[12+l>>2]+65536|0)||(hs[44+l>>2]=hs[4+l>>2]),hs[12+l>>2]=hs[12+l>>2]+1}hs[68+l>>2]||(hs[hs[16+l>>2]+40>>2]?1==hs[hs[16+l>>2]+40>>2]&&(r=hs[56+l>>2],n=hs[hs[88+l>>2]+48>>2],i=hs[72+l>>2],t=hs[i>>2],hs[i>>2]=t+1,hs[n+(t<<2)>>2]=r,hs[44+l>>2]=hs[hs[72+l>>2]>>2],r=hs[hs[76+l>>2]>>2],n=hs[hs[88+l>>2]+48>>2],i=hs[72+l>>2],t=hs[i>>2],hs[i>>2]=t+1,hs[n+(t<<2)>>2]=r):(hs[hs[hs[88+l>>2]+48>>2]+(hs[48+l>>2]<<2)>>2]=0-hs[16+l>>2],hs[hs[hs[88+l>>2]+48>>2]+(hs[48+l>>2]+1<<2)>>2]=hs[hs[16+l>>2]+4>>2],hs[44+l>>2]=hs[48+l>>2]+1))}hs[92+l>>2]=hs[44+l>>2]}else hs[92+l>>2]=-1;else{if(hs[60+l>>2]&&(-1==hs[hs[84+l>>2]+4>>2]&&(t=hs[76+l>>2],hs[t>>2]=hs[t>>2]+1),!hs[hs[84+l>>2]+4>>2])){if(!vs[hs[60+l>>2]+(hs[84+l>>2]+8|0)|0]){hs[92+l>>2]=-1;break e}t=hs[76+l>>2],hs[t>>2]=hs[t>>2]+1}hs[68+l>>2]||(r=hs[hs[76+l>>2]>>2],n=hs[hs[84+l>>2]+4>>2],i=hs[hs[88+l>>2]+48>>2],o=hs[72+l>>2],t=hs[o>>2],hs[o>>2]=t+1,hs[i+(t<<2)>>2]=r-(-2==(0|n)?0:1),r=hs[hs[76+l>>2]>>2],n=hs[hs[88+l>>2]+48>>2],i=hs[72+l>>2],t=hs[i>>2],hs[i>>2]=t+1,hs[n+(t<<2)>>2]=r),hs[92+l>>2]=hs[hs[72+l>>2]>>2]-1}return Es=96+l|0,hs[92+l>>2]}(hs[24+(o=i)>>2],hs[20+i>>2],hs[hs[24+i>>2]+44>>2],12+i|0,16+i|0,0,hs[hs[24+i>>2]+12>>2]<<1),hs[8+o>>2]=a,r=hs[hs[24+i>>2]+48>>2],n=hs[16+i>>2],hs[16+i>>2]=n+1,hs[r+(n<<2)>>2]=-1,r=hs[hs[24+i>>2]+48>>2],n=hs[16+i>>2],hs[16+i>>2]=n+1,hs[r+(n<<2)>>2]=0,ms[hs[hs[24+i>>2]+44>>2]+(hs[12+i>>2]<<1)>>1]|hs[8+i>>2]<0?hs[28+i>>2]=hs[12+i>>2]+1:hs[28+i>>2]=0,Es=32+i|0,hs[28+i>>2]);var r,n,i,o,a},llparser_get_input_buffer:function(e){var t;return e|=0,hs[12+(t=Es-16|0)>>2]=e,hs[hs[12+t>>2]+44>>2]},llparser_get_result:function(e){var t;return e|=0,hs[12+(t=Es-16|0)>>2]=e,hs[hs[12+t>>2]+48>>2]},wasm_main:Ns,__wbindgen_start:Ns};function As(e){var t=0,r=0,n=0,i=0,o=0,a=0,s=0;r=(t=e+-8|0)+(e=-8&(i=hs[e+-4>>2]))|0;e:{t:{r:{n:{i:if(!(1&i)){if(!(3&i))break n;if(e=(i=hs[t>>2])+e|0,(0|(t=t-i|0))==hs[262246]){if(3!=(3&hs[r+4>>2]))break i;return hs[262244]=e,hs[r+4>>2]=-2&hs[r+4>>2],hs[t+4>>2]=1|e,hs[e+t>>2]=e,0}256<=i>>>0?Ss(t):(0|(n=hs[t+8>>2]))==(0|(o=hs[t+12>>2]))?(a=1048576,s=hs[262144]&Is(i>>>3),hs[a>>2]=s):(hs[n+12>>2]=o,hs[o+8>>2]=n)}if(2&(i=hs[r+4>>2]))hs[r+4>>2]=-2&i,hs[t+4>>2]=1|e,hs[e+t>>2]=e;else{i:{if(hs[262247]!=(0|r)){if((0|r)!=hs[262246])break i;return hs[262246]=t,e=hs[262244]+e|0,hs[262244]=e,hs[t+4>>2]=1|e,hs[e+t>>2]=e,0}if(hs[262247]=t,e=hs[262245]+e|0,hs[262245]=e,hs[t+4>>2]=1|e,(0|t)==hs[262246]&&(hs[262244]=0,hs[262246]=0),(r=hs[262254])>>>0>=e>>>0)break n;if(!(e=hs[262247]))break n;o:if(!((i=hs[262245])>>>0<41))for(t=1049e3;;){if((n=hs[t>>2])+hs[t+4>>2]>>>0>e>>>0&&n>>>0<=e>>>0)break o;if(!(t=hs[t+8>>2]))break}if(n=4095,e=hs[262252]){for(t=0;t=t+1|0,e=hs[e+8>>2];);n=4095<t>>>0?t:4095}if(hs[262256]=n,i>>>0<=r>>>0)break n;return hs[262254]=-1,0}if(e=(n=-8&i)+e|0,256<=n>>>0?Ss(r):(0|(n=hs[r+12>>2]))==(0|(r=hs[r+8>>2]))?(a=1048576,s=hs[262144]&Is(i>>>3),hs[a>>2]=s):(hs[r+12>>2]=n,hs[n+8>>2]=r),hs[t+4>>2]=1|e,hs[e+t>>2]=e,hs[262246]==(0|t)){hs[262244]=e;break n}}if(e>>>0<256)break r;if(Cs(t,e),e=hs[262256]+-1|0,!(hs[262256]=e)){if(e=hs[262252])break t;e=4095;break e}}return}return e=1048584+((r=e>>>3)<<3)|0,i=hs[262144],r=1<<(31&r),n=hs[e+8>>2],i&r||(hs[262144]=r|i,n=e),r=n,hs[e+8>>2]=t,hs[r+12>>2]=t,hs[t+12>>2]=e,hs[t+8>>2]=r,0}for(t=0;t=t+1|0,e=hs[e+8>>2];);e=4095<t>>>0?t:4095}hs[262256]=e}function Cs(e,t){var r=0,n=0,i=0,o=0;hs[e+16>>2]=0,r=hs[(i=e)+20>>2]=0,(n=t>>>8)&&(r=31,16777215<t>>>0||(r=62+((t>>>(6-(n=bs(n))&31)&1)-(n<<1)|0)|0)),i=1048848+((hs[i+28>>2]=r)<<2)|0;e:{t:{r:{n:{if((o=hs[262145])&(n=1<<(31&r))){if(n=hs[i>>2],(-8&hs[n+4>>2])!=(0|t))break n;r=n;break r}hs[262145]=n|o,hs[i>>2]=e,hs[e+24>>2]=i;break e}for(i=t<<(31==(0|r)?0:25-(r>>>1)&31);;){if(!(r=hs[(o=16+((i>>>29&4)+n|0)|0)>>2]))break t;if(i<<=1,(-8&hs[(n=r)+4>>2])==(0|t))break}}return t=hs[r+8>>2],hs[t+12>>2]=e,hs[r+8>>2]=e,hs[e+24>>2]=0,hs[e+12>>2]=r,hs[e+8>>2]=t,0}hs[o>>2]=e,hs[e+24>>2]=n}hs[e+12>>2]=e,hs[e+8>>2]=e}function Ss(e){var t=0,r=0,n=0,i=0,o=0,a=0,s=hs[e+24>>2];e:{t:{if((0|e)==(0|(t=hs[e+12>>2]))){if(n=hs[(t=e+20|0)>>2],r=hs[(n?20:16)+e>>2])break t;t=0;break e}r=hs[e+8>>2],hs[r+12>>2]=t,hs[t+8>>2]=r;break e}for(n=n?t:e+16|0;i=n,(r=hs[(n=(t=r)+20|0)>>2])||(n=t+16|0,r=hs[t+16>>2]),r;);hs[i>>2]=0}e:if(s){r=1048848+(hs[e+28>>2]<<2)|0;t:{if((0|e)==hs[r>>2]){if(hs[r>>2]=t)break t;return o=1048580,a=hs[262145]&Is(hs[e+28>>2]),hs[o>>2]=a,0}if(!(hs[(hs[s+16>>2]==(0|e)?16:20)+s>>2]=t))break e}hs[t+24>>2]=s,(r=hs[e+16>>2])&&(hs[t+16>>2]=r,hs[r+24>>2]=t),(e=hs[e+20>>2])&&(hs[t+20>>2]=e,hs[e+24>>2]=t)}}function Ts(e,t){return 0|(!(n=function(e){var t=0,r=0,n=0,i=0,o=0,a=0,s=0,l=0,u=0,c=0,d=0;e:{t:{r:{if(245<=e>>>0){if(4294901709<=e>>>0)break t;if(i=-8&(e=e+11|0),!(l=hs[262145]))break r;r=0-i|0,s=0,(e>>>=8)&&(s=31,16777215<i>>>0||(s=62+((i>>>(6-(e=bs(e))&31)&1)-(e<<1)|0)|0));n:{i:{if(e=hs[1048848+(s<<2)>>2]){for(o=i<<(31==(0|s)?0:25-(s>>>1)&31);;){if(!((a=-8&hs[e+4>>2])>>>0<i>>>0||(a=a-i|0)>>>0>=r>>>0||(n=e,r=a))){r=0;break i}if(a=hs[e+20>>2],e=hs[16+((o>>>29&4)+e|0)>>2],t=a&&(0|a)!=(0|e)?a:t,o<<=1,!e)break}if(t){e=t;break i}if(n)break n}if(!(e=((n=0)-(e=2<<(31&s))|e)&l))break r;if(!(e=hs[1048848+(xs(e&0-e)<<2)>>2]))break r}for(;n=(a=(o=(t=-8&hs[e+4>>2])-i|0)>>>0<r>>>0&i>>>0<=t>>>0)?e:n,r=a?o:r,e=(t=hs[e+16>>2])||hs[e+20>>2];);if(!n)break r}if(r>>>0>=(e=hs[262244])-i>>>0&&i>>>0<=e>>>0)break r;Ss(n);n:if(16<=r>>>0){if(hs[n+4>>2]=3|i,hs[4+(t=n+i|0)>>2]=1|r,256<=(hs[t+r>>2]=r)>>>0){Cs(t,r);break n}e=1048584+((r>>>=3)<<3)|0,o=hs[262144],r=1<<(31&r),s=hs[e+8>>2],o&r||(hs[262144]=r|o,s=e),r=s,hs[e+8>>2]=t,hs[r+12>>2]=t,hs[t+12>>2]=e,hs[t+8>>2]=r}else e=r+i|0,hs[n+4>>2]=3|e,hs[4+(e=e+n|0)>>2]=1|hs[e+4>>2];return n+8|0}n:{i:{if(!(3&(e=(t=hs[262144])>>>(n=31&(r=(i=e>>>0<11?16:e+11&-8)>>>3))))){if(i>>>0<=gs[262244])break r;if(e)break i;if(!(e=hs[262145]))break r;for(t=hs[1048848+(xs(e&0-e)<<2)>>2],r=(-8&hs[t+4>>2])-i|0,o=t;;){if(!(e=hs[t+16>>2])&&!(e=hs[t+20>>2]))break n;r=(t=(n=(-8&hs[e+4>>2])-i|0)>>>0<r>>>0)?n:r,o=t?e:o,t=e}}r=(e=hs[1048592+(a=(n=r+(1&(-1^e))|0)<<3)>>2])+8|0,(0|(o=hs[e+8>>2]))==(0|(a=a+1048584|0))?(d=Is(n)&t,hs[(c=1048576)>>2]=d):(hs[o+12>>2]=a,hs[a+8>>2]=o),t=n<<3,hs[e+4>>2]=3|t,hs[4+(e=e+t|0)>>2]=1|hs[e+4>>2];break t}return n=xs(0-(e=(r=e<<n)&(0-(e=2<<n)|e))&e),e=hs[1048592+(o=n<<3)>>2],(0|(r=hs[e+8>>2]))==(0|(o=o+1048584|0))?(d=Is(n)&t,hs[(c=1048576)>>2]=d):(hs[r+12>>2]=o,hs[o+8>>2]=r),o=e+8|0,hs[e+4>>2]=3|i,r=(t=n<<3)-i|0,hs[4+(a=e+i|0)>>2]=1|r,hs[e+t>>2]=r,(e=hs[262244])&&(e=1048584+((n=e>>>3)<<3)|0,t=hs[262246],i=hs[262144],n=1<<(31&n),s=hs[e+8>>2],i&n||(hs[262144]=n|i,s=e),n=s,hs[e+8>>2]=t,hs[n+12>>2]=t,hs[t+12>>2]=e,hs[t+8>>2]=n),hs[262246]=a,hs[262244]=r,o}return Ss(o),16<=r>>>0?(hs[o+4>>2]=3|i,hs[4+(a=i+o|0)>>2]=1|r,hs[r+a>>2]=r,(e=hs[262244])&&(e=1048584+((n=e>>>3)<<3)|0,t=hs[262246],i=hs[262144],n=1<<(31&n),s=hs[e+8>>2],i&n||(hs[262144]=n|i,s=e),n=s,hs[e+8>>2]=t,hs[n+12>>2]=t,hs[t+12>>2]=e,hs[t+8>>2]=n),hs[262246]=a,hs[262244]=r):(e=r+i|0,hs[o+4>>2]=3|e,hs[4+(e=e+o|0)>>2]=1|hs[e+4>>2]),o+8|0}r:{n:{i:{o:{if((t=hs[262244])>>>0<i>>>0){if((e=hs[262245])>>>0>i>>>0)break e;if(-1==((r=0)|(t=Rs((e=i+65583|0)>>>16))))break t;if(!(n=t<<16))break t;if(e=(o=-65536&e)+hs[262248]|0,hs[262248]=e,t=hs[262249],hs[262249]=e>>>0<t>>>0?t:e,!(r=hs[262247]))break o;for(e=1049e3;;){if((0|n)==((t=hs[e>>2])+(a=hs[e+4>>2])|0))break i;if(!(e=hs[e+8>>2]))break}break n}return e=hs[262246],(n=t-i|0)>>>0<=15?(hs[262246]=0,hs[262244]=0,hs[e+4>>2]=3|t,i=4+(t=e+t|0)|0,r=1|hs[t+4>>2]):(hs[262244]=n,r=e+i|0,hs[262246]=r,hs[r+4>>2]=1|n,hs[e+t>>2]=n,r=3|i,i=e+4|0),hs[i>>2]=r,e+8|0}for((e=hs[262255])>>>0<=n>>>0&&e||(hs[262255]=n),e=0,hs[262256]=4095,hs[262251]=o,hs[262250]=n,hs[262253]=0;t=e+1048584|0,hs[e+1048592>>2]=t,hs[e+1048596>>2]=t,256!=(0|(e=e+8|0)););hs[262247]=n,e=o+-40|0,hs[262245]=e,hs[n+4>>2]=1|e,hs[4+(e+n|0)>>2]=40,hs[262254]=2097152;break r}if(!(hs[e+12>>2]|n>>>0<=r>>>0|r>>>0<t>>>0)){hs[e+4>>2]=o+a,t=(e=hs[262247])+15&-8,hs[262247]=t+-8,r=8+((n=o+hs[262245]|0)+(e-t|0)|0)|0,hs[262245]=r,hs[t+-4>>2]=1|r,hs[4+(e+n|0)>>2]=40,hs[262254]=2097152;break r}}e=hs[262255],hs[262255]=e>>>0<n>>>0?e:n,t=n+o|0,e=1049e3;n:{for(;(0|t)!=hs[e>>2];)if(!(e=hs[e+8>>2]))break n;if(!hs[e+12>>2]){hs[e>>2]=n,hs[e+4>>2]=o+hs[e+4>>2],hs[n+4>>2]=3|i,o=n+i|0,i=(t-n|0)-i|0;i:{o:{if((0|t)!=hs[262247]){if(hs[262246]==(0|t))break o;if(1==(3&(e=hs[t+4>>2]))&&(256<=(r=-8&e)>>>0?Ss(t):(0|(a=hs[t+12>>2]))==(0|(s=hs[t+8>>2]))?(c=1048576,d=hs[262144]&Is(e>>>3),hs[c>>2]=d):(hs[s+12>>2]=a,hs[a+8>>2]=s),i=r+i|0,t=t+r|0),hs[t+4>>2]=-2&hs[t+4>>2],hs[o+4>>2]=1|i,256<=(hs[i+o>>2]=i)>>>0){Cs(o,i);break i}e=1048584+((t=i>>>3)<<3)|0,r=hs[262144],t=1<<(31&t),s=hs[e+8>>2],r&t||(hs[262144]=t|r,s=e),r=s,hs[e+8>>2]=o,hs[r+12>>2]=o,hs[o+12>>2]=e,hs[o+8>>2]=r;break i}hs[262247]=o,e=hs[262245]+i|0,hs[262245]=e,hs[o+4>>2]=1|e;break i}hs[262246]=o,e=hs[262244]+i|0,hs[262244]=e,hs[o+4>>2]=1|e,hs[e+o>>2]=e}return n+8|0}}for(e=1049e3;!((t=hs[e>>2])>>>0<=r>>>0&&(a=t+hs[e+4>>2]|0)>>>0>r>>>0);)e=hs[e+8>>2];for(hs[262247]=n,e=o+-40|0,hs[262245]=e,hs[n+4>>2]=1|e,hs[4+(e+n|0)>>2]=40,hs[262254]=2097152,hs[(t=(e=(a+-32&-8)-8|0)>>>0<r+16>>>0?r:e)+4>>2]=27,e=hs[262250],s=hs[262251],u=hs[262253],hs[(l=t+16|0)>>2]=hs[262252],hs[l+4>>2]=u,hs[t+8>>2]=e,hs[t+12>>2]=s,hs[262251]=o,hs[262250]=n,hs[262252]=t+8,e=t+28|(hs[262253]=0);hs[e>>2]=7,a>>>0>(e=e+4|0)>>>0;);(0|t)!=(0|r)&&(hs[t+4>>2]=-2&hs[t+4>>2],e=t-r|0,hs[r+4>>2]=1|e,256<=(hs[t>>2]=e)>>>0?Cs(r,e):(e=1048584+((t=e>>>3)<<3)|0,n=hs[262144],t=1<<(31&t),s=hs[e+8>>2],n&t||(hs[262144]=t|n,s=e),t=s,hs[e+8>>2]=r,hs[t+12>>2]=r,hs[r+12>>2]=e,hs[r+8>>2]=t))}if(r=0,!((e=hs[262245])>>>0<=i>>>0))break e}return r}return t=e-i|0,hs[262245]=t,n=(e=hs[262247])+i|0,hs[262247]=n,hs[n+4>>2]=1|t,hs[e+4>>2]=3|i,e+8|0}(r=ys(e|=0,t|=0)))|!(3&vs[n+-4|0])||function(e,t){if(t)for(;e=e+1|(ps[0|e]=0),t=t+-1|0;);}(n,r),n);var r,n}function Ns(){}function xs(e){return e?31-bs(e+-1^e)|0:32}function Is(e){var t;return(-1>>>(t=31&e)&-2)<<t|(-1<<(e=0-e&31)&-2)>>>e}function Rs(e){e|=0;var t,r,n=0|_s.byteLength/65536,i=n+e|0;return n<i&&i<65536&&(t=new ArrayBuffer(ys(i,65536)),(r=new fs.Int8Array(t)).set(ps),ps=r,ps=new fs.Int8Array(t),new fs.Int16Array(t),hs=new fs.Int32Array(t),vs=new fs.Uint8Array(t),ms=new fs.Uint16Array(t),gs=new fs.Uint32Array(t),new fs.Float32Array(t),new fs.Float64Array(t),_s=t),n}var Ls=Os,Ms=function(){function e(){}return e.create=function(t,r,n){void 0===n&&(n=16384);var i={},o=new e;o._llp=Ls.llparser_create(n,128,128);var a=o._llp,s={ALL:Ls.llparser_create_descriptor(a,0),NULL:Ls.llparser_create_descriptor(a,0)};for(var l in Ls.llparser_descriptor_set_all(s.ALL),Ls.llparser_descriptor_set_nil(s.NULL),t){var u=a;s[l]=Ls.llparser_create_descriptor(u,1)}for(var l in t)for(var c=t[l],d=s[l],f=0;f<c.length;f++){for(var _=c[f].id,p=c[f].states,h=[],v=0;v<p.length;v++){var m=p[v];s[m]||(s[m]=function(e,t){for(var r=Ls.llparser_create_descriptor(e,0),n="^"===t[0],i=+n;i<t.length;i++){var o=t.charCodeAt(i),a=t.charCodeAt(i+2);"-"===t[i+1]&&o<=a?(Ls.llparser_descriptor_add_range(r,o,a),i+=2):Ls.llparser_descriptor_add_char(r,o)}return n&&Ls.llparser_descriptor_revert(r),r}(a,m)),h.push(s[m])}var g=0;"_raw"===_?g=1:"_jump"===_?g=65536:"_blank"===_&&(g=65537);var y=Ls.llparser_add_rule.apply(Ls,ls([a,g,d,h.length],h));0===g&&(i[y]=r[_])}return Ls.llparser_prepare(a),o._inputPtr=Ls.llparser_get_input_buffer(a),o._resultPtr=Ls.llparser_get_result(a),o._stateIdMap=s,o._ruleCbMap=i,o._charCountLimit=n,o},e.prototype.parse=function(e,t){var r=Date.now();!function(e,t,r,n){for(var i=n>e.length?e.length:n,o=0;o<i;o++)t[r+o]=e.charCodeAt(o);t[r+i]=0}(t,new Uint16Array(Ls.memory.buffer),this._inputPtr>>1,this._charCountLimit),ks.copyIn=ks.copyIn+Date.now()-r,r=Date.now();var n=Ls.llparser_parse(this._llp,this._stateIdMap[e]);if(ks.parse=ks.parse+Date.now()-r,r=Date.now(),n)throw new Error("Parsing failed at character position "+(n-1)+' near "'+t.slice(n-20,n)+'"');var i=function(e,t,r,n,i){for(var o=[],a={i:0,r:0,n:!1,cc:-1,c:[]},s=a,l=i.pos,u=!1,c=!1,d=!1;;){var f=t[l],_=t[l+1];if(_<0?(c=!0,_=-_-1):c=!1,f>=0){d=!0;var p=r.slice(f,_);s.c.push(p),u=c}else{if(-1===f&&0===_)break;d=!1;var h={i:s.c.length-(u?1:0),r:-f,n:c,cc:_,c:[]};if(u){var v=s.c.length-1,m=s.c[v];h.c.push(m),s.c[v]=h}else s.c.push(h);o.push(s),s=h,u=!1}if(!d||!u)for(;s.c.length===s.cc;){if(u=s.n,(h=o.pop()).c[s.i]=n[s.r].call(e,s.c),s=h,u)break}l+=2}return a.c[0]}(this,new Int32Array(Ls.memory.buffer),t,this._ruleCbMap,{pos:this._resultPtr>>2});return ks.constructOut=ks.constructOut+Date.now()-r,i},e.stats={all:0,copyIn:0,parse:0,constructOut:0},e}(),ks=Ms.stats,Ps=o.String,js=function(e){if("Symbol"===zn(e))throw TypeError("Cannot convert a Symbol value to a string");return Ps(e)},Ds=function(){var e=te(this),t="";return e.global&&(t+="g"),e.ignoreCase&&(t+="i"),e.multiline&&(t+="m"),e.dotAll&&(t+="s"),e.unicode&&(t+="u"),e.sticky&&(t+="y"),t},Bs=Ft.PROPER,Fs="toString",Us=RegExp.prototype,Gs=Us.toString,Hs=f(Ds),Vs=a((function(){return"/a/b"!=Gs.call({source:"a",flags:"b"})})),zs=Bs&&Gs.name!=Fs;(Vs||zs)&&Ut(RegExp.prototype,Fs,(function(){var e=te(this),t=js(e.source),r=e.flags;return"/"+t+"/"+js(void 0===r&&ce(Us,e)&&!("flags"in Us)?Hs(e):r)}),{unsafe:!0});var $s=ts("splice"),Ys=o.TypeError,Ws=Math.max,Zs=Math.min,Js=9007199254740991,Ks="Maximum allowed length exceeded";rr({target:"Array",proto:!0,forced:!$s},{splice:function(e,t){var r,n,i,o,a,s,l=N(this),u=Fe(l),c=je(e,u),d=arguments.length;if(0===d?r=n=0:1===d?(r=0,n=u-c):(r=d-2,n=Zs(Ws(Me(t),0),u-c)),u+r-n>Js)throw Ys(Ks);for(i=so(l,n),o=0;o<n;o++)(a=c+o)in l&&qr(i,o,l[a]);if(i.length=n,r<n){for(o=c;o<u-n;o++)s=o+r,(a=o+n)in l?l[s]=l[a]:delete l[s];for(o=u;o>u-n+r;o--)delete l[o-1]}else if(r>n)for(o=u-n;o>c;o--)s=o+r-1,(a=o+n-1)in l?l[s]=l[a]:delete l[s];for(o=0;o<r;o++)l[o+c]=arguments[o+2];return l.length=u-n+r,i}});var qs={renderingMode:"native",lazyRegistration:!1,publicProperties:!1,classPrefix:"",availability:null,domain:"//",writeOnly:!1,allowInWriteOnly:!0,addGlobalClass:!1,templateEngine:null,multipleSlots:!1,reflectToAttributes:!0,writeFieldsToNode:!0,writeIdToDOM:!1,separateInnerData:!1,innerDataExclude:null,listenerChangeLifeTimes:!1,randomizeTagName:!1,virtualHost:!1,throwGlobalError:!1,writeExtraInfoToAttr:!0,documentBackend:"undefined"!=typeof window&&"undefined"!=typeof document?"dom":"none",hasDOMBackend:!("undefined"==typeof window||"undefined"==typeof document)};function Xs(e){return Xs="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},Xs(e)}function Qs(e){return"[object Object]"===Object.prototype.toString.call(e)}function el(e){return"[object String]"===Object.prototype.toString.call(e)}function tl(e){return"[object Number]"===Object.prototype.toString.call(e)}function rl(e){return e&&("[object Function]"===Object.prototype.toString.call(e)||"function"==typeof e)}function nl(e){return Array.isArray?Array.isArray(e):"[object Array]"===Object.prototype.toString.call(e)}var il={element:null,component:null,freeTemplateEngine:null,textNode:null,nativeNode:null,virtualNode:null},ol=function(e){il.element=e,ol=null},al=function(e){il.component=e,al=null},sl=function(e){il.freeTemplateEngine=e,sl=null},ll=function(e){il.textNode=e,ll=null},ul=function(e){il.nativeNode=e,ul=null},cl=function(e){il.virtualNode=e,cl=null};function dl(){return il.component}function fl(e){return e instanceof il.element}function _l(e){return e instanceof il.component}function pl(e){return e instanceof il.textNode}var hl=function(){function e(e){this._arr=[],this._index=0,this._type=e}return e.getGlobalErrorInstance=function(){return e.instance||(e.instance=e.create()),e.instance},e.create=function(t){return new e(t)},e.addGlobalErrorListener=function(t){return e.getGlobalErrorInstance().add(t)},e.removeGlobalErrorListener=function(t){return e.getGlobalErrorInstance().remove(t)},e.safeCallback=function(t,r,n,i,o){try{return r.apply(n,i)}catch(u){__appServiceSDK__.reportUncaughtError({info:u.toString(),stack:u.stack});var a=e.getGlobalErrorInstance(),s="[Exparser] [Error] [Component] "+(t||"Error Listener")+" Error @ ";n&&n.is&&(s+=n.is),s+="#"+(r.name||"(anonymous)"),_l(o)&&o.triggerLifeTime("error",[u]);var l={message:s,type:t,element:n,method:r,args:i};if((!l.type||a.call(null,[u,l]))&&qs.throwGlobalError)throw u}},e.prototype.add=function(e){var t=this._index++;return this._arr.push({id:t,func:e}),t},e.prototype.remove=function(e){for(var t=this._arr,r=rl(e),n=0,i=t.length,o=void 0;n<i;n++)if(o=t[n],(r?o.func:o.id)===e)return t.splice(n,1),o.func;return null},e.prototype.call=function(t,r,n){for(var i=!1,o=0,a=this._arr;o<a.length;o++){var s=a[o];!1===e.safeCallback(this._type,s.func,t,r,n)&&(i=!0)}if(i)return!1},e.prototype.destroy=function(){for(var e=0;e<this._arr.length;e++)this._arr[e].func=void 0,this._arr[e]=null;this._arr.length=0},Object.defineProperty(e.prototype,"empty",{get:function(){return 0===this._arr.length},enumerable:!1,configurable:!0}),e}(),vl=f("".charAt),ml=f("".charCodeAt),gl=f("".slice),yl=function(e){return function(t,r){var n,i,o=js(b(t)),a=Me(r),s=o.length;return a<0||a>=s?e?"":void 0:(n=ml(o,a))<55296||n>56319||a+1===s||(i=ml(o,a+1))<56320||i>57343?e?vl(o,a):n:e?gl(o,a,a+2):i-56320+(n-55296<<10)+65536}},bl={codeAt:yl(!1),charAt:yl(!0)},El=bl.charAt,wl="String Iterator",Ol=xt.set,Al=xt.getterFor(wl);xr(String,"String",(function(e){Ol(this,{type:wl,string:js(e),index:0})}),(function(){var e,t=Al(this),r=t.string,n=t.index;return n>=r.length?{value:void 0,done:!0}:(e=El(r,n),t.index+=e.length,{value:e,done:!1})}));var Cl=Vt.f,Sl="object"==typeof window&&window&&Object.getOwnPropertyNames?Object.getOwnPropertyNames(window):[],Tl={f:function(e){return Sl&&"Window"==h(e)?function(e){try{return Cl(e)}catch(e){return en(Sl)}}(e):Cl(E(e))}},Nl=a((function(){if("function"==typeof ArrayBuffer){var e=new ArrayBuffer(8);Object.isExtensible(e)&&Object.defineProperty(e,"a",{value:8})}})),xl=Object.isExtensible,Il=a((function(){xl(1)}))||Nl?function(e){return!!X(e)&&((!Nl||"ArrayBuffer"!=h(e))&&(!xl||xl(e)))}:xl,Rl=!a((function(){return Object.isExtensible(Object.preventExtensions({}))})),Ll=t((function(e){var t=Ie.f,r=!1,n=k("meta"),i=0,o=function(e){t(e,n,{value:{objectID:"O"+i++,weakData:{}}})},a=e.exports={enable:function(){a.enable=function(){},r=!0;var e=Vt.f,t=f([].splice),i={};i[n]=1,e(i).length&&(Vt.f=function(r){for(var i=e(r),o=0,a=i.length;o<a;o++)if(i[o]===n){t(i,o,1);break}return i},rr({target:"Object",stat:!0,forced:!0},{getOwnPropertyNames:Tl.f}))},fastKey:function(e,t){if(!X(e))return"symbol"==typeof e?e:("string"==typeof e?"S":"P")+e;if(!I(e,n)){if(!Il(e))return"F";if(!t)return"E";o(e)}return e[n].objectID},getWeakData:function(e,t){if(!I(e,n)){if(!Il(e))return!0;if(!t)return!1;o(e)}return e[n].weakData},onFreeze:function(e){return Rl&&r&&Il(e)&&!I(e,n)&&o(e),e}};He[n]=!0})),Ml=function(e,t,r){var n,i;te(e);try{if(!(n=me(e,"return"))){if("throw"===t)throw r;return r}n=ue(n,e)}catch(e){i=!0,n=e}if("throw"===t)throw r;if(i)throw n;return te(n),r},kl=o.TypeError,Pl=function(e,t){this.stopped=e,this.result=t},jl=Pl.prototype,Dl=function(e,t,r){var n,i,o,a,s,l,u,c=r&&r.that,d=!(!r||!r.AS_ENTRIES),f=!(!r||!r.IS_ITERATOR),_=!(!r||!r.INTERRUPTED),p=Zi(t,c),h=function(e){return n&&Ml(n,"normal",e),new Pl(!0,e)},v=function(e){return d?(te(e),_?p(e[0],e[1],h):p(e[0],e[1])):_?p(e,h):p(e)};if(f)n=e;else{if(!(i=Ki(e)))throw kl(pe(e)+" is not iterable");if(to(i)){for(o=0,a=Fe(e);a>o;o++)if((s=v(e[o]))&&ce(jl,s))return s;return new Pl(!1)}n=Xi(e,i)}for(l=n.next;!(u=ue(l,n)).done;){try{s=v(u.value)}catch(e){Ml(n,"throw",e)}if("object"==typeof s&&s&&ce(jl,s))return s}return new Pl(!1)},Bl=Ll.getWeakData,Fl=xt.set,Ul=xt.getterFor,Gl=co.find,Hl=co.findIndex,Vl=f([].splice),zl=0,$l=function(e){return e.frozen||(e.frozen=new Yl)},Yl=function(){this.entries=[]},Wl=function(e,t){return Gl(e.entries,(function(e){return e[0]===t}))};Yl.prototype={get:function(e){var t=Wl(this,e);if(t)return t[1]},has:function(e){return!!Wl(this,e)},set:function(e,t){var r=Wl(this,e);r?r[1]=t:this.entries.push([e,t])},delete:function(e){var t=Hl(this.entries,(function(t){return t[0]===e}));return~t&&Vl(this.entries,t,1),!!~t}};var Zl,Jl={getConstructor:function(e,t,r,n){var i=e((function(e,i){Fr(e,o),Fl(e,{type:t,id:zl++,frozen:void 0}),null!=i&&Dl(i,e[n],{that:e,AS_ENTRIES:r})})),o=i.prototype,a=Ul(t),s=function(e,t,r){var n=a(e),i=Bl(te(t),!0);return!0===i?$l(n).set(t,r):i[n.id]=r,e};return Dr(o,{delete:function(e){var t=a(this);if(!X(e))return!1;var r=Bl(e);return!0===r?$l(t).delete(e):r&&I(r,t.id)&&delete r[t.id]},has:function(e){var t=a(this);if(!X(e))return!1;var r=Bl(e);return!0===r?$l(t).has(e):r&&I(r,t.id)}}),Dr(o,r?{get:function(e){var t=a(this);if(X(e)){var r=Bl(e);return!0===r?$l(t).get(e):r?r[t.id]:void 0}},set:function(e,t){return s(this,e,t)}}:{add:function(e){return s(this,e,!0)}}),i}},Kl=xt.enforce,ql=!o.ActiveXObject&&"ActiveXObject"in o,Xl=function(e){return function(){return e(this,arguments.length?arguments[0]:void 0)}},Ql=function(e,t,r){var n=-1!==e.indexOf("Map"),i=-1!==e.indexOf("Weak"),s=n?"set":"add",l=o[e],u=l&&l.prototype,c=l,d={},_=function(e){var t=f(u[e]);Ut(u,e,"add"==e?function(e){return t(this,0===e?0:e),this}:"delete"==e?function(e){return!(i&&!X(e))&&t(this,0===e?0:e)}:"get"==e?function(e){return i&&!X(e)?void 0:t(this,0===e?0:e)}:"has"==e?function(e){return!(i&&!X(e))&&t(this,0===e?0:e)}:function(e,r){return t(this,0===e?0:e,r),this})};if(er(e,!P(l)||!(i||u.forEach&&!a((function(){(new l).entries().next()})))))c=r.getConstructor(t,e,n,s),Ll.enable();else if(er(e,!0)){var p=new c,h=p[s](i?{}:-0,1)!=p,v=a((function(){p.has(1)})),m=yi((function(e){new l(e)})),g=!i&&a((function(){for(var e=new l,t=5;t--;)e[s](t,t);return!e.has(-0)}));m||((c=t((function(e,t){Fr(e,u);var r=po(new l,e,c);return null!=t&&Dl(t,r[s],{that:r,AS_ENTRIES:n}),r}))).prototype=u,u.constructor=c),(v||g)&&(_("delete"),_("has"),n&&_("get")),(g||h)&&_(s),i&&u.clear&&delete u.clear}return d[e]=c,rr({global:!0,forced:c!=l},d),pr(c,e),i||r.setStrong(c,e,n),c}("WeakMap",Xl,Jl);if(ht&&ql){Zl=Jl.getConstructor(Xl,"WeakMap",!0),Ll.enable();var eu=Ql.prototype,tu=f(eu.delete),ru=f(eu.has),nu=f(eu.get),iu=f(eu.set);Dr(eu,{delete:function(e){if(X(e)&&!Il(e)){var t=Kl(this);return t.frozen||(t.frozen=new Zl),tu(this,e)||t.frozen.delete(e)}return tu(this,e)},has:function(e){if(X(e)&&!Il(e)){var t=Kl(this);return t.frozen||(t.frozen=new Zl),ru(this,e)||t.frozen.has(e)}return ru(this,e)},get:function(e){if(X(e)&&!Il(e)){var t=Kl(this);return t.frozen||(t.frozen=new Zl),ru(this,e)?nu(this,e):t.frozen.get(e)}return nu(this,e)},set:function(e,t){if(X(e)&&!Il(e)){var r=Kl(this);r.frozen||(r.frozen=new Zl),ru(this,e)?iu(this,e,t):r.frozen.set(e,t)}else iu(this,e,t);return this}})}var ou={CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0},au=ae("span").classList,su=au&&au.constructor&&au.constructor.prototype,lu=su===Object.prototype?void 0:su,uu=q("iterator"),cu=q("toStringTag"),du=kr.values,fu=function(e,t){if(e){if(e[uu]!==du)try{mt(e,uu,du)}catch(t){e[uu]=du}if(e[cu]||mt(e,cu,t),ou[t])for(var r in kr)if(e[r]!==kr[r])try{mt(e,r,kr[r])}catch(t){e[r]=kr[r]}}};for(var _u in ou)fu(o[_u]&&o[_u].prototype,_u);function pu(e,t){if(function(e){return"object"===Xs(e)}(e)&&null!==e){var r=t?t.get(e):void 0;if(void 0!==r)return r;if(nl(e)){r=[],t&&t.set(e,r);for(var n=0,i=e.length;n<i;++n)r[n]=pu(e[n],t)}else for(var o in r={},t&&t.set(e,r),e)hu.call(e,o)&&(r[o]=pu(e[o],t));return r}if("symbol"!==Xs(e))return e}fu(lu,"DOMTokenList");var hu=Object.prototype.hasOwnProperty;function vu(e){return pu(e,new WeakMap)}var mu=Object.freeze({__proto__:null,hasOwnProperty:hu,deepCopy:vu}),gu=Ge.indexOf,yu=f([].indexOf),bu=!!yu&&1/yu([1],1,-0)<0,Eu=na("indexOf");function wu(e,t,r,n){for(var i=fl(e)?e.collectMarks():{},o=[],a=[],s=e,l=e;l;){if(s!==l&&(o.push(e),e=l,a.push(i),i=fl(e)?e.collectMarks():{}),s=l.parentNode,!1===n(l,e,i))return;if(l.__ddHost){if(r)break;e=o.pop()||l.__ddHost,i=a.pop()||(fl(e)?e.collectMarks():{}),s=l=l.__ddHost}else l=!fl(l)||r?l.parentNode:l.__ddSlotParent}}rr({target:"Array",proto:!0,forced:bu||!Eu},{indexOf:function(e){var t=arguments.length>1?arguments[1]:void 0;return bu?yu(this,e,t)||0:gu(this,e,t)}});var Ou=function(){function e(){}return e.setInitTimeStamp=function(t){return void 0===t&&(t=Date.now()),e.initTimeStamp=t},e.getInitTimeStamp=function(){return e.initTimeStamp},e.create=function(t,r,n){void 0===n&&(n={});var i=n.originalEvent,o=n.extraFields,a=void 0===o?{}:o,s=n.bubbles,l=n.composed,u=n.capturePhase,c=Date.now()-e.initTimeStamp,d=new e;for(var f in d.currentTarget=null,d.type=t,d.timeStamp=c,d.mark=null,d.detail=r,d.bubbles=!!s,d.composed=!!l,d.__originalEvent=i,d.__hasCapture=!!u,d.__stopped=!1,d.__dispatched=!1,a)d[f]=a[f];return d},e.dispatchEvent=function(e,t){if(t&&!t.__dispatched){t.__dispatched=!0,e.__ddElement&&e.__ddHost!==e.__ddElement&&fl((e=e.__ddElement).shadowRoot)&&(e=e.shadowRoot),t.target=fl(e)?e.__methodCaller:e;var r=t.type,n=!t.composed;if(t.__hasCapture){var i=[];wu(e,0,n,(function(e,t,n){return e.__ddCaptureEvents&&e.__ddCaptureEvents[r]&&i.push([e,t,n]),!0}));for(var o=i.length-1;o>=0;o--){var a=i[o],s=a[0],l=a[1],u=a[2];t.target=fl(l)?l.__methodCaller:l,t.mark=u;var c=s.__ddCaptureMutated&&s.__ddCaptureMutated[r];if(f(s.__ddCaptureEvents[r],c,s),t.__stopped)break}}if(t.target=fl(e)?e.__methodCaller:e,!t.__stopped){var d=!t.bubbles;wu(e,0,n,(function(e,n,i){t.target=fl(n)?n.__methodCaller:n,t.mark=i;var o=e.__ddMutated&&e.__ddMutated[r];return e.__ddEvents&&e.__ddEvents[r]&&f(e.__ddEvents[r],o,e),!d&&!t.__stopped}))}}function f(e,r,n){if(!(r&&r.length&&t.mutatedMarked())){var i=t.currentTarget=fl(n)?n.__methodCaller:n,o=e.call(i,[t],_l(n)?n:void 0);r&&r.length&&t.mutatedMarked(),!1===o&&(t.__originalEvent&&t.__originalEvent.preventDefault(),t.__stopped=!0)}}},e.triggerEvent=function(t,r,n,i){e.dispatchEvent(t,e.create(r,n,i))},e.addListenerToElement=function(e,t,r,n){var i,o=n&&n.mutated;if(o){var a=r;r=function(e){for(var t=[],r=1;r<arguments.length;r++)t[r-1]=arguments[r];if(!e.mutatedMarked())return a.apply(this,ls([e],t))}}return n&&(n.useCapture||n.capture)?(e.__ddCaptureEvents||(e.__ddCaptureEvents=Object.create(null)),e.__ddCaptureEvents[t]||(e.__ddCaptureEvents[t]=hl.create("Event Listener")),i=e.__ddCaptureEvents[t].add(r),o&&(e.__ddCaptureMutated||(e.__ddCaptureMutated=Object.create(null)),e.__ddCaptureMutated[t]||(e.__ddCaptureMutated[t]=[]),e.__ddCaptureMutated[t].push(i))):(e.__ddEvents||(e.__ddEvents=Object.create(null)),e.__ddEvents[t]||(e.__ddEvents[t]=hl.create("Event Listener")),i=e.__ddEvents[t].add(r),o&&(e.__ddMutated||(e.__ddMutated=Object.create(null)),e.__ddMutated[t]||(e.__ddMutated[t]=[]),e.__ddMutated[t].push(i))),_l(e)&&e.__componentOptions.listenerChangeLifeTimes&&e.triggerLifeTime("listenerChanged",[!0,t,r,n]),i},e.removeListenerFromElement=function(e,t,r,n){var i,o;n&&(n.useCapture||n.capture)?(e.__ddCaptureEvents&&e.__ddCaptureEvents[t]&&(i=e.__ddCaptureEvents[t].remove(r)),e.__ddCaptureMutated&&e.__ddCaptureMutated[t]&&-1!==(o=e.__ddCaptureMutated[t].indexOf(r))&&e.__ddCaptureMutated[t].splice(o,1)):(e.__ddEvents&&e.__ddEvents[t]&&(i=e.__ddEvents[t].remove(r)),e.__ddMutated&&e.__ddMutated[t]&&-1!==(o=e.__ddMutated[t].indexOf(r))&&e.__ddMutated[t].splice(o,1)),i&&_l(e)&&e.__componentOptions.listenerChangeLifeTimes&&e.triggerLifeTime("listenerChanged",[!1,t,i,n])},e.prototype.preventDefault=function(){this.__originalEvent&&this.__originalEvent.preventDefault()},e.prototype.stopPropagation=function(){this.__stopped=!0},e.prototype.isStopped=function(){return!!this.__stopped},e.prototype.markMutated=function(){this.__mutatedMarked=!0},e.prototype.mutatedMarked=function(){return!!this.__mutatedMarked},e.initTimeStamp=Date.now(),e}(),Au=o.RegExp,Cu=a((function(){var e=Au("a","y");return e.lastIndex=2,null!=e.exec("abcd")})),Su=Cu||a((function(){return!Au("a","y").sticky})),Tu={BROKEN_CARET:Cu||a((function(){var e=Au("^r","gy");return e.lastIndex=2,null!=e.exec("str")})),MISSED_STICKY:Su,UNSUPPORTED_Y:Cu},Nu=o.RegExp,xu=a((function(){var e=Nu(".","s");return!(e.dotAll&&e.exec("\n")&&"s"===e.flags)})),Iu=o.RegExp,Ru=a((function(){var e=Iu("(?<a>b)","g");return"b"!==e.exec("b").groups.a||"bc"!=="b".replace(e,"$<a>c")})),Lu=xt.get,Mu=S("native-string-replace",String.prototype.replace),ku=RegExp.prototype.exec,Pu=ku,ju=f("".charAt),Du=f("".indexOf),Bu=f("".replace),Fu=f("".slice),Uu=function(){var e=/a/,t=/b*/g;return ue(ku,e,"a"),ue(ku,t,"a"),0!==e.lastIndex||0!==t.lastIndex}(),Gu=Tu.BROKEN_CARET,Hu=void 0!==/()??/.exec("")[1];(Uu||Hu||Gu||xu||Ru)&&(Pu=function(e){var t,r,n,i,o,a,s,l=this,u=Lu(l),c=js(e),d=u.raw;if(d)return d.lastIndex=l.lastIndex,t=ue(Pu,d,c),l.lastIndex=d.lastIndex,t;var f=u.groups,_=Gu&&l.sticky,p=ue(Ds,l),h=l.source,v=0,m=c;if(_&&(p=Bu(p,"y",""),-1===Du(p,"g")&&(p+="g"),m=Fu(c,l.lastIndex),l.lastIndex>0&&(!l.multiline||l.multiline&&"\n"!==ju(c,l.lastIndex-1))&&(h="(?: "+h+")",m=" "+m,v++),r=new RegExp("^(?:"+h+")",p)),Hu&&(r=new RegExp("^"+h+"$(?!\\s)",p)),Uu&&(n=l.lastIndex),i=ue(ku,_?r:l,m),_?i?(i.input=Fu(i.input,v),i[0]=Fu(i[0],v),i.index=l.lastIndex,l.lastIndex+=i[0].length):l.lastIndex=0:Uu&&i&&(l.lastIndex=l.global?i.index+i[0].length:n),Hu&&i&&i.length>1&&ue(Mu,i[0],r,(function(){for(o=1;o<arguments.length-2;o++)void 0===arguments[o]&&(i[o]=void 0)})),i&&f)for(i.groups=a=it(null),o=0;o<f.length;o++)a[(s=f[o])[0]]=i[s[1]];return i});var Vu=Pu;rr({target:"RegExp",proto:!0,forced:/./.exec!==Vu},{exec:Vu});var zu=q("species"),$u=RegExp.prototype,Yu=function(e,t,r,n){var i=q(e),o=!a((function(){var t={};return t[i]=function(){return 7},7!=""[e](t)})),s=o&&!a((function(){var t=!1,r=/a/;return"split"===e&&((r={}).constructor={},r.constructor[zu]=function(){return r},r.flags="",r[i]=/./[i]),r.exec=function(){return t=!0,null},r[i](""),!t}));if(!o||!s||r){var l=f(/./[i]),u=t(i,""[e],(function(e,t,r,n,i){var a=f(e),s=t.exec;return s===Vu||s===$u.exec?o&&!i?{done:!0,value:l(t,r,n)}:{done:!0,value:a(r,t,n)}:{done:!1}}));Ut(String.prototype,e,u[0]),Ut($u,i,u[1])}n&&mt($u[i],"sham",!0)},Wu=bl.charAt,Zu=function(e,t,r){return t+(r?Wu(e,t).length:1)},Ju=Math.floor,Ku=f("".charAt),qu=f("".replace),Xu=f("".slice),Qu=/\$([$&'`]|\d{1,2}|<[^>]*>)/g,ec=/\$([$&'`]|\d{1,2})/g,tc=function(e,t,r,n,i,o){var a=r+e.length,s=n.length,l=ec;return void 0!==i&&(i=N(i),l=Qu),qu(o,l,(function(o,l){var u;switch(Ku(l,0)){case"$":return"$";case"&":return e;case"`":return Xu(t,0,r);case"'":return Xu(t,a);case"<":u=i[Xu(l,1,-1)];break;default:var c=+l;if(0===c)return o;if(c>s){var d=Ju(c/10);return 0===d?o:d<=s?void 0===n[d-1]?Ku(l,1):n[d-1]+Ku(l,1):o}u=n[c-1]}return void 0===u?"":u}))},rc=o.TypeError,nc=function(e,t){var r=e.exec;if(P(r)){var n=ue(r,e,t);return null!==n&&te(n),n}if("RegExp"===h(e))return ue(Vu,e,t);throw rc("RegExp#exec called on incompatible receiver")},ic=q("replace"),oc=Math.max,ac=Math.min,sc=f([].concat),lc=f([].push),uc=f("".indexOf),cc=f("".slice),dc="$0"==="a".replace(/./,"$0"),fc=!!/./[ic]&&""===/./[ic]("a","$0");Yu("replace",(function(e,t,r){var n=fc?"$":"$0";return[function(e,r){var n=b(this),i=null==e?void 0:me(e,ic);return i?ue(i,e,n,r):ue(t,js(n),e,r)},function(e,i){var o=te(this),a=js(e);if("string"==typeof i&&-1===uc(i,n)&&-1===uc(i,"$<")){var s=r(t,o,a,i);if(s.done)return s.value}var l=P(i);l||(i=js(i));var u=o.global;if(u){var c=o.unicode;o.lastIndex=0}for(var d=[];;){var f=nc(o,a);if(null===f)break;if(lc(d,f),!u)break;""===js(f[0])&&(o.lastIndex=Zu(a,Be(o.lastIndex),c))}for(var _,p="",h=0,v=0;v<d.length;v++){for(var m=js((f=d[v])[0]),g=oc(ac(Me(f.index),a.length),0),y=[],b=1;b<f.length;b++)lc(y,void 0===(_=f[b])?_:String(_));var E=f.groups;if(l){var w=sc([m],y,g,a);void 0!==E&&lc(w,E);var O=js(ra(i,void 0,w))}else O=tc(m,a,g,y,E,i);g>=h&&(p+=cc(a,h,g)+O,h=g+m.length)}return p+cc(a,h)}]}),!!a((function(){var e=/./;return e.exec=function(){var e=[];return e.groups={a:"7"},e},"7"!=="".replace(e,"$<a>")}))||!dc||fc);var _c=q("match"),pc=function(e){var t;return X(e)&&(void 0!==(t=e[_c])?!!t:"RegExp"==h(e))},hc=Tu.UNSUPPORTED_Y,vc=4294967295,mc=Math.min,gc=[].push,yc=f(/./.exec),bc=f(gc),Ec=f("".slice),wc=!a((function(){var e=/(?:)/,t=e.exec;e.exec=function(){return t.apply(this,arguments)};var r="ab".split(e);return 2!==r.length||"a"!==r[0]||"b"!==r[1]}));Yu("split",(function(e,t,r){var n;return n="c"=="abbc".split(/(b)*/)[1]||4!="test".split(/(?:)/,-1).length||2!="ab".split(/(?:ab)*/).length||4!=".".split(/(.?)(.?)/).length||".".split(/()()/).length>1||"".split(/.?/).length?function(e,r){var n=js(b(this)),i=void 0===r?vc:r>>>0;if(0===i)return[];if(void 0===e)return[n];if(!pc(e))return ue(t,n,e,i);for(var o,a,s,l=[],u=(e.ignoreCase?"i":"")+(e.multiline?"m":"")+(e.unicode?"u":"")+(e.sticky?"y":""),c=0,d=new RegExp(e.source,u+"g");(o=ue(Vu,d,n))&&!((a=d.lastIndex)>c&&(bc(l,Ec(n,c,o.index)),o.length>1&&o.index<n.length&&ra(gc,l,en(o,1)),s=o[0].length,c=a,l.length>=i));)d.lastIndex===o.index&&d.lastIndex++;return c===n.length?!s&&yc(d,"")||bc(l,""):bc(l,Ec(n,c)),l.length>i?en(l,0,i):l}:"0".split(void 0,0).length?function(e,r){return void 0===e&&0===r?[]:ue(t,this,e,r)}:t,[function(t,r){var i=b(this),o=null==t?void 0:me(t,e);return o?ue(o,t,i,r):ue(n,js(i),t,r)},function(e,i){var o=te(this),a=js(e),s=r(n,o,a,i,n!==t);if(s.done)return s.value;var l=ni(o,RegExp),u=o.unicode,c=(o.ignoreCase?"i":"")+(o.multiline?"m":"")+(o.unicode?"u":"")+(hc?"g":"y"),d=new l(hc?"^(?:"+o.source+")":o,c),f=void 0===i?vc:i>>>0;if(0===f)return[];if(0===a.length)return null===nc(d,a)?[a]:[];for(var _=0,p=0,h=[];p<a.length;){d.lastIndex=hc?0:p;var v,m=nc(d,hc?Ec(a,p):a);if(null===m||(v=mc(Be(d.lastIndex+(hc?p:0)),a.length))===_)p=Zu(a,p,u);else{if(bc(h,Ec(a,_,p)),h.length===f)return h;for(var g=1;g<=m.length-1;g++)if(bc(h,m[g]),h.length===f)return h;p=_=v}}return bc(h,Ec(a,_)),h}]}),!wc,hc);var Oc=f(1..valueOf),Ac=f("".replace),Cc="[\t\n\v\f\r                　\u2028\u2029\ufeff]",Sc=RegExp("^"+Cc+Cc+"*"),Tc=RegExp(Cc+Cc+"*$"),Nc=function(e){return function(t){var r=js(b(t));return 1&e&&(r=Ac(r,Sc,"")),2&e&&(r=Ac(r,Tc,"")),r}},xc={start:Nc(1),end:Nc(2),trim:Nc(3)},Ic=Vt.f,Rc=Pt.f,Lc=Ie.f,Mc=xc.trim,kc="Number",Pc=o.Number,jc=Pc.prototype,Dc=o.TypeError,Bc=f("".slice),Fc=f("".charCodeAt),Uc=function(e){var t=Ee(e,"number");return"bigint"==typeof t?t:Gc(t)},Gc=function(e){var t,r,n,i,o,a,s,l,u=Ee(e,"number");if(fe(u))throw Dc("Cannot convert a Symbol value to a number");if("string"==typeof u&&u.length>2)if(u=Mc(u),43===(t=Fc(u,0))||45===t){if(88===(r=Fc(u,2))||120===r)return NaN}else if(48===t){switch(Fc(u,1)){case 66:case 98:n=2,i=49;break;case 79:case 111:n=8,i=55;break;default:return+u}for(a=(o=Bc(u,2)).length,s=0;s<a;s++)if((l=Fc(o,s))<48||l>i)return NaN;return parseInt(o,n)}return+u};if(er(kc,!Pc(" 0o1")||!Pc("0b1")||Pc("+0x1"))){for(var Hc,Vc=function(e){var t=arguments.length<1?0:Pc(Uc(e)),r=this;return ce(jc,r)&&a((function(){Oc(r)}))?po(Object(t),r,Vc):t},zc=re?Ic(Pc):"MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,EPSILON,MAX_SAFE_INTEGER,MIN_SAFE_INTEGER,isFinite,isInteger,isNaN,isSafeInteger,parseFloat,parseInt,fromString,range".split(","),$c=0;zc.length>$c;$c++)I(Pc,Hc=zc[$c])&&!I(Vc,Hc)&&Lc(Vc,Hc,Rc(Pc,Hc));Vc.prototype=jc,jc.constructor=Vc,Ut(o,kc,Vc)}var Yc=function(e){if(!e||e.length<=0)throw new Error("Parsing failed: the path string should not be empty");for(var t=[],r=(e=e.replace(/\n|\\|\r|\t|\f/g,"")).split(","),n=r.length,i=0;i<n;i++){for(var o="",a=!1,s=0,l=r[i],u=l.length,c=[],d=0;d<u;d++){s++;var f=l.charAt(d);if(("."===f||"]"===f)&&o||"."===f&&"]"===l.charAt(d-1)){if(!a&&"]"===f)throw new Error("Parsing failed at character position "+s);a&&"]"===f?(a=!1,o&&c.push(Number(o))):o&&c.push(o),o=""}else if("["!==f||!o&&"]"!==l.charAt(d-1))if(a){if(!("9">=f&&f>="0"))throw new Error("Parsing failed at character position "+s);o+=f}else{var _=f.charCodeAt(0);if(!("9">=f&&f>="0"||97<=_&&_<=122||65<=_&&_<=90||42===_))throw new Error("Parsing failed at character position "+s);o+=f}else a=!0,o&&c.push(o),o=""}o&&c.push(o),t.push(c)}return t},Wc=function(e){for(var t=e.length,r=[],n="",i=0,o=!1,a=!1,s=0;s<t;s++){var l=e[s];if("\\"===l){if(s+1<t){var u=e[s+1];"."===u||"["===u||"]"===u||"\\"===u?(n+=u,s++):n+="\\"}}else if("."===l)n&&(r.push(n),n="");else if("["===l){if(n&&(r.push(n),n=""),0===r.length)throw new Error("The path string should not start with []: "+e);a=!0,o=!1}else if("]"===l){if(!o)throw new Error("There should be digits inside [] in the path string: "+e);a=!1,r.push(i),i=0}else if(a){if(l<"0"||l>"9")throw new Error("Only digits (0-9) can be put inside [] in the path string: "+e);o=!0,i=10*i+l.charCodeAt(0)-48}else n+=l}if(n&&r.push(n),0===t)throw new Error("The path string should not be empty");return r},Zc=Object.freeze({__proto__:null,parseMultiPaths:Yc,parseSinglePath:Wc}),Jc=co.filter,Kc=ts("filter");rr({target:"Array",proto:!0,forced:!Kc},{filter:function(e){return Jc(this,e,arguments.length>1?arguments[1]:void 0)}});var qc=co.forEach,Xc=na("forEach")?[].forEach:function(e){return qc(this,e,arguments.length>1?arguments[1]:void 0)},Qc=function(e){if(e&&e.forEach!==Xc)try{mt(e,"forEach",Xc)}catch(t){e.forEach=Xc}};for(var ed in ou)ou[ed]&&Qc(o[ed]&&o[ed].prototype);function td(e){for(var t=[],r=0;r<e.length;r++)t[r]=e[r];return t}function rd(e,t){for(var r in t)Object.prototype.hasOwnProperty.call(e,r)&&"object"===Xs(e[r])&&"object"===Xs(t[r])&&null!==t[r]&&(nl(t[r])?e[r]=td(t[r]):(e[r]=function(e){var t={};for(var r in e)t[r]=e[r];return t}(e[r]),rd(e[r],t[r])))}function nd(){}Qc(lu);var id=["created","ready","cacheAttached","attached","moved","detached","saved","restored","error","listenerChanged","performanceData"],od=[String,Number,Boolean,Object,Array,null],ad=function(){function e(){this.properties=Object.create(null),this.methods=Object.create(null),this.listeners=Object.create(null),this.lifetimes=Object.create(null),this.pageLifetimes=Object.create(null),this.observers=[],this.relations=Object.create(null),this.ancestors=[]}return e.matchTypeWithValue=function(e,t){if(e===String){if("string"!=typeof t)return!1}else if(e===Number){if(!Number.isFinite(t))return!1}else if(e===Boolean){if("boolean"!=typeof t)return!1}else if(e===Object){if(null===t||t.constructor!==Object)return!1}else if(e===Array){if(t.constructor!==Array)return!1}else if(void 0===t)return!1;return!0},e.create=function(t){var r=new e;r.is=t.is||"",r.using=t.using||{},r.placeholder=t.placeholder||{},r.generics=t.generics||{},r.template=t.template,r.externalClasses=t.externalClasses||[],r.data=Qs(t.data)?t.data:null,r.initiator=t.initiator,r.definitionFilter=t.definitionFilter,r.options={publicProperties:!!t.options&&(t.options.publicProperties||qs.publicProperties)},r._unprepared=t;var n=t.options&&void 0!==t.options.lazyRegistration?t.options.lazyRegistration:qs.lazyRegistration;return t.options&&n||e.prepare(r),t.is&&(e._list[r.is]=r),r},e.prepare=function(t){var r=t._unprepared;if(r){t._unprepared=null;for(var n=t.ancestors,i=void 0,o=nl(r.behaviors)?r.behaviors:[],a=0,s=o.length,l=void 0;a<s;a++){for(i in el(l=o[a])&&(l=e._list[l]),l._unprepared&&e.prepare(l),"object"===Xs(l.data)&&(null===t.data?t.data=l.data:rd(t.data,l.data)),l.generics){var u=l.generics[i];Qs(u)||(u={}),t.generics[i]={default:u.default}}for(i in l.properties)t.properties[i]=l.properties[i];for(i in l.relations)t.relations[i]=l.relations[i];for(i in l.methods)t.methods[i]=l.methods[i];for(var c=0,d=l.ancestors;c<d.length;c++){var f=d[c];n.indexOf(f)<0&&n.push(f)}}"object"===Xs(r.data)&&(null===t.data?t.data=r.data:rd(t.data,r.data));var _=void 0;for(i in r.properties)_=r.properties[i],od.indexOf(_)>=0?_={type:_}:od.indexOf(_.type)<0&&_.optionalTypes&&_.optionalTypes.length>0&&(_.type=_.optionalTypes[0]),void 0===_.value&&(_.type===String?_.value="":_.type===Number?_.value=0:_.type===Boolean?_.value=!1:_.type===Array?_.value=[]:_.value=null),t.properties[i]={type:_.type,optionalTypes:_.optionalTypes,value:_.value,filter:_.filter,observer:_.observer,public:!!(void 0===_.public?t.options.publicProperties:_.public),availability:_.availability,observeAssignments:!!_.observeAssignments};if(Qs(r.lifetimes))for(i in r.lifetimes)t.lifetimes[i]=r.lifetimes[i];for(var p=0,h=id;p<h.length;p++){var v=h[p],m=r[v];void 0===t.lifetimes[v]&&(t.lifetimes[v]=rl(m)?m:void 0)}for(i in r.listeners)t.listeners[i]=r.listeners[i];if(nl(r.observers))for(var g=0,y=r.observers;g<y.length;g++){l=y[g];t.observers.push({paths:Yc(l.fields||"**"),observer:l.observer})}else for(i in r.observers)t.observers.push({paths:Yc(i),observer:r.observers[i]});if(Qs(r.pageLifetimes))for(i in r.pageLifetimes)t.pageLifetimes[i]=r.pageLifetimes[i];for(i in r.relations){var b=r.relations[i];t.relations[i]={target:b.target||i,type:b.type,linked:b.linked||nd,linkChanged:b.linkChanged||nd,unlinked:b.unlinked||nd,linkFailed:b.linkFailed||nd}}for(i in r.methods)rl(r.methods[i])&&(t.methods[i]=r.methods[i]);n.push(t)}},e.callDefinitionFilter=function(t){var r=t.definitionFilter,n=[];return nl(t.behaviors)&&t.behaviors.forEach((function(r){el(r)&&(r=e._list[r]),r.definitionFilter&&(n.push(r.definitionFilter),r.definitionFilter.call(null,t))})),rl(r)?function(e){r(e,n)}:null},e.prototype.destroy=function(){var e;for(e in this.is=null,this.data=null,this.properties=null,this.methods)this.methods[e]=null,delete this.methods[e];for(e in this.listeners)this.listeners[e]=null,delete this.listeners[e];for(e in this.lifetimes)this.lifetimes[e]=null,delete this.lifetimes[e];for(e in this.pageLifetimes)this.pageLifetimes[e]=null,delete this.pageLifetimes[e];for(e in this.relations)this.relations[e]=null,delete this.relations[e];this.observers=null,this.using=null,this.externalClasses=null,this.generics=null,this.initiator=null,this.definitionFilter=null,this.template=null,this._unprepared=null,this.ancestors=null},e.prototype.hasBehavior=function(t){var r;this._unprepared&&e.prepare(this);for(var n=0,i=this.ancestors;n<i.length;n++)if(r=i[n],t instanceof e){if(r===t)return!0}else if(r===e._list[t])return!0;return!1},e.prototype._addObserversToDataProxy=function(e){for(var t,r=0,n=this.ancestors;r<n.length;r++)for(var i=0,o=n[r].observers;i<o.length;i++)t=o[i],e.addObserver(t.observer,t.paths)},e.prototype._getAllLifeTimeFuncs=function(){var e,t,r={};id.forEach((function(e){r[e]=hl.create("Lifetime Method")}));for(var n=0,i=this.ancestors;n<i.length;n++)for(t in(e=i[n]).lifetimes)rl(e.lifetimes[t])&&(r[t]||(r[t]=hl.create("Lifetime Method")),r[t].add(e.lifetimes[t]));return r},e.prototype._getAllListeners=function(){for(var e,t,r,n={},i=0,o=this.ancestors;i<o.length;i++)for(t in(e=o[i]).listeners)r=e.listeners[t],Object.prototype.hasOwnProperty.call(n,t)?n[t].push(r):n[t]=[r];return n},e.prototype._getAllPageLifeTimeFuncs=function(){for(var e,t,r={},n=0,i=this.ancestors;n<i.length;n++)for(t in(e=i[n]).pageLifetimes)rl(e.pageLifetimes[t])&&(r[t]||(r[t]=hl.create("Page Lifetime Method")),r[t].add(e.pageLifetimes[t]));return r},e._list=Object.create(null),e}();Yu("match",(function(e,t,r){return[function(t){var r=b(this),n=null==t?void 0:me(t,e);return n?ue(n,t,r):new RegExp(t)[e](js(r))},function(e){var n=te(this),i=js(e),o=r(t,n,i);if(o.done)return o.value;if(!n.global)return nc(n,i);var a=n.unicode;n.lastIndex=0;for(var s,l=[],u=0;null!==(s=nc(n,i));){var c=js(s[0]);l[u]=c,""===c&&(n.lastIndex=Zu(i,Be(n.lastIndex),a)),u++}return 0===u?null:l}]}));var sd=a((function(){We(1)}));rr({target:"Object",stat:!0,forced:sd},{keys:function(e){return We(N(e))}});var ld=function(){function e(){}return e.create=function(t){var r=new e;return r._cb=t,r._noSubtreeCb=function(e){e.target===this&&t.call(this,e)},r._binded=[],r},e._createObserverTree=function(){throw new Error("Method not implemented.")},e._updateSubtreeCaches=function(t,r){t.__subtreeObserversCount+=r;var n=t.childNodes;if(n)for(var i=0;i<n.length;i++)e._updateSubtreeCaches(n[i],r)},e._callSingleObserver=function(e,t,r){var n=e[t];n&&n.call(e,[r])},e._callObservers=function(e,t,r){do{e[t]&&e[t].call(e,[r]),e=e.parentNode}while(e&&e.__subtreeObserversCount)},e.prototype.observe=function(t,r){void 0===r&&(r={});var n=0,i=r.subtree?this._cb:this._noSubtreeCb;r.properties&&(t.__propObservers||(t.__propObservers=hl.create("Observer Callback")),this._binded.push({funcArr:t.__propObservers,id:t.__propObservers.add(i),subtree:r.subtree?t:null}),n+=1),r.childList&&(t.__childObservers||(t.__childObservers=hl.create("Observer Callback")),this._binded.push({funcArr:t.__childObservers,id:t.__childObservers.add(i),subtree:r.subtree?t:null}),n+=1),r.characterData&&(t.__textObservers||(t.__textObservers=hl.create("Observer Callback")),this._binded.push({funcArr:t.__textObservers,id:t.__textObservers.add(i),subtree:r.subtree?t:null}),n+=1),r.subtree&&e._updateSubtreeCaches(t,n),r.attachStatus&&(t.__attachedObservers||(t.__attachedObservers=hl.create("Observer Callback")),this._binded.push({funcArr:t.__attachedObservers,id:t.__attachedObservers.add(i),subtree:null}))},e.prototype.disconnect=function(){for(var t=0,r=this._binded;t<r.length;t++){var n=r[t];n.funcArr.remove(n.id),n.subtree&&e._updateSubtreeCaches(n.subtree,-1)}this._binded=[]},e}(),ud=function(){function e(e){this.tagName=e,this.id="",this.attrs={}}return e.toElement=function(e){var t,r=document.createElement(e.tagName);for(t in e.id&&(r.id=e.id),e.attrs)r.setAttribute(t,e.attrs[t]);return r},e.fromElement=function(t){var r=new e(t.tagName);r.id=t.id;for(var n=0,i=t.attributes;n<i.length;n++)r.attrs[i[n].name]=i[n].value;return r},e.prototype.cloneNode=function(){var t,r=new e;for(t in r.id=this.id,this.attrs)r.attrs[t]=this.attrs[t];return r},e.prototype.removeAttribute=function(e){delete this.attrs[e]},e.prototype.setAttribute=function(e,t){this.attrs[e]=t},e.prototype.getAttribute=function(e){return this.attrs[e]},e}(),cd=function(e,t,r,n){if(t&&e.ownerShadowRoot!==t.ownerShadowRoot)throw new Error("Cannot move the node from one shadow tree to another shadow tree.");var i=n?r:t,o=-1;r&&(o=e.childNodes.indexOf(r));var a=il.element.insertChildToElement;return r&&o<0||!a(e,t,o,n)?null:i},dd=function(e,t,r){if(e.__childObservers&&!e.__childObservers.empty||e.__subtreeObserversCount){var n=[r],i=void 0;i="add"===t?{type:"childList",target:e,addedNodes:n}:"remove"===t?{type:"childList",target:e,removedNodes:n}:{type:"childList",target:e,addedNodes:n,removedNodes:n},ld._callObservers(e,"__childObservers",i)}},fd=function e(t,r){for(var n=t.childNodes,i=0;i<n.length;i++){var o=n[i];r(t,o),o.__inheritSlots&&e(o,r)}};function _d(e,t){for(var r=0,n=void 0;r<e.__ddSlotChildren.length;r++)(n=e.__ddSlotChildren[r]).__virtual?_d(n,t):t.appendChild(n.__domElement)}function pd(e,t){for(var r=0,n=void 0;r<e.__ddSlotChildren.length;r++)(n=e.__ddSlotChildren[r]).__virtual?pd(n,t):t.removeChild(n.__domElement)}function hd(e){if(e.__virtual)for(var t=0;t<e.__ddSlotChildren.length;t++)hd(e.__ddSlotChildren[t]);else{var r=e.__domElement;r&&r.parentNode&&r.parentNode.removeChild(r)}}function vd(e,t){for(;t<e.__ddSlotChildren.length;t++){var r=e.__ddSlotChildren[t];if(!r.__virtual)return r;var n=vd(r,0);if(n)return n}}var md=function(e,t,r,n,i){var o=e,a=document.createDocumentFragment();if(fl(o)){for(;o.__virtual;){var s=o.__ddSlotParent;if(!s){o=null;break}if(t&&!r){var l=s.__ddSlotChildren.indexOf(o);r=s.__ddSlotChildren[l+1]}o=s}fl(o)&&(o=o.__domElement)}if(o){var u=n,c=null,d=null;if(t&&(t.__virtual?(_d(t,a),c=a):c=t.__domElement),r)if(r.__virtual){var f=e,_=void 0;if(n?(pd(r,o),u=!1,_=i+1):(f=r.__ddSlotParent,_=r===t?i:f.__ddSlotChildren.indexOf(r)),t){r=null;for(var p=f;!(r=vd(p,_))&&p.__virtual;p=p.__ddSlotParent)_=p.__ddSlotParent.__ddSlotChildren.indexOf(p)+1;r&&(d=r.__domElement)}}else d=r.__domElement;u?c?o.replaceChild(c,d):o.removeChild(d):c&&(d?o.insertBefore(c,d):o.appendChild(c))}else t&&t.__ddSlotParent&&hd(t);return i},gd=function(e,t,r,n,i,o,a){if(n&&(r.__ddSlotParent=null),i&&(a=e.__ddSlotChildren.indexOf(r)),t){var s=t.__ddSlotParent;if(t.__ddSlotParent=e,s&&o){var l=s.__ddSlotChildren.indexOf(t);s.__ddSlotChildren.splice(l,1),s===e&&l<a&&a--}}t&&t.__backendExtracted||r&&r.__backendExtracted||(a=md(e,t,r,n,a)),qs.writeExtraInfoToAttr&&(n&&fl(r)&&r.__domElement&&r.__domElement.removeAttribute("exparser:info-in-slot-of"),fl(t)&&t.__domElement&&(void 0!==e.__slotName&&e.ownerShadowRoot?t.__domElement.setAttribute("exparser:info-in-slot-of",e.ownerShadowRoot.__ddHost.__componentInstanceId):t.__domElement.removeAttribute("exparser:info-in-slot-of"))),i&&(-1===a&&(a=e.__ddSlotChildren.length),t?e.__ddSlotChildren.splice(a,n?1:0,t):e.__ddSlotChildren.splice(a,n?1:0))},yd=function(e,t,r,n){var i=e.childNodes;if(n){var o=t[""];if(o)for(var a=0;a<i.length;a++)gd(o,i[a],null,!1,!1,!1,-1);else if(r[""]){o=r[""];for(a=0;a<i.length;a++)gd(o,null,i[a],!0,!1,!1,a)}}else{!function e(n){for(var i=0;i<n.length;i++){var o=n[i],a=o.__slot||"",s=t[a];s?gd(s,o,null,!1,!0,!0):r[a]&&(s=r[a],gd(s,null,o,!0,!0,!0)),o.__inheritSlots&&e(o.childNodes)}}(i)}},bd=function(e){if(e.__hostAssociated&&e.__slotCacheDirty){e.__slotCacheDirty=!1;var t=e.__ddHost,r=Object.create(null),n=void 0!==t.__singleSlot?{"":t.__singleSlot}:t.__slots;!function e(t){void 0!==t.__slotName&&(r[t.__slotName]||(r[t.__slotName]=t));for(var n=t.childNodes,i=0;i<n.length;i++)fl(n[i])&&e(n[i])}(e),void 0!==t.__singleSlot?t.__singleSlot!==r[""]&&(r[""]&&(r[""].__ddSlotChildren=t.childNodes),yd(t,r,n,!0),t.__singleSlot&&(t.__singleSlot.__ddSlotChildren=[]),t.__singleSlot=r[""]||null):(yd(t,r,n,!1),t.__slots=r)}},Ed=function(e,t){if(!(!fl(e)||t.__ddHost.__idCacheDirty&&t.__slotCacheDirty)){!function e(r){r.__id&&(t.__ddHost.__idCacheDirty=!0),void 0!==r.__slotName&&(t.__slotCacheDirty=!0);for(var n=r.childNodes,i=0;i<n.length;i++){var o=n[i];fl(o)&&e(o)}}(e)}},wd=function(e,t,r,n){for(var i=function e(t,n,i){var o=t.childNodes,a=0;for(n&&(a=o.indexOf(n)+(i?0:1));a<o.length;a++){var s=o[a];if(s.__slot===r)return s;if(s.__inheritSlots){var l=e(s,null,!1);if(l)return l}}return null};t!==e;t=t.parentNode){var o=i(t.parentNode,t,n);if(o)return o;n=!1}return null};function Od(e){if((!e.parentNode||e.parentNode.__attached)&&fl(e)){e.__attached=!0,e.__lifeTimeFuncs&&e.__lifeTimeFuncs.attached.call(e.__methodCaller,[],e),e.__relationHandler&&e.__relationHandler("attached"),e.__attachedObservers&&!e.__attachedObservers.empty&&ld._callSingleObserver(e,"__attachedObservers",{type:"attachStatus",target:e,status:"attached"}),fl(e.shadowRoot)&&Od(e.shadowRoot);for(var t=0,r=e.childNodes;t<r.length;t++)Od(r[t])}}function Ad(e){if(fl(e)&&e.__attached){for(var t=0,r=e.childNodes;t<r.length;t++)Ad(r[t]);fl(e.shadowRoot)&&Ad(e.shadowRoot),e.__attached=!1,e.__lifeTimeFuncs&&e.__lifeTimeFuncs.detached.call(e.__methodCaller,[],e),e.__relationHandler&&e.__relationHandler("detached"),e.__attachedObservers&&!e.__attachedObservers.empty&&ld._callSingleObserver(e,"__attachedObservers",{type:"attachStatus",target:e,status:"detached"}),e.destroy&&e.destroy(!1)}}function Cd(e){var t=!0,r=!0;if(fl(e)?(e.__backendExtracted=!0,e.__domElement=null,e.$$=null,r=!1):pl(e)&&(e.__backendExtracted=!0,e.__domElement=null,e.$$=null,t=!1,r=!1),t&&e.__ddSlotChildren)for(var n=0,i=e.__ddSlotChildren;n<i.length;n++){Cd(i[n])}else if(r&&e.childNodes)for(var o=0,a=e.childNodes;o<a.length;o++){Cd(a[o])}}function Sd(e,t,r){var n,i=fl(e)&&e.__virtual,o=t.childNodes?t.childNodes[r]:void 0,a=!0,s=!0;if(fl(e)){var l;if(e.__backendExtracted=!1,!1===i)if(o)e.__domElement.tagName.toUpperCase()===o.tagName?(e.__domElement=o,e.$$=o):(l=ud.toElement(e.__domElement),e.__domElement=l,e.$$=l,o.parentNode.replaceChild(l,o)),n=null;else l=ud.toElement(e.__domElement),e.__domElement=l,e.$$=l,n=l;s=!1}else if(pl(e)){if(e.__backendExtracted=!1,o){if(void 0!==o.textContent)o.textContent=e.textContent,e.__domElement=o,e.$$=o;else{var u=document.createTextNode(e.textContent);e.__domElement=u,e.$$=u,o.parentNode.replaceChild(u,o)}n=null}else{u=document.createTextNode(e.textContent);e.__domElement=u,e.$$=u,n=u}s=!1,a=!1}else{var c=document.createDocumentFragment();if(c.__ddSlotChildren=e.__ddSlotChildren,o&&o.childNodes)for(;o.childNodes.length;)c.appendChild(o.childNodes[0]);if(o){for(;e.childNodes&&o.childNodes&&o.childNodes.length;)e.appendChild(o.childNodes[0]);o.parentNode.replaceChild(e,o),n=null}else n=e;e=c}n?(t.appendChild(n),o=n):o=t?t.childNodes[r]:void 0;var d=0;if(a&&e.__ddSlotChildren)for(var f=0,_=e.__ddSlotChildren;f<_.length;f++){var p=_[f];if(i)r=Sd(p,t,r);else if(p.asShadowRoot){for(var h=0,v=p.asShadowRoot.childNodes;h<v.length;h++){d=Sd(v[h],o,d)}o.__ddSlotParent=e,o.__ddHost=e,e.shadowRoot=o,e.__ddSlotChildren[0]=o,e.__singleSlot===p&&(e.__singleSlot=o)}else d=Sd(p,o,d)}else if(s&&e.childNodes)for(var m=0,g=e.childNodes;m<g.length;m++){d=Sd(p=g[m],o,d)}if(i)return r;for(;o.childNodes.length>d;)o.removeChild(o.childNodes[d]);return r+1}function Td(e,t,r,n,i){if(t===e)return!1;var o=r[n],a=!0;o.id&&o.id!==t.__id&&(a=!1);for(var s=o.classes,l=0;a&&l<s.length;l++)t.classList.contains(s[l])||(a=!1);if(!a&&">"===i)return!1;var u=t;if(a&&0===n){if(null===e)return!0;for(u=u.parentNode;u;u=u.parentNode)if(u===e)return!0;if(">>>"!==i)return!1;u=t,a=!1}for(var c=a?o.relation:i;(u=u.parentNode?u.parentNode:">>>"===c?u.__ddHost:">>>"===i?(a=!1,u.__ddHost):null)===e&&(u=null),u&&u.__virtual;);if(!u)return!1;if(a){if(Td(e,u,r,n-1,c))return!0;if(">>>"!==i)return!1}return Td(e,u,r,n,i)}function Nd(e,t,r){if(r.__virtual)return!1;for(var n=e.union,i=0;i<n.length;i++){var o=n[i];if(Td(t,r,o,o.length-1,">"))return!0}return!1}function xd(e,t,r,n,i){if(Nd(t,r,n)&&(e.push(n),i))return!0;if(n.shadowRoot&&t.crossShadow&&((n.ownerShadowRoot?n.ownerShadowRoot.__ddHost.__componentOptions.domain:qs.domain)===n.__componentOptions.domain&&xd(e,t,r,n.shadowRoot,i)&&i))return!0;for(var o=n.childNodes,a=0;a<o.length;a++)if(fl(o[a])&&xd(e,t,r,o[a],i)&&i)return!0;return!1}var Id=new(function(){function e(){this.backendExtractedDefault=!1}return e.prototype.enableBackendExtractedDefault=function(){this.backendExtractedDefault=!0},e.prototype.disableBackendExtractedDefault=function(){this.backendExtractedDefault=!1},e}()),Rd=function(){function e(){}return Object.defineProperty(e.prototype,"id",{get:function(){return this.__id},set:function(e){var t=String(e);if(this.__id!==t){if(this.__id=t,this.ownerShadowRoot){var r=this.ownerShadowRoot.__ddHost;r.__idCacheDirty=!0,this.__domElement&&r.__componentOptions.writeIdToDOM&&(this.__domElement.id=t)}qs.writeExtraInfoToAttr&&this.__domElement&&this.__domElement.setAttribute("exparser:info-attr-id",t),(this.__propObservers&&!this.__propObservers.empty||this.__subtreeObserversCount)&&ld._callObservers(this,"__propObservers",{type:"properties",target:this,propertyName:"id"})}},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"slot",{get:function(){return this.__slot},set:function(e){var t=String(e);this.__slot!==t&&(this.__inheritSlots||(this.__slot=t,function(e){for(var t=e.parentNode;t&&t.__inheritSlots;)t=t.parentNode;if(t&&!t.__singleSlot){var r=e.__slot||"",n=t.__slots[r];if(n){var i=wd(t,e,r,!1);gd(n,e,i,!1,!0,!0)}else e.__ddSlotParent&&(n=e.__ddSlotParent,gd(n,null,e,!0,!0,!0))}}(this),(this.__propObservers&&!this.__propObservers.empty||this.__subtreeObserversCount)&&ld._callObservers(this,"__propObservers",{type:"properties",target:this,propertyName:"slot"})))},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"attributes",{get:function(){var e=[];if(!this.__attributes)return e;for(var t in this.__attributes)e.push({name:t,value:this.__attributes[t]});return e},set:function(e){},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"class",{get:function(){return this.classList&&this.classList.getClassNames?this.classList.getClassNames():null},set:function(e){this.classList&&(this.classList.setClassNames(e),(this.__propObservers&&!this.__propObservers.empty||this.__subtreeObserversCount)&&ld._callObservers(this,"__propObservers",{type:"properties",target:this,propertyName:"class"}))},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"style",{get:function(){return this.__domElement?this.__domElement.style:null},set:function(e){this.setNodeStyle(e)},enumerable:!1,configurable:!0}),e.initialize=function(e,t,r){e.__id="",e.__slot="",e.__virtual=!1,e.__inheritSlots=!1,e.__attributes=null,e.__marks=null,e.__attached=!1,e.parentNode=null,e.childNodes=[],e.ownerShadowRoot=r,e.__ddSlotParent=null,e.__ddSlotChildren=e.childNodes,e.__subtreeObserversCount=0,e.classList=null,e.__styleSegments=[],e.__methodCaller=e,e.__relationHandler=null,e.__backendExtracted=Id.backendExtractedDefault,e.__domElement=t,(e.$$=t)&&(t.__ddElement=e)},e.create=function(t){var r=new e;return e.initialize(r,t,null),r},e._clone=function(e,t,r,n){if(e.__id=t.__id,e.__slot=t.__slot,e.__virtual=t.__virtual,e.__inheritSlots=t.__inheritSlots,e.__marks=t.__marks?{}:null,e.__marks)for(var i in t.__marks)e.__marks[i]=t.__marks[i];for(var o in e.__attributes=Object.create(null),e.__attributes)e.__attributes[o]=t.__attributes[o];e.__attached=!1,e.parentNode=null,e.childNodes=[],e.ownerShadowRoot=n,e.__ddSlotParent=null,e.__ddSlotChildren=e.childNodes,e.__subtreeObserversCount=0,e.classList=null,e.__styleSegments=[],e.__methodCaller=e,e.__relationHandler=null,e.__backendExtracted=Id.backendExtractedDefault,e.__domElement=r,e.$$=r,r&&(r.__ddElement=e)},e._updateIdMap=function(t){if(t.__idCacheDirty){t.__idCacheDirty=!1;var r=t.__idCache=Object.create(null);!function t(n){n.__id&&!r[n.__id]&&(r[n.__id]=n);for(var i=n.childNodes,o=0;o<i.length;o++)i[o]instanceof e&&t(i[o])}(t.shadowRoot)}},e.insertChildToElement=function(t,r,n,i){if(void 0===n&&(n=-1),void 0===i&&(i=!1),void 0!==t.__slotName)return!1;var o=0<=n?t.childNodes[n]:null;i&&r===o&&(i=!1);var a=null;if(r){a=r.parentNode,r.parentNode=t;var s=t.__subtreeObserversCount;if(a){var l=a.childNodes.indexOf(r);a.childNodes.splice(l,1),a===t&&l<n&&n--,s-=a.__subtreeObserversCount}s&&ld._updateSubtreeCaches(r,s)}for(var u=t;u&&u.__inheritSlots;)u=u.parentNode;for(var c=!(u&&u.__slots),d=!(c&&!t.__inheritSlots),f=a;f&&f.__inheritSlots;)f=f.parentNode;var _=!(f&&f.__slots),p=!(_&&!(null==a?void 0:a.__inheritSlots)),h=t;if(c)void 0!==t.__singleSlot&&(h=t.__singleSlot),h?gd(h,r,o,i,d,p,n):r.__ddSlotParent&&gd(r.__ddSlotParent,null,r,!0,p,!1),r&&!_&&r.__inheritSlots&&fd(r,(function(e,t){gd(e,t,null,!1,!0,!0,-1)}));else{var v="";if(r&&(v=r.__slot||"",h=u.__slots[v]||null),o){var m=u.__slots[o.__slot||""]||null;m&&i&&gd(m,null,o,i,!0,!1)}if(r)if(h){var g=o?wd(u,o,v,!i):wd(u,t,v,!1);gd(h,r,g,!1,!0,p)}else r.__ddSlotParent&&gd(r.__ddSlotParent,null,r,!0,p,!1);o&&i&&o.__inheritSlots&&fd(o,(function(e,t){gd(e,t,null,!1,!0,!0,-1)})),r&&r.__inheritSlots&&fd(r,(function(e,r){var n=r.__slot||"",a=u.__slots[n]||null;if(a){var s=o?wd(u,o,n,!i):wd(u,t,n,!1);gd(a,r,s,!1,!0,!0)}else r.__ddSlotParent&&gd(r.__ddSlotParent,null,r,!0,!0,!1)}))}if(i&&(t.__subtreeObserversCount&&ld._updateSubtreeCaches(o,-t.__subtreeObserversCount),o.parentNode=null),-1===n&&(n=t.childNodes.length),r?t.childNodes.splice(n,i?1:0,r):t.childNodes.splice(n,i?1:0),t.ownerShadowRoot&&(i&&Ed(o,t.ownerShadowRoot),r&&Ed(r,t.ownerShadowRoot),bd(t.ownerShadowRoot)),i&&(Ad(o),dd(t,"remove",o)),r){if(a){r.__attached||Od(r);!function t(r){if(r instanceof e){for(var n=r.childNodes,i=0;i<n.length;i++)t(n[i]);r.shadowRoot instanceof e&&t(r.shadowRoot),r.__lifeTimeFuncs&&r.__lifeTimeFuncs.moved.call(r.__methodCaller,[],r),r.__relationHandler&&r.__relationHandler("moved")}}(r)}else Od(r);a===t?dd(t,"move",r):(a&&dd(a,"remove",r),dd(t,"add",r))}return!0},e.appendChild=function(e,t){return cd(e,t,null,!1)},e.insertBefore=function(e,t,r){return cd(e,t,r,!1)},e.removeChild=function(e,t){return cd(e,null,t,!0)},e.replaceChild=function(e,t,r){return cd(e,t,r,!0)},e.extractBackend=function(e){return e.__backendExtracted?null:(Cd(e),e.__domElement)},e.getMethodCaller=function(e){return e.__methodCaller},e.setMethodCaller=function(e,t){e.__methodCaller=t},e.setSlotName=function(e,t){if(t=null==t?"":String(t),!e.__slotName){if(0!==e.childNodes.length||0!==e.__ddSlotChildren.length)return;e.__ddSlotChildren=[]}e.__slotName=t,e.ownerShadowRoot&&(e.ownerShadowRoot.__slotCacheDirty=!0,bd(e.ownerShadowRoot))},e.injectBackend=function(e,t){if(e.__backendExtracted){var r=document.createDocumentFragment();r.appendChild(t),Sd(e,r,0)}},e.parseSelector=function(e){for(var t=[],r=!1,n=0,i=String(e||"").split(",");n<i.length;n++){for(var o=i[n].split(/( |\t|>+)/g),a=[],s=0,l=void 0,u="";s<o.length;s++)if((l=o[s])&&" "!==l&&"\t"!==l)if(">"!==l[0]){var c=function(e,t){var r=e.match(/^(#[_a-zA-Z][-_a-zA-Z0-9:]*|)((?:\.-?[_a-zA-Z][-_a-zA-Z0-9]*)+|)$/);if(!r)return null;var n=r[1].slice(1),i=r[2].split(".");return i.shift(),n||i.length?{id:n,classes:i,relation:t||""}:null}(l,u);if(u="",!c)break;a.push(c)}else{if(""!==u)break;">>>"===(u=l)&&(r=!0)}s===o.length&&a.length&&t.push(a)}return t.length?{crossShadow:r,union:t}:null},e.delayDestroy=function(t){if(tl(t)){var r=t,n=e.delayDestroyViewElements[r],i=__virtualDOM__.TreeManager.get(r);if(i&&nl(n))for(var o=i.nodeId,a=0,s=void 0,l=n.length;a<l;a++)s=n[a],o&&o.removeNode(s),s.destroy(!0),n[a]=null;e.delayDestroyViewElements[r]=null}else if(t&&t.__treeManager__){tl(r=t.__treeManager__.viewId)&&r>0&&(e.delayDestroyViewElements[r]||(e.delayDestroyViewElements[r]=[]),e.delayDestroyViewElements[r].push(t))}},e.prototype.appendChild=function(e){return cd(this,e,null,!1)},e.prototype.insertBefore=function(e,t){return cd(this,e,t,!1)},e.prototype.removeChild=function(e){return cd(this,null,e,!0)},e.prototype.replaceChild=function(e,t){return cd(this,e,t,!0)},e.prototype.triggerEvent=function(e,t,r){Ou.triggerEvent(this,e,t,r)},e.prototype.dispatchEvent=function(e){Ou.dispatchEvent(this,e)},e.prototype.addListener=function(e,t,r){Ou.addListenerToElement(this,e,t,r)},e.prototype.removeListener=function(e,t,r){Ou.removeListenerFromElement(this,e,t,r)},e.prototype.getAttribute=function(e){if(!this.__attributes)return null;var t=this.__attributes[e];return void 0===t?null:t},e.prototype.setAttribute=function(e,t){this.__attributes||(this.__attributes=Object.create(null)),t=String(t),this.__attributes[e]=t,this.__domElement&&this.__domElement.setAttribute(e,t)},e.prototype.removeAttribute=function(e){this.__attributes&&(delete this.__attributes[e],this.__domElement&&this.__domElement.removeAttribute(e))},e.prototype.setMark=function(e,t){this.__marks||(this.__marks={}),this.__marks[e]=t},e.prototype.collectMarks=function(){for(var e={},t=this;t;t=t.parentNode)if(t.__marks)for(var r in t.__marks)Object.prototype.hasOwnProperty.call(e,r)||(e[r]=t.__marks[r]);return e},e.prototype.setNodeStyle=function(e,t){this.__styleSegments||(this.__styleSegments=[]),this.__styleSegments[t||0]=e;var r=this.__styleSegments.join(";");if(this.__domElement&&this.ownerShadowRoot&&this.ownerShadowRoot.__childrenPropsFilter){var n=this.ownerShadowRoot.__childrenPropsFilter.style;if("function"==typeof n)return void this.__domElement.setAttribute("style",n.call(this,r))}this.__domElement&&this.__domElement.setAttribute("style",r),(this.__propObservers&&!this.__propObservers.empty||this.__subtreeObserversCount)&&ld._callObservers(this,"__propObservers",{type:"properties",target:this,propertyName:"style"})},e.replaceDocumentElement=function(e,t){e.__attached&&(t.parentNode.replaceChild(e.__domElement,t),Od(e))},e.pretendAttached=function(e){e.__attached||Od(e)},e.pretendDetached=function(e){e.__attached&&Ad(e)},e.isAttached=function(e){return e.__attached},e.setInheritSlots=function(e){e.__singleSlot||e.__slots||e.__ddSlotChildren.length||(e.__ddSlotChildren=[],e.__inheritSlots=!0)},e.getInheritSlots=function(e){return e.__inheritSlots},e.prototype._querySelector=function(t){var r;if(!(r="object"===Xs(t)?t:e.parseSelector(t)))return null;var n=[];return xd(n,r,this,this,!0),n[0]||null},e._attachShadowRoot=function(e){var t=e.__ddHost;t.__ddSlotChildren=[e],gd(t,e,null,!1,!1,0),e.__hostAssociated=!0,bd(e)},e.prototype.querySelector=function(t){var r="object"===Xs(t)?t:e.parseSelector(t);if(!r)return null;var n=[];return xd(n,r,this,this,!0),n[0]||null},e.prototype.querySelectorAll=function(t){var r="object"===Xs(t)?t:e.parseSelector(t);if(!r)return[];var n=[];return xd(n,r,this,this,!1),n},e.matchSelector=function(t,r){var n="object"===Xs(t)?t:e.parseSelector(t);return!!n&&Nd(n,null,r)},e.prototype.matchSelector=function(t,r){var n="object"===Xs(t)?t:e.parseSelector(t);return!!n&&Nd(n,this,r)},e.prototype.destroy=function(t){for(var r in void 0===t&&(t=!1),this.__ddEvents)this.__ddEvents[r].destroy(),this.__ddEvents[r]=void 0;for(var r in this.__ddEvents=void 0,this.__ddCaptureEvents)this.__ddCaptureEvents[r].destroy(),this.__ddCaptureEvents[r]=void 0;if(this.clearNodeRelation(),this.clearMPXProxy(),_l(this)&&this.__dataProxy&&this.__dataProxy.destroy(),t){if(_l(this)){if(this.__behavior){var n=Object.keys(this.__behavior.methods);for(var r in n)this[r]=null;this.__behavior&&this.__behavior.destroy()}this.__dataProxy=null,this.__using=null,this.__lifeTimeFuncs=null,this.__pageLifeTimeFuncs=null,this.__generics=null,this.__templateInstance=null,this.__innerData=null,this.__propData=null,this.__externalClassAlias=null,this.__idCacheDirty=null,this.__idCache=null,this.__relationMap=null,this.__componentInstanceId=null,this.__propertyChangeListeners=null,this.__componentOptions=null,this.__propPublic=null}this.__ddHost=null,this.__ddCaptureEvents=void 0,this.__propObservers&&this.__propObservers.destroy(),this.__propObservers=void 0,this.__childObservers&&this.__childObservers.destroy(),this.__childObservers=void 0,this.__textObservers&&this.__textObservers.destroy(),this.__textObservers=void 0,this.__attachedObservers&&this.__attachedObservers.destroy(),this.__attachedObservers=void 0,this.__vtObj=void 0,this.__treeManager__=void 0,this.__customConstructor__&&(this.__customConstructor__=void 0),this.__propData=void 0,this.__innerData=void 0,this.__dataProxy=void 0,this.dataset=null,this.classList=null,this.__styleSegments=null}else e.delayDestroy(this);this.__treeManager__=null},e.prototype.clearNodeRelation=function(){if(this.ownerShadowRoot&&(this.ownerShadowRoot.__treeManager__=null,this.ownerShadowRoot=null),this.shadowRoot&&(this.shadowRoot.__treeManager__=null,this.shadowRoot=null),this.__ddSlotParent&&(this.__ddSlotParent.__treeManager__=null,this.__ddSlotParent=void 0),this.__ddSlotChildren){for(var e=0;e<this.__ddSlotChildren.length;e++)this.__ddSlotChildren[e]&&(this.__ddSlotChildren[e].__treeManager__=null,this.__ddSlotChildren[e]=null);this.__ddSlotChildren=null}this.__ddSlotParent&&(this.__ddSlotParent=null),this.parentNode&&(this.parentNode.__treeManager__=null,this.parentNode=null)},e.prototype.clearMPXProxy=function(){if(this.__methodCaller){if(__virtualDOM__.CustomComponent.callerMap.delete(this.__methodCaller),this.__methodCaller.__mpxProxy){if(this.__methodCaller.__mpxProxy.data)for(var e=Object.keys(this.__methodCaller.__mpxProxy.data),t=0,r=void 0;t<e.length;t++)r=e[t],this.__methodCaller.__mpxProxy.data[r]=void 0,this.__methodCaller[r]=void 0;this.__methodCaller.__mpxProxy._watcher&&this.__methodCaller.__mpxProxy._watcher.cleanupDeps(),this.__methodCaller.__mpxProxy.clearWatchers&&this.__methodCaller.__mpxProxy.clearWatchers(),this.__methodCaller.__mpxProxy.target=null,this.__methodCaller.__mpxProxy.data=null,this.__methodCaller.__mpxProxy=null}this.__methodCaller.__displayReporter&&(this.__methodCaller.__displayReporter=null),this.__methodCaller.__data__=null,this.__methodCaller.__exitState__=null,this.__methodCaller.__freeData__=null,this.__methodCaller=void 0}},e.delayDestroyViewElements={},e}();function Ld(e,t,r){for(var n=0,i=t;n<i.length;n++){for(var o=0,a=i[n];o<a.length;o++){var s=a[o];if(e["**"]||(e["**"]=[]),"**"===s)return void e["**"].push(r);e[s]||(e[s]={}),e=e[s]}e["~"]||(e["~"]=[]),e["~"].push(r)}}function Md(e,t,r){for(var n=0,i=t;n<i.length;n++){for(var o=i[n],a="",s=0;s<o.length&&"**"!==(a=o[s]);s++){if(!e)return;e=e[a]}var l="**"===a?e["**"]:e["~"];if(l)for(s=0;s<l.length;s++)if(l[s]===r){l.splice(s,1);break}}}function kd(e,t,r,n,i){for(var o,a,s=0;s<e.length;s++)if(o=e[s],t[s]){t[s]=!1,a=i?void 0:n;for(var l=[],u=0,c=o.pathObj;u<c.length;u++){for(var d=0,f=c[u];d<f.length;d++){var _=f[d];if("**"===_)break;if("object"!==Xs(a)){a=void 0;break}a=a[_]}l.push(a)}hl.safeCallback("Data Observer",o.func,r.__methodCaller,l,r)}}ol(Rd);var Pd=function(){function e(e){this._observerTree={},this._propFields=e,this._observerIdInc=0,this._observers=[],this._observerTree={}}return e.prototype.addObserver=function(e,t){var r=this._observerIdInc++;return this._observers[r]={pathObj:t,func:e},Ld(this._observerTree,t,r),r},e.prototype.removeObserver=function(e){var t=this._observers[e];Md(this._observerTree,t.pathObj,e),this._observers[e]=null},e.prototype.moveObserver=function(e,t){var r=this._observers[e];Md(this._observerTree,r.pathObj,e),r.pathObj=t,Ld(this._observerTree,t,e)},e}(),jd=function(){function e(e,t,r,n,i,o){this._data=t,this._innerData=r,this._innerDataExclude=n,this._comp=e,this._updateCb=o,this._beforeMergeCb=null,this._beforeUpdateCb=null,this._hidingValue=!1,this._changes=[],this._doingUpdates=null,this._propFields=i._propFields,this._observers=i._observers,this._observerTree=i._observerTree,this._relatedObserverTreeObj=i,this._observerStatus=[]}return e.setPropUpdater=function(t){e.propUpdater=t},e.setPropObserver=function(t){e.propObserver=t},e.create=function(t,r,n){return new e({__methodCaller:t},r,null,null,new Pd({}),n)},e._advancedCreate=function(t,r,n,i,o,a){return new e(t,r,n,i,o,a)},e._createObserverTree=function(e){return new Pd(e)},e.prototype.destroy=function(){this._data=null,this._innerData=null,this._innerDataExclude=null,this._comp&&this._comp.__dataProxy&&(this._comp.__dataProxy=null),this._comp=null,this._updateCb=null,this._relatedObserverTreeObj=null,this._observerStatus=null,this._propFields=null,this._observers=null,this._observerTree=null,this._beforeMergeCb=null,this._beforeUpdateCb=null,this._hidingValue=null,this._changes=null,this._doingUpdates=null},e.prototype.scheduleReplace=function(e,t,r){nl(this._changes)&&this._changes.push([e,t,r])},e.prototype.setChanges=function(e){this._changes=e},e.prototype.doUpdates=function(t,r){var n=this._propFields,i=this._comp,o=this._hidingValue,a=this._innerDataExclude,s=!!this._doingUpdates,l=this._relatedObserverTreeObj._observerIdInc||null,u=null,c=null,d=null,f=this._changes;l?(s||(this._doingUpdates={changedPaths:[],changedValues:[],combinedChanges:[],changesTotal:0}),u=this._doingUpdates.changedPaths,c=this._doingUpdates.changedValues,d=this._doingUpdates.combinedChanges):(u=[],c=[],d=[]),this._changes=[];var _=[];this._beforeMergeCb&&this._beforeMergeCb(f,_,t);for(var p=0;p<f.length;p++){var h=f[p],v=h[0],m=v[0],g=!!a&&a.test(m),y=n[m],b=h[1],E=b,w=void 0;if(y&&1===v.length)w=this._data[m],b=e.propUpdater.call(this._comp,v,y,b,this._hidingValue),g||(this._innerData?(E=vu(b),_[p]||(this._innerData[m]=E)):E=b,h[1]=E),g&&!this._innerData||(this._data[m]=b);else{var O=this._data,A=m,C=null,S=1;if(!g||this._innerData){for(;S<v.length;S++)"number"==typeof(C=v[S])&&isFinite(C)?hu.call(O,A)&&O[A]instanceof Array||(O[A]=[]):(!hu.call(O,A)||null===O[A]||"object"!==Xs(O[A])||O[A]instanceof Array)&&(O[A]={}),O=O[A],A=C;O[A]=b}if(this._innerData&&!g){for(O=this._innerData,A=m,S=1;S<v.length;S++)"number"==typeof(C=v[S])&&isFinite(C)?hu.call(O,A)&&O[A]instanceof Array||(O[A]=[]):(!hu.call(O,A)||null===O[A]||"object"!==Xs(O[A])||O[A]instanceof Array)&&(O[A]={}),O=O[A],A=C;E=vu(b),_[p]||(O[A]=E),h[1]=E}}Bd(this._observerTree,this._observerStatus,v),g||(u.push(v),c.push([E,w,b]),d.push(h)),l&&(this._doingUpdates.changesTotal+=1)}if(!s){if(this._beforeUpdateCb&&this._beforeUpdateCb(t),l){var T=0;do{T=this._doingUpdates.changesTotal,kd(this._observers,this._observerStatus,i,this._data,o)}while(T!==this._doingUpdates.changesTotal);this._doingUpdates=null}this._updateCb(u,c,d,t);for(var N=0;N<c.length;N++){var x=c[N];if(x){var I=u[N],R=n[I[0]];R&&e.propObserver.call(i,x[2],x[1],I,R,o,r)}}}},e.prototype.getChanges=function(){return this._changes},e.prototype.getObserverTree=function(){return this._relatedObserverTreeObj},e.prototype.replaceWholeData=function(e){this._data=e},e.prototype.setHidingValue=function(e){this._hidingValue=!!e},e.prototype.setBeforeMergeCb=function(e){this._beforeMergeCb=e},e.prototype.setBeforeUpdateCb=function(e){this._beforeUpdateCb=e},e}();function Dd(e,t){for(var r in e)if("~"!==r)if("**"!==r)Dd(e[r],t);else for(var n=e["**"],i=0;i<n.length;i++)t[n[i]]=!0;else for(n=e["~"],i=0;i<n.length;i++)t[n[i]]=!0}function Bd(e,t,r){for(var n=0,i=r;n<i.length;n++){var o=i[n],a=e["**"];if(a&&a.forEach((function(e){t[e]=!0})),tl(o)){if(!hu.call(e,o)){e=null;break}}else if(!/^[_a-zA-Z]/.test(o)||!hu.call(e,o)){e=null;break}e=e[o]}e&&Dd(e,t)}var Fd=/(~|\^+)?-?[_0-9a-z][-_0-9a-z]*/gi,Ud=function(){function e(){}return e.create=function(t,r){void 0===r&&(r=null);var n=new e;for(var i in n._prefix="",n._addOriginalClass=!1,n._alias=r,n._resolvedAlias={},r)n._resolvedAlias[i]="";return n._rawNames=[],n._elem=t,n._owner=null,n},e.composeClassName=function(e){var t=e._rawNames,r=e._prefix,n=e._addOriginalClass,i=e._owner?e._owner._resolvedAlias:null,o="";r&&(r+="--");for(var a=0,s=void 0,l=t.length;a<l;a++)if(s=t[a],a>0&&(o+=" "),i&&Object.prototype.hasOwnProperty.call(i,s))o+=i[s];else if("~"===s[0])o+=s.slice(1);else if("^"===s[0]){s=s.slice(1);for(var u=e._owner||null;"^"===t[0];)s=s.slice(1),u=u?u._owner:null;var c=u?u._prefix:"";c&&(o+=(c+="--")+s)}else n&&(o+=s+" "),o+=r+s;return o},e.handleClassName=function(t){var r=t._elem.__domElement;if(r){var n=e.composeClassName(t);n?r.setAttribute("class",n):r.removeAttribute("class")}},e.aliasClassName=function(t){var r=t.classList;if(r instanceof e&&(r._alias&&e.resolveAlias(r),e.handleClassName(r)),nl(t.childNodes))for(var n=0,i=t.childNodes;n<i.length;n++){var o=i[n];fl(o)&&e.aliasClassName(o)}},e.resolveAlias=function(t){var r=t._owner;if(r){var n,i,o=!1;for(n in t._alias){var a=[];if((i=t._alias[n])&&nl(i))for(var s=void 0,l=0,u=i;l<u.length;l++){var c=u[l];s=Object.prototype.hasOwnProperty.call(r._alias,c)?r._resolvedAlias[c]:t._prefix&&c?t._prefix+"--"+c:c,a.push(s)}var d=a.join(" ");t._resolvedAlias[n]!==d&&(o=!0,t._resolvedAlias[n]=d)}o&&fl(t._elem.shadowRoot)&&e.aliasClassName(t._elem.shadowRoot)}},e.prototype.toggle=function(t,r){var n=this._rawNames.indexOf(t);r||(r=n<0),r?n<0&&(this._rawNames.push(t),e.handleClassName(this)):n>=0&&(this._rawNames.splice(n,1),e.handleClassName(this))},e.prototype.contains=function(e){for(var t=0,r=void 0,n=this._rawNames.length;t<n;t++)if("~"===(r=this._rawNames[t])[0]){if(r.slice(1)===e)return!0}else if("^"===r[0]){for(;"^"===r[0];)if(r.slice(1)===e)return!0}else if(r===e)return!0;return!1},e.prototype._setOwnerOptions=function(t,r,n){this._prefix!==r&&(this._prefix=r,this._addOriginalClass=n,this._owner=t,this._alias&&e.resolveAlias(this),e.handleClassName(this))},e.prototype._setAlias=function(t,r){var n=this._owner,i=String(r).match(Fd),o=[];if(this._alias&&i){this._alias[t]=i;for(var a=0,s=i;a<s.length;a++){var l=s[a];n&&Object.prototype.hasOwnProperty.call(n._alias,l)?o.push(n._resolvedAlias[l]):o.push(this._prefix?this._prefix+"--"+l:l)}}this._resolvedAlias[t]=o.join(" "),e.aliasClassName(this._elem.shadowRoot)},e.prototype.setClassNames=function(t){t=null==t?"":String(t),this._rawNames=t.match(Fd)||[],e.handleClassName(this)},e.prototype.getClassNames=function(){return e.composeClassName(this)},e.prototype.getPrefix=function(){return this._prefix},e.prototype.getAddOriginalClass=function(){return this._addOriginalClass},e}(),Gd=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ss(t,e),t.create=function(e){return t._advancedCreate(e,null)},t.cloneNode=function(e){return t._advancedCreate(e,null)},t._advancedCreate=function(e,r){var n=new t;n.is=e.toLowerCase();var i=null;if("dom"===qs.documentBackend&&(i=Id.backendExtractedDefault?new ud(e):document.createElement(e)),Rd.initialize(n,i,r),n.classList=Ud.create(n,null),r){var o=r.__ddHost;if(n.classList._setOwnerOptions(o.classList,o.__componentOptions.classPrefix,o.__componentOptions.addGlobalClass),qs.writeExtraInfoToAttr&&i){var a=o.__componentOptions.classPrefix&&o.__componentOptions.classPrefix+"--";i.setAttribute("exparser:info-class-prefix",a)}}return n},t._advancedClone=function(e,r){var n=new t;n.is=e.is;var i=null;if(e.__domElement&&(i=e.__domElement instanceof ud?Id.backendExtractedDefault?e.__domElement.cloneNode():ud.toElement(e.__domElement):Id.backendExtractedDefault?ud.fromElement(e.__domElement):document.importNode?document.importNode(e.__domElement,!1):e.__domElement.cloneNode(!1)),Rd._clone(n,e,i,r),n.classList=Ud.create(n,null),r){var o=r.__ddHost;if(n.classList._setOwnerOptions(o.classList,o.__componentOptions.classPrefix,o.__componentOptions.addGlobalClass),qs.writeExtraInfoToAttr&&i){var a=o.__componentOptions.classPrefix&&o.__componentOptions.classPrefix+"--";i.setAttribute("exparser:info-class-prefix",a)}}return n},t}(Rd);ul(Gd);var Hd=function(e){var t=e.is,r=e.classPrefix,n=e.generics,i=e.initiator,o=e.behavior,a=e.options;this._unprepared=o,this.is=t||"",this.behavior=o,this.protoFunc=null,this.props=null,this.template=null,this.innerEvents=null,this.generics=n,this.initiator=i||null,this.options={availability:a.availability||qs.availability,domain:a.domain||qs.domain,writeOnly:a.writeOnly||qs.writeOnly,allowInWriteOnly:a.allowInWriteOnly||qs.allowInWriteOnly,classPrefix:r,addGlobalClass:a.addGlobalClass||qs.addGlobalClass,templateEngine:a.templateEngine||qs.templateEngine||il.freeTemplateEngine,renderingMode:a.renderingMode||qs.renderingMode,multipleSlots:a.multipleSlots||qs.multipleSlots,reflectToAttributes:a.reflectToAttributes||qs.reflectToAttributes,writeFieldsToNode:a.writeFieldsToNode||qs.writeFieldsToNode,writeIdToDOM:a.writeIdToDOM||qs.writeIdToDOM,separateInnerData:a.separateInnerData||qs.separateInnerData,innerDataExclude:a.innerDataExclude||qs.innerDataExclude,listenerChangeLifeTimes:a.listenerChangeLifeTimes||qs.listenerChangeLifeTimes,randomizeTagName:a.randomizeTagName||qs.randomizeTagName,virtualHost:a.virtualHost||qs.virtualHost,placeholder:a.placeholder}};function Vd(e,t,r){t.__relationLinks||(t.__relationLinks={}),t.__relationLinks[r]=new Array(e.length).fill(null)}function zd(e,t,r){if(void 0===r&&(r=[]),fl(e)){if(_l(e)){e.__pageLifeTimeFuncs[t]&&e.__pageLifeTimeFuncs[t].call(e.__methodCaller,r);for(var n=0,i=e.childNodes;n<i.length;n++)zd(i[n],t,r);e=e.shadowRoot}for(var o=0,a=e.childNodes;o<a.length;o++)zd(a[o],t,r)}}function $d(e,t,r,n,i){for(var o=dl().prototype.hasBehavior,a="parent"===n,s="shadowHost"===n,l=0,u=void 0;l<e.length;l++){var c="object"===Xs((u=e[l]).target)?u.target:ad._list[u.target];if(c){var d=void 0;if(!i)for(var f=s?r.ownerShadowRoot&&r.ownerShadowRoot.__ddHost:r.parentNode;f;){if(!f.__virtual&&o.call(f,c)){for(var _=0,p=a?f.__relationMap.child:s?f.__relationMap.shadowContent:f.__relationMap.descendant;_<p.length;_++){var h=p[_],v="object"===Xs(h.target)?h.target:ad._list[h.target];if(v&&o.call(r,v)){d={parent:f,relation:h};break}}if(a||d)break}f=s?f.ownerShadowRoot&&f.ownerShadowRoot.__ddHost:f.parentNode}var m=t[l];t[l]=d,!m||d&&m.parent===d.parent||(hl.safeCallback("Relation Unlinked Callback",m.relation.unlinked,m.parent.__methodCaller,[r.__methodCaller],m.parent),hl.safeCallback("Relation Unlinked Callback",u.unlinked,r.__methodCaller,[m.parent.__methodCaller],r)),!d||m&&m.parent===d.parent||(hl.safeCallback("Relation Linked Callback",d.relation.linked,d.parent.__methodCaller,[r.__methodCaller],d.parent),hl.safeCallback("Relation Linked Callback",u.linked,r.__methodCaller,[d.parent.__methodCaller],r)),m&&d&&m.parent===d.parent&&(hl.safeCallback("Relation Link Changed Callback",d.relation.linkChanged,d.parent.__methodCaller,[r.__methodCaller],d.parent),hl.safeCallback("Relation Link Changed Callback",u.linkChanged,r.__methodCaller,[d.parent.__methodCaller],r)),i||d||hl.safeCallback("Relation Link Failed Callback",u.linkFailed,r.__methodCaller,[],r)}}}function Yd(e,t){return function(r){return e.call(t.__methodCaller,r,t)}}rr({target:"Array",proto:!0},{fill:Kr}),st("fill");var Wd=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ss(t,e),t.register=function(e){var r=e.options||Object.create(null),n=ad.create(e),i=r.classPrefix||qs.classPrefix;null==i&&(i=n.is||"");var o=new Hd({is:e.is,behavior:n,classPrefix:i,generics:n.generics,initiator:n.initiator,options:r});return n._unprepared&&t.prepare(o),e.is&&(t._list[n.is]=o),o},t.isPrepared=function(e){return!e._unprepared},t.prototype.getPlaceholder=function(e){return this.__placeholder[e]},t.prepare=function(e){var r=e._unprepared;function n(){}if(!t.isPrepared(e)){e._unprepared=null;var i=void 0;r._unprepared&&ad.prepare(r);var o=e.options,a=e.props={},s={};if(o.writeOnly&&(s.data={value:null}),Object.keys(r.properties).forEach((function(e){var t=r.properties[e];a[e]={type:t.type,optionalTypes:t.optionalTypes,value:t.value,filter:rl(t.filter)?t.filter:null==t.filter?null:r.methods[t.filter],observer:rl(t.observer)?t.observer:null==t.observer?null:r.methods[t.observer],public:t.public,availability:t.availability,observeAssignments:t.observeAssignments},o.writeFieldsToNode&&(s[e]={enumerable:!0,get:function(){return this.__propData[e]},set:function(t){this.__dataProxy.scheduleReplace([e],t),this.__dataProxy.doUpdates()}})})),e.protoFunc=n,n.prototype=Object.create(t.prototype,s),n.prototype.is=e.is,n.prototype.__componentOptions=o,n.prototype.__using=r.using,n.prototype.__placeholder=r.placeholder,e.dataGroupObserverTree=jd._createObserverTree(a),r._addObserversToDataProxy(e.dataGroupObserverTree),n.prototype.__behavior=r,o.writeFieldsToNode)for(i in r.methods)n.prototype[i]=r.methods[i];n.prototype.__lifeTimeFuncs=r._getAllLifeTimeFuncs(),n.prototype.__pageLifeTimeFuncs=r._getAllPageLifeTimeFuncs(),n.prototype.__relationMap={};var l=r.relations;for(i in l){var u=l[i];n.prototype.__relationMap[u.type]?n.prototype.__relationMap[u.type].push(u):n.prototype.__relationMap[u.type]=[u]}var c=[];n.prototype.__relationMap.parent&&c.push((function(e){$d(this.__relationMap.parent,this.__relationLinks.parent,this,"parent","detached"===e)})),n.prototype.__relationMap.ancestor&&c.push((function(e){$d(this.__relationMap.ancestor,this.__relationLinks.ancestor,this,"ancestor","detached"===e)})),n.prototype.__relationMap.shadowHost&&c.push((function(e){$d(this.__relationMap.shadowHost,this.__relationLinks.shadowHost,this,"shadowHost","detached"===e)})),e.relationHandler=function(e){for(var t=0;t<c.length;t++)c[t].call(this,e)};var d={},f={};for(i in r.data)f[i]=r.data[i];var _=void 0;for(i in a)_=a[i],f[i]=_.value,d[i]=_.public;var p=f,h=o.separateInnerData,v=o.innerDataExclude;if(v){for(i in p={},f)!1===v.test(i)&&(p[i]=f[i]);h||(f=p)}e.template=o.templateEngine.create(r,f,p,o),n.prototype.__propPublic=d,e.innerEvents=[];var m=r._getAllListeners();for(i in m){for(var g=m[i],y=i.indexOf("."),b=i.slice(y+1),E=y<1?"":i.slice(0,y),w=[],O=0,A=g.length,C=void 0;O<A;O++)rl(C=g[O])||(C=null==C?null:r.methods[C]),w.push(C);e.innerEvents.push({id:E,name:b,funcs:w})}}},t._advancedCreate=function(e,r,n,i,o){var a;if(r&&r._unprepared&&t.prepare(r),!r||!r.options)throw new Error("Framework inner error (exparser not found "+e+")");rl(r.options.availability)&&(hl.safeCallback("Availablity Controller",r.options.availability,r,[n?n.__ddHost.__componentOptions.domain:void 0])||(r=t._list[""]));var s=new r.protoFunc,l=r.generics;if(l){var u={},c=void 0,d=void 0;for(a in l)c=l[a],"object"!==Xs(d=i[a])&&(d=t._list[d]),"object"!==Xs(d)&&null!=c.default&&(d=t._list[c.default]),d&&(u[a]=d);s.__generics=u}else s.__generics={};var f=null;r.options.virtualHost?(f="dom"===qs.documentBackend?void 0:null,Rd.initialize(s,f,n),s.__virtual=!0):"dom"===qs.documentBackend?(f=Id.backendExtractedDefault?new ud(e):document.createElement(e),Rd.initialize(s,f,n)):Rd.initialize(s,null,n),s.__externalClassAlias={};var _=r.behavior.externalClasses;if(_&&nl(_))for(var p=0;p<_.length;p++)s.__externalClassAlias[_[p]]=null;if(s.classList=Ud.create(s,s.__externalClassAlias),n){var h=n.__ddHost;if(s.classList._setOwnerOptions(h.classList,h.__componentOptions.classPrefix,h.__componentOptions.addGlobalClass),qs.writeExtraInfoToAttr&&f){var v=h.__componentOptions.classPrefix&&h.__componentOptions.classPrefix+"--";f.setAttribute("exparser:info-class-prefix",v)}}qs.writeExtraInfoToAttr&&f&&(s.__componentInstanceId=t.componentInstanceId++,f.setAttribute("exparser:info-component-id",String(s.__componentInstanceId))),s.__templateInstance=r.template.createInstance(s,o),s.__propData=s.__templateInstance.data;var m=r.options.separateInnerData,g=r.options.innerDataExclude;if(s.__innerData=m?vu(s.__propData):null,m&&g){var y={};for(a in s.__innerData)g.test(a)||(y[a]=s.__innerData[a]);s.__innerData=y}if(s.__dataProxy=jd._advancedCreate(s,s.__propData,s.__innerData,g,r.dataGroupObserverTree,(function(e,t,r,n){var i=qs.separateInnerData?s.__innerData:s.__propData;s.__templateInstance.updateValues(s,i,e,t,r,n)})),s.__templateInstance.beforeMergeValues&&s.__dataProxy.setBeforeMergeCb((function(e,t,r){s.__templateInstance.beforeMergeValues(e,t,r)})),s.__templateInstance.beforeUpdateValues){var b=m?s.__innerData:s.__propData;s.__dataProxy.setBeforeUpdateCb((function(e){s.__templateInstance.beforeUpdateValues(s,b,e)}))}qs.writeOnly&&s.__dataProxy.setHidingValue(!0),s.__idCacheDirty=!1,s.__idCache=s.__templateInstance.idMap,null===s.__templateInstance.slots[""]&&(s.__templateInstance.slots[""]=f),r.options.multipleSlots?s.__slots=s.__templateInstance.slots:(s.__singleSlot=s.__templateInstance.slots[""]||null,s.__singleSlot&&(s.__singleSlot.__ddSlotChildren=s.childNodes)),fl(s.__templateInstance.shadowRoot)?(s.shadowRoot=s.__templateInstance.shadowRoot,Rd._attachShadowRoot(s.__templateInstance.shadowRoot)):(f instanceof ud?(s.shadowRoot=f,s.shadowRoot.__ddHost=s,s.shadowRoot.__ddHost.__domElement.asShadowRoot=s.__templateInstance.shadowRoot):(s.shadowRoot=f,s&&s.shadowRoot&&(s.shadowRoot.__ddHost=s),s&&s.shadowRoot&&s.shadowRoot.__ddHost.__domElement.appendChild(s.__templateInstance.shadowRoot)),s.__ddSlotChildren=[f],f&&(f.__ddSlotParent=s));for(var E=0,w=s.__templateInstance.listeners;E<w.length;E++){var O=w[E];Ou.addListenerToElement(O.target,O.name,Yd(O.func,s))}for(var A=0,C=r.innerEvents;A<C.length;A++){var S=C[A],T=S.id?"this"===S.id?s:s.__idCache[S.id]:s.shadowRoot;if(T)for(var N=S.name,x=0,I=S.funcs;x<I.length;x++){var R=I[x];Ou.addListenerToElement(T,N,Yd(R,s))}}var L=s.__relationMap;return L.parent&&(Vd(L.parent,s,"parent"),s.__relationHandler=r.relationHandler),L.ancestor&&(Vd(L.ancestor,s,"ancestor"),s.__relationHandler=r.relationHandler),L.shadowHost&&(Vd(L.shadowHost,s,"shadowHost"),s.__relationHandler=r.relationHandler),s.__propertyChangeListeners=null,r.initiator&&hl.safeCallback("Component Initiator",r.initiator,s.__methodCaller,[],s),s.__lifeTimeFuncs.created.call(s.__methodCaller,[],s),s},t.createWithGenerics=function(e,r,n,i){var o;if(e instanceof Hd)o=t._advancedCreate(e.is,e,null,n,i);else if(e)if(-1!==e.indexOf("-")||r){var a=r||Object.prototype.hasOwnProperty.call(t._list,e)&&t._list[e]||t._list[""];o=t._advancedCreate(e.toLowerCase(),a,null,n,i)}else o=Gd.create(e);else o=t._advancedCreate("virtual",t._list[""],null,n,i);return o},t.create=function(e,r,n){var i;if(e instanceof Hd)i=t._advancedCreate(e.is,e,null,null,n);else if(e)if(-1!==e.indexOf("-")||r){var o=r||Object.prototype.hasOwnProperty.call(t._list,e)&&t._list[e]||t._list[""];i=t._advancedCreate(e.toLowerCase(),o,null,null,n)}else i=Gd.create(e);else i=t._advancedCreate("virtual",t._list[""],null,null,n);return i},t.listProperties=function(e){var t=[];for(var r in e.__propPublic)void 0!==e.__propPublic[r]&&t.push(r);return t},t.listPublicProperties=function(e){var t=[];for(var r in e.__propPublic)!0===e.__propPublic[r]&&t.push(r);return t},t.hasProperty=function(e,t){return void 0!==e.__propPublic[t]},t.hasPublicProperty=function(e,t){return!0===e.__propPublic[t]},t.getMethodsFromDef=function(e){return e.behavior._unprepared&&ad.prepare(e.behavior),e.behavior.methods},t.getMethod=function(e,t){return e.__behavior.methods[t]},t.getComponentOptions=function(e){if(e)return e.__componentOptions},t.getInnerData=function(e){return e.__innerData},t.getDataProxy=function(e){return e.__dataProxy},t.replaceWholeData=function(e,t){e.__propData=t,e.__dataProxy.replaceWholeData(t)},t.prototype.triggerLifeTime=function(e,t){void 0===t&&(t=[]),this.__lifeTimeFuncs[e].call(this.__methodCaller,t||[])},t.prototype.triggerPageLifeTime=function(e,t){void 0===t&&(t=[]),zd(this,e,t)},t.prototype.hasBehavior=function(e){return"object"!==Xs(e)&&Object.prototype.hasOwnProperty.call(this.__using,e)&&(e=this.__using[e]),this.__behavior instanceof ad&&this.__behavior.hasBehavior(e)},t.prototype.getRootBehavior=function(){return this.__behavior},t.prototype.getRelationNodes=function(e){var t=this.__behavior.relations[e];if(!t)return null;var r=t.type,n="child"===r,i="shadowContent"===r;if("parent"!==r&&"ancestor"!==r&&"shadowHost"!==r){var o=this,a=[];return function e(r){var s=r.childNodes;if(Array.isArray(s))for(var l=0,u=void 0;l<s.length;l++)if((u=s[l])instanceof Rd)if(u.__virtual)e(u);else{if(u.__relationLinks){var c=n?u.__relationLinks.parent:i?u.__relationLinks.shadowHost:u.__relationLinks.ancestor;if(c)for(var d=0,f=void 0;d<c.length;d++)if((f=c[d])&&f.parent===o&&f.relation===t){a.push(u);break}}i&&_l(u)&&e(u.shadowRoot),n||e(u)}}(i?o.shadowRoot:o),a}for(var s=this.__relationMap[t.type],l=0;l<s.length;l++)if(s[l]===t)return this.__relationLinks[t.type][l]?[this.__relationLinks[t.type][l].parent]:[]},t.prototype.hasExternalClass=function(e){return Object.prototype.hasOwnProperty.call(this.__externalClassAlias,e)},t.prototype.setExternalClass=function(e,t){this.classList._setAlias(e,t)},t.prototype.setPropertyChangeListener=function(e,t){this.__propertyChangeListeners||(this.__propertyChangeListeners={}),this.__propertyChangeListeners[e]=t},t.prototype.replaceDataOnPath=function(e,t){this.__dataProxy.scheduleReplace(e,t)},t.prototype.isInnerDataExcluded=function(e){var t=this.__componentOptions.innerDataExclude;return!!t&&t.test(e)},t.prototype.applyDataUpdates=function(){this.__dataProxy.doUpdates()},t.prototype.setData=function(e){var t=this.__dataProxy;for(var r in e)t.scheduleReplace(Wc(r),e[r]);t.doUpdates()},Object.defineProperty(t.prototype,"data",{get:function(){return this.__dataProxy?this.__dataProxy._data:null},set:function(e){if(this.__dataProxy){for(var t in e)this.__dataProxy.scheduleReplace([t],e[t]);this.__dataProxy.doUpdates()}},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"$",{get:function(){return Rd._updateIdMap(this),this.__idCache},set:function(e){},enumerable:!1,configurable:!0}),t._list={},t.componentInstanceId=1,t}(Rd);jd.setPropUpdater((function(e,t,r,n){var i=e[0],o=this.__propData[i];if(r=function(e,t,r){if(r)for(var n=0;n<r.length;n++)if(ad.matchTypeWithValue(r[n],e))return e;switch(t){case String:return null==e?"":String(e);case Number:return isFinite(e)?Number(e):e;case Boolean:return!!e;case Array:return e instanceof Array?e:[];case Object:return"object"===Xs(e)?e:null;default:return void 0===e?null:e}}(r,t.type,t.optionalTypes),t.availability){var a=this,s=t.availability,l=[a.ownerShadowRoot?a.ownerShadowRoot.__wxHost.__componentOptions.domain:void 0,n?void 0:r];if(!hl.safeCallback("Availablity Controller",s,a.__methodCaller,l,a))return o}if(t.filter){var u=hl.safeCallback("Property Filter",t.filter,this.__methodCaller,n?[]:[r,o,e],this);void 0!==u&&(r=u)}if(this.__domElement&&this.__componentOptions.reflectToAttributes&&this.__propPublic[i]){a=this;var c=i.replace(/(\w)([A-Z])/g,(function(e,t,r){return t+"-"+r.toLowerCase()})),d=Xs(r);"boolean"===d?r?a.__domElement.setAttribute(c,""):a.__domElement.removeAttribute(c):"object"===d?a.__domElement.setAttribute(c,JSON.stringify(r)):a.__domElement.setAttribute(c,r)}return r})),jd.setPropObserver((function(e,t,r,n,i,o){if(n.observeAssignments||e!==t){var a=r[0];this.__propertyChangeListeners&&this.__propertyChangeListeners[a]&&!o&&hl.safeCallback("Property Observer",this.__propertyChangeListeners[a],this.__methodCaller,[e],this),rl(n.observer)&&hl.safeCallback("Property Observer",n.observer,this.__methodCaller,i?[]:[e,t,r],this),n.public&&(this.__propObservers&&!this.__propObservers.empty||this.__subtreeObserversCount)&&ld._callObservers(this,"__propObservers",{type:"properties",target:this,propertyName:a})}})),al(Wd);var Zd=function(){function e(){}return e.create=function(t){return void 0===t&&(t=""),e._advancedCreate(t,null)},e._advancedCreate=function(t,r){void 0===t&&(t="");var n=new e;n.__slot="";var i=null;return!1===Id.backendExtractedDefault&&("dom"===qs.documentBackend?(i=document.createTextNode(t)).__ddElement=n:n.__textContent=t),n.$$=i,n.__domElement=i,n.__backendExtracted=Id.backendExtractedDefault,n.__subtreeObserversCount=0,n.parentNode=null,n.ownerShadowRoot=r,n},Object.defineProperty(e.prototype,"textContent",{get:function(){return this.__domElement?this.__domElement.textContent:this.__textContent},set:function(e){this.__domElement?this.__domElement.textContent=e:this.__textContent=e,(this.__textObservers&&!this.__textObservers.empty||this.__subtreeObserversCount)&&ld._callObservers(this,"__textObservers",{type:"characterData",target:this})},enumerable:!1,configurable:!0}),e.prototype.destroy=function(e){this.__textContent=null,this.parentNode=null,this.ownerShadowRoot=null,this.$$=null,this.__slot=null,this.__ddHost=null,this.__ddSlotParent=null,e?(this.__textObservers.destroy(),this.__textObservers=null):Rd.delayDestroy(this)},e}();ll(Zd);var Jd=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ss(t,e),t.initialize=function(e,t,r){e.is=t||"";var n=null;"dom"===qs.documentBackend&&(n=void 0),Rd.initialize(e,n,r),e.__virtual=!0},t.create=function(e){var r=new t;return t.initialize(r,e,null),r},t._advancedCreate=function(e,r){var n=new t;return t.initialize(n,e,r),n},t}(Rd);cl(Jd);var Kd=function(e){function t(t){var r=e.call(this)||this;return Jd.initialize(r,"shadow",r),r.__hostAssociated=!1,r.__ddHost=t,r.__childrenPropsFilter=null,r.__slotCacheDirty=!1,r}return ss(t,e),t.create=function(e){var r=new t(e);if(e.ownerShadowRoot&&e.ownerShadowRoot.__childrenPropsFilter)if(r.__childrenPropsFilter)for(var n in e.ownerShadowRoot.__childrenPropsFilter)r.__childrenPropsFilter[n]||(r.__childrenPropsFilter[n]=e.ownerShadowRoot.__childrenPropsFilter[n]);else r.__childrenPropsFilter=e.ownerShadowRoot.__childrenPropsFilter;return r},t.prototype.createTextNode=function(e){return Zd._advancedCreate(e,this)},t.prototype.createNativeNode=function(e){return Gd._advancedCreate(e,this)},t.prototype.cloneNativeNode=function(e){return Gd._advancedClone(e,this)},t.prototype.createVirtualNode=function(e){return Jd._advancedCreate(e,this)},t.prototype.createComponent=function(e,t,r,n){var i=Object.prototype.hasOwnProperty,o=t||e,a=this.__ddHost;if("object"!==Xs(o)&&(i.call(a.__using,o)?o=a.__using[o]:i.call(a.__generics,o)&&(o=a.__generics[o]),"object"!==Xs(o)&&(o=Wd._list[o]||Wd._list[""])),r&&(r=function(e,t){var r={};for(var n in e){var o=e[n];"object"!==Xs(o)&&(i.call(t.__using,o)?o=t.__using[o]:i.call(t.__generics,o)&&(o=t.__generics[o]||Wd._list[""]),r[n]=o)}return r}(r,a)),"object"===Xs(e)&&(e=o.is),a.__componentOptions.randomizeTagName){e=function(){for(var e=Date.now(),t="exparser-",r=0;r<8;r++){var n=(e+Math.floor(26*Math.random()))%26;e=Math.floor(e/26),t+="abcdefghijklmnopqrstuvwxyz"[n]}return t}()}return a.__componentOptions.writeOnly&&!o.options.allowInWriteOnly&&(o=Wd._list[""]),Wd._advancedCreate(e,o,this,r,n)},t.prototype.tagNameUsed=function(e){var t=this.__ddHost,r=Object.prototype.hasOwnProperty;return!!r.call(t.__using,e)||!!r.call(t.__generics,e)},t.prototype.getHostNode=function(){return this.__ddHost},t.prototype.getElementById=function(e){return Rd._updateIdMap(this.__ddHost),this.__ddHost.__idCache[e]},t}(Jd),qd=function(){function e(){}return e.getInstance=function(){return e.instance||(e.instance=new e)},e.iterator=function(t){var r=e.getInstance();return r._iterator=r._getElementChildren(t),r._iterator},e.create=function(t,r,n){var i=new e;if(!fl(t)&&!pl(t))throw new Error("ElementIterator can only be used for exparser.Element or exparser.TextNode");i._elem=t,i._elemTypeLimit=n||Rd;var o=r.split("-");if("shadow"===o[0])i._composed=!1;else{if("composed"!==o[0])throw new Error("Unrecognized iterator type: "+r);i._composed=!0}if("ancestors"===o[1])i._relation="ancestors",i._order=0;else{if("descendants"!==o[1])throw new Error("Unrecognized iterator type: "+r);if(i._relation="descendants","root"!==o[2])throw new Error("Unrecognized iterator type: "+r);if("first"===o[3])i._order=-1;else{if("last"!==o[3])throw new Error("Unrecognized iterator type: "+r);i._order=1}}return i},e.prototype.forEach=function(e){if("ancestors"===this._relation){for(var t=this._elem;t;){if(t instanceof this._elemTypeLimit&&!1===e(t))return!1;t=this._composed&&(t.__ddSlotParent||t.__ddHost)||t.parentNode}return!0}return Xd(this._elem,this._elemTypeLimit,this._composed,this._order,e)},e.prototype._getElementChildren=function(e){var t=this;return e.childNodes&&e.childNodes.length&&e.childNodes.forEach((function(e){t._getElementChildren(e)})),e},e}();function Xd(e,t,r,n,i){if(n<0&&e instanceof t&&!1===i(e))return!1;var o=r&&e.__ddSlotChildren||e.childNodes;if(o)for(var a=0;a<o.length;a++){if(!1===Xd(o[a],t,r,n,i))return!1}return!(0<n&&e instanceof t&&!1===i(e))}var Qd=q("isConcatSpreadable"),ef=9007199254740991,tf="Maximum allowed index exceeded",rf=o.TypeError,nf=z>=51||!a((function(){var e=[];return e[Qd]=!1,e.concat()[0]!==e})),of=ts("concat"),af=function(e){if(!X(e))return!1;var t=e[Qd];return void 0!==t?!!t:io(e)};function sf(){}rr({target:"Array",proto:!0,forced:!nf||!of},{concat:function(e){var t,r,n,i,o,a=N(this),s=so(a,0),l=0;for(t=-1,n=arguments.length;t<n;t++)if(af(o=-1===t?a:arguments[t])){if(l+(i=Fe(o))>ef)throw rf(tf);for(r=0;r<i;r++,l++)r in o&&qr(s,l,o[r])}else{if(l>=ef)throw rf(tf);qr(s,l++,o)}return s.length=l,s}});var lf={title:"browser",browser:!0,env:{},argv:[],version:"",versions:{},on:sf,addListener:sf,once:sf,off:sf,removeListener:sf,removeAllListeners:sf,emit:sf,prependListener:sf,prependOnceListener:sf,listeners:function(){return[]},binding:function(){throw new Error("process.binding is not supported")},cwd:function(){return"/"},chdir:function(){throw new Error("process.chdir is not supported")},umask:function(){return 0}};function uf(e,t,r,n,i){var o;e.linked?cf.updateBinding(e,t,r,n,i):(o=n[e.name],n[e.name]=e.exp(r,n,i),cf.updateBinding(e,t,r,n,i),n[e.name]=o)}var cf={create:function(e,t,r,n,i,o,a){for(var s={inc:1,name:e,exp:n,lp:i,scopes:{},targets:{},children:null,lu:a,__scopeBinded:[]},l=0;l<o.length;l++){var u=o[l];null===u[0]?cf.addBinding(t,u,null,s):cf.addBinding(r[u[0]],u,null,s)}return s},proxyTopScope:function(e){var t={inc:1,linked:e,scopes:{},targets:{},children:null,__scopeBinded:[]};return cf.addBinding(e,[null],null,t),t},proxySubScopes:function(e){var t={};for(var r in e)t[r]={inc:1,linked:e[r],scopes:{},targets:{},children:null,__scopeBinded:[]},cf.addBinding(e[r],[null],null,t[r]);return t},addBinding:function(e,t,r,n){for(var i=e,o=1,a=void 0;o<t.length;o++){a=t[o],i.children||(i.children=Object.create(null));var s=i.children;s[a]||(s[a]={scopes:{},targets:{},children:null}),i=s[a]}var l=e.inc++;return r?i.targets[l]=[r,n]:(i.scopes[l]=n,i.scopes[l].__scopeBinded.push([i,l])),l},addBindings:function(e,t,r,n,i){for(var o=0;o<r.length;o++){var a=r[o];a[0]?cf.addBinding(t[a[0]],a,n,i):cf.addBinding(e,a,n,i)}},updateBinding:function(e,t,r,n,i){for(var o,a=e,s=0;s<t.length;s++){for(o in a.scopes)uf(a.scopes[o],t,r,n,i);var l=t[s],u=a.children;if(!u||!u[l])return;a=u[l]}!function e(t){for(o in t.targets){var a=t.targets[o],s=a[1];s.o(a[0],s.n,s.e(r,n,i))}for(o in t.scopes)uf(t.scopes[o],[],r,n,i);for(o in t.children)e(t.children[o])}(a)},updateLvaluePath:function(e,t){e.lp=t},removeBindingsForScope:function(e){for(var t=e.__scopeBinded,r=0,n=void 0;r<t.length;r++)delete(n=t[r])[0].scopes[n[1]]}},df=Ie.f,ff=Vt.f,_f=xt.enforce,pf=q("match"),hf=o.RegExp,vf=hf.prototype,mf=o.SyntaxError,gf=f(Ds),yf=f(vf.exec),bf=f("".charAt),Ef=f("".replace),wf=f("".indexOf),Of=f("".slice),Af=/^\?<[^\s\d!#%&*+<=>@^][^\s!#%&*+<=>@^]*>/,Cf=/a/g,Sf=/a/g,Tf=new hf(Cf)!==Cf,Nf=Tu.MISSED_STICKY,xf=Tu.UNSUPPORTED_Y,If=re&&(!Tf||Nf||xu||Ru||a((function(){return Sf[pf]=!1,hf(Cf)!=Cf||hf(Sf)==Sf||"/a/i"!=hf(Cf,"i")})));if(er("RegExp",If)){for(var Rf=function(e,t){var r,n,i,o,a,s,l=ce(vf,this),u=pc(e),c=void 0===t,d=[],f=e;if(!l&&u&&c&&e.constructor===Rf)return e;if((u||ce(vf,e))&&(e=e.source,c&&(t="flags"in f?f.flags:gf(f))),e=void 0===e?"":js(e),t=void 0===t?"":js(t),f=e,xu&&"dotAll"in Cf&&(n=!!t&&wf(t,"s")>-1)&&(t=Ef(t,/s/g,"")),r=t,Nf&&"sticky"in Cf&&(i=!!t&&wf(t,"y")>-1)&&xf&&(t=Ef(t,/y/g,"")),Ru&&(o=function(e){for(var t,r=e.length,n=0,i="",o=[],a={},s=!1,l=!1,u=0,c="";n<=r;n++){if("\\"===(t=bf(e,n)))t+=bf(e,++n);else if("]"===t)s=!1;else if(!s)switch(!0){case"["===t:s=!0;break;case"("===t:yf(Af,Of(e,n+1))&&(n+=2,l=!0),i+=t,u++;continue;case">"===t&&l:if(""===c||I(a,c))throw new mf("Invalid capture group name");a[c]=!0,o[o.length]=[c,u],l=!1,c="";continue}l?c+=t:i+=t}return[i,o]}(e),e=o[0],d=o[1]),a=po(hf(e,t),l?this:vf,Rf),(n||i||d.length)&&(s=_f(a),n&&(s.dotAll=!0,s.raw=Rf(function(e){for(var t,r=e.length,n=0,i="",o=!1;n<=r;n++)"\\"!==(t=bf(e,n))?o||"."!==t?("["===t?o=!0:"]"===t&&(o=!1),i+=t):i+="[\\s\\S]":i+=t+bf(e,++n);return i}(e),r)),i&&(s.sticky=!0),d.length&&(s.groups=d)),e!==f)try{mt(a,"source",""===f?"(?:)":f)}catch(e){}return a},Lf=function(e){e in Rf||df(Rf,e,{configurable:!0,get:function(){return hf[e]},set:function(t){hf[e]=t}})},Mf=ff(hf),kf=0;Mf.length>kf;)Lf(Mf[kf++]);vf.constructor=Rf,Rf.prototype=vf,Ut(o,"RegExp",Rf)}_o("RegExp");var Pf,jf={TAG_START:1,TAG_END:-1,TEXT:3,COMMENT:8},Df="m",Bf="f",Ff="e",Uf="c",Gf="t",Hf="s",Vf={n:"\n",r:"\r",b:"\b",f:"\f",t:"\t",v:"\v",'"':'"',"'":"'","\\":"\\","\r":"\r","\n":"\n"},zf={},$f="";for(Pf in Vf)zf[Vf[Pf]]=Pf,$f+=Vf[Pf];var Yf=new RegExp("["+$f+"]","g"),Wf=1,Zf=-1,Jf=8,Kf=["area","base","br","col","embed","hr","img","link","meta","input","keygen","source","param","track","wbr"];function qf(e,t){return e.substring(t)}function Xf(e){var t=new RegExp("^<((?:[a-zA-Z_][\\w\\-\\.]*\\:)?[a-zA-Z_][\\w\\-\\.]*)"),r=/^\s*(\/?)>/,n=/^\s*([^\s"'<>\/=]+)(?:\s*(=)\s*(?:"([^"]*)"+|'([^']*)'+|([^\s"'=<>`]+)))?/,i=e.match(t);if(i){e=qf(e,i[0].length);for(var o={t:Wf,n:i[1],a:[],selfClose:!(Kf.indexOf(i[1])<0)||void 0},a=void 0,s=void 0;!(a=e.match(r))&&(s=e.match(n));){e=qf(e,s[0].length);var l=s[3]||s[4]||s[5]||"";o.a.push({n:String(s[1]),v:String(l)})}if(a)return{match:o,html:e=qf(e,a[0].length)}}}function Qf(e){var t=new RegExp("^<\\/((?:[a-zA-Z_][\\w\\-\\.]*\\:)?[a-zA-Z_][\\w\\-\\.]*)[^>]*>"),r=e.match(t);return e=qf(e,r[0].length),{match:{t:Zf,n:r[1]},html:e}}function e_(e){var t=e.indexOf("--\x3e");if(t<0)throw new Error("💔fail to compile html template: comment no end");var r={t:Jf,c:e.substring(4,t)};return{html:e=qf(e,t+3),match:r}}function t_(e){var t,r={t:3,c:null},n="[a-zA-Z_][\\w\\-\\.]*",i="((?:"+n+"\\:)?"+n+")",o=new RegExp("^<"+i),a=new RegExp("^<\\/"+i+"[^>]*>"),s=e.indexOf("<");if(s>=0){for(t=e.slice(s);!o.test(t)&&!a.test(t);){var l=t.indexOf("<",1);if(l<0){s+=t.length;break}s+=l,t=e.slice(s)}r.c=e.substring(0,s),e=qf(e,s)}return s<0&&(r.c=e,e=""),{match:r,html:e}}var r_={parse:function(e){var t="[a-zA-Z_][\\w\\-\\.]*",r="((?:"+t+"\\:)?"+t+")",n=new RegExp("^<"+r),i=new RegExp("^<\\/"+r+"[^>]*>"),o=new RegExp("^\x3c!--"),a=[];e=function(e){return e.replace(/\n|\r|\t|\f/g," ")}(e);try{for(;e;){var s=void 0;s=e.match(n)?Xf(e):e.match(i)?Qf(e):e.match(o)?e_(e):t_(e),e=s.html,a.push(s.match)}return a}catch(e){}}},n_=/^[ \n\r\t\f]+|[ \n\r\t\f]+$/g,i_=qs.hasDOMBackend?document.createElement("div"):null,o_={amp:"&",gt:">",lt:"<",nbsp:" ",quot:'"',apos:"'"},a_=function(){function e(){}return e.decodeEntities=function(e){return e.replace(/&(([a-zA-Z]+)|(#x{0,1}[\da-zA-Z]+));/gi,(function(e,t){if(o_[t])return o_[t];if(/^#[0-9]{1,4}$/.test(t))return String.fromCharCode(t.slice(1));if(/^#x[0-9a-f]{1,4}$/i.test(t))return String.fromCharCode("0"+t.slice(1));if(qs.hasDOMBackend){var r=e;return i_?(i_.innerHTML=r,i_.innerText||i_.textContent):r}return e}))},e.parse=function(t,r){for(var n=r_.parse(t)||[],i={c:[]},o=i,a=[],s=0;s<n.length;s++){var l=n[s];if(l.t===jf.TAG_START){var u={t:jf.TAG_START,n:l.n,a:l.a,c:[]};o.c.push(u),l.selfClose||(a.push(o),o=u)}else if(l.t===jf.TAG_END){var c=a.length-1,d=!0;for(u=o;l.n!==u.n;)if(!(u=a[c--])){d=!1;break}if(d)for(;a.length>c;)o=a.pop()}else l.t===jf.TEXT&&(l.c=e.decodeEntities(r?l.c:l.c.replace(n_,"")),l.c&&o.c.push(l))}return i.c},e.TAG_TYPES=jf,e}(),s_=" \n\r\t\f",l_=["true","false","null","undefined"],u_={$1:{VARIABLE:[{id:"_concat",states:["a-zA-Z_$","VARIABLE_AFTER"]}],VARIABLE_AFTER:[{id:"_concat",states:["a-zA-Z_$0-9","VARIABLE_AFTER"]},{id:"_null",states:["NULL"]}],STRING:[{id:"str^",states:["'","STRING_INNER_1"]},{id:"str^",states:['"',"STRING_INNER_2"]}],STRING_INNER_1:[{id:"str$",states:["'"]},{id:"str\\",states:["\\","nrbftv'\"\\\r\n","STRING_INNER_1"]},{id:"_concat",states:["ALL","STRING_INNER_1"]}],STRING_INNER_2:[{id:"str$",states:['"']},{id:"str\\",states:["\\","nrbftv'\"\\\r\n","STRING_INNER_2"]},{id:"_concat",states:["ALL","STRING_INNER_2"]}],NUMBER:[{id:"_concat",states:["NUMBER_BEFORE_E","NUMBER_E"]}],NUMBER_E:[{id:"_concat",states:["e","NUMBER_AFTER_E"]},{id:"_null",states:["NULL"]}],NUMBER_AFTER_E:[{id:"_concat",states:["-","NUMBER_AFTER_E-INT"]},{id:"_jump",states:["NUMBER_AFTER_E-INT"]}],"NUMBER_AFTER_E-INT":[{id:"_concat",states:["NUMBER_AFTER_E-INT","0-9"]},{id:"_jump",states:["0-9"]}],NUMBER_BEFORE_E:[{id:"_concat",states:[".","NUMBER_AFTER_DOT"]},{id:"_concat",states:["0","NUMBER_AFTER_ZERO"]},{id:"_concat",states:["1-9","NUMBER_AFTER_NON_ZERO"]}],NUMBER_AFTER_ZERO:[{id:"_concat",states:["x","NUMBER_BASE_16"]},{id:"_jump",states:["NUMBER_AFTER_NON_ZERO"]},{id:"_null",states:["NULL"],overwrite:!0}],NUMBER_BASE_16:[{id:"_concat",states:["0-9a-fA-F","NUMBER_BASE_16-AFTER"]}],"NUMBER_BASE_16-AFTER":[{id:"_concat",states:["0-9a-fA-F","NUMBER_BASE_16-AFTER"]},{id:"_null",states:["NULL"],overwrite:!0}],NUMBER_AFTER_NON_ZERO:[{id:"_concat",states:[".","NUMBER_AFTER_DOT"]},{id:"_concat",states:["0-9","NUMBER_AFTER_NON_ZERO"]},{id:"_null",states:["NULL"],overwrite:!0}],NUMBER_AFTER_DOT:[{id:"_concat",states:["NUMBER_AFTER_DOT","0-9"]},{id:"_jump",states:["0-9"]}],VALUE:[{id:"_blank",states:[s_,"VALUE"],overwrite:!0},{id:"_jump",states:["VALUE_NOSPACE"]}],VALUE_NOSPACE:[{id:"_jump",states:["VALUE_NOSPACE",s_]},{id:"var",states:["VARIABLE"]},{id:"str",states:["STRING"]},{id:"num",states:["NUMBER"]},{id:"()",states:["(","COMMA",")"]},{id:"al",states:["[","ARRAY_ITEMS","]"]},{id:"ol",states:["{","OBJECT_ITEMS","}"]}],ARRAY_ITEMS:[{id:"_blank",states:[s_,"ARRAY_ITEMS"],overwrite:!0},{id:"_jump",states:["ARRAY_ITEMS_NOSPACE"]}],ARRAY_ITEMS_NOSPACE:[{id:"_join",states:["ARRAY_ITEMS_NOSPACE",",","ARRAY_ITEM"]},{id:"_jump",states:["ARRAY_ITEM"]},{id:"_empty",states:["NULL"],overwrite:!0}],ARRAY_ITEM:[{id:"_blank",states:[s_,"ARRAY_ITEM"],overwrite:!0},{id:"_jump",states:["ARRAY_ITEM_NOSPACE"]}],ARRAY_ITEM_NOSPACE:[{id:"ai",states:["CONDITIONAL"]},{id:"aie",states:["NULL"],overwrite:!0}],OBJECT_ITEMS:[{id:"_join",states:["OBJECT_ITEMS",",","OBJECT_ITEM_AFTER_COMMA"]},{id:"_jump",states:["OBJECT_ITEM"]},{id:"_empty",states:["NULL"],overwrite:!0}],OBJECT_ITEM_AFTER_COMMA:[{id:"_blank",states:[s_,"OBJECT_ITEM_AFTER_COMMA"],overwrite:!0},{id:"_jump",states:["OBJECT_ITEM"]},{id:"_empty",states:["NULL"],overwrite:!0}],OBJECT_ITEM:[{id:"_blank",states:[s_,"OBJECT_ITEM"],overwrite:!0},{id:"_jump",states:["OBJECT_ITEM_NOSPACE"]}],OBJECT_ITEM_NOSPACE:[{id:"_jump",states:["OBJECT_ITEM_NOSPACE",s_]},{id:"onv",states:["VARIABLE","OBJECT_ITEM_AFTER"]},{id:"ons",states:["STRING","OBJECT_ITEM_AFTER"]},{id:"onn",states:["NUMBER","OBJECT_ITEM_AFTER"]}],OBJECT_ITEM_AFTER:[{id:"_blank",states:[s_,"OBJECT_ITEM_AFTER"],overwrite:!0},{id:"ov",states:[":","CONDITIONAL"]},{id:"_null",states:["NULL"]}],MEMBER:[{id:"_jump",states:["MEMBER",s_]},{id:"_op2",states:["MEMBER",".","VARIABLE_WITH_BLACK"]},{id:"[]",states:["MEMBER","[","CONDITIONAL","]"]},{id:"f()",states:["MEMBER","(","FUNCARGS",")"]},{id:"_jump",states:["VALUE"]}],VARIABLE_WITH_BLACK:[{id:"_blank",states:[s_,"VARIABLE_WITH_BLACK"],overwrite:!0},{id:"_jump",states:["VARIABLE"]}],FUNCARGS:[{id:"_blank",states:[s_,"FUNCARGS"],overwrite:!0},{id:"_join",states:["FUNCARGS",",","CONDITIONAL"]},{id:"fa",states:["CONDITIONAL"]},{id:"_empty",states:["NULL"],overwrite:!0}],LOGICAL:[{id:"_blank",states:[s_,"LOGICAL"],overwrite:!0},{id:"_jump",states:["LOGICAL_NOSPACE"]}],LOGICAL_NOSPACE:[{id:"!",states:["!","LOGICAL"]},{id:"!",states:["+","LOGICAL"]},{id:"!",states:["-","LOGICAL"]},{id:"_jump",states:["MEMBER"]}],MULTIPLY:[{id:"_op2",states:["MULTIPLY","*","LOGICAL"]},{id:"_op2",states:["MULTIPLY","/","LOGICAL"]},{id:"_op2",states:["MULTIPLY","%","LOGICAL"]},{id:"_jump",states:["LOGICAL"]}],ADDITION:[{id:"_op2",states:["ADDITION","+","MULTIPLY"]},{id:"_op2",states:["ADDITION","-","MULTIPLY"]},{id:"_jump",states:["MULTIPLY"]}],COMPARISON:[{id:"<>",states:["COMPARISON","<","COMPARISON_AFTER"]},{id:"<>",states:["COMPARISON",">","COMPARISON_AFTER"]},{id:"_jump",states:["ADDITION"]}],COMPARISON_AFTER:[{id:"a=",states:["=","ADDITION"]},{id:"_jump",states:["ADDITION"]}],EQUALITY:[{id:"=!",states:["EQUALITY","=","=","EQUALITY_AFTER"]},{id:"=!",states:["EQUALITY","!","=","EQUALITY_AFTER"]},{id:"_jump",states:["COMPARISON"]}],EQUALITY_AFTER:[{id:"a=",states:["=","COMPARISON"]},{id:"_jump",states:["COMPARISON"]}],LOGICAL_AND:[{id:"&&||",states:["LOGICAL_AND","&","&","EQUALITY"]},{id:"_jump",states:["EQUALITY"]}],LOGICAL_OR:[{id:"&&||",states:["LOGICAL_OR","|","|","LOGICAL_AND"]},{id:"_jump",states:["LOGICAL_AND"]}],CONDITIONAL:[{id:"?",states:["LOGICAL_OR","CONDITIONAL_AFTER"]}],CONDITIONAL_AFTER:[{id:"?:",states:["?","LOGICAL_OR",":","CONDITIONAL"]},{id:"_null",states:["NULL"]}],COMMA:[{id:",",states:["COMMA",",","CONDITIONAL"]},{id:"_jump",states:["CONDITIONAL"]}]},$2:{_null:function(e){},_empty:function(e){return[]},_jump:function(e){return e[0]},_concat:function(e){return(e[0]||"")+(e[1]||"")},_blank:function(e){return e[1]},"str^":function(e){return e[1]},str$:function(e){return""},"str\\":function(e){if(!Vf[e[1]])throw new Error('String escaping "\\'+e[1]+'" is currently not supported.');return Vf[e[1]]+e[2]},var:function(e){return{p:"var",v:e[0]}},str:function(e){return{p:"str",v:e[0]}},num:function(e){return{p:"num",v:Number(e[0])}},"()":function(e){return{p:"()",v:e[1]}},al:function(e){return e[1].forEach((function(t,r){null===t&&(r!==e[1].length-1?e[1][r]={p:"var",v:"undefined"}:e[1].pop())})),{p:"arr",v:e[1]}},ai:function(e){return[e[0]]},aie:function(e){return[null]},_join:function(e){return e[0].concat(e[2])},ol:function(e){for(var t={},r=e[1],n=0;n<r.length;n++)t[r[n].n]=r[n].v;return{p:"obj",v:t}},onv:function(e){return[{n:e[0],v:e[1]||{p:"var",v:e[0]}}]},ons:function(e){return[{n:e[0],v:e[1]||{p:"str",v:e[0]}}]},onn:function(e){return[{n:e[0],v:e[1]||{p:"num",v:Number(e[0])}}]},ov:function(e){return e[1]},"!":function(e){return{p:e[0]+"n",v:e[1]}},_op1:function(e){return{p:e[0],v:e[1]}},_op2:function(e){return{p:e[1],v:[e[0],e[2]]}},"f()":function(e){return{p:"f()",v:[e[0],e[2]]}},fa:function(e){return[e[0]]},"[]":function(e){return{p:"[]",v:[e[0],e[2]]}},"<>":function(e){return"a="===e[2].p?{p:e[1]+"=",v:[e[0],e[2].v]}:{p:e[1],v:[e[0],e[2]]}},"a=":function(e){return{p:"a=",v:e[1]}},"=!":function(e){return"a="===e[3].p?{p:e[1]+"==",v:[e[0],e[3].v]}:{p:e[1]+"=",v:[e[0],e[3]]}},"&&||":function(e){return{p:e[1]+e[2],v:[e[0],e[3]]}},"?":function(e){return e[1]?{p:"?:",v:[e[0],e[1][0],e[1][1]]}:e[0]},"?:":function(e){return[e[1],e[3]]},",":function(e){return{p:",",v:[e[0],e[2]]}}}},c_=function(){function e(){}return e.parse=function(t){return e.r||(e.r=Ms.create(u_.$1,u_.$2)),e.r.parse("COMMA",t)},e.stringify=function(e,t){return"("+function e(r){var n=[];switch(r.p){case"var":return 0<=l_.indexOf(r.v)?r.v:0<=t.indexOf(r.v)?Hf+"."+r.v:Gf+"."+r.v;case"str":return'"'+r.v.replace(Yf,(function(e){return"\\"+zf[e]}))+'"';case"num":return r.v;case"arr":return r.v.forEach((function(t){n.push(e(t))})),"["+n.join(",")+"]";case"obj":for(var i in r.v){var o='"'+i.replace(Yf,(function(e){return"\\"+zf[e]}))+'"';n.push(o+":"+e(r.v[i]))}return"{"+n.join(",")+"}";case"()":return"("+e(r.v)+")";case".":return Df+"("+e(r.v[0])+',"'+r.v[1]+'")';case"[]":return Df+"("+e(r.v[0])+","+e(r.v[1])+")";case"f()":if("var"!==r.v[0].p)throw new Error("The function name could only be a variable identifier.");return r.v[1].forEach((function(t){n.push(e(t))})),Bf+"("+Uf+","+Ff+',"'+r.v[0].v+'",['+n.join(",")+"])";case"!n":case"+n":case"-n":return"("+r.p[0]+e(r.v)+")";case"+":case"-":case"*":case"/":case"%":case">":case"<":case">=":case"<=":case"==":case"!=":case"===":case"!==":case"&&":case"||":case",":return e(r.v[0])+r.p+e(r.v[1]);case"?:":return e(r.v[0])+"?"+e(r.v[1])+":"+e(r.v[2]);default:throw new Error("The AST is illegal.")}}(e)+")"},e.lvalueStringify=function(t,r){for(var n=[],i=t;i;){if("var"===i.p)return 0<=l_.indexOf(i.v)?null:0<=r.indexOf(i.v)?'["'+i.v+'",'+n.join(",")+"]":"[null,"+n.join(",")+"]";if("."!==i.p)if("[]"!==i.p){if("()"!==i.p)return null;i=i.v}else n.unshift(e.stringify(i.v[1],r)),i=i.v[0];else n.unshift('"'+i.v[1]+'"'),i=i.v[0]}return null},e.searchBindingPaths=function(t,r){var n=[],i="",o=function t(o,a,s){if(s>1)throw new Error("Dynamical binding paths are not supported.");switch(o.p){case"var":if(a){if(l_.indexOf(o.v)>=0)return;return r.indexOf(o.v)>=0?['"'+o.v+'"']:['null,"'+o.v+'"']}if(s>=1)throw new Error("Dynamical binding paths are not supported.");if(0<=l_.indexOf(o.v))return;return void(r.indexOf(o.v)>=0?n.push('["'+o.v+'"]'):n.push('[null,"'+o.v+'"]'));case"str":case"num":case"arr":case"obj":return;case"()":return t(o.v,a,s);case".":if(a){if(!(i=t(o.v[0],!0,s)))return;return i.push('"'+o.v[1]+'"'),i}if(!(i=t(o.v[0],!0,s+1)))return;return i.push('"'+o.v[1]+'"'),void n.push("["+i.join(",")+"]");case"[]":if(a){if(!(i=t(o.v[0],!0,s)))return;return t(o.v[1],!0,s),i.push(e.lvalueStringify(o.v[1])),i}if(!(i=t(o.v[0],!0,s+1)))return;return t(o.v[1],!0,s+1),i.push(e.lvalueStringify(o.v[1])),void n.push("["+i.join(",")+"]");case"f()":return t(o.v[0],!1,s),void o.v[1].forEach((function(e){t(e,!1,s)}));case"!n":case"+n":case"-n":return void t(o.v,!1,s);case"+":case"-":case"*":case"/":case"%":case">":case"<":case">=":case"<=":case"==":case"!=":case"===":case"!==":case"&&":case"||":case",":return t(o.v[0],!1,s),void t(o.v[1],!1,s);case"?:":return t(o.v[0],!1,s),t(o.v[1],!1,s),void t(o.v[2],!1,s);default:throw new Error("The AST is illegal.")}};return t.forEach((function(e){o(e,!1,0)})),"["+n.join(",")+"]"},e}(),d_=Gf+","+Hf+","+Uf,f_={requireBlock:!0,precompile:function(e,t,r){if("else"===e)return{s:[],d:"true"};var n=t.match(/^\{\{(.+)\}\}$/);if(!n)throw new Error("Illegal expression is found in dd:"+e+".");var i=c_.parse(n[1]),o=c_.searchBindingPaths([i],r);return{s:[],d:"function("+d_+"){return "+c_.stringify(i,r)+"}",b:o}},register:function(e,t,r){},create:function(e,t,r,n,i,o,a,s,l,u,c){var d=l.createVirtualNode("dd:"+e);d.__ddIfCondValue=!0,d.__ddIfNextNode=null,d.__ddIfHasTrueCond=!0;var f=null;"if"!==e&&(f=c.childNodes[c.childNodes.length-1])&&("dd:if"!==f.is&&"dd:elif"!==f.is?f=null:f.__ddIfNextNode=d),r.id&&(d.id=r.id);var _=d.__ddIfUpdateNode=function(){var e=d.__ddIfCondValue;if(f&&f.__ddIfHasTrueCond&&(e=!0),e&&!d.childNodes.length){var t=cf.proxyTopScope(o),c=cf.proxySubScopes(a);d.__ddTopScope=t,d.__ddSubScopes=c,u(r.c,l,d,n,i,t,c,s)}else if(!e&&d.childNodes.length){for(var _ in cf.removeBindingsForScope(d.__ddTopScope),d.__ddSubScopes)cf.removeBindingsForScope(d.__ddSubScopes[_]);for(;d.childNodes.length;)d.removeChild(d.childNodes[0])}d.__ddIfNextNode&&d.__ddIfNextNode.__ddIfUpdateNode()};function p(e){d.__ddIfCondValue=!!e,d.__ddIfHasTrueCond=d.__ddIfCondValue||f&&f.__ddIfHasTrueCond,_()}return"else"===e?p(!0):(cf.addBindings(o,a,t.b,d,{e:t.d,o:function(e,t,r){p(r)}}),p(t.d(n,i,null))),d}},__=Gf+","+Hf+","+Uf,p_={requireBlock:!0,addDefaultAttrs:[{n:"wx:for-index",v:"index"},{n:"wx:for-item",v:"item"}],precompile:function(e,t,r){var n=t.match(/^\{\{(.+)\}\}$/);if(!n)throw new Error("Illegal expression is found in wx:for.");var i=c_.parse(n[1]),o=c_.lvalueStringify(i,r),a=c_.searchBindingPaths([i],r);return{s:[],d:"function("+__+"){return "+c_.stringify(i,r)+"}",l:o,b:a}},register:function(e,t,r){},create:function(e,t,r,n,i,o,a,s,l,u){var c=r._ddForIndex||"index",d=r._ddForItem||"item",f=r._ddKey,_=l.createVirtualNode("wx:for:list");function p(e,t,n,i,f){var p=l.createVirtualNode("wx:for:item"),h=cf.proxyTopScope(o),v=cf.proxySubScopes(a);p.__ddTopScope=h,p.__ddSubScopes=v,p.__ddForToRemove=!1,p.__ddForKeyStr="";var m=cf.create(c,h,v,null,null,[]),g=cf.create(d,h,v,null,[n],[]);return v[c]=m,v[d]=g,t[c]=n,t[d]=i,u(r.c,l,p,e,t,h,v,s),void 0===f?_.appendChild(p):_.insertBefore(p,f),p}function h(e){for(var t in _.__ddSubScopes,cf.removeBindingsForScope(e.__ddTopScope),_.__ddSubScopes)cf.removeBindingsForScope(e.__ddSubScopes[t]);_.removeChild(e)}r.id&&(_.id=r.id),cf.create("",o,a,(function(e,r,n){var i=t.d(e,r,null);return v(i,e,r,n),i}),t.l,t.b);var v=function(e,t,r,i){var o="",a=e;"object"==Xs(e)&&null!==e||(a=[]);var s={};for(o in r)s[o]=r[o];var l,u,v,m,g,y,b=0;if(f){var E=[],w=e instanceof Array,O=[];if(!w){var A=a;for(o in a=[],A)a.push(A[o]),O.push(o)}for(b=0;b<a.length;b++)E.push(String(a[b][f]));if(0===a.length)for(;_.childNodes.length;)h(_.childNodes[0]);else{var C=Object.create(null),S=Object.create(null),T=_.childNodes,N=null,x="";for(b=0;b<T.length;b++)0<=C[x=(N=T[b]).__ddForKeyStr]?(h(N),b--):(C[x]=b,(S[x]=N).__ddForToRemove=!0);var I=-1,R=0,L=1,M=[];for(0<=(R=C[a[0][f]])||(R=-1),T[R]&&(T[R].__ddForToRemove=!1),b=1;b<a.length;b++)0<=(L=C[a[b][f]])&&(I<R&&(R<L||L<I)&&(M.push(T[R]),I=R),T[R=L]&&(T[R].__ddForToRemove=!1));for(I<R&&M.push(T[R]),b=0;b<T.length;b++)(N=T[b]).__ddForToRemove&&(h(N),b--);var k=M.shift(),P=0;for(b=0;b<a.length;b++){var j=a[b],D=S[j[f]];if(S[j[f]]=null,D){var B=!0;if(D===k){for(;T[P]!==k;)P++;P++,k=M.shift(),B=!1}(function(e,t,r,i,o,a){var s=e.__ddSubScopes[d];cf.updateLvaluePath(s,[i]),o&&(a?_.insertBefore(e,a):_.appendChild(e));var l=e.__ddSubScopes[c];r[c]=i,cf.updateBinding(l,[],n,r,t)})(N=D,i,s,w?b:O[b],B,T[P]),B&&T[P]===N&&P++,l=N,u=[],v=t,m=s,g=a[b],y=i,m[d]=g,cf.updateBinding(l.__ddSubScopes[d],u,v,m,y)}else N=p(t,s,w?b:O[b],a[b],T[P]),P++,N.__ddForKeyStr=String(j[f])}}}else{for(;_.childNodes.length;)h(_.childNodes[0]);if(e instanceof Array)for(b=0;b<a.length;b++)p(t,s,b,a[b]);else for(o in a)p(t,s,o,a[o])}};return v(t.d(n,i,null),n,i,null),_}},h_={attachedToBlock:"for",precompile:function(e,t,r){var n=t.match(/^\s*([$_a-zA-Z][$_a-zA-Z0-9]*)\s*$/);if(!n)throw new Error("Illegal variable name is found in wx:for-item.");return{s:[n[1]],d:'"'+n[1]+'"'}},register:function(e,t,r){r._ddForItem=t.d},create:function(){}},v_={attachedToBlock:"for",precompile:function(e,t,r){var n=t.match(/^\s*([$_a-zA-Z][$_a-zA-Z0-9]*)\s*$/);if(!n)throw new Error("Illegal variable name is found in wx:for-index.");return{s:[n[1]],d:'"'+n[1]+'"'}},register:function(e,t,r){r._wxForIndex=t.d},create:function(){}},m_={attachedToBlock:!0,precompile:function(e,t,r){var n=t.match(/^\s*([$_a-zA-Z][$_a-zA-Z0-9]*)\s*$/);if(!n)throw new Error("Illegal variable name is found in wx:for-key.");return{s:[],d:'"'+n[1]+'"'}},register:function(e,t,r){r._ddKey=t.d},create:function(){}},g_=Gf+","+Hf+","+Uf,y_={requireBlock:!0,precompile:function(e,t,r){var n=t.match(/^\{\{\s*([$_a-zA-Z][$_a-zA-Z0-9]*)\s*=(.+)\}\}$/);if(!n)throw new Error("Illegal expression is found in wx:alias.");var i=n[1],o=c_.parse(n[2]),a=c_.lvalueStringify(o,r),s=c_.searchBindingPaths([o],r);return{s:[i],d:"function("+g_+"){return "+c_.stringify(o,r)+"}",l:a,b:s}},register:function(e,t,r){},create:function(e,t,r,n,i,o,a,s,l,u){var c=t.s[0],d=cf.create(c,o,a,t.d,t.l,t.b),f={},_="";for(_ in a)f[_]=a[_];f[c]=d;var p={};for(_ in i)p[_]=i[_];p[c]=t.d(n,i,null);var h=l.createVirtualNode("wx:alias");return r.id&&(h.id=r.id),u(r.c,l,h,n,p,o,f,s),h}},b_={if:f_,elif:f_,else:f_,for:p_,key:m_,"for-index":v_,"for-item":h_,alias:y_},E_=Gf+","+Hf+","+Uf,w_=Df+","+Bf+","+Ff,O_=function(){function e(){}return e.toUpperCase=function(e){return e.replace(/-([a-z])/g,(function(e,t){return t.toUpperCase()}))},e.addBackSlashToSign=function(e){return'"'+e.replace(Yf,(function(e){return"\\"+zf[e]}))+'"'},e.formatToArrayStr=function(e){return"["+e.join(",")+"]"},e.formatToObjStr=function(e){var t=[];for(var r in e)void 0!==e[r]&&(/^[_a-z]+$/i.test(r)?t.push(r+":"+e[r]):t.push(this.addBackSlashToSign(r)+":"+e[r]));return"{"+t.join(",")+"}"},e.parseDynamicValue=function(e,t){for(var r=e.split(/\{\{(.*?)\}\}/),n=[],i=[],o=null,a=0;a<r.length;a++){var s=r[a];if(a%2){var l=c_.parse(s);o=c_.lvalueStringify(l,t),n.push(c_.stringify(l,t)),i.push(l)}else n.push(this.addBackSlashToSign(s))}if(1===n.length)return{c:n[0]};var u=c_.searchBindingPaths(i,t);return'""'===n[n.length-1]&&n.pop(),2===n.length&&'""'===n[0]?{c:void 0,e:"function("+E_+"){return "+n[1]+"}",l:o,b:u}:{c:void 0,e:"function("+E_+"){return "+n.join("+")+"}",l:void 0,b:u}},e.format=function(e,t){for(var r=[],n=0;n<e.length;n++){var i=e[n];if(3!==i.t){var o={t:1,n:'"'+i.n+'"',g:void 0,v:void 0,id:void 0,cl:void 0,cpf:void 0,st:void 0,sl:void 0,sn:void 0,a:"",c:""},a=i.c;"slot"===i.n?(o.v=!0,o.sn='""',a=[]):"block"!==i.n&&"virtual"!==i.n||(o.v=!0);var s=i.a;if(s){for(var l=0,u=[],c=[],d=null,f=Object.create(null),_=Object.create(null),p=Object.create(null),h=!1,v=!1,m=!1,g=!1,y=0;y<s.length;y++){var b=s[y],E=b.n;if(!f[E]){f[E]=!0;var w=null;if("id"===E)o.id=this.addBackSlashToSign(b.v);else if("class"===E||"class$"===E||"class:"===E)(w=this.parseDynamicValue(b.v,t)).e&&(h=!0),o.cl=this.formatToObjStr({v:w.c,e:w.e,l:void 0,b:w.b});else if("style"===E||"style$"===E||"style:"===E)(w=this.parseDynamicValue(b.v,t)).e&&(v=!0),o.st=this.formatToObjStr({v:w.c,e:w.e,l:void 0,b:w.b});else if("slot"===E)o.sl=this.addBackSlashToSign(b.v);else if("name"===E&&"slot"===i.n)o.sn=this.addBackSlashToSign(b.v);else if("generic:"===E.slice(0,8))o.g="",_[E.slice(8)]=this.addBackSlashToSign(b.v);else if("filter:"===E.slice(0,7))o.cpf="",p[E.slice(7)]=this.addBackSlashToSign(b.v);else if("wx:"===E.slice(0,3)||"dd:"===E.slice(0,3)){var O=E.slice(3);if(!Object.prototype.hasOwnProperty.call(b_,O))throw new Error('Directive "'+O+'" is not found.');var A=b_[O].precompile(O,b.v,t);l+=A.s.length,t=t.concat(A.s);var C=this.formatToObjStr({s:JSON.stringify(A.s),n:'"'+O+'"',d:A.d,l:A.l,b:A.b}),S=b_[O].addDefaultAttrs;if(S&&s.push.apply(s,S),b_[O].attachedToBlock)u.push(C);else if(b_[O].requireBlock){if(null!==d)throw new Error("Uncompatible directives are used in a single element.");d=C}else c.push(C)}else{var T={n:'"'+b.n+'"',v:this.addBackSlashToSign(b.v),o:void 0,e:void 0,l:void 0,b:void 0};if("$"===E.slice(-1)?(T.o='"$"',T.n='"'+E.slice(0,-1)+'"'):":"===E.slice(-1)?(T.o='":"',T.n='"'+this.toUpperCase(E.slice(0,-1))+'"'):"&"===E.slice(-1)?(T.o='"&"',T.n='"'+this.toUpperCase(E.slice(0,-1))+'"'):"class."===E.slice(0,6)?(T.o='"c"',T.n='"'+E.slice(6)+'"',g=!0):"style."===E.slice(0,6)?(T.o='"s"',T.n='"'+E.slice(6)+'"',m=!0):"data-"===E.slice(0,5)&&(T.o='"d"',T.n='"'+this.toUpperCase(E.slice(5))+'"',g=!0),"id"===T.n||"slot"===T.n)throw new Error('"id" and "slot" do not support dynamic binding symbol.');w=this.parseDynamicValue(b.v,t),T.v=w.c,T.e=w.e,T.l=w.l,T.b=w.b,c.push(this.formatToObjStr(T))}}}if(h&&g)throw new Error("Class bindings cannot be used with dynamic class property.");if(v&&m)throw new Error("Style bindings cannot be used with dynamic style property.");o.a=this.formatToArrayStr(c),o.c=this.format(a,t),""===o.g&&(o.g=this.formatToObjStr(_)),""===o.cpf&&(o.cpf=this.formatToObjStr(p)),d?'"block"'===o.n&&"[]"===o.a?(o.a="["+u.concat(d).join(",")+"]",r.push(this.formatToObjStr(o))):r.push(this.formatToObjStr({t:1,n:'"block"',v:!0,a:"["+u.concat(d).join(",")+"]",c:"["+this.formatToObjStr(o)+"]"})):r.push(this.formatToObjStr(o)),t.splice(t.length-l,l)}}else{var N=this.parseDynamicValue(i.c,t);N.t=3,N.l=void 0,N.c=N.c||'""',r.push(this.formatToObjStr(N))}}return this.formatToArrayStr(r)},e.compile=function(t){var r=a_.parse(t),n=e.format(r,[]);return"function("+w_+"){return "+n+"}"},e}();function A_(e){return e.replace(/-([a-z])/g,(function(e,t){return t.toUpperCase()}))}function C_(e,t){if(null!==e&&"object"===Xs(e)&&Object.prototype.hasOwnProperty.call(e,t))return e[t]}function S_(e,t,r){e[t]=r}function T_(e,t,r){var n=e.__dataProxy;n.scheduleReplace([t],r),n.doUpdates()}function N_(e,t,r,n){if(void 0===n&&(n=[]),Object.prototype.hasOwnProperty.call(t,r)){var i=t[r];if(rl(i))return hl.safeCallback("Template Method",i,e,n)}}function x_(e,t,r){e.setAttribute("style",r)}function I_(e,t,r){e.class=r}function R_(e,t,r){e.setAttribute("class",r)}function L_(e,t,r){e.textContent=r}function M_(e,t,r){e.dataset||(e.dataset={}),e.dataset[t]=r}function k_(e,t,r){e.classList.toggle(t,!!r)}function P_(){return[{t:1,n:"slot",v:!0,sn:"",a:[],c:[]}]}function j_(){return[{t:1,n:"slot",a:[],c:[],p:null}]}var D_={t:1,n:'"slot"',v:!0,sn:"",a:[],c:[],p:null},B_={$:function(e,t,r){!0===r?e.setAttribute(t,""):!1===r||null==r?e.removeAttribute(t):e.setAttribute(t,r)},":":S_,c:k_,s:function(e,t,r){e.style&&(e.style[t]=r)},d:M_};function F_(e,t){return function(r){if(this[e](r),t)return!1}}function U_(e,t,r,n,i,o,a,s){for(var l=null,u=0,c=e;u<c.length;u++){var d=c[u],f=a;if(3===d.t)l=d.e?t.createTextNode(d.e(n,i,null)):t.createTextNode(d.c),d.e&&cf.addBindings(o,a,d.b,l,d),Rd.appendChild(r,l);else{for(var _=d.id,p=d.n,h=d.a,v=d.g,m=d.cl,g=d.st,y=d.cpf,b=!1,E=0,w=h;E<w.length;E++){if((M=w[E]).d&&b_[M.n]){var O=b_[M.n].create(M.n,M,d,n,i,o,f,s,t,U_,r);if(b_[M.n].requireBlock){l=O,Rd.appendChild(r,l),b=!0;break}}}if(b)continue;if(d.v)l=t.createVirtualNode(p);else if(d.p){l=t.cloneNativeNode(d.p);for(var A=0,C=h;A<C.length;A++){(M=C[A]).d||(M.ev?s(l,M.ev,M.v,M.evCatch):M.o===S_?l.__domElement&&(M.o(l.__domElement,M.n,M.e(n,i,null)),cf.addBindings(o,f,M.b,l.__domElement,M)):M.e&&(M.o(l,M.n,M.e(n,i,null)),M.o!==k_&&M.o!==M_||cf.addBindings(o,f,M.b,l,M)))}g&&g.e&&(l.setAttribute("style",g.e(n,i,null)),cf.addBindings(o,f,g.b,l,g))}else{if(y){var S={},T=t.__ddHost,N=void 0,x=void 0;for(N in y)x=y[N],S[N]=T.__behavior.methods[x];t.__childrenPropsFilter=S}l=t.createComponent(p,void 0,v,void 0);for(var I=void 0,R=0,L=h;R<L.length;R++){var M;(M=L[R]).d||(I=M.v,M.o===T_&&Wd.hasPublicProperty(l,M.n)?M.e?(I=M.e(n,i,null),cf.addBindings(o,f,M.b,l,M)):l.__behavior.properties[M.n].type===Boolean?T_(l,M.n,!0):T_(l,M.n,I):M.ev?s(l,M.ev,I,M.evCatch):M.o!==T_&&(M.e&&(I=M.e(n,i,null),cf.addBindings(o,f,M.b,l,M)),M.o(l,M.n,I)))}g&&(g.e?(l.__domElement.setAttribute("style",g.e(n,i,null)),cf.addBindings(o,f,g.b,l.__domElement,g)):l.__domElement.setAttribute("style",g.v))}_&&(l.id=_),m&&(m.e?l.class=m.e(n,i,null):l.class=m.v,m.o&&cf.addBindings(o,f,m.b,l,m)),d.sl&&(l.slot=d.sl),void 0!==d.sn&&Rd.setSlotName(l,d.sn),Rd.appendChild(r,l),U_(d.c,t,l,n,i,o,f,s)}}}function G_(e,t,r){for(var n=e.childNodes,i=0,o=void 0;i<n.length;i++)(o=n[i])instanceof Zd||(o.__id&&(t[o.__id]=o),void 0!==o.__slotName&&(r[o.__slotName]=o),G_(o,t,r))}function H_(e,t,r,n,i,o){for(var a=null,s=0;s<e.length;s++){var l=e[s];if(void 0===l.n)a=document.createTextNode(l.c),l.e&&cf.addBindings(i,o,l.b,a,l),t.appendChild(a);else{var u=l.cl,c=l.st,d=l.a,f=l.id;a=l.v?document.createElement("virtual"):document.importNode?document.importNode(l.p,!1):l.p.cloneNode(!1);for(var _=0,p=d;_<p.length;_++){var h=p[_];h.e&&cf.addBindings(i,o,h.b,a,h)}t.appendChild(a),f&&(r[f]=a),u&&u.e&&cf.addBindings(i,o,u.b,a,u),c&&c.e&&cf.addBindings(i,o,c.b,a,c),void 0!==l.sn&&(n[l.sn]=a),H_(l.c,a,r,n,i,o)}}}var V_=function(){function e(){}return e.prototype.updateValues=function(e,t,r){for(var n=Rd.getMethodCaller(e),i=0,o=r;i<o.length;i++){var a=o[i];cf.updateBinding(this._topScope,a,t,{},n)}},e}(),z_=function(){function e(){}return e.create=function(t,r,n,i){var o=t.template||P_;if(!rl(o)){var a="undefined"!=typeof window&&"undefined"!=typeof document;if(O_&&a){var s="__exparserFreeTmpl",l=O_.compile(o),u=document.createElement("script");u.type="text/javascript",u.innerHTML="window.__exparserFreeTmpl="+l,document.head.appendChild(u),document.head.removeChild(u),o=window[s],window[s]=null}else o=void 0!==lf&&void 0!==lf.versions&&void 0!==lf.versions.node?e.precompileAndGetCreator(o):j_}var c=new e;return c._initValuesJSON=JSON.stringify(n),c._dataJSON=r!==n?JSON.stringify(r):null,c._tagTreeRoot=function(e,t,r,n){var i="native"===n.renderingMode;i&&!qs.hasDOMBackend&&(e=j_);var o=e(C_,N_,r),a=!1,s=Object.create(null);return function e(r){for(var n=0,o=r;n<o.length;n++){var l=o[n];if(3!==l.t){var u=l.n,c=l.st,d=l.cl,f=l.a,_=l.c,p=!(i||el(u)&&u.indexOf("-")<0);"slot"===u&&""===l.sn&&(a=!0),l.n=u,c&&c.e&&(c.o=x_,i&&(c.v=c.e(t,s,null))),d&&d.e&&(d.o=i?R_:I_,i&&(d.v=d.e(t,s,null))),p||(l.p=i?document.createElement(u):Gd.create(u),c&&void 0!==c.v&&l.p.setAttribute("style",c.v),i&&d&&void 0!==d.v&&l.p.setAttribute("class",d.v));for(var h=0,v=f;h<v.length;h++){var m=v[h],g=m.n,y=void 0;m.d?i||b_[g]&&b_[g].register(m.n,m,l):(i||("bind"===g.slice(0,4)?(m.evCatch=!1,m.ev=A_(g.slice(4)),":"===m.ev[0]&&(m.ev=m.ev.slice(1))):"catch"===g.slice(0,5)&&(m.evCatch=!0,m.ev=A_(g.slice(5)),":"===m.ev[0]&&(m.ev=m.ev.slice(1)))),y=m.o,p?(y?m.o="&"===y?B_[":"]:B_[y]:(m.o=B_[":"],m.n=A_(m.n)),m.o===S_&&(m.o=T_),i&&m.e&&(m.v=m.e(t,s,null))):m.ev||(m.o=y?"&"===y?B_[":"]:B_[y]:B_.$,i?(m.e&&(m.v=m.e(t,s,null)),m.o!==k_&&m.o(l.p,m.n,m.v)):m.e||m.o(l.p,m.n,m.v)))}e(_),i&&1===_.length&&void 0!==_[0].sn&&!_[0].compressed&&(l.sn=_[0].sn,l.compressed=!0,_.pop())}else l.e&&(l.o=L_,l.c=i?l.e(t,s,null):"")}}(o),i&&(a||o.push(D_),1!==o.length||""!==o[0].sn||o[0].compressed||o.pop()),o}(o,n,t.methods,i),c._renderingMode=i.renderingMode,c},e.precompileAndGetCreator=function(e){return e},e.prototype.createInstance=function(e){var t,r=new V_,n=JSON.parse(this._initValuesJSON),i=null===this._dataJSON?n:JSON.parse(this._dataJSON),o=Object.create(null),a=Object.create(null),s=[],l=cf.create("",null,null,null,null,[],(function(){}));if("native"===this._renderingMode)"dom"===qs.documentBackend&&(t=document.createDocumentFragment()),H_(this._tagTreeRoot,t,o,a,l,{}),a[""]||(a[""]=null);else{var u=Kd.create(e);if(e.ownerShadowRoot&&e.ownerShadowRoot.__childrenPropsFilter)if(u.__childrenPropsFilter){var c=void 0;for(c in e.ownerShadowRoot.__childrenPropsFilter)u.__childrenPropsFilter[c]||(u.__childrenPropsFilter[c]=e.ownerShadowRoot.__childrenPropsFilter[c])}else u.__childrenPropsFilter=e.ownerShadowRoot.__childrenPropsFilter;U_(this._tagTreeRoot,u,u,n,{},l,{},(function(e,t,r,n){u.__ddHost?e.addListener(t,F_(r,n).bind(u.__ddHost)):s.push({target:e,name:t,func:F_(r,n)})})),G_(u,o,a),t=u}return r.data=i,r.shadowRoot=t,r.idMap=o,r.slots=a,r.listeners=s,r._topScope=l,r},e.precompiler=O_,e.htmlParser=a_,e}();return sl(z_),function(){var e=dl();delete e._list[""],e.register({is:"",options:{writeOnly:!0,allowInWriteOnly:!0,lazyRegistration:!1,classPrefix:"",addGlobalClass:!1,templateEngine:null,renderingMode:"full",multipleSlots:!1,reflectToAttributes:!1}})}(),{precompileTemplate:z_.precompiler?z_.precompiler.compile:null,precompiler:z_.precompiler?z_.precompiler:null,HtmlLLParser:z_.htmlParser?z_.htmlParser:null,LLParser:Ms,dataPath:Zc,dataUtils:mu,Event:Ou,EventBus:hl,Element:Rd,TextNode:Zd,NativeNode:Gd,VirtualNode:Jd,ShadowRoot:Kd,Behavior:ad,Component:Wd,Observer:ld,DataGroup:jd,ElementIterator:qd,FakeDomElement:ud,registerBehavior:ad.create,registerElement:Wd.register,createElement:Wd.create,createTextNode:Zd.create,createVirtualNode:Jd.create,appendChild:Rd.appendChild,insertBefore:Rd.insertBefore,removeChild:Rd.removeChild,replaceChild:Rd.replaceChild,addListenerToElement:Ou.addListenerToElement,removeListenerFromElement:Ou.removeListenerFromElement,triggerEvent:Ou.triggerEvent,safeCallback:hl.safeCallback,addGlobalErrorListener:hl.addGlobalErrorListener,removeGlobalErrorListener:hl.removeGlobalErrorListener,globalState:Id,globalOptions:qs}}();

!function(t){"function"==typeof define&&define.amd?define(t):t()}((function(){"use strict";var t={is:"dd-view",options:{renderingMode:"full"},template:function(t,n,e){return[{t:1,n:"slot",v:!0,sn:"",a:[],c:[]}]},properties:{hoverClass:String},listeners:{"this.touchstart":function(){this.hoverStart()},"this.touchend":function(){this.hoverEnd()},"this.canceltap":function(){this.hoverEnd()}},methods:{hoverStart:function(){},hoverEnd:function(){}}};exparser.registerElement(t)}));

exparser.globalOptions.renderingMode = 'full';
exparser.globalState.enableBackendExtractedDefault();

var __virtualDOMDataThread__ = true;
var __virtualDOMTunnelPrintLog__ = false;
var __virtualDOM__=function(){"use strict";var e="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function t(e,t,r){return e(r={path:t,exports:{},require:function(e,t){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==t&&r.path)}},r.exports),r.exports}var r,n,o=function(e){return e&&e.Math==Math&&e},i=o("object"==typeof globalThis&&globalThis)||o("object"==typeof window&&window)||o("object"==typeof self&&self)||o("object"==typeof e&&e)||function(){return this}()||Function("return this")(),a=function(e){try{return!!e()}catch(e){return!0}},s=!a((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),u=!a((function(){var e=function(){}.bind();return"function"!=typeof e||e.hasOwnProperty("prototype")})),l=Function.prototype.call,c=u?l.bind(l):function(){return l.apply(l,arguments)},d={}.propertyIsEnumerable,f=Object.getOwnPropertyDescriptor,p={f:f&&!d.call({1:2},1)?function(e){var t=f(this,e);return!!t&&t.enumerable}:d},_=function(e,t){return{enumerable:!(1&e),configurable:!(2&e),writable:!(4&e),value:t}},h=Function.prototype,v=h.bind,g=h.call,E=u&&v.bind(g,g),m=u?function(e){return e&&E(e)}:function(e){return e&&function(){return g.apply(e,arguments)}},y=m({}.toString),N=m("".slice),b=function(e){return N(y(e),8,-1)},w=i.Object,C=m("".split),A=a((function(){return!w("z").propertyIsEnumerable(0)}))?function(e){return"String"==b(e)?C(e,""):w(e)}:w,S=i.TypeError,T=function(e){if(null==e)throw S("Can't call method on "+e);return e},O=function(e){return A(T(e))},I=function(e){return"function"==typeof e},x=function(e){return"object"==typeof e?null!==e:I(e)},D=function(e){return I(e)?e:void 0},M=function(e,t){return arguments.length<2?D(i[e]):i[e]&&i[e][t]},L=m({}.isPrototypeOf),R=M("navigator","userAgent")||"",P=i.process,F=i.Deno,V=P&&P.versions||F&&F.version,k=V&&V.v8;k&&(n=(r=k.split("."))[0]>0&&r[0]<4?1:+(r[0]+r[1])),!n&&R&&(!(r=R.match(/Edge\/(\d+)/))||r[1]>=74)&&(r=R.match(/Chrome\/(\d+)/))&&(n=+r[1]);var j=n,Y=!!Object.getOwnPropertySymbols&&!a((function(){var e=Symbol();return!String(e)||!(Object(e)instanceof Symbol)||!Symbol.sham&&j&&j<41})),W=Y&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,B=i.Object,H=W?function(e){return"symbol"==typeof e}:function(e){var t=M("Symbol");return I(t)&&L(t.prototype,B(e))},U=i.String,G=function(e){try{return U(e)}catch(e){return"Object"}},z=i.TypeError,$=function(e){if(I(e))return e;throw z(G(e)+" is not a function")},q=function(e,t){var r=e[t];return null==r?void 0:$(r)},X=i.TypeError,K=Object.defineProperty,Q=function(e,t){try{K(i,e,{value:t,configurable:!0,writable:!0})}catch(r){i[e]=t}return t},Z="__core-js_shared__",J=i[Z]||Q(Z,{}),ee=t((function(e){(e.exports=function(e,t){return J[e]||(J[e]=void 0!==t?t:{})})("versions",[]).push({version:"3.21.1",mode:"global",copyright:"© 2014-2022 Denis Pushkarev (zloirock.ru)",license:"https://github.com/zloirock/core-js/blob/v3.21.1/LICENSE",source:"https://github.com/zloirock/core-js"})})),te=i.Object,re=function(e){return te(T(e))},ne=m({}.hasOwnProperty),oe=Object.hasOwn||function(e,t){return ne(re(e),t)},ie=0,ae=Math.random(),se=m(1..toString),ue=function(e){return"Symbol("+(void 0===e?"":e)+")_"+se(++ie+ae,36)},le=ee("wks"),ce=i.Symbol,de=ce&&ce.for,fe=W?ce:ce&&ce.withoutSetter||ue,pe=function(e){if(!oe(le,e)||!Y&&"string"!=typeof le[e]){var t="Symbol."+e;Y&&oe(ce,e)?le[e]=ce[e]:le[e]=W&&de?de(t):fe(t)}return le[e]},_e=i.TypeError,he=pe("toPrimitive"),ve=function(e,t){if(!x(e)||H(e))return e;var r,n=q(e,he);if(n){if(void 0===t&&(t="default"),r=c(n,e,t),!x(r)||H(r))return r;throw _e("Can't convert object to primitive value")}return void 0===t&&(t="number"),function(e,t){var r,n;if("string"===t&&I(r=e.toString)&&!x(n=c(r,e)))return n;if(I(r=e.valueOf)&&!x(n=c(r,e)))return n;if("string"!==t&&I(r=e.toString)&&!x(n=c(r,e)))return n;throw X("Can't convert object to primitive value")}(e,t)},ge=function(e){var t=ve(e,"string");return H(t)?t:t+""},Ee=i.document,me=x(Ee)&&x(Ee.createElement),ye=function(e){return me?Ee.createElement(e):{}},Ne=!s&&!a((function(){return 7!=Object.defineProperty(ye("div"),"a",{get:function(){return 7}}).a})),be=Object.getOwnPropertyDescriptor,we={f:s?be:function(e,t){if(e=O(e),t=ge(t),Ne)try{return be(e,t)}catch(e){}if(oe(e,t))return _(!c(p.f,e,t),e[t])}},Ce=s&&a((function(){return 42!=Object.defineProperty((function(){}),"prototype",{value:42,writable:!1}).prototype})),Ae=i.String,Se=i.TypeError,Te=function(e){if(x(e))return e;throw Se(Ae(e)+" is not an object")},Oe=i.TypeError,Ie=Object.defineProperty,xe=Object.getOwnPropertyDescriptor,De="enumerable",Me="configurable",Le="writable",Re={f:s?Ce?function(e,t,r){if(Te(e),t=ge(t),Te(r),"function"==typeof e&&"prototype"===t&&"value"in r&&Le in r&&!r.writable){var n=xe(e,t);n&&n.writable&&(e[t]=r.value,r={configurable:Me in r?r.configurable:n.configurable,enumerable:De in r?r.enumerable:n.enumerable,writable:!1})}return Ie(e,t,r)}:Ie:function(e,t,r){if(Te(e),t=ge(t),Te(r),Ne)try{return Ie(e,t,r)}catch(e){}if("get"in r||"set"in r)throw Oe("Accessors not supported");return"value"in r&&(e[t]=r.value),e}},Pe=s?function(e,t,r){return Re.f(e,t,_(1,r))}:function(e,t,r){return e[t]=r,e},Fe=m(Function.toString);I(J.inspectSource)||(J.inspectSource=function(e){return Fe(e)});var Ve,ke,je,Ye=J.inspectSource,We=i.WeakMap,Be=I(We)&&/native code/.test(Ye(We)),He=ee("keys"),Ue=function(e){return He[e]||(He[e]=ue(e))},Ge={},ze="Object already initialized",$e=i.TypeError,qe=i.WeakMap;if(Be||J.state){var Xe=J.state||(J.state=new qe),Ke=m(Xe.get),Qe=m(Xe.has),Ze=m(Xe.set);Ve=function(e,t){if(Qe(Xe,e))throw new $e(ze);return t.facade=e,Ze(Xe,e,t),t},ke=function(e){return Ke(Xe,e)||{}},je=function(e){return Qe(Xe,e)}}else{var Je=Ue("state");Ge[Je]=!0,Ve=function(e,t){if(oe(e,Je))throw new $e(ze);return t.facade=e,Pe(e,Je,t),t},ke=function(e){return oe(e,Je)?e[Je]:{}},je=function(e){return oe(e,Je)}}var et={set:Ve,get:ke,has:je,enforce:function(e){return je(e)?ke(e):Ve(e,{})},getterFor:function(e){return function(t){var r;if(!x(t)||(r=ke(t)).type!==e)throw $e("Incompatible receiver, "+e+" required");return r}}},tt=Function.prototype,rt=s&&Object.getOwnPropertyDescriptor,nt=oe(tt,"name"),ot={EXISTS:nt,PROPER:nt&&"something"===function(){}.name,CONFIGURABLE:nt&&(!s||s&&rt(tt,"name").configurable)},it=t((function(e){var t=ot.CONFIGURABLE,r=et.get,n=et.enforce,o=String(String).split("String");(e.exports=function(e,r,a,s){var u,l=!!s&&!!s.unsafe,c=!!s&&!!s.enumerable,d=!!s&&!!s.noTargetGet,f=s&&void 0!==s.name?s.name:r;I(a)&&("Symbol("===String(f).slice(0,7)&&(f="["+String(f).replace(/^Symbol\(([^)]*)\)/,"$1")+"]"),(!oe(a,"name")||t&&a.name!==f)&&Pe(a,"name",f),(u=n(a)).source||(u.source=o.join("string"==typeof f?f:""))),e!==i?(l?!d&&e[r]&&(c=!0):delete e[r],c?e[r]=a:Pe(e,r,a)):c?e[r]=a:Q(r,a)})(Function.prototype,"toString",(function(){return I(this)&&r(this).source||Ye(this)}))})),at=Math.ceil,st=Math.floor,ut=function(e){var t=+e;return t!=t||0===t?0:(t>0?st:at)(t)},lt=Math.max,ct=Math.min,dt=function(e,t){var r=ut(e);return r<0?lt(r+t,0):ct(r,t)},ft=Math.min,pt=function(e){return e>0?ft(ut(e),9007199254740991):0},_t=function(e){return pt(e.length)},ht=function(e){return function(t,r,n){var o,i=O(t),a=_t(i),s=dt(n,a);if(e&&r!=r){for(;a>s;)if((o=i[s++])!=o)return!0}else for(;a>s;s++)if((e||s in i)&&i[s]===r)return e||s||0;return!e&&-1}},vt={includes:ht(!0),indexOf:ht(!1)},gt=vt.indexOf,Et=m([].push),mt=function(e,t){var r,n=O(e),o=0,i=[];for(r in n)!oe(Ge,r)&&oe(n,r)&&Et(i,r);for(;t.length>o;)oe(n,r=t[o++])&&(~gt(i,r)||Et(i,r));return i},yt=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],Nt=yt.concat("length","prototype"),bt={f:Object.getOwnPropertyNames||function(e){return mt(e,Nt)}},wt={f:Object.getOwnPropertySymbols},Ct=m([].concat),At=M("Reflect","ownKeys")||function(e){var t=bt.f(Te(e)),r=wt.f;return r?Ct(t,r(e)):t},St=function(e,t,r){for(var n=At(t),o=Re.f,i=we.f,a=0;a<n.length;a++){var s=n[a];oe(e,s)||r&&oe(r,s)||o(e,s,i(t,s))}},Tt=/#|\.prototype\./,Ot=function(e,t){var r=xt[It(e)];return r==Mt||r!=Dt&&(I(t)?a(t):!!t)},It=Ot.normalize=function(e){return String(e).replace(Tt,".").toLowerCase()},xt=Ot.data={},Dt=Ot.NATIVE="N",Mt=Ot.POLYFILL="P",Lt=Ot,Rt=we.f,Pt=function(e,t){var r,n,o,a,s,u=e.target,l=e.global,c=e.stat;if(r=l?i:c?i[u]||Q(u,{}):(i[u]||{}).prototype)for(n in t){if(a=t[n],o=e.noTargetGet?(s=Rt(r,n))&&s.value:r[n],!Lt(l?n:u+(c?".":"#")+n,e.forced)&&void 0!==o){if(typeof a==typeof o)continue;St(a,o)}(e.sham||o&&o.sham)&&Pe(a,"sham",!0),it(r,n,a,e)}},Ft={};Ft[pe("toStringTag")]="z";var Vt,kt="[object z]"===String(Ft),jt=pe("toStringTag"),Yt=i.Object,Wt="Arguments"==b(function(){return arguments}()),Bt=kt?b:function(e){var t,r,n;return void 0===e?"Undefined":null===e?"Null":"string"==typeof(r=function(e,t){try{return e[t]}catch(e){}}(t=Yt(e),jt))?r:Wt?b(t):"Object"==(n=b(t))&&I(t.callee)?"Arguments":n},Ht=i.String,Ut=function(e){if("Symbol"===Bt(e))throw TypeError("Cannot convert a Symbol value to a string");return Ht(e)},Gt=function(){var e=Te(this),t="";return e.global&&(t+="g"),e.ignoreCase&&(t+="i"),e.multiline&&(t+="m"),e.dotAll&&(t+="s"),e.unicode&&(t+="u"),e.sticky&&(t+="y"),t},zt=i.RegExp,$t=a((function(){var e=zt("a","y");return e.lastIndex=2,null!=e.exec("abcd")})),qt=$t||a((function(){return!zt("a","y").sticky})),Xt={BROKEN_CARET:$t||a((function(){var e=zt("^r","gy");return e.lastIndex=2,null!=e.exec("str")})),MISSED_STICKY:qt,UNSUPPORTED_Y:$t},Kt=Object.keys||function(e){return mt(e,yt)},Qt=s&&!Ce?Object.defineProperties:function(e,t){Te(e);for(var r,n=O(t),o=Kt(t),i=o.length,a=0;i>a;)Re.f(e,r=o[a++],n[r]);return e},Zt={f:Qt},Jt=M("document","documentElement"),er=Ue("IE_PROTO"),tr=function(){},rr=function(e){return"<script>"+e+"</"+"script>"},nr=function(e){e.write(rr("")),e.close();var t=e.parentWindow.Object;return e=null,t},or=function(){try{Vt=new ActiveXObject("htmlfile")}catch(e){}var e,t;or="undefined"!=typeof document?document.domain&&Vt?nr(Vt):((t=ye("iframe")).style.display="none",Jt.appendChild(t),t.src=String("javascript:"),(e=t.contentWindow.document).open(),e.write(rr("document.F=Object")),e.close(),e.F):nr(Vt);for(var r=yt.length;r--;)delete or.prototype[yt[r]];return or()};Ge[er]=!0;var ir=Object.create||function(e,t){var r;return null!==e?(tr.prototype=Te(e),r=new tr,tr.prototype=null,r[er]=e):r=or(),void 0===t?r:Zt.f(r,t)},ar=i.RegExp,sr=a((function(){var e=ar(".","s");return!(e.dotAll&&e.exec("\n")&&"s"===e.flags)})),ur=i.RegExp,lr=a((function(){var e=ur("(?<a>b)","g");return"b"!==e.exec("b").groups.a||"bc"!=="b".replace(e,"$<a>c")})),cr=et.get,dr=ee("native-string-replace",String.prototype.replace),fr=RegExp.prototype.exec,pr=fr,_r=m("".charAt),hr=m("".indexOf),vr=m("".replace),gr=m("".slice),Er=function(){var e=/a/,t=/b*/g;return c(fr,e,"a"),c(fr,t,"a"),0!==e.lastIndex||0!==t.lastIndex}(),mr=Xt.BROKEN_CARET,yr=void 0!==/()??/.exec("")[1];(Er||yr||mr||sr||lr)&&(pr=function(e){var t,r,n,o,i,a,s,u=this,l=cr(u),d=Ut(e),f=l.raw;if(f)return f.lastIndex=u.lastIndex,t=c(pr,f,d),u.lastIndex=f.lastIndex,t;var p=l.groups,_=mr&&u.sticky,h=c(Gt,u),v=u.source,g=0,E=d;if(_&&(h=vr(h,"y",""),-1===hr(h,"g")&&(h+="g"),E=gr(d,u.lastIndex),u.lastIndex>0&&(!u.multiline||u.multiline&&"\n"!==_r(d,u.lastIndex-1))&&(v="(?: "+v+")",E=" "+E,g++),r=new RegExp("^(?:"+v+")",h)),yr&&(r=new RegExp("^"+v+"$(?!\\s)",h)),Er&&(n=u.lastIndex),o=c(fr,_?r:u,E),_?o?(o.input=gr(o.input,g),o[0]=gr(o[0],g),o.index=u.lastIndex,u.lastIndex+=o[0].length):u.lastIndex=0:Er&&o&&(u.lastIndex=u.global?o.index+o[0].length:n),yr&&o&&o.length>1&&c(dr,o[0],r,(function(){for(i=1;i<arguments.length-2;i++)void 0===arguments[i]&&(o[i]=void 0)})),o&&p)for(o.groups=a=ir(null),i=0;i<p.length;i++)a[(s=p[i])[0]]=o[s[1]];return o});var Nr=pr;Pt({target:"RegExp",proto:!0,forced:/./.exec!==Nr},{exec:Nr});var br=pe("species"),wr=RegExp.prototype,Cr=function(e,t,r,n){var o=pe(e),i=!a((function(){var t={};return t[o]=function(){return 7},7!=""[e](t)})),s=i&&!a((function(){var t=!1,r=/a/;return"split"===e&&((r={}).constructor={},r.constructor[br]=function(){return r},r.flags="",r[o]=/./[o]),r.exec=function(){return t=!0,null},r[o](""),!t}));if(!i||!s||r){var u=m(/./[o]),l=t(o,""[e],(function(e,t,r,n,o){var a=m(e),s=t.exec;return s===Nr||s===wr.exec?i&&!o?{done:!0,value:u(t,r,n)}:{done:!0,value:a(r,t,n)}:{done:!1}}));it(String.prototype,e,l[0]),it(wr,o,l[1])}n&&Pe(wr[o],"sham",!0)},Ar=m("".charAt),Sr=m("".charCodeAt),Tr=m("".slice),Or=function(e){return function(t,r){var n,o,i=Ut(T(t)),a=ut(r),s=i.length;return a<0||a>=s?e?"":void 0:(n=Sr(i,a))<55296||n>56319||a+1===s||(o=Sr(i,a+1))<56320||o>57343?e?Ar(i,a):n:e?Tr(i,a,a+2):o-56320+(n-55296<<10)+65536}},Ir={codeAt:Or(!1),charAt:Or(!0)},xr=Ir.charAt,Dr=function(e,t,r){return t+(r?xr(e,t).length:1)},Mr=i.TypeError,Lr=function(e,t){var r=e.exec;if(I(r)){var n=c(r,e,t);return null!==n&&Te(n),n}if("RegExp"===b(e))return c(Nr,e,t);throw Mr("RegExp#exec called on incompatible receiver")};Cr("match",(function(e,t,r){return[function(t){var r=T(this),n=null==t?void 0:q(t,e);return n?c(n,t,r):new RegExp(t)[e](Ut(r))},function(e){var n=Te(this),o=Ut(e),i=r(t,n,o);if(i.done)return i.value;if(!n.global)return Lr(n,o);var a=n.unicode;n.lastIndex=0;for(var s,u=[],l=0;null!==(s=Lr(n,o));){var c=Ut(s[0]);u[l]=c,""===c&&(n.lastIndex=Dr(o,pt(n.lastIndex),a)),l++}return 0===l?null:u}]}));var Rr=Array.isArray||function(e){return"Array"==b(e)},Pr=function(){},Fr=[],Vr=M("Reflect","construct"),kr=/^\s*(?:class|function)\b/,jr=m(kr.exec),Yr=!kr.exec(Pr),Wr=function(e){if(!I(e))return!1;try{return Vr(Pr,Fr,e),!0}catch(e){return!1}},Br=function(e){if(!I(e))return!1;switch(Bt(e)){case"AsyncFunction":case"GeneratorFunction":case"AsyncGeneratorFunction":return!1}try{return Yr||!!jr(kr,Ye(e))}catch(e){return!0}};Br.sham=!0;var Hr=!Vr||a((function(){var e;return Wr(Wr.call)||!Wr(Object)||!Wr((function(){e=!0}))||e}))?Br:Wr,Ur=function(e,t,r){var n=ge(t);n in e?Re.f(e,n,_(0,r)):e[n]=r},Gr=pe("species"),zr=function(e){return j>=51||!a((function(){var t=[];return(t.constructor={})[Gr]=function(){return{foo:1}},1!==t[e](Boolean).foo}))},$r=m([].slice),qr=zr("slice"),Xr=pe("species"),Kr=i.Array,Qr=Math.max;Pt({target:"Array",proto:!0,forced:!qr},{slice:function(e,t){var r,n,o,i=O(this),a=_t(i),s=dt(e,a),u=dt(void 0===t?a:t,a);if(Rr(i)&&(r=i.constructor,(Hr(r)&&(r===Kr||Rr(r.prototype))||x(r)&&null===(r=r[Xr]))&&(r=void 0),r===Kr||void 0===r))return $r(i,s,u);for(n=new(void 0===r?Kr:r)(Qr(u-s,0)),o=0;s<u;s++,o++)s in i&&Ur(n,o,i[s]);return n.length=o,n}});var Zr=function(e,t){var r=[][e];return!!r&&a((function(){r.call(null,t||function(){return 1},1)}))},Jr=vt.indexOf,en=m([].indexOf),tn=!!en&&1/en([1],1,-0)<0,rn=Zr("indexOf");Pt({target:"Array",proto:!0,forced:tn||!rn},{indexOf:function(e){var t=arguments.length>1?arguments[1]:void 0;return tn?en(this,e,t)||0:Jr(this,e,t)}});var nn=Function.prototype,on=nn.apply,an=nn.call,sn="object"==typeof Reflect&&Reflect.apply||(u?an.bind(on):function(){return an.apply(on,arguments)}),un=pe("match"),ln=function(e){var t;return x(e)&&(void 0!==(t=e[un])?!!t:"RegExp"==b(e))},cn=i.TypeError,dn=pe("species"),fn=function(e,t){var r,n=Te(e).constructor;return void 0===n||null==(r=Te(n)[dn])?t:function(e){if(Hr(e))return e;throw cn(G(e)+" is not a constructor")}(r)},pn=i.Array,_n=Math.max,hn=function(e,t,r){for(var n=_t(e),o=dt(t,n),i=dt(void 0===r?n:r,n),a=pn(_n(i-o,0)),s=0;o<i;o++,s++)Ur(a,s,e[o]);return a.length=s,a},vn=Xt.UNSUPPORTED_Y,gn=4294967295,En=Math.min,mn=[].push,yn=m(/./.exec),Nn=m(mn),bn=m("".slice),wn=!a((function(){var e=/(?:)/,t=e.exec;e.exec=function(){return t.apply(this,arguments)};var r="ab".split(e);return 2!==r.length||"a"!==r[0]||"b"!==r[1]}));Cr("split",(function(e,t,r){var n;return n="c"=="abbc".split(/(b)*/)[1]||4!="test".split(/(?:)/,-1).length||2!="ab".split(/(?:ab)*/).length||4!=".".split(/(.?)(.?)/).length||".".split(/()()/).length>1||"".split(/.?/).length?function(e,r){var n=Ut(T(this)),o=void 0===r?gn:r>>>0;if(0===o)return[];if(void 0===e)return[n];if(!ln(e))return c(t,n,e,o);for(var i,a,s,u=[],l=(e.ignoreCase?"i":"")+(e.multiline?"m":"")+(e.unicode?"u":"")+(e.sticky?"y":""),d=0,f=new RegExp(e.source,l+"g");(i=c(Nr,f,n))&&!((a=f.lastIndex)>d&&(Nn(u,bn(n,d,i.index)),i.length>1&&i.index<n.length&&sn(mn,u,hn(i,1)),s=i[0].length,d=a,u.length>=o));)f.lastIndex===i.index&&f.lastIndex++;return d===n.length?!s&&yn(f,"")||Nn(u,""):Nn(u,bn(n,d)),u.length>o?hn(u,0,o):u}:"0".split(void 0,0).length?function(e,r){return void 0===e&&0===r?[]:c(t,this,e,r)}:t,[function(t,r){var o=T(this),i=null==t?void 0:q(t,e);return i?c(i,t,o,r):c(n,Ut(o),t,r)},function(e,o){var i=Te(this),a=Ut(e),s=r(n,i,a,o,n!==t);if(s.done)return s.value;var u=fn(i,RegExp),l=i.unicode,c=(i.ignoreCase?"i":"")+(i.multiline?"m":"")+(i.unicode?"u":"")+(vn?"g":"y"),d=new u(vn?"^(?:"+i.source+")":i,c),f=void 0===o?gn:o>>>0;if(0===f)return[];if(0===a.length)return null===Lr(d,a)?[a]:[];for(var p=0,_=0,h=[];_<a.length;){d.lastIndex=vn?0:_;var v,g=Lr(d,vn?bn(a,_):a);if(null===g||(v=En(pt(d.lastIndex+(vn?_:0)),a.length))===p)_=Dr(a,_,l);else{if(Nn(h,bn(a,p,_)),h.length===f)return h;for(var E=1;E<=g.length-1;E++)if(Nn(h,g[E]),h.length===f)return h;_=p=v}}return Nn(h,bn(a,p)),h}]}),!wn,vn);var Cn=kt?{}.toString:function(){return"[object "+Bt(this)+"]"};kt||it(Object.prototype,"toString",Cn,{unsafe:!0});var An=!a((function(){function e(){}return e.prototype.constructor=null,Object.getPrototypeOf(new e)!==e.prototype})),Sn=Ue("IE_PROTO"),Tn=i.Object,On=Tn.prototype,In=An?Tn.getPrototypeOf:function(e){var t=re(e);if(oe(t,Sn))return t[Sn];var r=t.constructor;return I(r)&&t instanceof r?r.prototype:t instanceof Tn?On:null},xn=a((function(){In(1)}));Pt({target:"Object",stat:!0,forced:xn,sham:!An},{getPrototypeOf:function(e){return In(re(e))}});var Dn=ot.PROPER,Mn="toString",Ln=RegExp.prototype,Rn=Ln.toString,Pn=m(Gt),Fn=a((function(){return"/a/b"!=Rn.call({source:"a",flags:"b"})})),Vn=Dn&&Rn.name!=Mn;(Fn||Vn)&&it(RegExp.prototype,Mn,(function(){var e=Te(this),t=Ut(e.source),r=e.flags;return"/"+t+"/"+Ut(void 0===r&&L(Ln,e)&&!("flags"in Ln)?Pn(e):r)}),{unsafe:!0});var kn=m(m.bind),jn=function(e,t){return $(e),void 0===t?e:u?kn(e,t):function(){return e.apply(t,arguments)}},Yn=pe("species"),Wn=i.Array,Bn=function(e,t){return new(function(e){var t;return Rr(e)&&(t=e.constructor,(Hr(t)&&(t===Wn||Rr(t.prototype))||x(t)&&null===(t=t[Yn]))&&(t=void 0)),void 0===t?Wn:t}(e))(0===t?0:t)},Hn=m([].push),Un=function(e){var t=1==e,r=2==e,n=3==e,o=4==e,i=6==e,a=7==e,s=5==e||i;return function(u,l,c,d){for(var f,p,_=re(u),h=A(_),v=jn(l,c),g=_t(h),E=0,m=d||Bn,y=t?m(u,g):r||a?m(u,0):void 0;g>E;E++)if((s||E in h)&&(p=v(f=h[E],E,_),e))if(t)y[E]=p;else if(p)switch(e){case 3:return!0;case 5:return f;case 6:return E;case 2:Hn(y,f)}else switch(e){case 4:return!1;case 7:Hn(y,f)}return i?-1:n||o?o:y}},Gn={forEach:Un(0),map:Un(1),filter:Un(2),some:Un(3),every:Un(4),find:Un(5),findIndex:Un(6),filterReject:Un(7)},zn=Gn.map,$n=zr("map");Pt({target:"Array",proto:!0,forced:!$n},{map:function(e){return zn(this,e,arguments.length>1?arguments[1]:void 0)}});var qn=a((function(){Kt(1)}));Pt({target:"Object",stat:!0,forced:qn},{keys:function(e){return Kt(re(e))}});var Xn=/^[-+a-z]+:\/\//i;function Kn(e,t){if(Xn.test(t))return t;var r=e.match(Xn),n="";r&&(n=r[0],e=e.slice(n.length)),0===t.indexOf("/")&&(e="");var o=e.split("/");o.pop();for(var i=t.split("/");i.length;){var a=i.shift();""!==a&&"."!==a&&(".."===a?o.pop():o.push(a))}return n+o.join("/")}function Qn(e){return e&&("[object Function]"===Object.prototype.toString.call(e)||"function"==typeof e)}function Zn(e){return Array.isArray?Array.isArray(e):"[object Array]"===Object.prototype.toString.call(e)}function Jn(e){var t=("undefined"==typeof window?this:window).__wcc_version_info__;if(t)return t[e]}function eo(){return Math.floor(4294967296*(1+Math.random())).toString(16).slice(1)}function to(e,t,r){e instanceof exparser.Component&&(t>0&&r(e),t&&e.shadowRoot instanceof exparser.Element&&to(e.shadowRoot,t,r),t<0&&r(e));for(var n=e.childNodes||[],o=0;o<n.length;o++)n[o]instanceof exparser.Element&&to(n[o],t,r)}var ro=function(){function e(){this._idNodeMap={}}return e.prototype.getAll=function(){return this._idNodeMap},e.prototype.getNodeById=function(e){return this._idNodeMap[e]},e.prototype.getNodeId=function(e){return e.__ddTmplId},e.prototype.allocNodeId=function(e,t){var r=t||eo();return e.__ddTmplId=r,this._idNodeMap[e.__ddTmplId]=e,r},e.prototype.addNode=function(){},e.prototype.removeNode=function(e){if(e){if(e.__ddTmplId&&(this._idNodeMap[e.__ddTmplId]=null,delete this._idNodeMap[e.__ddTmplId]),e.childNodes)for(var t=0;t<e.childNodes.length;t++)this.removeNode(e.childNodes[t]);e.shadowRoot instanceof exparser.Element&&this.removeNode(e.shadowRoot)}},e.prototype.destroy=function(){var e;for(e in this._idNodeMap)this._idNodeMap[e]=null;e=null,this._idNodeMap=null},e}(),no=zr("splice"),oo=i.TypeError,io=Math.max,ao=Math.min,so=9007199254740991,uo="Maximum allowed length exceeded";Pt({target:"Array",proto:!0,forced:!no},{splice:function(e,t){var r,n,o,i,a,s,u=re(this),l=_t(u),c=dt(e,l),d=arguments.length;if(0===d?r=n=0:1===d?(r=0,n=l-c):(r=d-2,n=ao(io(ut(t),0),l-c)),l+r-n>so)throw oo(uo);for(o=Bn(u,n),i=0;i<n;i++)(a=c+i)in u&&Ur(o,i,u[a]);if(o.length=n,r<n){for(i=c;i<l-n;i++)s=i+r,(a=i+n)in u?u[s]=u[a]:delete u[s];for(i=l;i>l-n+r;i--)delete u[i-1]}else if(r>n)for(i=l-n;i>c;i--)s=i+r-1,(a=i+n-1)in u?u[s]=u[a]:delete u[s];for(i=0;i<r;i++)u[i+c]=arguments[i+2];return u.length=l-n+r,o}});var lo={CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0},co=ye("span").classList,fo=co&&co.constructor&&co.constructor.prototype,po=fo===Object.prototype?void 0:fo,_o=Gn.forEach,ho=Zr("forEach")?[].forEach:function(e){return _o(this,e,arguments.length>1?arguments[1]:void 0)},vo=function(e){if(e&&e.forEach!==ho)try{Pe(e,"forEach",ho)}catch(t){e.forEach=ho}};for(var go in lo)lo[go]&&vo(i[go]&&i[go].prototype);vo(po);
/*! *****************************************************************************
	Copyright (c) Microsoft Corporation.

	Permission to use, copy, modify, and/or distribute this software for any
	purpose with or without fee is hereby granted.

	THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
	REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
	AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
	INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
	LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
	OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
	PERFORMANCE OF THIS SOFTWARE.
	***************************************************************************** */
var Eo=function(){return Eo=Object.assign||function(e){for(var t,r=1,n=arguments.length;r<n;r++)for(var o in t=arguments[r])Object.prototype.hasOwnProperty.call(t,o)&&(e[o]=t[o]);return e},Eo.apply(this,arguments)};var mo={TEST:0,FLOW_DEPTH:2,FLOW_INITIAL_CREATION:3,FLOW_APPLY_PROPERTY:4,FLOW_CREATE_NODE:5,FLOW_UPDATE:6,FLOW_MINIPULATE_CHILD:7,FLOW_DATA_OBSERVER:8,FLOW_REPEAT:9,DD_EVENT:11,REQUEST_SAVE:12,COMPONENT_DEF:21,SAVE_STATE:22,RESTORE_STATE:23,FLOW_INITIAL_RENDERING_CACHE:24,FLOW_CLEAR_INITIAL_RENDERING_CACHE:25,SET_DATA_CALLBACK:32,FLOW_SET_DATA:33,FLOW_GROUP:41,FLOW_GROUP_END:42,FLUSH_BLOCKED:43,CALL_METHOD_FROM_DDS:50,REQUEST_TAB:51,COMPONENT_DEF_TAB:52,FLOW_CREATE_TAB:53,DESTROY_TAB:54,REQUEST_BROADCAST_VIEW_ID:61,RESPONSE_BROADCAST_VIEW_ID:62,FLOW_VIEW_INFO:63,RESPONSE_VIEW_INFO:64,MODEL_VALUE_CHANGE:65,BANNING_MAP:90,PERFORMANCE_DATA:91,FLOW_SET_NODE_ANIMATION_INFO:100,ANIMATION_TRANSITION_END:101,FLOW_CLEAR_NODE_ANIMATION_INFO:102,CLEAR_ANIMATION_COMPLETE:103,FLOW_SET_NODE_NEXT_ANIMATION_INFO:104,LOAD_COMPONENT_DEF:110,COMPONENT_DEF_LAZY:111,FLOW_DO_REPLACE_PLACEHOLDER:112,FLOW_REPLACE_PLACEHOLDER:113,UPDATE_PERFORMANCE_STAT:800,ENABLE_UPDATE_PERFORMANCE_STAT:801,DISABLE_UPDATE_PERFORMANCE_STAT:802,FLOW_HOT_UPDATE:900,FLOW_HOT_UPDATE_CHILD:901,FLOW_HOT_UPDATE_RESET:902,UPDATE_COMPONENT_DEF:903},yo={};Object.keys(mo).forEach((function(e){yo[mo[e]]=e}));var No={RPX_RATE:20,BASE_DEVICE_WIDTH:750,SYNC_EVENT_NAME:mo,STYLE_SEGMENT_INDEX:{ATTR:0,ANIMATION:1,DDS_STYLE:2},getEvName:function(e){return yo[e]||"UNKNOWN_EVENT_"+e}},bo=function(){function e(e,t,r){this._treeManager=e,this._arr=t,this._depth=0,this._startCb=r}return e.prototype.destroy=function(){this._treeManager=null,this._arr=null,this._startCb=null,this._depth=null},e.prototype._consumeHead=function(){return this._arr.shift()},e.prototype.nextStepType=function(){return this._arr[0][0]},e.prototype.nextStep=function(){for(;this._arr[0][0]===No.SYNC_EVENT_NAME.FLOW_DEPTH;)this._startCb(this._treeManager);if(this._arr[0][0]!==No.SYNC_EVENT_NAME.FLOW_REPEAT)return this._consumeHead();var e=this._arr[0][2];return--this._arr[0][1]||this._consumeHead(),[e]},e.prototype.nextStepIf=function(e){for(;this._arr[0][0]===No.SYNC_EVENT_NAME.FLOW_DEPTH;)this._startCb(this._treeManager);return this._arr[0][0]===e?this._consumeHead():null},e.prototype.expectStart=function(){var e=this._consumeHead(),t=e[0],r=e[1],n=e[2];if(this._depth++,t!==No.SYNC_EVENT_NAME.FLOW_DEPTH||r!==this._depth)throw new Error("Framework inner error (expect START descriptor with depth "+this._depth+" but get "+No.getEvName(t)+")");return n},e.prototype.expectEnd=function(){for(;this._arr[0][0]===No.SYNC_EVENT_NAME.FLOW_DEPTH&&this._arr[0][1]!==this._depth-1;)this._startCb(this._treeManager);var e=this._consumeHead(),t=e[0],r=e[1];if(this._depth--,t!==No.SYNC_EVENT_NAME.FLOW_DEPTH||r!==this._depth)throw new Error("Framework inner error (expect END descriptor with depth "+this._depth+" but get "+No.getEvName(t)+")")},e.prototype.skipToEnd=function(){for(;this._arr[0];)if(this._arr[0][0]!==No.SYNC_EVENT_NAME.FLOW_DEPTH)this._consumeHead();else{if(this._arr[0][1]===this._depth-1)break;this._startCb(this._treeManager)}},e.prototype.getQueueLength=function(){return this._arr.length},e.prototype.getDepth=function(){return this._depth},e}(),wo=pe("isConcatSpreadable"),Co=9007199254740991,Ao="Maximum allowed index exceeded",So=i.TypeError,To=j>=51||!a((function(){var e=[];return e[wo]=!1,e.concat()[0]!==e})),Oo=zr("concat"),Io=function(e){if(!x(e))return!1;var t=e[wo];return void 0!==t?!!t:Rr(e)};Pt({target:"Array",proto:!0,forced:!To||!Oo},{concat:function(e){var t,r,n,o,i,a=re(this),s=Bn(a,0),u=0;for(t=-1,n=arguments.length;t<n;t++)if(Io(i=-1===t?a:arguments[t])){if(u+(o=_t(i))>Co)throw So(Ao);for(r=0;r<o;r++,u++)r in i&&Ur(s,u,i[r])}else{if(u>=Co)throw So(Ao);Ur(s,u++,i)}return s.length=u,s}});var xo=null,Do={},Mo=-1,Lo=null,Ro=[],Po=null,Fo=null,Vo=!1;function ko(e,t){void 0===t&&(t=0);var r,n=e.shift();if(Wo()||(t=0),__virtualDOMTunnelPrintLog__&&Yo(n,e,!1,t),""===n)return Mo=t,Lo&&Lo(t),0;Do[t]&&(r=Do[t][n]),!r&&Do.$GLOBAL&&(r=Do.$GLOBAL[n]),Qn(r)&&r(e,n,t)}function jo(){(xo=Wo()?__appServiceSDK__._virtualDOMTunnel:__webViewSDK__._virtualDOMTunnel).onVdSync((function(e,t){ko(e,t)})),xo.onVdSyncBatch((function(e,t){for(var r=0;r<e.length;r++)ko(e[r],t)}))}function Yo(e,t,r,n){void 0===n&&(n=0);Wo()}function Wo(){return __virtualDOMDataThread__}function Bo(){Fo=Fo&&clearTimeout(Fo),Ro.length&&xo.vdSyncBatch(Ro,Po),Po=null,Ro.length=0,Vo=!1}function Ho(e,t,r,n){if(__virtualDOMTunnelPrintLog__&&Yo(0,0,0,r),t=[e].concat(t),!Vo||n)return Bo(),Vo=!0,void xo.vdSync(t,r);Po!==r&&Bo(),Po=r,Ro.push(t),Vo=!0,Fo=Fo||setTimeout((function(){Fo=null,Bo()}),15)}function Uo(e,t,r){if(void 0===r&&(r=0),""===e)return Lo=t,void(0<=Mo&&Lo(Mo));Do[r]||(Do[r]={}),Do[r][e]=t}Wo()&&"undefined"!=typeof __clientsubcontext&&__clientsubcontext?__clientsubcontext.onInitReady(jo):jo();var Go=Math.floor,zo=m("".charAt),$o=m("".replace),qo=m("".slice),Xo=/\$([$&'`]|\d{1,2}|<[^>]*>)/g,Ko=/\$([$&'`]|\d{1,2})/g,Qo=function(e,t,r,n,o,i){var a=r+e.length,s=n.length,u=Ko;return void 0!==o&&(o=re(o),u=Xo),$o(i,u,(function(i,u){var l;switch(zo(u,0)){case"$":return"$";case"&":return e;case"`":return qo(t,0,r);case"'":return qo(t,a);case"<":l=o[qo(u,1,-1)];break;default:var c=+u;if(0===c)return i;if(c>s){var d=Go(c/10);return 0===d?i:d<=s?void 0===n[d-1]?zo(u,1):n[d-1]+zo(u,1):i}l=n[c-1]}return void 0===l?"":l}))},Zo=pe("replace"),Jo=Math.max,ei=Math.min,ti=m([].concat),ri=m([].push),ni=m("".indexOf),oi=m("".slice),ii="$0"==="a".replace(/./,"$0"),ai=!!/./[Zo]&&""===/./[Zo]("a","$0");function si(e,t){var r=e.$$,n={};if(t.id&&(n.id=e.id),t.dataset&&(n.dataset=e.dataset),t.mark&&(n.mark=e.collectMarks()||{}),t.rect||t.size){var o=r.getBoundingClientRect();t.rect&&(n.left=o.left,n.right=o.right,n.top=o.top,n.bottom=o.bottom),t.size&&(n.width=o.width,n.height=o.height)}if(t.properties)for(var i=void 0,a=0,s=t.properties;a<s.length;a++)i=(i=s[a]).replace(/-([a-z])/g,(function(e,t){return t.toUpperCase()})),exparser.Component.hasPublicProperty(e,i)&&(n[i]=e[i]);if(t.scrollOffset)if(e.hasBehavior("dd-positioning-container")){var u=e.getScrollPosition();n.scrollLeft=u.scrollLeft,n.scrollTop=u.scrollTop,n.scrollWidth=u.scrollWidth,n.scrollHeight=u.scrollHeight}else n.scrollLeft=0,n.scrollTop=0,n.scrollWidth=0,n.scrollHeight=0;if(t.computedStyle&&t.computedStyle.length)for(var l=window.getComputedStyle(r),c=t.computedStyle.length,d=0,f=void 0;d<c;d++)(f=t.computedStyle[d])&&l[f]&&(n[f]=l[f]);return t.context&&(n.contextIs=e.is),t.node&&(n.nodeIs=e.is,n.nodeId="function"==typeof e.getContextId&&e.getContextId(),n.nodeCanvasId=e.canvasId||"",n.nodeCanvasType=e.type||""),n}Cr("replace",(function(e,t,r){var n=ai?"$":"$0";return[function(e,r){var n=T(this),o=null==e?void 0:q(e,Zo);return o?c(o,e,n,r):c(t,Ut(n),e,r)},function(e,o){var i=Te(this),a=Ut(e);if("string"==typeof o&&-1===ni(o,n)&&-1===ni(o,"$<")){var s=r(t,i,a,o);if(s.done)return s.value}var u=I(o);u||(o=Ut(o));var l=i.global;if(l){var c=i.unicode;i.lastIndex=0}for(var d=[];;){var f=Lr(i,a);if(null===f)break;if(ri(d,f),!l)break;""===Ut(f[0])&&(i.lastIndex=Dr(a,pt(i.lastIndex),c))}for(var p,_="",h=0,v=0;v<d.length;v++){for(var g=Ut((f=d[v])[0]),E=Jo(ei(ut(f.index),a.length),0),m=[],y=1;y<f.length;y++)ri(m,void 0===(p=f[y])?p:String(p));var N=f.groups;if(u){var b=ti([g],m,E,a);void 0!==N&&ri(b,N);var w=Ut(sn(o,void 0,b))}else w=Qo(g,a,E,m,N,o);E>=h&&(_+=oi(a,h,E)+w,h=E+g.length)}return _+oi(a,h)}]}),!!a((function(){var e=/./;return e.exec=function(){var e=[];return e.groups={a:"7"},e},"7"!=="".replace(e,"$<a>")}))||!ii||ai);var ui={},li={},ci={},di=!1;function fi(e){return{left:e.left,top:e.top,right:e.right,bottom:e.bottom,width:e.width,height:e.height}}function pi(e,t){var r={left:e.left<t.left?t.left:e.left,top:e.top<t.top?t.top:e.top,right:e.right>t.right?t.right:e.right,bottom:e.bottom>t.bottom?t.bottom:e.bottom,width:0,height:0};return r.right>r.left?r.width=r.right-r.left:r.right=r.left=r.bottom=r.top=0,r.bottom>r.top?r.height=r.bottom-r.top:r.right=r.left=r.bottom=r.top=0,r}"undefined"!=typeof window&&"undefined"!=typeof document&&"function"==typeof document.addEventListener&&(document.addEventListener("pageReRender",(function(){vi()})),window.addEventListener("scroll",(function(){vi()}),{capture:!0,passive:!0}));function _i(e){var t=e.targetNode,r=e.relatives,n=e.thresholds,o=e.minWidthOrHeight,i=e.cb,a=e.currentRatio,s=function(e){for(var t=document.documentElement.clientWidth,r=document.documentElement.clientHeight,n=null,o=0;o<e.length;o++){var i=e[o],a=i.node,s=i.margins,u=a?a.$$.getBoundingClientRect():{left:0,top:0,right:t,bottom:r,width:t,height:r},l={left:u.left-s.left,top:u.top-s.top,right:u.right+s.right,bottom:u.bottom+s.bottom};n=n?pi(u,l):l}return n}(r),u=fi(t.$$.getBoundingClientRect());u.right-u.left<o&&(u.right=u.left+o,u.width=o),u.bottom-u.top<o&&(u.bottom=u.top+o,u.height=o);var l=pi(s,u),c=u.width*u.height,d=c?l.width*l.height/c:0;e.currentRatio=d;var f=void 0===a;a!==d&&n.forEach((function(e){void 0!==a&&(d<=e&&e<=a||e<=d&&a<=e)&&(f=!0)})),f&&i.call(t,{id:t.id,dataset:t.dataset,time:Date.now(),boundingClientRect:u,intersectionRatio:d,intersectionRect:fi(l),relativeRect:s})}function hi(e,t,r,n,o){var i=e.querySelector(t)?[e.querySelector(t)]:[],a=n||{},s=a.observeAll?e.querySelectorAll(t):i,u=[];return r.forEach((function(t){var r=t.selector,n=t.margins,o=null==r?null:e.querySelector(r);if(o||null==r){var i=n||{};u.push({node:o,margins:{left:i.left||0,top:i.top||0,right:i.right||0,bottom:i.bottom||0}})}})),u.length,function(e,t,r,n,o,i){var a=eo();if(!e.length||!t.length)return a;var s=e.length;return ci[a]=s,e.forEach((function(e,u){var l=a+"#"+u,c={targetNode:e,relatives:t,thresholds:r,currentRatio:n,minWidthOrHeight:o,cb:i},d=exparser.Observer.create((function(e){"attached"===e.status?(ui[l]=c,requestAnimationFrame((function(){_i(c)}))):"detached"===e.status&&(delete ui[l],d.disconnect(),delete li[l],--s>0&&delete ci[a])}));(li[l]=d).observe(e,{attachStatus:!0}),exparser.Element.isAttached(e)&&(ui[l]=c,requestAnimationFrame((function(){_i(c)})))})),a}(s,u,a.thresholds||[0],a.initialRatio||0,a.minWidthOrHeight||0,o)}function vi(){di||(di=!0,requestAnimationFrame((function(){for(var e in di=!1,ui)_i(ui[e])})))}function gi(e,t,r){if("addIntersectionObserver"===e.type){var n=null;if(e.nodeId){var o=t.nodeId.getNodeById(e.nodeId);if(!o)return;n=o.shadowRoot}else e.pluginId||(n=window.__DOMTree__.shadowRoot);if(!n)return;return{observerId:hi(n,e.targetSelector,e.relativeInfo,e.options,(function(e){r({info:e})}))}}if("removeIntersectionObserver"===e.type)return function(e){var t=ci[e];delete ci[e];for(var r=0;r<t;r++){var n=e+"#"+r,o=li[n];if(!o)break;delete ui[n],o.disconnect(),delete li[n]}}(e.observerId),{reqEnd:!0}}var Ei=i.String,mi=i.TypeError,yi=Object.setPrototypeOf||("__proto__"in{}?function(){var e,t=!1,r={};try{(e=m(Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set))(r,[]),t=r instanceof Array}catch(e){}return function(r,n){return Te(r),function(e){if("object"==typeof e||I(e))return e;throw mi("Can't set "+Ei(e)+" as a prototype")}(n),t?e(r,n):r.__proto__=n,r}}():void 0),Ni=function(e,t,r){var n,o;return yi&&I(n=t.constructor)&&n!==r&&x(o=n.prototype)&&o!==r.prototype&&yi(e,o),e},bi=m(1..valueOf),wi="\t\n\v\f\r                　\u2028\u2029\ufeff",Ci=m("".replace),Ai="["+wi+"]",Si=RegExp("^"+Ai+Ai+"*"),Ti=RegExp(Ai+Ai+"*$"),Oi=function(e){return function(t){var r=Ut(T(t));return 1&e&&(r=Ci(r,Si,"")),2&e&&(r=Ci(r,Ti,"")),r}},Ii={start:Oi(1),end:Oi(2),trim:Oi(3)},xi=bt.f,Di=we.f,Mi=Re.f,Li=Ii.trim,Ri="Number",Pi=i.Number,Fi=Pi.prototype,Vi=i.TypeError,ki=m("".slice),ji=m("".charCodeAt),Yi=function(e){var t=ve(e,"number");return"bigint"==typeof t?t:Wi(t)},Wi=function(e){var t,r,n,o,i,a,s,u,l=ve(e,"number");if(H(l))throw Vi("Cannot convert a Symbol value to a number");if("string"==typeof l&&l.length>2)if(l=Li(l),43===(t=ji(l,0))||45===t){if(88===(r=ji(l,2))||120===r)return NaN}else if(48===t){switch(ji(l,1)){case 66:case 98:n=2,o=49;break;case 79:case 111:n=8,o=55;break;default:return+l}for(a=(i=ki(l,2)).length,s=0;s<a;s++)if((u=ji(i,s))<48||u>o)return NaN;return parseInt(i,n)}return+l};if(Lt(Ri,!Pi(" 0o1")||!Pi("0b1")||Pi("+0x1"))){for(var Bi,Hi=function(e){var t=arguments.length<1?0:Pi(Yi(e)),r=this;return L(Fi,r)&&a((function(){bi(r)}))?Ni(Object(t),r,Hi):t},Ui=s?xi(Pi):"MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,EPSILON,MAX_SAFE_INTEGER,MIN_SAFE_INTEGER,isFinite,isInteger,isNaN,isSafeInteger,parseFloat,parseInt,fromString,range".split(","),Gi=0;Ui.length>Gi;Gi++)oe(Pi,Bi=Ui[Gi])&&!oe(Hi,Bi)&&Mi(Hi,Bi,Di(Pi,Bi));Hi.prototype=Fi,Fi.constructor=Hi,it(i,Ri,Hi)}function zi(e){return zi="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},zi(e)}function $i(){return $i=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var r=arguments[t];for(var n in r)Object.prototype.hasOwnProperty.call(r,n)&&(e[n]=r[n])}return e},$i.apply(this,arguments)}var qi=bt.f,Xi="object"==typeof window&&window&&Object.getOwnPropertyNames?Object.getOwnPropertyNames(window):[],Ki={f:function(e){return Xi&&"Window"==b(e)?function(e){try{return qi(e)}catch(e){return hn(Xi)}}(e):qi(O(e))}},Qi={f:pe},Zi=i,Ji=Re.f,ea=function(e){var t=Zi.Symbol||(Zi.Symbol={});oe(t,e)||Ji(t,e,{value:Qi.f(e)})},ta=Re.f,ra=pe("toStringTag"),na=function(e,t,r){e&&!r&&(e=e.prototype),e&&!oe(e,ra)&&ta(e,ra,{configurable:!0,value:t})},oa=Gn.forEach,ia=Ue("hidden"),aa="Symbol",sa=pe("toPrimitive"),ua=et.set,la=et.getterFor(aa),ca=Object.prototype,da=i.Symbol,fa=da&&da.prototype,pa=i.TypeError,_a=i.QObject,ha=M("JSON","stringify"),va=we.f,ga=Re.f,Ea=Ki.f,ma=p.f,ya=m([].push),Na=ee("symbols"),ba=ee("op-symbols"),wa=ee("string-to-symbol-registry"),Ca=ee("symbol-to-string-registry"),Aa=ee("wks"),Sa=!_a||!_a.prototype||!_a.prototype.findChild,Ta=s&&a((function(){return 7!=ir(ga({},"a",{get:function(){return ga(this,"a",{value:7}).a}})).a}))?function(e,t,r){var n=va(ca,t);n&&delete ca[t],ga(e,t,r),n&&e!==ca&&ga(ca,t,n)}:ga,Oa=function(e,t){var r=Na[e]=ir(fa);return ua(r,{type:aa,tag:e,description:t}),s||(r.description=t),r},Ia=function(e,t,r){e===ca&&Ia(ba,t,r),Te(e);var n=ge(t);return Te(r),oe(Na,n)?(r.enumerable?(oe(e,ia)&&e[ia][n]&&(e[ia][n]=!1),r=ir(r,{enumerable:_(0,!1)})):(oe(e,ia)||ga(e,ia,_(1,{})),e[ia][n]=!0),Ta(e,n,r)):ga(e,n,r)},xa=function(e,t){Te(e);var r=O(t),n=Kt(r).concat(Ra(r));return oa(n,(function(t){s&&!c(Da,r,t)||Ia(e,t,r[t])})),e},Da=function(e){var t=ge(e),r=c(ma,this,t);return!(this===ca&&oe(Na,t)&&!oe(ba,t))&&(!(r||!oe(this,t)||!oe(Na,t)||oe(this,ia)&&this[ia][t])||r)},Ma=function(e,t){var r=O(e),n=ge(t);if(r!==ca||!oe(Na,n)||oe(ba,n)){var o=va(r,n);return!o||!oe(Na,n)||oe(r,ia)&&r[ia][n]||(o.enumerable=!0),o}},La=function(e){var t=Ea(O(e)),r=[];return oa(t,(function(e){oe(Na,e)||oe(Ge,e)||ya(r,e)})),r},Ra=function(e){var t=e===ca,r=Ea(t?ba:O(e)),n=[];return oa(r,(function(e){!oe(Na,e)||t&&!oe(ca,e)||ya(n,Na[e])})),n};if(Y||(da=function(){if(L(fa,this))throw pa("Symbol is not a constructor");var e=arguments.length&&void 0!==arguments[0]?Ut(arguments[0]):void 0,t=ue(e),r=function(e){this===ca&&c(r,ba,e),oe(this,ia)&&oe(this[ia],t)&&(this[ia][t]=!1),Ta(this,t,_(1,e))};return s&&Sa&&Ta(ca,t,{configurable:!0,set:r}),Oa(t,e)},fa=da.prototype,it(fa,"toString",(function(){return la(this).tag})),it(da,"withoutSetter",(function(e){return Oa(ue(e),e)})),p.f=Da,Re.f=Ia,Zt.f=xa,we.f=Ma,bt.f=Ki.f=La,wt.f=Ra,Qi.f=function(e){return Oa(pe(e),e)},s&&(ga(fa,"description",{configurable:!0,get:function(){return la(this).description}}),it(ca,"propertyIsEnumerable",Da,{unsafe:!0}))),Pt({global:!0,wrap:!0,forced:!Y,sham:!Y},{Symbol:da}),oa(Kt(Aa),(function(e){ea(e)})),Pt({target:aa,stat:!0,forced:!Y},{for:function(e){var t=Ut(e);if(oe(wa,t))return wa[t];var r=da(t);return wa[t]=r,Ca[r]=t,r},keyFor:function(e){if(!H(e))throw pa(e+" is not a symbol");if(oe(Ca,e))return Ca[e]},useSetter:function(){Sa=!0},useSimple:function(){Sa=!1}}),Pt({target:"Object",stat:!0,forced:!Y,sham:!s},{create:function(e,t){return void 0===t?ir(e):xa(ir(e),t)},defineProperty:Ia,defineProperties:xa,getOwnPropertyDescriptor:Ma}),Pt({target:"Object",stat:!0,forced:!Y},{getOwnPropertyNames:La,getOwnPropertySymbols:Ra}),Pt({target:"Object",stat:!0,forced:a((function(){wt.f(1)}))},{getOwnPropertySymbols:function(e){return wt.f(re(e))}}),ha){var Pa=!Y||a((function(){var e=da();return"[null]"!=ha([e])||"{}"!=ha({a:e})||"{}"!=ha(Object(e))}));Pt({target:"JSON",stat:!0,forced:Pa},{stringify:function(e,t,r){var n=$r(arguments),o=t;if((x(t)||void 0!==e)&&!H(e))return Rr(t)||(t=function(e,t){if(I(o)&&(t=c(o,this,e,t)),!H(t))return t}),n[1]=t,sn(ha,null,n)}})}if(!fa[sa]){var Fa=fa.valueOf;it(fa,sa,(function(e){return c(Fa,this)}))}na(da,aa),Ge[ia]=!0;var Va=Re.f,ka=i.Symbol,ja=ka&&ka.prototype;if(s&&I(ka)&&(!("description"in ja)||void 0!==ka().description)){var Ya={},Wa=function(){var e=arguments.length<1||void 0===arguments[0]?void 0:Ut(arguments[0]),t=L(ja,this)?new ka(e):void 0===e?ka():ka(e);return""===e&&(Ya[t]=!0),t};St(Wa,ka),Wa.prototype=ja,ja.constructor=Wa;var Ba="Symbol(test)"==String(ka("test")),Ha=m(ja.toString),Ua=m(ja.valueOf),Ga=/^Symbol\((.*)\)[^)]+$/,za=m("".replace),$a=m("".slice);Va(ja,"description",{configurable:!0,get:function(){var e=Ua(this),t=Ha(e);if(oe(Ya,e))return"";var r=Ba?$a(t,7,-1):za(t,Ga,"$1");return""===r?void 0:r}}),Pt({global:!0,forced:!0},{Symbol:Wa})}ea("iterator");var qa=pe("unscopables"),Xa=Array.prototype;null==Xa[qa]&&Re.f(Xa,qa,{configurable:!0,value:ir(null)});var Ka,Qa,Za,Ja=function(e){Xa[qa][e]=!0},es={},ts=pe("iterator"),rs=!1;[].keys&&("next"in(Za=[].keys())?(Qa=In(In(Za)))!==Object.prototype&&(Ka=Qa):rs=!0);var ns=null==Ka||a((function(){var e={};return Ka[ts].call(e)!==e}));ns&&(Ka={}),I(Ka[ts])||it(Ka,ts,(function(){return this}));var os={IteratorPrototype:Ka,BUGGY_SAFARI_ITERATORS:rs},is=os.IteratorPrototype,as=function(){return this},ss=ot.PROPER,us=ot.CONFIGURABLE,ls=os.IteratorPrototype,cs=os.BUGGY_SAFARI_ITERATORS,ds=pe("iterator"),fs="keys",ps="values",_s="entries",hs=function(){return this},vs=function(e,t,r,n,o,i,a){!function(e,t,r,n){var o=t+" Iterator";e.prototype=ir(is,{next:_(+!n,r)}),na(e,o,!1),es[o]=as}(r,t,n);var s,u,l,d=function(e){if(e===o&&g)return g;if(!cs&&e in h)return h[e];switch(e){case fs:case ps:case _s:return function(){return new r(this,e)}}return function(){return new r(this)}},f=t+" Iterator",p=!1,h=e.prototype,v=h[ds]||h["@@iterator"]||o&&h[o],g=!cs&&v||d(o),E="Array"==t&&h.entries||v;if(E&&(s=In(E.call(new e)))!==Object.prototype&&s.next&&(In(s)!==ls&&(yi?yi(s,ls):I(s[ds])||it(s,ds,hs)),na(s,f,!0)),ss&&o==ps&&v&&v.name!==ps&&(us?Pe(h,"name",ps):(p=!0,g=function(){return c(v,this)})),o)if(u={values:d(ps),keys:i?g:d(fs),entries:d(_s)},a)for(l in u)(cs||p||!(l in h))&&it(h,l,u[l]);else Pt({target:t,proto:!0,forced:cs||p},u);return h[ds]!==g&&it(h,ds,g,{name:o}),es[t]=g,u},gs=Re.f,Es="Array Iterator",ms=et.set,ys=et.getterFor(Es),Ns=vs(Array,"Array",(function(e,t){ms(this,{type:Es,target:O(e),index:0,kind:t})}),(function(){var e=ys(this),t=e.target,r=e.kind,n=e.index++;return!t||n>=t.length?(e.target=void 0,{value:void 0,done:!0}):"keys"==r?{value:n,done:!1}:"values"==r?{value:t[n],done:!1}:{value:[n,t[n]],done:!1}}),"values"),bs=es.Arguments=es.Array;if(Ja("keys"),Ja("values"),Ja("entries"),s&&"values"!==bs.name)try{gs(bs,"name",{value:"values"})}catch(e){}var ws=Ir.charAt,Cs="String Iterator",As=et.set,Ss=et.getterFor(Cs);vs(String,"String",(function(e){As(this,{type:Cs,string:Ut(e),index:0})}),(function(){var e,t=Ss(this),r=t.string,n=t.index;return n>=r.length?{value:void 0,done:!0}:(e=ws(r,n),t.index+=e.length,{value:e,done:!1})}));var Ts=pe("iterator"),Os=pe("toStringTag"),Is=Ns.values,xs=function(e,t){if(e){if(e[Ts]!==Is)try{Pe(e,Ts,Is)}catch(t){e[Ts]=Is}if(e[Os]||Pe(e,Os,t),lo[t])for(var r in Ns)if(e[r]!==Ns[r])try{Pe(e,r,Ns[r])}catch(t){e[r]=Ns[r]}}};for(var Ds in lo)xs(i[Ds]&&i[Ds].prototype,Ds);xs(po,"DOMTokenList");var Ms=function(e,t,r){var n,o;Te(e);try{if(!(n=q(e,"return"))){if("throw"===t)throw r;return r}n=c(n,e)}catch(e){o=!0,n=e}if("throw"===t)throw r;if(o)throw n;return Te(n),r},Ls=function(e,t,r,n){try{return n?t(Te(r)[0],r[1]):t(r)}catch(t){Ms(e,"throw",t)}},Rs=pe("iterator"),Ps=Array.prototype,Fs=function(e){return void 0!==e&&(es.Array===e||Ps[Rs]===e)},Vs=pe("iterator"),ks=function(e){if(null!=e)return q(e,Vs)||q(e,"@@iterator")||es[Bt(e)]},js=i.TypeError,Ys=function(e,t){var r=arguments.length<2?ks(e):t;if($(r))return Te(c(r,e));throw js(G(e)+" is not iterable")},Ws=i.Array,Bs=pe("iterator"),Hs=!1;try{var Us=0,Gs={next:function(){return{done:!!Us++}},return:function(){Hs=!0}};Gs[Bs]=function(){return this},Array.from(Gs,(function(){throw 2}))}catch(e){}var zs=function(e,t){if(!t&&!Hs)return!1;var r=!1;try{var n={};n[Bs]=function(){return{next:function(){return{done:r=!0}}}},e(n)}catch(e){}return r},$s=!zs((function(e){Array.from(e)}));Pt({target:"Array",stat:!0,forced:$s},{from:function(e){var t=re(e),r=Hr(this),n=arguments.length,o=n>1?arguments[1]:void 0,i=void 0!==o;i&&(o=jn(o,n>2?arguments[2]:void 0));var a,s,u,l,d,f,p=ks(t),_=0;if(!p||this==Ws&&Fs(p))for(a=_t(t),s=r?new this(a):Ws(a);a>_;_++)f=i?o(t[_],_):t[_],Ur(s,_,f);else for(d=(l=Ys(t,p)).next,s=r?new this:[];!(u=c(d,l)).done;_++)f=i?Ls(l,o,[u.value,_],!0):u.value,Ur(s,_,f);return s.length=_,s}});var qs=function(e){return(qs="function"==typeof Symbol&&"symbol"===zi(Symbol.iterator)?function(e){return zi(e)}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":zi(e)})(e)};function Xs(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var Ks={},Qs=1;function Zs(e,t){function r(e){t({matches:e.matches})}var n=function(e){if("object"!==qs(e))return"";var t="";return["minWidth","maxWidth","width","minHeight","maxHeight","height"].forEach((function(r){var n,o;void 0!==e[r]&&(0<=(n=Number(e[r]))||(n=""),o=r.replace(/[A-Z]/g,(function(e){return"-"+e.toLowerCase()})),t&&(t+=" and "),t=t+"("+o+": "+n+"px)")})).orientation.forEach((function(r){var n,o;void 0!==e[r]&&(n=/^[-_a-z0-9]+$/i.test(e[r])?e[r]:"",o=r.replace(/[A-Z]/g,(function(e){return"-"+e.toLowerCase()})),t&&(t+=" and "),t=t+"("+o+": "+n+")")})),t}(e),o=window.matchMedia(n),i=Qs++;return Ks[i]={observer:o,listener:r},o.addListener(r),t({matches:o.matches}),i}function Js(e,t){return"addMediaQueryObserver"===e.type?{observerId:Zs(e.mediaQueryCond,(function(e){t({info:e})}))}:"removeMediaQueryObserver"===e.type?(function(e){var t=Ks[e],r=t.observer,n=t.listener;r.removeListener(n),delete Ks[e]}(e.observerId),{reqEnd:!0}):void 0}var eu=function(){function e(t,r){var n=this;for(var o in this.flowSetData=function(e){n._pendingSetDataCallbacks.push(e[0])},this.viewInfoCb=function(e){n._received.length||n._blocked?n._fetchingViewInfoCallbacks.push(n.handleViewInfo.bind(n,e)):n.handleViewInfo(e)},this.handleViewInfo=function(e){var t=e[0],r=e[1],o=e[2],i=null;"selectorQuery"===t?i=function(e,t){for(var r=[],n=e.pluginId,o=0,i=e.queue;o<i.length;o++){var a=i[o],s=a.component,u=a.selector,l=a.single,c=a.fields,d=null;if(0===s){var f={};c.id&&(f.id=""),c.dataset&&(f.dataset={}),c.mark&&(f.mark={}),c.rect&&(f.left=0,f.right=0,f.top=0,f.bottom=0),c.size&&(f.width=document.documentElement.clientWidth,f.height=document.documentElement.clientHeight),c.scrollOffset&&(f.scrollLeft=document.documentElement.scrollLeft||document.body.scrollLeft||0,f.scrollTop=document.documentElement.scrollTop||document.body.scrollTop||0,f.scrollWidth=document.documentElement.scrollWidth||document.body.scrollWidth||0,f.scrollHeight=document.documentElement.scrollHeight||document.body.scrollHeight||0),d=f}else{var p=void 0,_=!1;if((p=t.nodeId.getNodeById(s))?(exparser.Component.getComponentOptions(p).writeOnly&&(_=!0),p=p.shadowRoot):n||(p=window.__DOMTree__?window.__DOMTree__.shadowRoot:null),l){var h=p&&!_?p.querySelector(u):null;d=h?si(h,c):null}else{var v=p&&!_?p.querySelectorAll(u):[];d=[];for(var g=0;g<v.length;g++)d.push(si(v[g],c))}}r.push(d)}return r}(r,n._treeManager):"intersection"===t?i=gi(r,n._treeManager,(function(e){Ho(No.SYNC_EVENT_NAME.RESPONSE_VIEW_INFO,[e,o])})):"matchMedia"===t&&(i=Js(r,(function(e){Ho(No.SYNC_EVENT_NAME.RESPONSE_VIEW_INFO,[e,o])}))),i&&Ho(No.SYNC_EVENT_NAME.RESPONSE_VIEW_INFO,[i,o])},this.receiveSyncEvent=function(t,r){if(n._received.push(function(){for(var e=0,t=0,r=arguments.length;t<r;t++)e+=arguments[t].length;var n=Array(e),o=0;for(t=0;t<r;t++)for(var i=arguments[t],a=0,s=i.length;a<s;a++,o++)n[o]=i[a];return n}([r],t)),r===No.SYNC_EVENT_NAME.FLOW_DEPTH&&(n._depth=t[0],0===n._depth)){var o=n._received;n._received=[],n._blocked?n._blocked.push(o):(n.iterator=new bo(n._treeManager,o,e._startCb),e._startCb(n._treeManager),document.dispatchEvent(new CustomEvent("pageReRender",{})),Ho(No.SYNC_EVENT_NAME.SET_DATA_CALLBACK,[n._pendingSetDataCallbacks],-1,!0),n._pendingSetDataCallbacks=[],n.checkDelayFetchingViewInfo())}},this._viewId=t,this._treeManager=r,this._depth=0,this._curWinSize=0,this._setDataCallbackInc=1,this._pendingSetDataCallbacks=[],this._setDataCallbackMap={},this._received=[],this._cache=[],this._blocked=[],this._fetchingViewInfoCallbacks=[],No.SYNC_EVENT_NAME)if("FLOW_"===o.slice(0,5))switch(o){case"FLOW_SET_DATA":Uo(No.SYNC_EVENT_NAME[o],this.flowSetData,t);break;case"FLOW_VIEW_INFO":Uo(No.SYNC_EVENT_NAME[o],this.viewInfoCb,t);break;case"FLOW_SET_NODE_ANIMATION_INFO":case"FLOW_CLEAR_NODE_ANIMATION_INFO":case"FLOW_SET_NODE_NEXT_ANIMATION_INFO":break;default:Uo(No.SYNC_EVENT_NAME[o],this.receiveSyncEvent,t)}Uo(No.SYNC_EVENT_NAME.SET_DATA_CALLBACK,(function(e){n.triggerSetDataCallbacks(e[0])}),t)}return e.setStartOperation=function(t){e._startCb=t},e.prototype.destroy=function(){for(var e in this.flowSetData=null,this.viewInfoCb=null,this.receiveSyncEvent=null,delete this.flowSetData,delete this.viewInfoCb,delete this.receiveSyncEvent,this.iterator&&this.iterator.destroy(),this._pendingSetDataCallbacks=null,this._received=null,this._blocked=null,this._fetchingViewInfoCallbacks=null,this._cache=null,this._treeManager=null,this._setDataCallbackMap)delete this._setDataCallbackMap[e];this._setDataCallbackMap=null},e.prototype.flushBlocked=function(){if(this._blocked){for(;this._blocked.length;)try{var t=this._blocked.shift();this.iterator=new bo(this._treeManager,t,e._startCb),e._startCb(this._treeManager),document.dispatchEvent(new CustomEvent("pageReRender",{}))}catch(e){}if(!this._blocked.length){var r=Wo()?this._treeManager.viewId:-1;Ho(No.SYNC_EVENT_NAME.SET_DATA_CALLBACK,[this._pendingSetDataCallbacks],r,!0),this._pendingSetDataCallbacks=[],this.checkDelayFetchingViewInfo()}}},e.prototype.unblock=function(){this.flushBlocked(),this._blocked&&0===this._blocked.length&&(this._blocked=null)},e.prototype.block=function(){null===this._blocked&&(this._blocked=[])},e.prototype.start=function(){this.flush(),this._depth++,Ho(No.SYNC_EVENT_NAME.FLOW_DEPTH,[this._depth,Date.now()],this._viewId)},e.prototype.dedupe=function(){var e=this._cache;if(this._curWinSize){if(2===e.length)if(e[0][0]===e[1][2])e.shift(),e[0][1]++;else Ho((r=e.pop()).shift(),r,this._viewId)}else{var t=e[0][0];if(e.length>2&&t===e[1][0]&&t===e[2][0]&&t!==No.SYNC_EVENT_NAME.FLOW_SET_DATA&&t!==No.SYNC_EVENT_NAME.FLOW_VIEW_INFO)e.splice(0,3),this.flush(),this._curWinSize=1,e.unshift([No.SYNC_EVENT_NAME.FLOW_REPEAT,3,t]);else if(e.length>3){var r;Ho((r=e.pop()).shift(),r,this._viewId)}}},e.prototype.push=function(e){this._cache.unshift(e),1===e.length?this.dedupe():this.flush()},e.prototype.flush=function(){for(this._curWinSize=0;this._cache.length;){var e=this._cache.pop();Ho(e.shift(),e,this._viewId)}},e.prototype.end=function(){this.flush(),this._depth--,Ho(No.SYNC_EVENT_NAME.FLOW_DEPTH,this._depth,this._viewId),0===this._depth&&Bo()},e.prototype.checkDelayFetchingViewInfo=function(){var e;this._fetchingViewInfoCallbacks.length&&(e=this._fetchingViewInfoCallbacks,this._fetchingViewInfoCallbacks=[],e.forEach((function(e){e()})))},e.prototype.registerSetDataCallback=function(e,t,r){var n=this._setDataCallbackInc++;this._setDataCallbackMap[n]=[e,t,r],this.push([No.SYNC_EVENT_NAME.FLOW_SET_DATA,n])},e.prototype.triggerSetDataCallbacks=function(e){for(var t=0;t<e.length;t++){var r=e[t],n=this._setDataCallbackMap[r],o=n[0],i=n[1],a=n[2];delete this._setDataCallbackMap[r],exparser.safeCallback("SetData Callback",o,i,[],a)}},e}(),tu={};function ru(e,t){if(e){if(Zn(e.childNodes))for(var r=0,n=e.childNodes;r<n.length;r++)ru(n[r],t);if(Zn(e.__ddSlotChildren)){r=0;for(var o=e.__ddSlotChildren;r<o.length;r++)ru(o[r],t)}e.shadowRoot instanceof exparser.Element&&ru(e.shadowRoot,t),t(e)}}var nu=function(){function e(e){this.listenerInited=!1,this.root=null,this.tabRoot=null,this.tabDestroyed=!1,this.usedDef=null,this.tabUsedDef=null,this.statesData=null,this.operationFlow=new eu(e,this),this.nodeId=new ro,this.rootNodeId="",this.tabNodeId="",this.rootCompName="",this.tabCompName="",this.applyAnimationCbMap={},this.clearAnimationCbMap={},this.viewInfoCbMap={},this.initialRootData=null,this.lifetimeListener=null}return e.create=function(t){var r=new e(t);return r.viewId=t,tu[t]=r,r},e.destroy=function(e){var t=tu[e],r=t.nodeId;ru(t.root,(function(e){r.removeNode(e),e.destroy(!0)})),exparser.Element.delayDestroy(e),r=null,t.destroy(),t=null,tu[e]=null,dd&&Qn(dd.triggerGC)&&dd.triggerGC()},e.get=function(e){return tu[e]},e.listViewId=function(){var e=[];for(var t in tu)e.push(tu[t].viewId);return e},e.list=function(){var e=[];for(var t in tu)e.push(tu[t]);return e},e.prototype.destroy=function(){if(this.listenerInited=null,this.root=null,this.tabRoot=null,this.tabDestroyed=null,this.usedDef=null,this.tabUsedDef=null,this.statesData=null,this.operationFlow&&this.operationFlow.destroy(),this.operationFlow=null,this.nodeId&&this.nodeId.destroy(),this.nodeId=null,this.rootNodeId=null,this.tabNodeId=null,this.rootCompName=null,this.tabCompName=null,this.applyAnimationCbMap=null,this.clearAnimationCbMap=null,this.viewInfoCbMap)for(var e in this.viewInfoCbMap)this.viewInfoCbMap[e]=null;this.viewInfoCbMap=null,this.initialRootData=null,this.lifetimeListener=null,this.viewId=null},e}(),ou=null;function iu(){ou={};var e,t=null;__ddConfig&&__ddConfig.plugins?t=__ddConfig.plugins:"undefined"!=typeof window&&window&&window.__ddConfigAppService__&&window.__ddConfigAppService__.plugins&&(t=window.__ddConfigAppService__.plugins);var r=!1;if(t)for(var n in t){var o=t[n],i=o.provider,a=o.subpackage,s=void 0;void 0!==a&&(r=!0,"__APP__"===(s=a||"")&&(s=""),"/"===s[0]&&s.slice(1),s&&"/"!==s.slice(-1)&&(s+="/"),ou[i]=s)}if(!r){if(__ddConfig&&__ddConfig.subPackages)e=__ddConfig.subPackages;else{if("undefined"==typeof window||!window||!window.__subPackages)return;e=window.__subPackages}if(Zn(e))for(var u=0,l=e;u<l.length;u++){var c=l[u],d=(i=void 0,c.root||"");if(d&&"/"!==d.slice(-1)&&(d+="/"),c.plugins)for(var n in c.plugins)Object.prototype.hasOwnProperty.call(c.plugins,n)&&(i=c.plugins[n]&&c.plugins[n].provider,ou[i]=d)}}}function au(e){var t=e.match(/(?:^|\/)__(dd|plugin)__\/(.*)$/);return t?"dd"===t[1]?"dd://"+t[2]:"plugin-private://"+t[2]:e}function su(e){return ou[e]||""}var uu=0;function lu(){return uu=Date.now()+Math.random()}function cu(){return!!uu}function du(e){uu===e&&(uu=0)}function fu(e){var t,r=lu();try{t=e(r)}catch(e){throw setTimeout((function(){du(r)}),0),e}return setTimeout((function(){du(r)}),0),t}var pu=a((function(){if("function"==typeof ArrayBuffer){var e=new ArrayBuffer(8);Object.isExtensible(e)&&Object.defineProperty(e,"a",{value:8})}})),_u=Object.isExtensible,hu=a((function(){_u(1)}))||pu?function(e){return!!x(e)&&((!pu||"ArrayBuffer"!=b(e))&&(!_u||_u(e)))}:_u,vu=!a((function(){return Object.isExtensible(Object.preventExtensions({}))})),gu=t((function(e){var t=Re.f,r=!1,n=ue("meta"),o=0,i=function(e){t(e,n,{value:{objectID:"O"+o++,weakData:{}}})},a=e.exports={enable:function(){a.enable=function(){},r=!0;var e=bt.f,t=m([].splice),o={};o[n]=1,e(o).length&&(bt.f=function(r){for(var o=e(r),i=0,a=o.length;i<a;i++)if(o[i]===n){t(o,i,1);break}return o},Pt({target:"Object",stat:!0,forced:!0},{getOwnPropertyNames:Ki.f}))},fastKey:function(e,t){if(!x(e))return"symbol"==typeof e?e:("string"==typeof e?"S":"P")+e;if(!oe(e,n)){if(!hu(e))return"F";if(!t)return"E";i(e)}return e[n].objectID},getWeakData:function(e,t){if(!oe(e,n)){if(!hu(e))return!0;if(!t)return!1;i(e)}return e[n].weakData},onFreeze:function(e){return vu&&r&&hu(e)&&!oe(e,n)&&i(e),e}};Ge[n]=!0})),Eu=i.TypeError,mu=function(e,t){this.stopped=e,this.result=t},yu=mu.prototype,Nu=function(e,t,r){var n,o,i,a,s,u,l,d=r&&r.that,f=!(!r||!r.AS_ENTRIES),p=!(!r||!r.IS_ITERATOR),_=!(!r||!r.INTERRUPTED),h=jn(t,d),v=function(e){return n&&Ms(n,"normal",e),new mu(!0,e)},g=function(e){return f?(Te(e),_?h(e[0],e[1],v):h(e[0],e[1])):_?h(e,v):h(e)};if(p)n=e;else{if(!(o=ks(e)))throw Eu(G(e)+" is not iterable");if(Fs(o)){for(i=0,a=_t(e);a>i;i++)if((s=g(e[i]))&&L(yu,s))return s;return new mu(!1)}n=Ys(e,o)}for(u=n.next;!(l=c(u,n)).done;){try{s=g(l.value)}catch(e){Ms(n,"throw",e)}if("object"==typeof s&&s&&L(yu,s))return s}return new mu(!1)},bu=i.TypeError,wu=function(e,t){if(L(t,e))return e;throw bu("Incorrect invocation")},Cu=function(e,t,r){var n=-1!==e.indexOf("Map"),o=-1!==e.indexOf("Weak"),s=n?"set":"add",u=i[e],l=u&&u.prototype,c=u,d={},f=function(e){var t=m(l[e]);it(l,e,"add"==e?function(e){return t(this,0===e?0:e),this}:"delete"==e?function(e){return!(o&&!x(e))&&t(this,0===e?0:e)}:"get"==e?function(e){return o&&!x(e)?void 0:t(this,0===e?0:e)}:"has"==e?function(e){return!(o&&!x(e))&&t(this,0===e?0:e)}:function(e,r){return t(this,0===e?0:e,r),this})};if(Lt(e,!I(u)||!(o||l.forEach&&!a((function(){(new u).entries().next()})))))c=r.getConstructor(t,e,n,s),gu.enable();else if(Lt(e,!0)){var p=new c,_=p[s](o?{}:-0,1)!=p,h=a((function(){p.has(1)})),v=zs((function(e){new u(e)})),g=!o&&a((function(){for(var e=new u,t=5;t--;)e[s](t,t);return!e.has(-0)}));v||((c=t((function(e,t){wu(e,l);var r=Ni(new u,e,c);return null!=t&&Nu(t,r[s],{that:r,AS_ENTRIES:n}),r}))).prototype=l,l.constructor=c),(h||g)&&(f("delete"),f("has"),n&&f("get")),(g||_)&&f(s),o&&l.clear&&delete l.clear}return d[e]=c,Pt({global:!0,forced:c!=u},d),na(c,e),o||r.setStrong(c,e,n),c},Au=function(e,t,r){for(var n in t)it(e,n,t[n],r);return e},Su=pe("species"),Tu=function(e){var t=M(e),r=Re.f;s&&t&&!t[Su]&&r(t,Su,{configurable:!0,get:function(){return this}})},Ou=Re.f,Iu=gu.fastKey,xu=et.set,Du=et.getterFor,Mu={getConstructor:function(e,t,r,n){var o=e((function(e,o){wu(e,i),xu(e,{type:t,index:ir(null),first:void 0,last:void 0,size:0}),s||(e.size=0),null!=o&&Nu(o,e[n],{that:e,AS_ENTRIES:r})})),i=o.prototype,a=Du(t),u=function(e,t,r){var n,o,i=a(e),u=l(e,t);return u?u.value=r:(i.last=u={index:o=Iu(t,!0),key:t,value:r,previous:n=i.last,next:void 0,removed:!1},i.first||(i.first=u),n&&(n.next=u),s?i.size++:e.size++,"F"!==o&&(i.index[o]=u)),e},l=function(e,t){var r,n=a(e),o=Iu(t);if("F"!==o)return n.index[o];for(r=n.first;r;r=r.next)if(r.key==t)return r};return Au(i,{clear:function(){for(var e=a(this),t=e.index,r=e.first;r;)r.removed=!0,r.previous&&(r.previous=r.previous.next=void 0),delete t[r.index],r=r.next;e.first=e.last=void 0,s?e.size=0:this.size=0},delete:function(e){var t=this,r=a(t),n=l(t,e);if(n){var o=n.next,i=n.previous;delete r.index[n.index],n.removed=!0,i&&(i.next=o),o&&(o.previous=i),r.first==n&&(r.first=o),r.last==n&&(r.last=i),s?r.size--:t.size--}return!!n},forEach:function(e){for(var t,r=a(this),n=jn(e,arguments.length>1?arguments[1]:void 0);t=t?t.next:r.first;)for(n(t.value,t.key,this);t&&t.removed;)t=t.previous},has:function(e){return!!l(this,e)}}),Au(i,r?{get:function(e){var t=l(this,e);return t&&t.value},set:function(e,t){return u(this,0===e?0:e,t)}}:{add:function(e){return u(this,e=0===e?0:e,e)}}),s&&Ou(i,"size",{get:function(){return a(this).size}}),o},setStrong:function(e,t,r){var n=t+" Iterator",o=Du(t),i=Du(n);vs(e,t,(function(e,t){xu(this,{type:n,target:e,state:o(e),kind:t,last:void 0})}),(function(){for(var e=i(this),t=e.kind,r=e.last;r&&r.removed;)r=r.previous;return e.target&&(e.last=r=r?r.next:e.state.first)?"keys"==t?{value:r.key,done:!1}:"values"==t?{value:r.value,done:!1}:{value:[r.key,r.value],done:!1}:(e.target=void 0,{value:void 0,done:!0})}),r?"entries":"values",!r,!0),Tu(t)}};Cu("Set",(function(e){return function(){return e(this,arguments.length?arguments[0]:void 0)}}),Mu);var Lu=Gn.filter,Ru=zr("filter");Pt({target:"Array",proto:!0,forced:!Ru},{filter:function(e){return Lu(this,e,arguments.length>1?arguments[1]:void 0)}});var Pu=Re.f,Fu=bt.f,Vu=et.enforce,ku=pe("match"),ju=i.RegExp,Yu=ju.prototype,Wu=i.SyntaxError,Bu=m(Gt),Hu=m(Yu.exec),Uu=m("".charAt),Gu=m("".replace),zu=m("".indexOf),$u=m("".slice),qu=/^\?<[^\s\d!#%&*+<=>@^][^\s!#%&*+<=>@^]*>/,Xu=/a/g,Ku=/a/g,Qu=new ju(Xu)!==Xu,Zu=Xt.MISSED_STICKY,Ju=Xt.UNSUPPORTED_Y,el=s&&(!Qu||Zu||sr||lr||a((function(){return Ku[ku]=!1,ju(Xu)!=Xu||ju(Ku)==Ku||"/a/i"!=ju(Xu,"i")})));if(Lt("RegExp",el)){for(var tl=function(e,t){var r,n,o,i,a,s,u=L(Yu,this),l=ln(e),c=void 0===t,d=[],f=e;if(!u&&l&&c&&e.constructor===tl)return e;if((l||L(Yu,e))&&(e=e.source,c&&(t="flags"in f?f.flags:Bu(f))),e=void 0===e?"":Ut(e),t=void 0===t?"":Ut(t),f=e,sr&&"dotAll"in Xu&&(n=!!t&&zu(t,"s")>-1)&&(t=Gu(t,/s/g,"")),r=t,Zu&&"sticky"in Xu&&(o=!!t&&zu(t,"y")>-1)&&Ju&&(t=Gu(t,/y/g,"")),lr&&(i=function(e){for(var t,r=e.length,n=0,o="",i=[],a={},s=!1,u=!1,l=0,c="";n<=r;n++){if("\\"===(t=Uu(e,n)))t+=Uu(e,++n);else if("]"===t)s=!1;else if(!s)switch(!0){case"["===t:s=!0;break;case"("===t:Hu(qu,$u(e,n+1))&&(n+=2,u=!0),o+=t,l++;continue;case">"===t&&u:if(""===c||oe(a,c))throw new Wu("Invalid capture group name");a[c]=!0,i[i.length]=[c,l],u=!1,c="";continue}u?c+=t:o+=t}return[o,i]}(e),e=i[0],d=i[1]),a=Ni(ju(e,t),u?this:Yu,tl),(n||o||d.length)&&(s=Vu(a),n&&(s.dotAll=!0,s.raw=tl(function(e){for(var t,r=e.length,n=0,o="",i=!1;n<=r;n++)"\\"!==(t=Uu(e,n))?i||"."!==t?("["===t?i=!0:"]"===t&&(i=!1),o+=t):o+="[\\s\\S]":o+=t+Uu(e,++n);return o}(e),r)),o&&(s.sticky=!0),d.length&&(s.groups=d)),e!==f)try{Pe(a,"source",""===f?"(?:)":f)}catch(e){}return a},rl=function(e){e in tl||Pu(tl,e,{configurable:!0,get:function(){return ju[e]},set:function(t){ju[e]=t}})},nl=Fu(ju),ol=0;nl.length>ol;)rl(nl[ol++]);Yu.constructor=tl,tl.prototype=Yu,it(i,"RegExp",tl)}Tu("RegExp");var il=Math.min,al=[].lastIndexOf,sl=!!al&&1/[1].lastIndexOf(1,-0)<0,ul=Zr("lastIndexOf"),ll=sl||!ul?function(e){if(sl)return sn(al,this,arguments)||0;var t=O(this),r=_t(t),n=r-1;for(arguments.length>1&&(n=il(n,ut(arguments[1]))),n<0&&(n=r+n);n>=0;n--)if(n in t&&t[n]===e)return n||0;return-1}:al;Pt({target:"Array",proto:!0,forced:ll!==[].lastIndexOf},{lastIndexOf:ll});var cl=!0,dl=Object.create(null);function fl(){return cl}var pl={},_l=function(){return this}();try{_l=globalThis||new Function("return this")()}catch(e){"object"===("undefined"==typeof window?"undefined":zi(window))&&(_l=window)}var hl=_l,vl=Ki.f,gl=a((function(){return!Object.getOwnPropertyNames(1)}));Pt({target:"Object",stat:!0,forced:gl},{getOwnPropertyNames:vl});var El,ml=ot.PROPER,yl=Ii.trim;Pt({target:"String",proto:!0,forced:(El="trim",a((function(){return!!wi[El]()||"​᠎"!=="​᠎"[El]()||ml&&wi[El].name!==El})))},{trim:function(){return yl(this)}});var Nl=Ii.trim,bl=i.parseInt,wl=i.Symbol,Cl=wl&&wl.iterator,Al=/^[+-]?0x/i,Sl=m(Al.exec),Tl=8!==bl(wi+"08")||22!==bl(wi+"0x16")||Cl&&!a((function(){bl(Object(Cl))}))?function(e,t){var r=Nl(Ut(e));return bl(r,t>>>0||(Sl(Al,r)?16:10))}:bl;Pt({global:!0,forced:parseInt!=Tl},{parseInt:Tl});var Ol=gu.onFreeze,Il=Object.freeze,xl=a((function(){Il(1)}));Pt({target:"Object",stat:!0,forced:xl,sham:!vu},{freeze:function(e){return Il&&x(e)?Il(Ol(e)):e}});var Dl={restoring:null,idDataMap:null,compIdArr:null,compExtraDataMap:null,compIdArrIndex:0};function Ml(e,t,r){var n;void 0===e.__resizers&&(e.__resizers=[],n=e,exparser.Observer.create((function(e){e.status})).observe(n,{attachStatus:!0})),e.__resizers[t]=r}var Ll=null,Rl=!1,Pl=!1,Fl=[],Vl=null,kl=[],jl=0,Yl=null,Wl=Object.prototype.hasOwnProperty;function Bl(e){return e instanceof exparser.Component&&exparser.Component.getComponentOptions(e).domain}function Hl(e,t){var r=this;if(e){var n,o=e,i=Bl(o),a=(n=o)instanceof exparser.Component&&"//"===exparser.Component.getComponentOptions(n).domain,s={selectAllComponents:function(r){if(t!==i)return[];var n=Pl?e.shadowRoot.querySelectorAll(r):e.querySelectorAll(r),o=[];return n.forEach((function(e){o.push(Gl(Hl(e,t),!0))})),o},selectComponent:function(r){if(t!==i)return null;var n=Pl?e.shadowRoot.querySelector(r):e.querySelector(r);return n?Gl(Hl(n,t),!0):null},removeClass:function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];if(Wo()||!o||!e.length)return r;var n=o.__wxsClass?o.__wxsClass.split(/\s+/):[],i=[];return e.forEach((function(e){(e=e.replace(/^\s+|\s+$/g,""))&&o.classList.contains(e)&&(o.classList.toggle(e),Rl=!0,i.push(e))})),i.forEach((function(e){n.forEach((function(t,r){return t!==e||(n.splice(r,1),!1)}))})),o.__wxsClass=n.join(" "),r},addClass:function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];if(Wo()||!o||!e.length)return r;var n=o.__wxsClass||"",i=[];return e.forEach((function(e){(e=e.replace(/^\s+|\s+$/g,""))&&(o.classList.contains(e)||(o.classList.toggle(e),i.push(e),Rl=!0))})),o.__wxsClass=n+(n?" ":"")+i.join(" "),r},hasClass:function(e){return!(Wo()||!o)&&o.classList.contains(e)},setStyle:function(e){if(Wo()||!o)return r;if(e===o.__wxsStyle)return r;var t=[];if("object"===qs(e))for(var n in e=e?zl(e):{})Wl.call(e,n)&&t.push(n+":"+e[n]);else t=[String(e)];function i(){var e=dd.transformRpx(o.__wxsStyle,!0);o.setNodeStyle(e,No.STYLE_SEGMENT_INDEX.DDS_STYLE)}return o.__wxsStyle=t.join(";"),i(),Ml(o,No.STYLE_SEGMENT_INDEX.DDS_STYLE,i),Rl=!0,r},getDataset:function(){return o?Gl(o.dataset):null},getState:function(){return o?(o.__wxsState=o.__wxsState||{},o.__wxsState):null},triggerEvent:function(t,n,i){return!a&&e&&(n=n?zl(n):n,i=i?zl(i):i,jl++,o.triggerEvent(t,n,i),jl--),r},callMethod:function(t,n){var o,i,a=n||{};return!Wo()&&t&&(a=zl(a),Pl?Ho(No.SYNC_EVENT_NAME.CALL_METHOD_FROM_DDS,[null===(o=window.nativeParam)||void 0===o?void 0:o.webViewId,e&&e.__ddTmplId||0,t,a,cu()]):dd.callMethodFromWxs([(null===(i=window.nativeParam)||void 0===i||i.webViewId,e&&e.__ddTmplId||0),t,a,cu()])),r},requestAnimationFrame:function(e){if(!Wo()&&"function"==typeof e){var t=e;Wo()||"function"!=typeof t||(Fl.push(t),Vl||window.requestAnimationFrame((function(){Vl=null;var e=Fl;Fl=[],e.forEach((function(e){e(),ql()}))})))}return r},getComputedStyle:function(e){Array.isArray(e)||(e=[]);var t={computedStyle:e.filter((function(e){return"string"==typeof e}))};return Gl(si(o,t))},animate:function(){},clearAnimation:function(e,t){var r=Math.random()+"-"+ +new Date,n=nu.instance;"function"==typeof t?(e=zl(e),n.clearAnimationCbMap[r]=t):"function"==typeof e&&(n.clearAnimationCbMap[r]=e)}};return Object.freeze(s),s}}function Ul(){return"function"==typeof Ll?Ll:null}function Gl(e,t){return Ll?Ll(e,"nv_",t?2:void 0):e}function zl(e,t){var r;return 1<arguments.length&&t&&(r=2),Ll?Ll(e,void 0,r):e}function $l(e,t,r){return t?r?t+e+r:t||"":r||""}function ql(){!Wo()&&Rl&&0===jl&&(Rl=!1,document.dispatchEvent(new CustomEvent("pageReRender",{})))}function Xl(e,t){var r=e.ownerShadowRoot?e.ownerShadowRoot.__ddHost:window.__DOMTree__,n=t?r:e;return Pl=!!e.ownerShadowRoot,Hl(n,Bl(n))}function Kl(e){var t=e[0],r=e[1],n=e[2],o=e[3],i=void 0===o?{}:o,a=e[4];if(r){var s=nu.get(t);if(!s)return;var u=s.nodeId.getNodeById(r);if(!u)return;var l=exparser.Element.getMethodCaller(u);l&&"function"==typeof l[n]&&(a?fu((function(){l[n](i)})):l[n](i))}else{var c=__appServiceEngine__.getCurrentPagesByDomain("");if(!c.length)return;var d=c[c.length-1];d&&"function"==typeof d[n]&&(a?fu((function(){d[n](i)})):d[n](i))}}function Ql(e,t,r){if(e){var n=null;if(t.ownerShadowRoot&&nu.instance&&e._custom){var o=nu.instance.nodeId.getNodeId(t.ownerShadowRoot.__ddHost);if(!(e=e._custom)[o])return;e=e[o]}var i=t.is;if(e[i]&&e[i].length&&e[i][0]&&e[i][0].index===r&&(n=e[i].shift()),n){if(t.__ddsStyle=n.ddsStyle,t.__ddsClass=n.ddsClass,t.__ddsState=Gl(n.ddsState),n.ddsStyle){var a=function(){var e=window.dd.transformRpx(t.__ddsStyle,!0);t.setNodeStyle(e,No.STYLE_SEGMENT_INDEX.DDS_STYLE)};a(),Ml(t,No.STYLE_SEGMENT_INDEX.DDS_STYLE,a)}n.ddsClass&&(t.class=$l(" ",t.class,n.ddsClass))}}}Wo()&&__appServiceSDK__.onCallMethodFromWxs(Kl);var Zl=null,Jl=null;function ec(e){e.$$.style.display="none"}function tc(e){if(e instanceof exparser.Component)ec(e);else if(e instanceof exparser.VirtualNode)for(var t=0;t<e.childNodes.length;t++)tc(e.childNodes[t]);else e instanceof exparser.TextNode&&(e.textContent="");e.__banned=!0}function rc(e){var t,r;e&&(Zl&&(t=exparser.Component.getComponentOptions(e).domain.split("/",1)[0],r=e.shadowRoot,Zl[t]&&function(e,t){tc(e),Jl=Jl||exparser.registerElement({options:{renderingMode:"native"}});var r=e.createComponent("dd-hint",Jl),n=document.createElement("div");n.innerText=t.hint,r.$$.appendChild(n),e.appendChild(r)}(r,Zl[t])))}var nc={},oc=void 0!==dd&&dd.transformRpx,ic=/-[a-z]/g,ac=/([A-Z])/g;function sc(e){return nc[e]||(nc[e]=e.replace(ac,"-$1").toLowerCase()),nc[e]}function uc(e){return Wo()&&e instanceof exparser.Component?nu.get(e.__ddWebViewId__).nodeId.getNodeById(e.__ddExparserNodeId__):e}function lc(e,t,r){var n=uc(e);return r&&n instanceof exparser.VirtualNode&&!n.id&&!Object.getOwnPropertyNames(n.dataset).length&&(n=uc(r)),{id:t?"":n.id,offsetLeft:n.$$&&!t?n.$$.offsetLeft:0,offsetTop:n.$$&&!t?n.$$.offsetTop:0,dataset:t?{}:n.dataset}}function cc(e,t,r){var n=uc(e);return r&&n instanceof exparser.VirtualNode&&!n.id&&!Object.getOwnPropertyNames(n.dataset).length&&(n=uc(r)),{id:t?"":n.id,dataset:t?{}:n.dataset}}function dc(e){if(e){for(var t=[],r=0,n=e;r<n.length;r++){var o=n[r];t.push({identifier:o.identifier,pageX:o.pageX,pageY:o.pageY,clientX:o.clientX,clientY:o.clientY,force:o.force||0})}return t}}function fc(e,t,r,n,o,i,a){var s=o?"__ddEventCaptureHandleName":"__ddEventHandleName";e[s]||(e[s]=Object.create(null)),void 0===e[s][t]&&e.addListener(t,(function(r){var o=e[s][t],u=r.mutatedMarked();if((!a||!u)&&(a&&r.markMutated(),o)){r._hasListeners=!0;var l=e.ownerShadowRoot;if(l){var c=l.getHostNode();if(!c)return;var d=exparser.Component.getComponentOptions(c).writeOnly;if(!d||r._allowWriteOnly)if(Wo()){if(i&&Qn(o))return;var f=exparser.Element.getMethodCaller(c);Qn(f[o])&&f[o]({type:r.type,timeStamp:r.timeStamp,target:cc(r.target,d,this),currentTarget:cc(this,d,null),mark:r.mark,detail:r.detail,touches:r.touches,changedTouches:r.changedTouches,mut:u,_requireActive:r._requireActive})}else if(i){if(Qn(o)&&Ul()){var p={type:r.type,timeStamp:r.timeStamp,target:lc(r.target,d,this),currentTarget:lc(this,d,null),mark:r.mark,detail:r.detail,touches:dc(r.touches),changedTouches:dc(r.changedTouches),mut:u};p.instance=Xl(e);var _=o(Gl(p,!0),Gl(Xl(e,!0),!0));if(ql(),!1===_)return _}}else{var h={type:r.type,timeStamp:r.timeStamp,target:lc(r.target,d,this),currentTarget:lc(this,d,null),mark:r.mark,detail:r.detail,touches:dc(r.touches),changedTouches:dc(r.changedTouches),mut:u,_requireActive:r._requireActive,_relatedInfo:r._relatedInfo,_userTap:cu()};Ho(No.SYNC_EVENT_NAME.DD_EVENT,[nu.instance.nodeId.getNodeId(c),o,h],void 0,!!r._requireActive||void 0)}}if(n)return!1}}),{capture:o}),i?e[s][t]=r:(e[s][t]=null==r?"":String(r),Qn(e.__eventHandlerChangeListener__)&&e.__eventHandlerChangeListener__(r,e[s][t],o))}function pc(e,t,r,n){if(e){e.dataset=e.dataset||{};var o=0,i=!1,a=[],s=e instanceof exparser.Component,u=s&&"//"===exparser.Component.getComponentOptions(e).domain,l=exparser.Component.getDataProxy(e);for(var c in t)v(c);i&&l.doUpdates(o,!Wo());for(var d,f,p=function(t){e.__ddPropertyListener__&&e.__ddPropertyListener__[t]||(e.setPropertyChangeListener(t,(function(r){var n=e.ownerShadowRoot.getHostNode();if(Wo())n.setData(Xs({},e.__modelValueName[t],r));else{var o=nu.instance.nodeId.getNodeId(n);Ho(No.SYNC_EVENT_NAME.MODEL_VALUE_CHANGE,{data:r,modelValueName:e.__modelValueName&&e.__modelValueName[t],nodeId:o})}})),e.__ddPropertyListener__=e.__ddPropertyListener__||{},e.__ddPropertyListener__[t]=!0)},_=0,h=a;_<h.length;_++){p(h[_])}if(!Wo()&&e.ddsObserver&&Ul()&&(f=t,!(d=e).ddsObserver||Wo()||Dl.restoring||(kl.push({node:d,props:f}),Yl=Yl||window.requestAnimationFrame((function(){Yl=null;var e=kl;kl=[],e.forEach((function(e){var t;for(t in d.node.ddsObserver){var r=void 0;Wl.call(d.props,t)&&e.ddsObserver[t]&&"function"==typeof e.ddsObserver[t].observer&&(r=e.ddsObserver[t].value,exparser.safeCallback("DDS Observer",e.ddsObserver[t].observer,null,[Gl(d.props[t]),Gl(r),Gl(Xl(e,!0),!0),Gl(Xl(e),!0)],e.ownerShadowRoot?e.ownerShadowRoot.__ddHost:void 0),e.ddsObserver[t].value=d.props[t])}}))})))),e.__component__&&!Dl.restoring)if(Wo())e.__treeManager__.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_APPLY_PROPERTY]);else if(nu.instance.operationFlow.iterator.nextStep()[0]!==No.SYNC_EVENT_NAME.FLOW_APPLY_PROPERTY)throw new Error("Framework inner error (expect FLOW_APPLY_PROPERTY but get another)")}function v(c){var d,f,p,_,h,v=t[c],g=null,E=function(e){return null==e?"":e};if("slot"===e.is&&e instanceof exparser.VirtualNode&&"name"===c)return exparser.Element.setSlotName(e,v),"continue";if("id"===c)return e.id=E(v),"continue";if("slot"===c)return e.slot=E(v),"continue";if("class"===c&&s&&(e.class=e.__ddsClass?$l(" ",E(v),e.__ddsClass):E(v),e.hasExternalClass("class")&&e.setExternalClass("class",v)),"style"===c&&s&&e.$$&&(d=oc(v,!0),e.setNodeStyle(d,No.STYLE_SEGMENT_INDEX.ATTR),d===v?(p=e,_=No.STYLE_SEGMENT_INDEX.ATTR,void 0!==p.__resizers&&(p.__resizers[_]=void 0)):Ml(e,No.STYLE_SEGMENT_INDEX.ATTR,(function(){var t=oc(v,!0);e.setNodeStyle(t,No.STYLE_SEGMENT_INDEX.ATTR),e.__transformedPropValue=t})),e.__banned&&ec(e)),s&&exparser.Component.hasPublicProperty(e,c)){!u&&Dl.restoring||(l.scheduleReplace([c],v,null!=r?r[c]:null),u?l.doUpdates(void 0,!0):(i=!0,e.isInnerDataExcluded(c)||o++));var m=n&&n["model:"+sc(c)];if(m){var y=m.match(/^\{\{(.*?)\}\}$/);if(y){var N=y[1].match(/^\s*([_a-zA-Z$][_a-zA-Z0-9$]+)\s*$/);if(N){var b=N[1];e.__modelValueName=$i(e.__modelValueName||{},Xs({},c,b)),a.push(c)}}}return"continue"}if("style"===c)return"continue";if(/^data-/.test(c)){f=c.slice(5).toLowerCase();var w=nc[f]?nc[f]:nc[f]=f.indexOf("-")<=0?f:f.replace(ic,(function(e){return e[1].toUpperCase()}));return e.dataset[w]=v,e.setAttribute(c,v),"continue"}if("$gdc"===c&&"function"==typeof(h=v)&&(Ll=h),(g=c.match(/^\$wxs:(capture-)?(mut-)?(bind|catch):?(.+)$/))&&(Qn(v)||!v))return fc(e,g[4],v,"catch"===g[3],g[1],!0,g[2]),Wo()||e.setAttribute("exparser:info-attr-"+c.slice(4),v.name),"continue";if(g=c.match(/^(capture-)?(mut-)?(bind|catch):?(.+)$/))return fc(e,g[4],v,"catch"===g[3],g[1],!1,g[2]),Wo()||e.setAttribute("exparser:info-attr-"+c,v),"continue";if("on"===c.slice(0,2))return fc(e,c.slice(2),v,!1,!1,!1),"continue";if("animation"===c){if(s&&e.$$&&null!==v&&"object"===qs(v)&&v.actions&&v.actions.length>0){var C=0,A=v.actions,S=v.actions.length,T=function(){if(C<S){var t=dd.animationToStyle(A[C]),r=t.transition,n=t.transitionProperty,o=t.transform,i=t.transformOrigin,a=t.style,s={transition:r,transform:o,transitionProperty:n,transformOrigin:i},u=e.__styleObj?Eo(Eo({},e.__styleObj),s):s;for(var l in u["-webkit-transition"]=u.transition,u["-webkit-transform"]=u.transform,u["-webkit-transition-property"]=u.transitionProperty,u["-webkit-transform-origin"]=u.transformOrigin,a)u[l]=a[l];e.__styleObj=u,""!==e.__styleObj.transform&&(e.__transformNoneEnabled=!0);var c=Object.keys(u).filter((function(t){return!(/transition/i.test(t)&&""===u[t]||""===t.trim()||void 0===u[t]||!/transform/i.test(t)&&""===u[t]||!isNaN(parseInt(t,10)))&&(/transform/i.test(t)&&""===u[t]&&e.__transformNoneEnabled&&(u[t]="none"),!0)})).map((function(e){return e.replace(/([A-Z]{1})/g,(function(e){return"-"+e.toLowerCase()}))+":"+u[e]})).join(";"),d=function(){e.setNodeStyle(oc(c,!0),No.STYLE_SEGMENT_INDEX.ANIMATION)};d(),Ml(e,No.STYLE_SEGMENT_INDEX.ANIMATION,d),e.__banned&&ec(e)}};e.addListener("transitionend",(function(){C+=1,T()})),T()}return"continue"}if(g=c.match(/^\$wxs:change:(.+)$/))return e.ddsObserver=e.ddsObserver||{},e.ddsObserver[g[1]]=e.ddsObserver[g[1]]||{},e.ddsObserver[g[1]].observer=v,"continue";if(g=c.match(/^mark:(.+)$/))return e.setMark(g[1],v),"continue";var O=sc(c);return s&&e.hasExternalClass(O)?(e.setExternalClass(O,v),"continue"):void 0}}var _c={tag:"shadow",children:[]};function hc(e,t,r){if((3!==e.wxXCkey&&4!==e.wxXCkey||Wo()||window&&window.__customComponentMode__)&&(t.__ddDynamicSync__=4===e.wxXCkey?"wx:for":"wx:if"),!Wo()){if(e.extraAttr)for(var n in e.extraAttr)t.setAttribute(n,e.extraAttr[n]);void 0!==e.wxScopeData&&(t.__wxScopeData__=e.wxScopeData)}var o=t.__component__,i=t.__placeholder__;if(o||i)if(Wo())exparser.Element.getMethodCaller(t).__ddExparserNodeId__=r.nodeId.allocNodeId(t,""),exparser.Element.getMethodCaller(t).__wxExparserNodeId__=exparser.Element.getMethodCaller(t).__ddExparserNodeId__,r.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_CREATE_NODE,r.nodeId.getNodeId(t)]);else{if(r=nu.instance,Dl.restoring){var a=Dl.idDataMap[r.nodeId.getNodeId(t)];exparser.Component.replaceWholeData(t,a,null)}else{var s=r.operationFlow.iterator.nextStep();if(s[0]!==No.SYNC_EVENT_NAME.FLOW_CREATE_NODE)throw new Error("Framework inner error (expect FLOW_CREATE_NODE but get another)");r.nodeId.allocNodeId(t,s[1])}rc(t),t.setAttribute("is",t.is)}pc(t,e.attr,e.raw,e.rawAttr)}function vc(e,t){var r=e?e(t,null,hl):_c;return r.tag="shadow",r}function gc(e,t,r,n,o){var i,a,s=null;if(Wo()||n||(n=nu.instance),"shadow"===e.tag&&t)r=s=exparser.ShadowRoot.create(t);else if("shadow"===e.tag||"virtual"===e.tag)i="virtual",1===e.wxXCkey||3===e.wxXCkey?i="wx:if":2!==e.wxXCkey&&4!==e.wxXCkey||(i="wx:for"),s=r.createVirtualNode(i),exparser.Element.setInheritSlots(s),Wo()?s.__treeManager__=n:s.__wxVkey__=e.wxVkey;else if("dd-slot"===e.tag)s=r.createVirtualNode("slot"),exparser.Element.setSlotName(s,"");else{var u=r.tagNameUsed(e.tag);if(Wo()&&!u)(s=r.createVirtualNode(e.tag)).__treeManager__=n;else if(u){var l=r.getHostNode().__using[e.tag],c=r.getHostNode().getPlaceholder(e.tag);cf(n.viewId,l)&&void 0!==c?((s=r.createComponent(e.tag,c,e.generics,n)).__placeholder__=!0,a=function(t){df(l,t,n,(function(){var t=r.createComponent(e.tag,void 0,e.generics,n);hc(e,t,n),s.childNodes.forEach((function(e){t.appendChild(e),s.removeChild(e)})),s.parentNode&&s.parentNode.replaceChild(t,s)}))}):s=r.createComponent(e.tag,void 0,e.generics,n)}else s=r.createComponent(e.tag,void 0,e.generics,n)}hc(e,s,n),a&&a(n.nodeId.getNodeId(s));var d=e.children;if(d)for(var f=0,p=void 0,_=d.length;f<_;++f)if(null!==(p=d[f]))if("object"===qs(p))s.appendChild(gc(p,null,r,n));else{var h=r.createTextNode(p);s.appendChild(h)}return s}var Ec={id:null,prev:null,data:[],clear:function(){this.id=null,this.prev=null,this.data=[]}};function mc(e){!function(e){var t,r=e.__page__;r&&(t=parseInt(r.scrollTop,10),requestAnimationFrame((function(){document.body.scrollTop=document.documentElement.scrollTop=t})))}(e);var t=0;window.__TAB_BAR__&&(to(window.__TAB_BAR__,1,(function(r){r.triggerLifeTime("restored",[e]),Ql(e.compExtraDataMap,r,t++)})),function(e){if(!Wo()&&e){var t=window.__TAB_BAR__;t&&(t.__ddsState=Gl(e.ddsTabRootState))}}(e.compExtraDataMap)),to(window.__DOMTree__,1,(function(r){r.triggerLifeTime("restored",[e]),Ql(e.compExtraDataMap,r,t++)})),function(e){if(!Wo()&&e){var t=Pl?nu.instance.nodeId.getNodeById(nu.instance.rootNodeId):window.__DOMTree__;t&&(t.__ddsState=e.ddsPageState)}}(e.compExtraDataMap)}function yc(e,t){return e+"/"+t}Uo(No.SYNC_EVENT_NAME.SAVE_STATE,(function(){Qn(dd.webViewReadyToTerminate)&&dd.webViewReadyToTerminate()})),Uo(No.SYNC_EVENT_NAME.RESTORE_STATE,(function(e){var t=e[0],r=e[1],n=e[2];if(t&&t.isSplitData){var o=t.splitInfo,i=o.id,a=o.index,s=o.total,u=o.data;if(1!==a&&(a!==Ec.prev+1||i!==Ec.id))return Ec.clear();if(a!==s)return Ec.id=i,Ec.prev=a,void Ec.data.push(u);Ec.data.push(u);var l=e.data.join("");try{l=JSON.parse(l)}catch(e){Reporter&&Reporter.errorReport({key:"webviewScriptError",error:new Error("Expected parse completed data with split data but got error")}),Reporter&&Reporter.ravenReport("pub_saga_error_message_bt",{key:"webviewScriptError",error:new Error("Expected parse completed data with split data but got error"),fail:function(e){}}),l=null}if(Ec.clear(),!l)return;t=l[0],r=l[1],n=l[2]}Dl.restoring=t||{},Dl.idDataMap=r,Dl.compIdArr=n,Dl.compIdArrIndex=0}));var Nc,bc={},wc={};function Cc(e,t){Qn(Nc)&&Nc()}var Ac=exparser.dataUtils.deepCopy,Sc=Object.prototype.hasOwnProperty;function Tc(e){return"number"==typeof e&&isNaN(e)}function Oc(e){if(Wo())e.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_MINIPULATE_CHILD]);else if(e.operationFlow.iterator.nextStep()[0]!==No.SYNC_EVENT_NAME.FLOW_MINIPULATE_CHILD)throw new Error("Expect FLOW_MINIPULATE_CHILD but get another")}function Ic(e,t,r,n,o){for(var i=o?Ac(e):e,a=0;a<t.length;a++){var s=t[a],u=s[0],l=s[1],c=s[2];if(void 0!==l){for(var d=i,f=u[0],p=1;p<u.length;p++)if(null!=(d=d[f])&&d.__wxspec__&&(d=d.__value__),f=u[p],null!=d&&!Sc.call(d,f)){d=null;break}null!=d&&Sc.call(d,f)&&(r?null!=c&&"object"===qs(l)&&l instanceof Array==c instanceof Array?d[f]={__value__:c,__wxspec__:!0}:null!=d[f]&&d[f].__wxspec__||(d[f]={__value__:d[f],__wxspec__:!0}):d[f]=n?Ac(l,!1):l)}}return i}function xc(e,t,r){if(e!==t&&(!e||r))if(null==t)r.parentNode.removeChild(r);else if("object"===qs(t)){if("object"!==qs(e)||null===e||e.tag!==t.tag||String(e.wxKey)!==String(t.wxKey)||"virtual"===e.tag&&e.wxVkey!==t.wxVkey){var n=Wo()?r.__treeManager__:nu.instance,o=r.parentNode,i=gc(t,null,o.ownerShadowRoot,n);o&&("wx:for"===o.__ddDynamicSync__||"wx:if"===r.__ddDynamicSync__?(n.nodeId.addNode(i),o.replaceChild(i,r),Oc(n),n.nodeId.removeNode(r)):o.replaceChild(i,r),r.__banned&&tc(i))}else{if(t.n&&t.n.length){for(var a=t.n,s=t.attr,u={},l=0,c=a;l<c.length;l++){var d=c[l];u[d]=s[d]}pc(r,u,t.attr,t.rawAttr)}void 0!==t.wxScopeData&&(r.__wxScopeData__=t.wxScopeData),function(e,t,r){var n=!!Jn("customComponents"),o=e.children,i=t.children,a="virtual"===e.tag&&(2===e.wxXCkey||4===e.wxXCkey||void 0===e.wxXCkey)||!n&&i.length!==o.length,s=null,u=null;if(a){var l=function(e,t){for(var r=function(e){for(var t={},r=0;r<e.length;++r){var n=e[r],o=n&&n.wxKey;o?Sc.call(t,o)?n.wxKey=void 0:t[o]=r:Tc(o)&&(n.wxKey=void 0)}return t}(e),n=function(e){for(var t={},r=[],n=0;n<e.length;++n){var o=e[n],i=o&&o.wxKey;i?Sc.call(t,i)?(o.wxKey=void 0,r.push(n)):t[i]=n:(Tc(i)&&(o.wxKey=void 0),r.push(n))}return[t,r]}(t),o=n[0],i=n[1],a=[],s=[],u=[],l=0,c=0,d=0;d<e.length;++d){var f=void 0,p=void 0,_=e[d].wxKey;_?Sc.call(o,_)?(f=o[_],a.push(t[f])):(s.push(d-c),++c,a.push(null)):l<i.length?(p=i[l],a.push(t[p]),++l):(s.push(d-c),++c,a.push(null))}var h=a,v=0,g=[];for(d=0;d<t.length;){for(var E=t[d],m=E&&E.wxKey,y=h[v],N=y&&y.wxKey;null===y;)N=(y=h[++v])&&y.wxKey;v>=h.length?(u.push({oldIndex:r[m],index:d,pos:-1}),++v,++d):N===m?(g.push(v),++v,++d):m?(N&&o[N]!==d+1?(y=h[++v])&&y.wxKey===m?(g.push(v),++v):(--v,u.push({oldIndex:r[m],index:d,pos:v})):u.push({oldIndex:r[m],index:d,pos:v}),++d):++v}var b=0;for(d=0;d<u.length;d++){var w=u[d].pos;if(-1===w)break;for(;b<g.length&&w>g[b];)b++;b>=g.length?u[d].pos=-1:u[d].pos=g[b]}return{children:a,removes:s,inserts:u}}(o,t.children);i=l.children,s=l.removes,u=l.inserts}for(var c=r.childNodes,d=0,f=void 0,p=void 0;d<o.length;d++)f=o[d],!(p=i[d])&&a||xc(f,p,c[d]);if(a){for(var _=Wo()?r.__treeManager__:nu.instance,h=r.childNodes,v=r.ownerShadowRoot,g=u.length,E=[],m=(d=0,void 0);d<g;d++)m=u[d],E.push({node:void 0!==m.oldIndex?h[m.oldIndex]:null,before:m.pos>=0?h[m.pos]:void 0,index:m.index});d=0;for(var y=void 0,N=s.length;d<N;d++)y=h[s[d]],r.removeChild(y),_.nodeId.removeNode(y),"wx:for"===h.__ddDynamicSync__&&(Oc(_),_.nodeId.removeNode(y));d=0;var b=void 0,w=void 0,C=void 0;for(m=void 0;d<g;d++)b=(m=E[d]).before,w=m.index,null===(C=E[d].node)&&(C=gc(t.children[w],null,v,_)),"wx:for"===r.__ddDynamicSync__?(_.nodeId.addNode(C),r.insertBefore(C,b),Oc(_)):r.insertBefore(C,b);r.__banned&&tc(r)}}(e,t,r)}}else if("string"==typeof e)t!==e&&(r.textContent=t);else{var f=r.ownerShadowRoot.createTextNode(t);r.parentNode.replaceChild(f,r)}}var Dc={},Mc={},Lc=1,Rc=[];function Pc(){Rc.pop()}function Fc(e,t){if(Mc[e]){var r=Mc[e],n=Rc[Rc.length-1],o=Rc[Rc.length-2],i=t(r),a=i.isMergedUpdate,s=i.dataPaths,u=i.pendingStartTimestamp,l=i.updateEndTimestamp,c=i.updateStartTimestamp;Ho(No.SYNC_EVENT_NAME.UPDATE_PERFORMANCE_STAT,[e,{isMergedUpdate:a,dataPaths:s,updateProcessId:n,parentUpdateProcessId:o,pendingStartTimestamp:u,updateStartTimestamp:c,updateEndTimestamp:l}])}}Uo(No.SYNC_EVENT_NAME.PERFORMANCE_DATA,(function(e){var t=e[0],r=e[1];nu.get(t).root.triggerLifeTime("performanceData",[r])}));var Vc=function(){function e(){}return e.prototype.beforeMergeValues=function(e,t,r){if(Wo())if("number"!=typeof r)e.forEach((function(e,r){void 0!==e[1]?t[r]=!1:t[r]=!0}));else{for(var n=0;n<r;n++)t[n]=!1;for(var o=r;o<e.length;o++){void 0!==e[o][1]?t[o]=!1:t[o]=!0}}},e.prototype.beforeUpdateValues=function(e,t,r){if(!Wo()&&"number"==typeof r){var n=nu.instance.operationFlow.iterator.nextStepIf(No.SYNC_EVENT_NAME.FLOW_DATA_OBSERVER);if(n){var o=n[1];if(e&&o.length){Fc(nu.instance.nodeId.getNodeId(e),(function(e){return{isMergedUpdate:!0,dataPaths:e.withDataPaths?o.map((function(e){return e[0]})):void 0}}));var i=exparser.Component.getDataProxy(e);i.setChanges(o),i.doUpdates(void 0,!0)}}}},e.prototype.updateValues=function(e,t,r,n,o,i){if(!Dl.restoring){var a,s="number"!=typeof i;if(Wo())if(a=e.__treeManager__,s){a.operationFlow.start();var u=o.filter((function(e){return void 0!==e[1]})),l=a.nodeId.getNodeId(e);a.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_UPDATE,l,Ac(u)])}else{for(var c=[],d=i,f=void 0;d<o.length;d++)void 0!==(f=o[d])[1]&&c.push(f);a.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_DATA_OBSERVER,Ac(c)])}if(this._delayedUpdateValues)this._delayedUpdateValues.push([Ac(t),r,n,o,i]);else{this._delayedUpdateValues=[];try{this._updateValues(e,t,r,n,o,i);var p=this._delayedUpdateValues;this._delayedUpdateValues=null;for(var _=0,h=p;_<h.length;_++){var v=h[_];this._updateValues(e,v[0],v[1],v[2],v[3],v[4])}}catch(e){throw this._delayedUpdateValues=null,e}}s&&Wo()&&a.operationFlow.end()}},e.prototype._updateValues=function(e,t,r,n,o,i){var a="number"!=typeof i,s=Ic(t,o,!0,!1,!Jn("propValueDeepCopy")),u=vc(this._generateFunc,s);Ic(t,o,!1,a,!1);var l=this._virtualTree;this._virtualTree=u,xc(l,u,this.shadowRoot),l=null},e.prototype._resetShadowChildren=function(e,t,r){function n(){if(Wo())r.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_HOT_UPDATE_CHILD]);else if(r.operationFlow.iterator.nextStep()[0]!==No.SYNC_EVENT_NAME.FLOW_HOT_UPDATE_CHILD)throw new Error("Expect FLOW_HOT_UPDATE_CHILD but get another")}Wo()&&(r.operationFlow.start(),r.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_HOT_UPDATE,r.nodeId.getNodeId(e)]));for(var o=this.shadowRoot,i=(this._virtualTree.children||[]).length,a=0;a<i;a++)o.removeChild(o.childNodes[0]);n();var s=vc(this._generateFunc,t);n(),this._virtualTree=s;var u=gc(s,null,e.shadowRoot,r).childNodes;for(a=0;a<u.length;a++)o.insertBefore(u[0],o.childNodes[a]);Wo()&&r.operationFlow.end()},e}(),kc=function(){function e(){}return e.create=function(t,r,n,o){var i=new e;i._initValues=n,i._data=r;var a,s=t.template;try{i._generateFunc="function"==typeof(a=s.func)?a:a.shift().call(void 0,a.shift())}catch(e){}return i._isSimpleComponent="simple://"===o.domain.slice(0,9),i},e.collectIdAndSlotsToMap=function(t,r,n){for(var o=t&&t.childNodes||[],i=0,a=void 0;i<o.length;i++)(a=o[i])instanceof exparser.TextNode||(a.__id&&(r[a.__id]=a),void 0!==a.__slotName&&(n[a.__slotName]=a),e.collectIdAndSlotsToMap(a,r,n))},e.prototype.createInstance=function(t,r){var n=new Vc;if(Wo()||(r=nu.instance),n._template=this,n._generateFunc=this._generateFunc,n.data=Ac(this._data),n.idMap=Object.create(null),n.slots=Object.create(null),Dl.restoring){if(Dl.compIdArrIndex>=Dl.compIdArr.length)throw new Error("Component count unmatched while page recovering");r.nodeId.allocNodeId(t,Dl.compIdArr[Dl.compIdArrIndex++]);var o=Dl.idDataMap[r.nodeId.getNodeId(t)];n._virtualTree=vc(this._generateFunc,o)}else n._virtualTree=vc(this._generateFunc,n.data);return n.shadowRoot=gc(n._virtualTree,t,null,r),e.collectIdAndSlotsToMap(n.shadowRoot,n.idMap,n.slots),n.listeners=[],this._isSimpleComponent||(t.__component__=!0),Wo()&&(t.__treeManager__=r,n.shadowRoot.__treeManager__=r,r.operationFlow.registerSetDataCallback((function(){t.__methodCaller&&t.triggerLifeTime("ready")}))),n._delayedUpdateValues=null,n},e}(),jc=gu.getWeakData,Yc=et.set,Wc=et.getterFor,Bc=Gn.find,Hc=Gn.findIndex,Uc=m([].splice),Gc=0,zc=function(e){return e.frozen||(e.frozen=new $c)},$c=function(){this.entries=[]},qc=function(e,t){return Bc(e.entries,(function(e){return e[0]===t}))};$c.prototype={get:function(e){var t=qc(this,e);if(t)return t[1]},has:function(e){return!!qc(this,e)},set:function(e,t){var r=qc(this,e);r?r[1]=t:this.entries.push([e,t])},delete:function(e){var t=Hc(this.entries,(function(t){return t[0]===e}));return~t&&Uc(this.entries,t,1),!!~t}};var Xc,Kc={getConstructor:function(e,t,r,n){var o=e((function(e,o){wu(e,i),Yc(e,{type:t,id:Gc++,frozen:void 0}),null!=o&&Nu(o,e[n],{that:e,AS_ENTRIES:r})})),i=o.prototype,a=Wc(t),s=function(e,t,r){var n=a(e),o=jc(Te(t),!0);return!0===o?zc(n).set(t,r):o[n.id]=r,e};return Au(i,{delete:function(e){var t=a(this);if(!x(e))return!1;var r=jc(e);return!0===r?zc(t).delete(e):r&&oe(r,t.id)&&delete r[t.id]},has:function(e){var t=a(this);if(!x(e))return!1;var r=jc(e);return!0===r?zc(t).has(e):r&&oe(r,t.id)}}),Au(i,r?{get:function(e){var t=a(this);if(x(e)){var r=jc(e);return!0===r?zc(t).get(e):r?r[t.id]:void 0}},set:function(e,t){return s(this,e,t)}}:{add:function(e){return s(this,e,!0)}}),o}},Qc=et.enforce,Zc=!i.ActiveXObject&&"ActiveXObject"in i,Jc=function(e){return function(){return e(this,arguments.length?arguments[0]:void 0)}},ed=Cu("WeakMap",Jc,Kc);if(Be&&Zc){Xc=Kc.getConstructor(Jc,"WeakMap",!0),gu.enable();var td=ed.prototype,rd=m(td.delete),nd=m(td.has),od=m(td.get),id=m(td.set);Au(td,{delete:function(e){if(x(e)&&!hu(e)){var t=Qc(this);return t.frozen||(t.frozen=new Xc),rd(this,e)||t.frozen.delete(e)}return rd(this,e)},has:function(e){if(x(e)&&!hu(e)){var t=Qc(this);return t.frozen||(t.frozen=new Xc),nd(this,e)||t.frozen.has(e)}return nd(this,e)},get:function(e){if(x(e)&&!hu(e)){var t=Qc(this);return t.frozen||(t.frozen=new Xc),nd(this,e)?od(this,e):t.frozen.get(e)}return od(this,e)},set:function(e,t){if(x(e)&&!hu(e)){var r=Qc(this);r.frozen||(r.frozen=new Xc),nd(this,e)?id(this,e,t):r.frozen.set(e,t)}else id(this,e,t);return this}})}function ad(e,t,r){e instanceof ld&&Object.defineProperty(e,t,{value:r,writable:!0,enumerable:!0,configurable:!0})}function sd(e,t,r){var n=ld.getExparserComponent(e);if(!n)return r?[]:null;var o=exparser.Component.getComponentOptions(n).domain,i=n.shadowRoot;if(r)return i.querySelectorAll(t).map((function(t){return ud(o,t,e)}));var a=i.querySelector(t);return a?ud(o,a,e):null}function ud(e,t,r){if(!t)return null;var n=exparser.Component.getComponentOptions(t).domain,o=exparser.Component.getMethod(t,"__export__"),i=n===e?exparser.Element.getMethodCaller(t):null;if(o){var a=n===e?r:null,s=o.call(exparser.Element.getMethodCaller(t),a);return void 0===s?i:s}return i}var ld=function(){function e(){this.__data__=null,this.__exitState__=null}return e.getExparserComponent=function(t){return e.callerMap.get(t)},e.getExparserProtocol=function(e){return e?exparser.Component.getComponentOptions(e).domain.split("/",1)[0]:""},Object.defineProperty(e.prototype,"is",{get:function(){var t=e.getExparserComponent(this);return t?t.is:""},set:function(e){ad(this,"is",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"id",{get:function(){var t=e.getExparserComponent(this);return t?exparser.Component.getComponentOptions(t).writeOnly?"":t.id:""},set:function(e){ad(this,"id",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"getPageId",{get:function(){return function(){var t=e.getExparserComponent(this);return t?"pageId:"+t.__treeManager__.viewId:""}},set:function(e){ad(this,"getPageId",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"dataset",{get:function(){var t=e.getExparserComponent(this);return t?exparser.Component.getComponentOptions(t).writeOnly?null:t.dataset:null},set:function(e){ad(this,"dataset",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"properties",{get:function(){return this.__data__},set:function(e){ad(this,"properties",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"data",{get:function(){return this.__data__},set:function(e){ad(this,"data",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"setData",{get:function(){return function(t,r){var n=e.getExparserComponent(this);if(n)return Qn(r)&&n.__treeManager__.operationFlow.registerSetDataCallback(r,this,n),n.setData(t)}},set:function(e){ad(this,"setData",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"groupSetData",{get:function(){return function(t){var r=e.getExparserComponent(this);if(r){var n=r.__treeManager__;n.operationFlow.start(),n.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_GROUP]);var o=null;try{t.call(this)}catch(e){o=e}if(n.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_GROUP_END]),n.operationFlow.end(),o)throw o}}},set:function(e){ad(this,"setData",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"replaceDataOnPath",{get:function(){var t=this;return function(r,n){var o=e.getExparserComponent(t);return o?o.replaceDataOnPath(r,n):void 0}},set:function(e){ad(this,"replaceDataOnPath",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"applyDataUpdates",{get:function(){var t=this;return function(){var r=e.getExparserComponent(t);return r?r.applyDataUpdates():void 0}},set:function(e){ad(this,"applyDataUpdates",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"hasBehavior",{get:function(){var t=this;return function(r){var n=e.getExparserComponent(t);return!!n&&n.hasBehavior(r)}},set:function(e){ad(this,"hasBehavior",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"triggerEvent",{get:function(){var t=this;return function(r,n,o){var i=e.getExparserComponent(t);return i?i.triggerEvent(r,n,o):void 0}},set:function(e){ad(this,"triggerEvent",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"createSelectorQuery",{get:function(){var t=this;return function(){var r=e.getExparserComponent(t);return r?__appServiceSDK__._createSelectorQuery({},e.getExparserProtocol(r)).in(t):null}},set:function(e){ad(this,"createSelectorQuery",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"createIntersectionObserver",{get:function(){var t=this;return function(r){var n=e.getExparserComponent(t);return n?__appServiceSDK__._createIntersectionObserver(t,r,e.getExparserProtocol(n)):null}},set:function(e){ad(this,"createIntersectionObserver",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"createMediaQueryObserver",{get:function(){return function(){}},set:function(e){ad(this,"createMediaQueryObserver",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"getOpenerEventChannel",{get:function(){return function(){return __appServiceEngine__.getCurrentPageWithAdditionalInfo().eventChannel}},set:function(e){ad(this,"getOpenerEventChannel",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"applyAnimation",{get:function(){return function(){}},set:function(e){ad(this,"applyAnimation",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"clearAnimation",{get:function(){return function(){}},set:function(e){ad(this,"clearAnimation",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"animate",{get:function(){return function(){}},set:function(e){ad(this,"animate",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"selectOwnerComponent",{get:function(){var t=this;return function(){var r=e.getExparserComponent(t);if(!r)return null;if(exparser.Component.getComponentOptions(r).writeOnly)return null;var n=exparser.Component.getComponentOptions(r).domain,o=r.ownerShadowRoot;if(!(o instanceof exparser.ShadowRoot))return null;var i=o.getHostNode();return i?ud(n,i,t):null}},set:function(e){ad(this,"selectOwnerComponent",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"selectComponent",{get:function(){var t=this;return function(r){var n=e.getExparserComponent(t);return n?exparser.Component.getComponentOptions(n).writeOnly?null:sd(t,r,!1):null}},set:function(e){ad(this,"selectComponent",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"selectAllComponents",{get:function(){var t=this;return function(r){var n=e.getExparserComponent(t);return n?exparser.Component.getComponentOptions(n).writeOnly?[]:sd(t,r,!0):[]}},set:function(e){ad(this,"selectAllComponents",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"getRelationNodes",{get:function(){var t=this;return function(r){var n=e.getExparserComponent(t);if(!n)return null;var o=n.getRelationNodes(r);return null===o?null:o.map((function(e){return exparser.Element.getMethodCaller(e)}))}},set:function(e){ad(this,"getRelationNodes",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"getTabBar",{get:function(){return function(){var t=e.getExparserComponent(this);if(!t)return null;var r=t.__treeManager__;return r.tabDestroyed||!r.tabRoot?null:exparser.Element.getMethodCaller(r.tabRoot)}},set:function(e){ad(this,"getTabBar",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"exitState",{get:function(){return this.__exitState__},set:function(e){ad(this,"exitState",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"setInitialRenderingCache",{get:function(){return function(t){var r=e.getExparserComponent(this);if(r){var n=r.__treeManager__;null===t?function(e){e.operationFlow.start(),e.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE,"",null]),e.operationFlow.end()}(n):function(e,t){var r=au(e.rootCompName),n=eo();e.operationFlow.start(),e.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE,r,n]);var o=exparser.createElement("initial-rendering-cache",exparser.Component._list[r],e);exparser.Element.getMethodCaller(o).__ddExparserNodeId__=e.nodeId.allocNodeId(o,n),exparser.Element.getMethodCaller(o).__wxExparserNodeId__=exparser.Element.getMethodCaller(o).__ddExparserNodeId__,e.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE]),e.nodeId.addNode(),o.setData(t),e.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE,t]),e.operationFlow.end(),e.nodeId.removeNode(o)}(n,t)}}},set:function(e){ad(this,"exitState",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"setUpdatePerformanceListener",{get:function(){return function(t,r){var n=e.getExparserComponent(this);if(n){var o=n.__treeManager__,i=o.nodeId.getNodeId(n);"function"==typeof r?(n.__updatePerformanceListener__=r,o.operationFlow.push([No.SYNC_EVENT_NAME.ENABLE_UPDATE_PERFORMANCE_STAT,i,t])):(n.__updatePerformanceListener__=null,o.operationFlow.push([No.SYNC_EVENT_NAME.DISABLE_UPDATE_PERFORMANCE_STAT,i]))}}},set:function(e){ad(this,"exitState",e)},enumerable:!1,configurable:!0}),e.callerMap=new WeakMap,e}();function cd(){return __ddConfigWindow__&&__ddConfigWindow__.initialRenderingCache?String(__ddConfigWindow__.initialRenderingCache):""}function fd(e,t){var r=[],n={},o={};exparser.ElementIterator.create(e,"composed-descendants-root-first",exparser.Component).forEach((function(t){t instanceof exparser.Component&&!t.hasBehavior("dd-base")&&(n["./"+e.is+".wxss"]=!0)})),Object.keys(exparser.Component._list).forEach((function(e){o["./"+e+".wxss"]=!0}));for(var i=document.head.querySelectorAll("style")||[],a=0,s=void 0,u=void 0;a<i.length;a++)null!=(u=(s=i[a]).getAttribute("wxss:path"))&&(o[u]&&!n[u]||r.push("<style>"+s.innerHTML+"</style>"));var l=r.join("")+e.$$.innerHTML;dd.saveInitialRenderingCache({content:l,appserviceData:t})}function pd(e,t){return"dynamic"!==cd()&&(e?fd(e,t):dd.saveInitialRenderingCache({content:""}),!0)}var _d,hd=1<<18,vd=Date.now();function gd(e,t){var r=nu.get(e);r&&(r.statesData=t,r.tabRoot&&to(r.tabRoot,1,(function(e){e.triggerLifeTime("saved")})),to(r.root,1,(function(e){e.triggerLifeTime("saved")})),Ho(No.SYNC_EVENT_NAME.SAVE_STATE,[],e))}var Ed={domain:"/",writeOnly:!1,allowInWriteOnly:!1,lazyRegistration:!0,classPrefix:"",templateEngine:kc,renderingMode:"full",multipleSlots:!1,publicProperties:!0,reflectToAttributes:!1,writeFieldsToNode:!1,writeIdToDOM:!1,separateInnerData:!0,innerDataExclude:null,randomizeTagName:!1,virtualHost:!1},md={domain:"/",writeOnly:!1,allowInWriteOnly:!1,lazyRegistration:!0,classPrefix:"",renderingMode:"full",templateEngine:kc,multipleSlots:!1,publicProperties:!0,reflectToAttributes:!1,writeFieldsToNode:!1,writeIdToDOM:!1,separateInnerData:!1,innerDataExclude:null,randomizeTagName:!1,virtualHost:!1},yd=1,Nd=!1,bd=!1,wd=[],Cd=[],Ad={},Sd=new Set,Td=new Set,Od="custom-tab-bar/index",Id=new Set([Od]),xd={},Dd={},Md=void 0,Ld={},Rd={},Pd={},Fd={},Vd={},kd=[],jd=!1,Yd=Object.create(null),Wd={lazyRegistration:!0,publicProperties:!0},Bd=null,Hd=null,Ud=null,Gd={String:String,Number:Number,Boolean:Boolean,Object:Object,Array:Array,null:null},zd={jsFileLoaded:!1,jsFileLoadedCallback:[],compDefLoaded:!1,compDefLoadedCallback:[]},$d=function(e){zd.jsFileLoaded?e():zd.jsFileLoadedCallback.push(e)},qd=function(){zd.compDefLoaded=!0,zd.compDefLoadedCallback.forEach((function(e){e()})),zd.compDefLoadedCallback=[]},Xd=function(e){zd.compDefLoaded?e():zd.compDefLoadedCallback.push(e)},Kd=function(){zd={jsFileLoaded:!1,jsFileLoadedCallback:[],compDefLoaded:!1,compDefLoadedCallback:[]}},Qd=!1,Zd=[];function Jd(e){Qd?e():Zd.push(e)}function ef(){!0!==Qd&&(Qd=!0,Zd.forEach((function(e){return e()})))}function tf(e){for(var t,r,n=Object.create(null),o=0,i=e;o<i.length;o++){var a=i[o];r="";for(var s=0,u=(t="string"==typeof a?a:a.is).length,l=void 0,c=void 0;s<u;++s)r+=(c=(l=t[s]).charCodeAt(0))>=48&&c<=57||c>=65&&c<=90||c>=97&&c<=122||45===c||95===c?l:"/"===l?"-":c;n[t]=r}return n}function rf(e,t){var r={},n=(t[e+".json"]||{}).usingComponents;for(var o in n)r["dd-"+o]=Kn(e,String(n[o]));return r}function nf(e,t){for(var r in t){var n=t[r];n.target=null!=n.target?String(n.target):Kn(e,String(r))}return t}function of(e,t){if("undefined"!=typeof __DDML_DEP__){var r=__DDML_DEP__["./"+e+".wxml"];Zn(r)&&r.forEach((function(e){var r=e.substr(2,e.length-7);_d[r]&&t.add(r)}))}}function af(e,t){var r,n,o,i,a=t.set,s=t.dropLazy;a.has(e)||(a.add(e),r=_d?Object.keys(_d[e]||{}):[],s&&(n=new Set(r),o=Ad[e]||{},Object.keys(o).forEach((function(e){n.delete(e)})),(i=o,Object.keys(i).map((function(e){return i[e]}))).forEach((function(e){n.add(e)})),r=Array.from(n)),r.forEach((function(t){af(_d[e][t],{set:a,dropLazy:s})})))}function sf(e,t,r){void 0===r&&(r=null);var n=Wo()?__ddConfig.subPackages:void 0,o=(n=(n=n||[]).filter((function(t){return 0===e.indexOf(t.root)})))[0]&&n[0].root||"",i=n[0]&&n[0].allExtendedComponents||[],a=Array.from(t).map((function(e){return-1<i.indexOf(e)?o+e:e}));Wo()&&(xd[r]||(xd[r]=new Set),a.forEach((function(e){return xd[r].add(e)})));var s=a.filter((function(e){return!Tf(e)}));return s.forEach((function(e){Id.add(e)})),s}function uf(e,t,r,n){var o,i;if(void 0===n&&(n=!1),__ddConfig&&__ddConfig.isLazyLoad){var a="undefined"!=typeof __ddAppCode__?__ddAppCode__:{};for(var s in void 0===_d&&(_d={}),a)if(".json"===s.substr(s.length-5)){var u=s.slice(0,-5),l=a[s],c={},d={},f=l.usingComponents;for(var p in f)c[p]=Kn(u,f[p]);var _=l.componentGenerics;for(var h in _){var v=_[h].default;v&&(c[String(v)]=Kn(u,v))}var g=l.componentPlaceholder;for(var p in g)d[p]=g[p];_d[u]=c,Ad[u]=d||{}}var E=Object.keys(_d);Bd=tf(E),n||(Cc(),Cc(0,Wo()),Cc(0,E.length)),o=new Set,af(e,{set:o,dropLazy:!0}),Object.keys(Ad).forEach((function(e){af(e,{set:Td})})),o.forEach((function(e){return of(e,o)}));var m=sf(e,o,t);if(n||(Cc(0,m.length),Cc(),Cc()),Wo()){!function(e){if(0===e.length)return 0;var t=Date.now();Date.now()}(m.map((function(e){return"/"+e+".appservice.js"})))}else{var y=m.map((function(e){return"/"+e+".webview.js"}));i=function(t){function r(){var t,r;Cc(),void 0!==(t=("undefined"!=typeof __ddAppCode__?__ddAppCode__:{})[e+".ddss"])&&"function"==typeof t||(t=function(){}),window.__setCssStartTime__=Date.now(),t(),window.__setCssEndTime__=Date.now(),r=("undefined"!=typeof __ddAppCode__?__ddAppCode__:{})["./"+e+".ddml"],Array.isArray(r)&&(r=r[0][r[1]]),window.__ddAppCodeReadyCallback__?window.__ddAppCodeReadyCallback__(r):document.dispatchEvent(new CustomEvent("generateFuncReady",{detail:{generateFunc:r}}))}n?!0!==jd&&(jd=!0,kd.forEach((function(e){e()}))):Sf()?Cf(r):r()},y.length||i&&i(0)}}}function lf(e,t,r,n){var o=nu.get(r).nodeId.getNodeById(n);if(o&&t){var i=Xs({},t,e);exparser.Element.getMethodCaller(o).setData(i)}}function cf(e,t){return Wo()?t!==Od&&!(xd[e]&&xd[e].has(t)):!Tf(t)}function df(e,t,r,n){Sd.add(e),Dd[t]=n,void 0!==Md&&clearTimeout(Md),Md=setTimeout((function(){var e=Array.from(Sd),t=r.rootCompName,n=r.viewId;if(Sd=new Set,Wo()){_f(e,t,n),e.forEach((function(e){Td.delete(e)}));var o=[[],[],t,bc];e.forEach((function(e){hf(o,e,Yd,t)})),Ho(No.SYNC_EVENT_NAME.COMPONENT_DEF_LAZY,o,n),r.operationFlow.start(),r.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_DO_REPLACE_PLACEHOLDER]),r.operationFlow.end();var i=Object.keys(Dd);r.operationFlow.start(),r.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_REPLACE_PLACEHOLDER,i]),i.forEach((function(e){Dd[e](),delete Dd[e]})),r.operationFlow.end()}else _f(e,t,null)}),50)}function ff(e,t){var r,n={};for(var o in e.properties){var i=e.properties[o];null===i?n[o]={type:null}:(r=i)===Number||r===String||r===Boolean||r===Object||r===Array?n[o]={type:i.name}:(void 0===i.public||i.public)&&(n[o]={type:i.type?i.type.name:null,value:i.value})}var a=e.options.innerDataExclude;return{is:e.is,using:e.using,generics:e.generics,behaviors:e.behaviors,placeholder:e.placeholder,data:e.data,properties:n,externalClasses:e.externalClasses,template:t,options:{domain:e.options.domain,writeOnly:e.options.writeOnly||void 0,multipleSlots:e.options.multipleSlots||void 0,writeIdToDOM:e.options.writeIdToDOM||void 0,styleIsolation:e.options.styleIsolation||void 0,addGlobalClass:e.options.addGlobalClass||void 0,hasObservers:!!e.observers,innerDataExcludeString:a?a.toString():null,virtualHost:e.options.virtualHost||void 0}}}function pf(e){if(e.behaviors){for(var t=[],r=0,n=e.behaviors;r<n.length;r++){var o=n[r],i=String(o);if("/"!==i[0]&&"dd://"!==i.slice(0,5))throw new Error("Behaviors should be constructed with Behavior()");t.push(i)}e.behaviors=t,Fd[e.is]=t}else e.behaviors=null}Wo()||(Wo()||(Uo(No.SYNC_EVENT_NAME.ENABLE_UPDATE_PERFORMANCE_STAT,(function(e){var t=e[0],r=e[1];Mc[t]=r})),Uo(No.SYNC_EVENT_NAME.DISABLE_UPDATE_PERFORMANCE_STAT,(function(e){var t=e[0];Mc[t]=null}))),"undefined"!=typeof __ddAppCode__?ef():window.__mainPageFrameReady__=ef,Jd((function(){if(__ddConfig.isFirstPage){var e=__ddConfig.appLaunchInfo.path.replace(/\.html$/,"").replace(/^\//,"");setTimeout((function(){uf(e,null)}),0)}})),Jd((function(){uf(Od,null,__ddConfig.isFirstPage,!0),Cf((function(){wf()}))})),Uo(No.SYNC_EVENT_NAME.DESTROY_TAB,(function(){nu.instance.tabDestroyed=!0,window.__TAB_BAR__&&window.__TAB_BAR__.parentNode.removeChild(window.__TAB_BAR__)}))),Uo(No.SYNC_EVENT_NAME.COMPONENT_DEF_LAZY,(function(e){bd?Nf(e,!1):wd.push(e),$d((function(){qd()}))}),0),Uo(No.SYNC_EVENT_NAME.LOAD_COMPONENT_DEF,(function(e){uf(e[0],null)}),0),Uo(No.SYNC_EVENT_NAME.COMPONENT_DEF,(function(e){bd?Nf(e,!1):wd.push(e)}),0),Uo(No.SYNC_EVENT_NAME.COMPONENT_DEF_TAB,(function(e){bd?Nf(e[0],!0):Cd.push(e[0])}),0),Uo(No.SYNC_EVENT_NAME.UPDATE_COMPONENT_DEF,(function(e){var t=e[0],r=nu.instance;exparser.Component._list[t.is]&&Ef(t,r.rootCompName===t.is)})),Wo()||Uo(No.SYNC_EVENT_NAME.FLUSH_BLOCKED,(function(){nu.instance.operationFlow.flushBlocked()}),0);var _f=function(e,t,r){var n=new Set;e.forEach((function(e){af(e,{set:n})})),n.forEach((function(e){return of(e,n)}));var o=sf(t,n,r);o.forEach((function(e){return Id.add(e)})),0!==o.length&&Wo()&&Array.from(o).forEach((function(e){var t=new Set;__appServiceSDK__.requireByRoute(e,t)}))};function hf(e,t,r,n){var o;Sc.call(bc,t)&&(t=bc[t]);var i=Ld[t];if(!i){if(Td.has(t))return;throw new Error('Component is not found in path "'+t+'"'+(n?' (using by "'+n+'")':""))}"dd://"!==t.slice(0,5)&&(e[1].unshift(i),r[t]=!0);var a,s=Rd[i.is];for(o in s)Sc.call(s,o)&&(r[a=s[o]]||hf(e,a,r,t));var u,l=Pd[i.is];for(o in l)Sc.call(l,o)&&(u=l[o].default)&&(r[u]||hf(e,u,r,t));var c=Fd[i.is];if(c)for(var d=function e(t,r,n){if("dd://"!==r.slice(0,5)){var o=Vd[r];if(!o)throw new Error('"'+r+'" is not a behavior registered by Behavior()');t[0].unshift(o),n[r]=!0;var i=Fd[o.is];if(i)for(var a=0,s=i;a<s.length;a++){var u=s[a];n[u]||e(t,u,n)}}},f=0,p=c;f<p.length;f++){var _=p[f];r[_]||d(e,_,r)}return e}function vf(e,t,r){var n=t[r+".json"]||{};void 0!==n.styleIsolation&&(e.options||(e.options={}),e.options.styleIsolation=n.styleIsolation),void 0!==n.pureDataPattern&&(e.options||(e.options={}),e.options.pureDataPattern=new RegExp(n.pureDataPattern))}function gf(e,t){e.using=Rd[e.is]=rf(e.is,t),e.placeholder=function(e,t){var r=t[e+".json"]||{},n={},o=r.componentPlaceholder||{};return Object.keys(o).forEach((function(e){n["dd-"+e]="dd-"+String(o[e])})),n}(e.is,t),e.generics=Pd[e.is]=function(e,t){var r={},n=(t[e+".json"]||{}).componentGenerics;for(var o in n){var i=n[o];"object"===qs(i)?r["dd-"+o]={default:Kn(e,String(i.default||""))}:null!=i&&(r["dd-"+o]={})}return r}(e.is,t),pf(e);var r=e.is;t[r+".wxml"]?r+=".wxml":t[r+".ddml"]&&(r+=".ddml"),e.template={path:r,func:pl[r]||t[r]||null},Ld[e.is]=ff(e,r);var n=exparser.registerElement(e),o=new ld;exparser.Behavior.prepare(n.behavior);var i=n.behavior.methods;for(var a in i)o[a]=i[a];return o}function Ef(e,t,r){var n;for(n in e.properties){var o=e.properties[n].type;e.properties[n].type=Gd[o]}var i="";t||(i=r?Ud[e.is]:Hd[e.is]);var a=e.options,s=!(!a.writeIdToDOM&&!t);e.options=md,e.options.multipleSlots=a.multipleSlots||!1,e.options.writeOnly=a.writeOnly||!1,e.options.writeIdToDOM=s,e.options.domain=a.domain,e.options.randomizeTagName=!1,e.options.virtualHost=a.virtualHost,e.options.innerDataExclude=function(e){if(!e)return null;var t=e.lastIndexOf("/"),r=e.slice(1,t),n=e.slice(t+1);return new RegExp(r,n)}(a.innerDataExcludeString);var u=!1;if(a.styleIsolation){var l=a.styleIsolation;"page-"===l.slice(0,5)&&(u=!0,l=l.slice(5)),"isolated"===l?(i=Hd[e.is],e.options.addGlobalClass=!1):"strong-isolated"===l?(i=Hd[e.is],e.options.addGlobalClass=!1,e.options.randomizeTagName=!0):"apply-shared"===l?(i=Hd[e.is],e.options.addGlobalClass=!0):"shared"===l&&"/"===a.domain?(i="",e.options.addGlobalClass=!1):u=!1}else e.options.addGlobalClass=a.addGlobalClass||!1;e.options.classPrefix=i,a.hasObservers&&(e.observers={"**":function(){}});var c="undefined"!=typeof __ddAppCode__&&__ddAppCode__[e.template];window.__customComponentMode__=c;var d=c?__ddAppCode__[e.template]:window.__generateFunc__,f=e.template;return e.template={path:f,func:d},exparser.registerElement(e),{disableAppDdss:u,classPrefix:i}}function mf(e){var t=Date.now(),r=e.operationFlow.iterator,n=r.expectStart(),o=r.nextStepType();if(o===No.SYNC_EVENT_NAME.FLOW_INITIAL_CREATION)yf(e,No.SYNC_EVENT_NAME.FLOW_INITIAL_CREATION);else if(o===No.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE)yf(e,No.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE);else if(o===No.SYNC_EVENT_NAME.FLOW_CREATE_TAB)yf(e,No.SYNC_EVENT_NAME.FLOW_CREATE_TAB);else if(o===No.SYNC_EVENT_NAME.FLOW_DO_REPLACE_PLACEHOLDER)r.nextStep(),nu.instance.operationFlow.block(),nu.instance.operationFlow.unblock(),Xd((function(){Kd(),nu.instance.operationFlow.unblock()}));else{var i=r.nextStep(),a=void 0;if((o=i[0])===No.SYNC_EVENT_NAME.FLOW_UPDATE){var s=i[1];if(a=e.nodeId.getNodeById(s)){var u=i[2];if(Zn(u)&&u.length){var l=exparser.Component.getDataProxy(a);l.setChanges(u),l.doUpdates(void 0,!Wo()),Fc(s,(function(e){return{isMergedUpdate:!1,dataPaths:e.withDataPaths?u.map((function(e){return e[0]})):void 0,pendingStartTimestamp:n,updateStartTimestamp:t,updateEndTimestamp:Date.now()}}))}}else r.skipToEnd()}else if(o===No.SYNC_EVENT_NAME.FLOW_GROUP){var c=r.nextStep();if(c[0]!==No.SYNC_EVENT_NAME.FLOW_GROUP_END)throw new Error("Framework inner error (expect FLOW_GROUP_END but get "+No.getEvName(c[0])+")")}else if(o===No.SYNC_EVENT_NAME.FLOW_REPLACE_PLACEHOLDER)i[1].forEach((function(e){Dd[e](),delete Dd[e]}));else if(o===No.SYNC_EVENT_NAME.FLOW_HOT_UPDATE)(a=e.nodeId.getNodeById(i[1]))?a.__templateInstance._resetShadowChildren(a,a.data,e):r.skipToEnd();else{if(o!==No.SYNC_EVENT_NAME.FLOW_HOT_UPDATE_RESET)throw new Error("Framework inner error (expect an update event but get "+No.getEvName(o)+")");!function(e,t){if(fl()){Wo()&&(t.operationFlow.start(),t.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_HOT_UPDATE_RESET,t.nodeId.getNodeId(e)]));var r="";e===t.root?r="body":e===t.tabRoot&&(r="tab-bar");var n=e.__vtObj,o=e.ownerShadowRoot?e.ownerShadowRoot.createComponent(n.tag,void 0,n.generics,t):exparser.createElement(r,exparser.Component._list[e.is],t);if(Wo())t.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_HOT_UPDATE_RESET]);else if(t.operationFlow.iterator.nextStep()[0]!==No.SYNC_EVENT_NAME.FLOW_HOT_UPDATE_RESET)throw new Error("Expect FLOW_HOT_UPDATE_RESET but get another");var i=t.nodeId.getNodeId(e);if(t.nodeId.removeNode(e),t.nodeId.allocNodeId(o,i),e===t.root){exparser.Element.pretendDetached(e),t.root=o,Wo()||(window.__DOMTree__=o,document.body=o.$$),exparser.Element.pretendAttached(o);var a={},s=!1;Object.keys(t.initialRootData).forEach((function(e){exparser.Component.hasProperty(o,e)&&(a[e]=t.initialRootData[e],s=!0)})),s&&t.root.setData(a)}else t.tabRoot;Wo()&&t.operationFlow.end()}}(e.nodeId.getNodeById(i[1]),e)}}r.expectEnd()}function yf(e,t){var r,n,o,i,a=t===No.SYNC_EVENT_NAME.FLOW_CREATE_TAB,s=t===No.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE,u=e.operationFlow.iterator,l=u.nextStep(),c=null,d=l[1],f=l[2];if(a)e.tabNodeId=f,e.tabRoot=c=window.__TAB_BAR__=exparser.createElement("tab-bar",exparser.Component._list[d]);else if(s){if(!d)return void pd(null);c=exparser.createElement("initial-rendering-cache",exparser.Component._list[d])}else{var p=l[3]||{};e.rootNodeId=f,e.root=c=window.__DOMTree__=exparser.Component.createWithGenerics("body",exparser.Component._list[d],p,e)}if(e.nodeId.allocNodeId(c,f),c.setAttribute("is",d),Dl.restoring&&!a&&(r=Dl.idDataMap[e.nodeId.getNodeId(c)],exparser.Component.replaceWholeData(c,r,null),mc(Dl.restoring),Dl.restoring=null,Dl.idDataMap=null),(l=u.nextStep())[0]!==t)throw new Error("Framework inner error (expect "+No.getEvName(t)+" end but get "+No.getEvName(l[0])+")");if(e.nodeId.addNode(),a){var _=exparser.createElement("dd-tab-bar-wrapper",exparser.Component._list["dd://tab-bar-wrapper"]);_.appendChild(c),document.documentElement.insertBefore(_.$$,document.body),exparser.Element.pretendAttached(_),e.tabDestroyed&&_.removeChild(c)}else if(s){var h=document.createElement("dd-initial-rendering-cache-wrapper");if(h.setAttribute("style","height: 0; overflow: hidden"),h.appendChild(c.$$),document.documentElement.insertBefore(h,document.body),(l=u.nextStep())[0]!==No.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE)throw new Error("Framework inner error (expect initial rendering end but get another)");to(c,1,(function(e){e.triggerLifeTime("cacheAttached")})),pd(c,l[1]),e.nodeId.removeNode(c),document.documentElement.removeChild(h)}else document.body=c.$$,to(c,1,(function(e){e.triggerLifeTime("cacheAttached")})),i=c,"static"===cd()&&fd(i),exparser.Element.pretendAttached(c),n="initialRenderingDone",o=Date.now(),Dc[n]=o,setTimeout((function(){var e;Ho(No.SYNC_EVENT_NAME.PERFORMANCE_DATA,[(null===(e=window.nativeParam)||void 0===e?void 0:e.webViewId)||0,Dc],void 0,!0)}),0)}function Nf(e,t){var r=e[0],n=e[1],o=e[2],i=e[3];t||(nu.instance.rootCompName=o);var a=__ddAppCode__[o+".wxss"]||__ddAppCode__[o+".ddss"];"function"==typeof a&&a(o);for(var s=0,u=r;s<u.length;s++){var l=u[s];l.options=Wd,exparser.registerBehavior(l)}var c,d=n.map((function(e){return e.is}));t?Ud=Bd||tf(d):Hd=tf(n);for(var f=0,p=n;f<p.length;f++){var _=(c=p[f]).is===o&&!t;Ef(c,_,t).disableAppDdss&&_&&(__webviewEngine__.disableStyleElement("app.wxss"),__webviewEngine__.disableStyleElement("app.ddss"));var h=__ddAppCode__[c.is+".wxss"]||__ddAppCode__[c.is+".ddss"];"function"==typeof h&&h(c.is)}for(var v in i)exparser.Component._list[v]=exparser.Component._list[i[v]]}function bf(e,t,r){var n=[[],[],r=au(r),bc];hf(n,r,Yd=Object.create(null),"");Ho(No.SYNC_EVENT_NAME.COMPONENT_DEF,n,e),function(e){Zl&&Ho(No.SYNC_EVENT_NAME.BANNING_MAP,[Zl],e,null)}(e),t.rootCompName=r,t.rootNodeId=eo(),t.operationFlow.start(),t.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_INITIAL_CREATION,r,t.rootNodeId,null]);var o=exparser.Component.createWithGenerics("body",exparser.Component._list[r],null,t);return t.root=o,t.usedDef=n,exparser.Element.getMethodCaller(o).__ddExparserNodeId__=t.nodeId.allocNodeId(o,t.rootNodeId),exparser.Element.getMethodCaller(o).__wxExparserNodeId__=exparser.Element.getMethodCaller(o).__ddExparserNodeId__,t.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_INITIAL_CREATION]),t.nodeId.addNode(),o}function wf(){Nd||(Nd=!0,Ho(No.SYNC_EVENT_NAME.REQUEST_TAB,[]))}function Cf(e){__ddConfig&&__ddConfig.isLazyLoad&&!jd?kd.push(e):e()}function Af(e,t){if(Sf()){var r=nu.get(e)||nu.create(e);if(!r.tabRoot&&!r.tabDestroyed){uf(Od,e,0,!0);var n=au(Od),o=[[],[],n,{}];hf(o,n,Object.create(null),""),r.operationFlow.push([No.SYNC_EVENT_NAME.COMPONENT_DEF_TAB,o,e]),r.tabCompName=n,r.tabNodeId=eo(),r.operationFlow.start(),r.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_CREATE_TAB,n,r.tabNodeId]);var i=exparser.createElement("tab-bar",exparser.Component._list[n],r);r.tabRoot=i,r.tabUsedDef=o,exparser.Element.getMethodCaller(i).__ddExparserNodeId__=r.nodeId.allocNodeId(i,r.tabNodeId),exparser.Element.getMethodCaller(i).__wxExparserNodeId__=exparser.Element.getMethodCaller(i).__ddExparserNodeId__,r.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_CREATE_TAB]),r.nodeId.addNode(),exparser.Element.pretendAttached(r.tabRoot),r.operationFlow.end(),t&&r.operationFlow.push([No.SYNC_EVENT_NAME.FLUSH_BLOCKED,[],e]),r.rootCompName&&function(e,t,r){var n=!0,o=__ddConfig.tabBar&&__ddConfig.tabBar.list;o instanceof Array&&(o=o.map((function(e){return e&&e.pagePath}))).indexOf(t+".html")&&(n=!1),n&&(e.tabDestroyed=!0,Ho(No.SYNC_EVENT_NAME.DESTROY_TAB,[],r))}(r,r.rootCompName,e)}}}function Sf(){var e=!1;return __ddConfig.tabBar&&!0===__ddConfig.tabBar.custom&&(e=!0),function(e){e=au(e),Sc.call(bc,e)&&(e=bc[e]);return Ld[e]}(Od)||(e=!1),__ddConfig.appLaunchInfo&&"singlePage"===__ddConfig.appLaunchInfo.mode&&(e=!1),e}function Tf(e){return Id.has(e)}var Of={sendData:Ho,setDataListener:Uo,TreeManager:nu,requestViewInfo:function(e,t,r,n){var o=Math.random()+"-"+Date.now(),i=nu.get(r);if(i)return i.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_VIEW_INFO,e,t,o]),Qn(n)&&(i.viewInfoCbMap[o]=n),o},endViewInfoCallback:function(e,t){var r=nu.get(e);r&&delete r.viewInfoCbMap[t]},setModelValueData:lf,getLazyCompPlaceholder:function(e){if(!Ad[e])return{};var t={};return Object.keys(Ad[e]).forEach((function(r){t["dd-"+r]="dd-"+Ad[e][r]})),t},componentLoaded:Tf,shouldUsePlaceholder:cf,arrangePlaceholderReplace:df,getOwnerPluginAppId:function(e){var t=ld.getExparserComponent(e);return t?ld.getExparserProtocol(t):""},Behavior:function(e){var t="/"+yd+++"/"+eo(),r={},n=e.behaviors;if(n&&n.length)for(var o=0;o<n.length;o++){var i=String(n[o]);-1!==i.indexOf("wx://")&&(n[o]="dd://"+i.substr(5))}for(var a in r.behaviors=n,e)r[a]="data"===a?Ac(e[a]):e[a];return r.is=t,pf(r),r.options=Wd,Vd[t]=ff(r),r.definitionFilter=exparser.Behavior.callDefinitionFilter(r),exparser.registerBehavior(r),r.is},CustomComponent:ld,Component:function e(t,r,n,o){var i=o||__ddAppCurrentFile__,a=n||__ddAppCode__,s=a[i+"on"];if(!i||!s)return"";var u=t.behaviors;if(u&&u.length)for(var l=0;l<u.length;l++){var c=String(u[l]);-1!==c.indexOf("wx://")&&(u[l]="dd://"+c.substr(5))}t.behaviors=u;var d=i.slice(0,-3);if(s.component&&"simple"===s.component.type)return function(e,t,r,n){vf(e,n,t);var o={is:t,using:rf(t,n),properties:e.properties,externalClasses:e.externalClasses,options:Ed},i=e.options||{};o.options=Eo(Eo({},Ed),{multipleSlots:i.multipleSlots||!1,writeOnly:!0,writeIdToDOM:!1,domain:"simple://"+(r||"/"),styleIsolation:i.styleIsolation||"",addGlobalClass:i.addGlobalClass||!1,innerDataExclude:null,virtualHost:!1});var a=t;n[a+".wxml"]?a+=".wxml":n[a+".ddml"]&&(a+=".ddml");Ld[t]=ff(o,a)}(t,d,r,a),d;vf(t,a,d);var f=exparser.Behavior.callDefinitionFilter(t),p=t.options||{},_={is:d,properties:t.properties,data:Ac(t.data),methods:t.methods,behaviors:t.behaviors,lifetimes:t.lifetimes,pageLifetimes:t.pageLifetimes,created:t.created,attached:t.attached,ready:t.ready,moved:t.moved,detached:t.detached,saved:t.saved,restored:t.restored,relations:t.relations?nf(i,t.relations):void 0,externalClasses:t.externalClasses,observers:t.observers,definitionFilter:f,options:Eo(Eo({},Ed),{addGlobalClass:p.addGlobalClass||!1,multipleSlots:p.multipleSlots||!1,writeOnly:p.writeOnly||!1,writeIdToDOM:!1,domain:(p.writeOnly?"wo://":"")+(r||"/"),styleIsolation:p.styleIsolation||"",innerDataExclude:p.pureDataPattern||null,virtualHost:p.virtualHost||!1}),initiator:function(){this.__customConstructor__=e;var t=Object.create(h);ld.callerMap.set(t,this),exparser.Element.setMethodCaller(this,t),Object.defineProperties(t,{__data__:{value:this.data,writable:!0,enumerable:!1},__ddWebViewId__:{value:this.__treeManager__.viewId,writable:!0,enumerable:!1}})}},h=gf(_,a);return _.is},Page:function e(t,r,n,o){var i=o||__ddAppCurrentFile__;if(!i)return"";var a,s=i.slice(0,-3),u=n||"undefined"!=typeof __ddAppCode__&&__ddAppCode__||{},l=Object.create(null),c={methods:{}};for(a in t)"data"===a?c.data=t.data:Qn(t[a])?c.methods[a]=t[a]:"methods"===a?l.methods=t.methods:c[a]=t[a];var d=c.behaviors;if(d&&d.length)for(var f=0;f<d.length;f++){var p=String(d[f]);-1!==p.indexOf("wx://")&&(d[f]="dd://"+p.substr(5))}c.behaviors=d;var _,h=function(e){if(!e)return!1;if(Zn(e)){for(var t=0;t<e.length;t++){var r=String(e[t]);if("dd://"!==r.slice(0,5)&&!Vd[r])return!1}return!0}return!1}(c.behaviors);for(a in vf(c,u,s),h&&exparser.Behavior.callDefinitionFilter(c),c)"data"!==a&&"methods"!==a&&(l[a]=c[a]);var v=c.options||{},g={is:s,behaviors:h?c.behaviors:void 0,data:Ac(c.data),methods:c.methods,properties:void 0===t.properties?c.properties:void 0,lifetimes:void 0===t.lifetimes?c.lifetimes:void 0,pageLifetimes:void 0===t.pageLifetimes?c.pageLifetimes:void 0,created:void 0===t.created?c.created:void 0,attached:void 0===t.attached?c.attached:void 0,ready:void 0===t.ready?c.ready:void 0,moved:void 0===t.moved?c.moved:void 0,detached:void 0===t.detached?c.detached:void 0,saved:void 0===t.saved?c.saved:void 0,restored:void 0===t.restored?c.restored:void 0,relations:void 0===t.relations&&c.relations?nf(i,c.relations):void 0,externalClasses:void 0===t.externalClasses?c.externalClasses:void 0,observers:void 0===t.observers?c.observers:void 0,options:Eo(Eo({},Ed),{multipleSlots:!1,writeOnly:!1,writeIdToDOM:!0,domain:r||"/",styleIsolation:v.styleIsolation||"shared",addGlobalClass:!1,innerDataExclude:v.pureDataPattern||null,virtualHost:v.virtualHost||!1}),initiator:function(){this.__customConstructor__=e;var t=Object.create(_);ld.callerMap.set(t,this),exparser.Element.setMethodCaller(this,t),Object.defineProperties(t,{__data__:{value:this.data,writable:!0,enumerable:!1},__ddWebViewId__:{value:this.__treeManager__.viewId,writable:!0,enumerable:!1}})}};return(_=gf(g,u)).__freeData__=l,g.is},initViewThread:function(){eu.setStartOperation((function(e){Rc.push(Lc),Lc+=1;try{mf(e)}catch(e){Pc();var t="[webview-error]: flowUpdateView error\n";throw e.name&&(t+="["+e.name+"] "),e.message&&(t+=e.message+"\n"),e.stack&&(t+=e.stack),t.length>1e3&&(t=t.substr(0,1e3)+" ..."),Reporter.errorReport({key:"webview-error",type:"flowUpdateView",error:t}),Reporter.ravenReport("pub_saga_error_message_bt",{key:"webview-error",type:"flowUpdateView",error:t,fail:function(e){}}),e}Pc()})),nu.instance=nu.create(0)},runComponentDef:function(){bd=!0,wf(),wd.forEach((function(e){return Nf(e,!1)})),wd=[],Cd.forEach((function(e){return Nf(e,!0)})),Cd=[]},sendTabBarCreationRequest:wf,addView:function(e,t,r){var n=nu.get(e)||nu.create(e);n.lifetimeListener=r,n.operationFlow.unblock(),function(e,t){t.listenerInited||(t.listenerInited=!0,Uo(No.SYNC_EVENT_NAME.DD_EVENT,(function(r){var n=r[0],o=r[1],i=r[2],a=t.nodeId.getNodeById(n);if(a){var s=exparser.Element.getMethodCaller(a),u=i._userTap,l=i._requireActive,c=i._relatedInfo;if(l){var d=__appServiceEngine__.getCurrentPagesByDomain("");if(d[d.length-1].__ddWebViewId__!==e)return;delete i._requireActive}c&&delete i._relatedInfo;var f=s&&s[o];Qn(f)&&(u?fu((function(){exparser.safeCallback("Event Handler",f,s,[i],a)})):exparser.safeCallback("Event Handler",f,s,[i],a))}}),e),Uo(No.SYNC_EVENT_NAME.MODEL_VALUE_CHANGE,(function(e,t,r){var n=e[0];lf(n.data,n.modelValueName,r,n.nodeId)}),e),Uo(No.SYNC_EVENT_NAME.REQUEST_SAVE,(function(t){gd(e,t)}),e),Uo(No.SYNC_EVENT_NAME.CALL_METHOD_FROM_DDS,(function(e){Kl(e)}),e),Uo(No.SYNC_EVENT_NAME.ANIMATION_TRANSITION_END,(function(e){var r,n;e&&e[0]&&e[0].reqId&&("function"==typeof(r=t.applyAnimationCbMap[e[0].reqId])&&(delete t.applyAnimationCbMap[e[0].reqId],exparser.safeCallback("Animation",r,null,[])),n=JSON.parse(e[0].args),t.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_SET_NODE_NEXT_ANIMATION_INFO,n]))}),e),Uo(No.SYNC_EVENT_NAME.CLEAR_ANIMATION_COMPLETE,(function(e){var r;e&&e[0]&&e[0].reqId&&"function"==typeof(r=t.clearAnimationCbMap[e[0].reqId])&&(delete t.clearAnimationCbMap[e[0].reqId],exparser.safeCallback("Clear Animation",r,null,[]))}),e),Uo(No.SYNC_EVENT_NAME.RESPONSE_VIEW_INFO,(function(e){var r=e[0],n=e[1];if(n){var o=t.viewInfoCbMap[n];o&&o(r)}}),e),Uo(No.SYNC_EVENT_NAME.UPDATE_PERFORMANCE_STAT,(function(e){var r=e[0],n=e[1],o=t.nodeId.getNodeById(r);o&&o.__updatePerformanceListener__&&exparser.safeCallback("Update Performance Listener",o.__updatePerformanceListener__,exparser.Element.getMethodCaller(o),[n],o)}),e))}(e,n),t=au(t),Ho(No.SYNC_EVENT_NAME.LOAD_COMPONENT_DEF,[t],e),uf(t,e),!1;var o=bf(e,n,t);return function(e){var t=__ddConfig.tabBar&&__ddConfig.tabBar.list;return t instanceof Array&&(t=t.map((function(e){return e&&e.pagePath}))).indexOf(e)>=0}(t)&&Af(e,!0),o},attachView:function(e,t){var r=nu.get(e);if(r){var n=r.root,o=!1,i={};Object.keys(t).forEach((function(e){exparser.Component.hasProperty(n,e)&&(i[e]=t[e],o=!0)})),o&&r.root.setData(i),fl()&&(r.initialRootData=t),exparser.Element.pretendAttached(n),r.root.__treeManager__.operationFlow.end()}},removeView:function(e){var t=nu.get(e);t&&(exparser.Element.pretendDetached(t.root),nu.destroy(e),function(e){for(var t in Do[e])Do[e][t]=null,delete Do[e][t];delete Do[e]}(e))},componentAliases:bc,componentPathToAlias:wc,getDomainByPluginId:yc,publishDomainComponents:function(e,t){var r;for(var n in t){var o=t[n];if(!(r=o.match(/^plugin-private:\/\/(.*?)\//)))return;if(yc(r[1],"0")!==e)return;if(!(r=n.match(/^plugin:\/\/(.*?)\//)))return;yc(r[1],"0")===e&&(exparser.Component._list[n]||(exparser.Component._list[n]=exparser.Component._list[o],bc[n]=o,wc[o]=n))}return{componentAliases:bc,componentPathToAlias:wc}},getNodeById:function(e,t){if(Wo()){var r=nu.get(t);return r?r.nodeId.getNodeById(e):null}return nu.instance?nu.instance.nodeId.getNodeById(e):null},getNodeId:function(e,t){return Wo()?nu.get(t).nodeId.getNodeId(e):nu.instance?nu.instance.nodeId.getNodeId(e):""},getRootNodeId:function(e){if(Wo()){var t=nu.get(e);return t?t.rootNodeId:""}return nu.instance.rootNodeId},saveView:gd,restoreView:function(e){var t=nu.get(e);if(t){var r=t.nodeId.getAll(),n={},o=[],i=function(e){var i=t.nodeId.getNodeId(e);o.push(i),n[i]=r[i].data};t.tabRoot&&!t.tabDestroyed&&to(t.tabRoot,1,i),to(t.root,1,i);var a=[t.statesData||{},n,o],s=JSON.stringify(a),u=s.length;if(u>hd){for(var l=[],c=0;c<u;)l.push(s.substr(c,hd)),c+=hd;for(var d=++vd,f=l.length,p=0;p<f;p++)Ho(No.SYNC_EVENT_NAME.RESTORE_STATE,[{isSplitData:!0,splitInfo:{id:d,index:p+1,total:f,data:l[p]}}],e)}else Ho(No.SYNC_EVENT_NAME.RESTORE_STATE,a,e);if(t.statesData=void 0,!t.tabDestroyed&&t.tabRoot){Ho(No.SYNC_EVENT_NAME.COMPONENT_DEF_TAB,t.tabUsedDef,e);var _=t.tabRoot;t.operationFlow.start(),t.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_CREATE_TAB,_.is,t.nodeId.getNodeId(_)]),t.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_CREATE_TAB]),t.operationFlow.end()}Ho(No.SYNC_EVENT_NAME.COMPONENT_DEF,t.usedDef,e);var h=t.root;t.operationFlow.start(),t.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_INITIAL_CREATION,h.is,t.nodeId.getNodeId(h),{}]),t.operationFlow.push([No.SYNC_EVENT_NAME.FLOW_INITIAL_CREATION]),t.operationFlow.end(),t.tabRoot&&to(t.tabRoot,1,(function(e){e.triggerLifeTime("restored")})),to(t.root,1,(function(e){e.triggerLifeTime("restored")}))}},convertRouteToComponentAlias:au,convertComponentAliasToRoute:function(e){ou||iu();var t=exparser.Component._list[e]&&exparser.Component._list[e].is||e;return t=(t=t.replace(/^plugin-private:\/\/([0-9a-zA-Z]+)\//,(function(e,t){return(ou[t]||"")+"__plugin__/"+t+"/"}))).replace(/^dd:\/\//,"__dd__/")},getPluginRoutePrefix:function(e){return ou||iu(),su(e)+"__plugin__/"+e+"/"},getPluginSubPackagePrefix:su,initBannedMap:function(e){Object.keys(e).length>0&&(Zl=e,nu.listViewId().forEach((function(t){Ho(No.SYNC_EVENT_NAME.BANNING_MAP,[e],t,null)})))},beginTapMark:lu,endTapMark:du,checkTapMark:cu,wrapTapMark:fu,updateDdAppCode:function(e,t){var r=dl[e];if(Wo()){if(r)return pl[e]=t,r(t)}else if(r)return pl[e]=t,__ddAppCode__[e]=t,r(t)},enableUpdateDdAppCode:function(){cl=!0},mergeData:function(e){return e},globalThis:hl};return exparser.globalOptions.createFakeDomElement=!1,exparser.globalOptions.inDocument=!1,exparser.globalOptions.documentBackend="none",exparser.registerBehavior({is:"dd://form-field",properties:{name:{type:null,public:!0},value:{type:null,public:!0}}}),exparser.registerBehavior({is:"dd://form-field-group"}),exparser.registerBehavior({is:"dd://form-field-button"}),exparser.registerBehavior({is:"dd://style-filter"}),exparser.registerBehavior({is:"dd://request-filter"}),exparser.registerBehavior({is:"dd://request-sender"}),exparser.registerBehavior({is:"dd://component-export",definitionFilter:function(e){"function"==typeof e.export&&("object"===qs(e.methods)?e.methods.__export__=e.export:e.methods={__export__:e.export})}}),Of}();


var __appServiceEngine__=function(){"use strict";function e(t){return e="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},e(t)}function t(){return t=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},t.apply(this,arguments)}var n="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function r(e,t,n){return e(n={path:t,exports:{},require:function(e,t){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==t&&n.path)}},n.exports),n.exports}var o,i,a=function(e){return e&&e.Math==Math&&e},c=a("object"==typeof globalThis&&globalThis)||a("object"==typeof window&&window)||a("object"==typeof self&&self)||a("object"==typeof n&&n)||function(){return this}()||Function("return this")(),u=function(e){try{return!!e()}catch(e){return!0}},f=!u((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),l=!u((function(){var e=function(){}.bind();return"function"!=typeof e||e.hasOwnProperty("prototype")})),s=Function.prototype.call,p=l?s.bind(s):function(){return s.apply(s,arguments)},d={}.propertyIsEnumerable,g=Object.getOwnPropertyDescriptor,_={f:g&&!d.call({1:2},1)?function(e){var t=g(this,e);return!!t&&t.enumerable}:d},v=function(e,t){return{enumerable:!(1&e),configurable:!(2&e),writable:!(4&e),value:t}},h=Function.prototype,y=h.bind,b=h.call,m=l&&y.bind(b,b),w=l?function(e){return e&&m(e)}:function(e){return e&&function(){return b.apply(e,arguments)}},S=w({}.toString),P=w("".slice),O=function(e){return P(S(e),8,-1)},I=c.Object,E=w("".split),T=u((function(){return!I("z").propertyIsEnumerable(0)}))?function(e){return"String"==O(e)?E(e,""):I(e)}:I,R=c.TypeError,x=function(e){if(null==e)throw R("Can't call method on "+e);return e},C=function(e){return T(x(e))},k=function(e){return"function"==typeof e},j=function(e){return"object"==typeof e?null!==e:k(e)},A=function(e){return k(e)?e:void 0},D=function(e,t){return arguments.length<2?A(c[e]):c[e]&&c[e][t]},L=w({}.isPrototypeOf),B=D("navigator","userAgent")||"",M=c.process,N=c.Deno,V=M&&M.versions||N&&N.version,F=V&&V.v8;F&&(i=(o=F.split("."))[0]>0&&o[0]<4?1:+(o[0]+o[1])),!i&&B&&(!(o=B.match(/Edge\/(\d+)/))||o[1]>=74)&&(o=B.match(/Chrome\/(\d+)/))&&(i=+o[1]);var U=i,G=!!Object.getOwnPropertySymbols&&!u((function(){var e=Symbol();return!String(e)||!(Object(e)instanceof Symbol)||!Symbol.sham&&U&&U<41})),K=G&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,$=c.Object,H=K?function(e){return"symbol"==typeof e}:function(e){var t=D("Symbol");return k(t)&&L(t.prototype,$(e))},W=c.String,J=function(e){try{return W(e)}catch(e){return"Object"}},z=c.TypeError,Y=function(e){if(k(e))return e;throw z(J(e)+" is not a function")},q=function(e,t){var n=e[t];return null==n?void 0:Y(n)},Q=c.TypeError,X=Object.defineProperty,Z=function(e,t){try{X(c,e,{value:t,configurable:!0,writable:!0})}catch(n){c[e]=t}return t},ee="__core-js_shared__",te=c[ee]||Z(ee,{}),ne=r((function(e){(e.exports=function(e,t){return te[e]||(te[e]=void 0!==t?t:{})})("versions",[]).push({version:"3.21.1",mode:"global",copyright:"© 2014-2022 Denis Pushkarev (zloirock.ru)",license:"https://github.com/zloirock/core-js/blob/v3.21.1/LICENSE",source:"https://github.com/zloirock/core-js"})})),re=c.Object,oe=function(e){return re(x(e))},ie=w({}.hasOwnProperty),ae=Object.hasOwn||function(e,t){return ie(oe(e),t)},ce=0,ue=Math.random(),fe=w(1..toString),le=function(e){return"Symbol("+(void 0===e?"":e)+")_"+fe(++ce+ue,36)},se=ne("wks"),pe=c.Symbol,de=pe&&pe.for,ge=K?pe:pe&&pe.withoutSetter||le,_e=function(e){if(!ae(se,e)||!G&&"string"!=typeof se[e]){var t="Symbol."+e;G&&ae(pe,e)?se[e]=pe[e]:se[e]=K&&de?de(t):ge(t)}return se[e]},ve=c.TypeError,he=_e("toPrimitive"),ye=function(e,t){if(!j(e)||H(e))return e;var n,r=q(e,he);if(r){if(void 0===t&&(t="default"),n=p(r,e,t),!j(n)||H(n))return n;throw ve("Can't convert object to primitive value")}return void 0===t&&(t="number"),function(e,t){var n,r;if("string"===t&&k(n=e.toString)&&!j(r=p(n,e)))return r;if(k(n=e.valueOf)&&!j(r=p(n,e)))return r;if("string"!==t&&k(n=e.toString)&&!j(r=p(n,e)))return r;throw Q("Can't convert object to primitive value")}(e,t)},be=function(e){var t=ye(e,"string");return H(t)?t:t+""},me=c.document,we=j(me)&&j(me.createElement),Se=function(e){return we?me.createElement(e):{}},Pe=!f&&!u((function(){return 7!=Object.defineProperty(Se("div"),"a",{get:function(){return 7}}).a})),Oe=Object.getOwnPropertyDescriptor,Ie={f:f?Oe:function(e,t){if(e=C(e),t=be(t),Pe)try{return Oe(e,t)}catch(e){}if(ae(e,t))return v(!p(_.f,e,t),e[t])}},Ee=f&&u((function(){return 42!=Object.defineProperty((function(){}),"prototype",{value:42,writable:!1}).prototype})),Te=c.String,Re=c.TypeError,xe=function(e){if(j(e))return e;throw Re(Te(e)+" is not an object")},Ce=c.TypeError,ke=Object.defineProperty,je=Object.getOwnPropertyDescriptor,Ae="enumerable",De="configurable",Le="writable",Be={f:f?Ee?function(e,t,n){if(xe(e),t=be(t),xe(n),"function"==typeof e&&"prototype"===t&&"value"in n&&Le in n&&!n.writable){var r=je(e,t);r&&r.writable&&(e[t]=n.value,n={configurable:De in n?n.configurable:r.configurable,enumerable:Ae in n?n.enumerable:r.enumerable,writable:!1})}return ke(e,t,n)}:ke:function(e,t,n){if(xe(e),t=be(t),xe(n),Pe)try{return ke(e,t,n)}catch(e){}if("get"in n||"set"in n)throw Ce("Accessors not supported");return"value"in n&&(e[t]=n.value),e}},Me=f?function(e,t,n){return Be.f(e,t,v(1,n))}:function(e,t,n){return e[t]=n,e},Ne=w(Function.toString);k(te.inspectSource)||(te.inspectSource=function(e){return Ne(e)});var Ve,Fe,Ue,Ge=te.inspectSource,Ke=c.WeakMap,$e=k(Ke)&&/native code/.test(Ge(Ke)),He=ne("keys"),We=function(e){return He[e]||(He[e]=le(e))},Je={},ze="Object already initialized",Ye=c.TypeError,qe=c.WeakMap;if($e||te.state){var Qe=te.state||(te.state=new qe),Xe=w(Qe.get),Ze=w(Qe.has),et=w(Qe.set);Ve=function(e,t){if(Ze(Qe,e))throw new Ye(ze);return t.facade=e,et(Qe,e,t),t},Fe=function(e){return Xe(Qe,e)||{}},Ue=function(e){return Ze(Qe,e)}}else{var tt=We("state");Je[tt]=!0,Ve=function(e,t){if(ae(e,tt))throw new Ye(ze);return t.facade=e,Me(e,tt,t),t},Fe=function(e){return ae(e,tt)?e[tt]:{}},Ue=function(e){return ae(e,tt)}}var nt={set:Ve,get:Fe,has:Ue,enforce:function(e){return Ue(e)?Fe(e):Ve(e,{})},getterFor:function(e){return function(t){var n;if(!j(t)||(n=Fe(t)).type!==e)throw Ye("Incompatible receiver, "+e+" required");return n}}},rt=Function.prototype,ot=f&&Object.getOwnPropertyDescriptor,it=ae(rt,"name"),at={EXISTS:it,PROPER:it&&"something"===function(){}.name,CONFIGURABLE:it&&(!f||f&&ot(rt,"name").configurable)},ct=r((function(e){var t=at.CONFIGURABLE,n=nt.get,r=nt.enforce,o=String(String).split("String");(e.exports=function(e,n,i,a){var u,f=!!a&&!!a.unsafe,l=!!a&&!!a.enumerable,s=!!a&&!!a.noTargetGet,p=a&&void 0!==a.name?a.name:n;k(i)&&("Symbol("===String(p).slice(0,7)&&(p="["+String(p).replace(/^Symbol\(([^)]*)\)/,"$1")+"]"),(!ae(i,"name")||t&&i.name!==p)&&Me(i,"name",p),(u=r(i)).source||(u.source=o.join("string"==typeof p?p:""))),e!==c?(f?!s&&e[n]&&(l=!0):delete e[n],l?e[n]=i:Me(e,n,i)):l?e[n]=i:Z(n,i)})(Function.prototype,"toString",(function(){return k(this)&&n(this).source||Ge(this)}))})),ut=Math.ceil,ft=Math.floor,lt=function(e){var t=+e;return t!=t||0===t?0:(t>0?ft:ut)(t)},st=Math.max,pt=Math.min,dt=function(e,t){var n=lt(e);return n<0?st(n+t,0):pt(n,t)},gt=Math.min,_t=function(e){return e>0?gt(lt(e),9007199254740991):0},vt=function(e){return _t(e.length)},ht=function(e){return function(t,n,r){var o,i=C(t),a=vt(i),c=dt(r,a);if(e&&n!=n){for(;a>c;)if((o=i[c++])!=o)return!0}else for(;a>c;c++)if((e||c in i)&&i[c]===n)return e||c||0;return!e&&-1}},yt={includes:ht(!0),indexOf:ht(!1)},bt=yt.indexOf,mt=w([].push),wt=function(e,t){var n,r=C(e),o=0,i=[];for(n in r)!ae(Je,n)&&ae(r,n)&&mt(i,n);for(;t.length>o;)ae(r,n=t[o++])&&(~bt(i,n)||mt(i,n));return i},St=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],Pt=St.concat("length","prototype"),Ot={f:Object.getOwnPropertyNames||function(e){return wt(e,Pt)}},It={f:Object.getOwnPropertySymbols},Et=w([].concat),Tt=D("Reflect","ownKeys")||function(e){var t=Ot.f(xe(e)),n=It.f;return n?Et(t,n(e)):t},Rt=function(e,t,n){for(var r=Tt(t),o=Be.f,i=Ie.f,a=0;a<r.length;a++){var c=r[a];ae(e,c)||n&&ae(n,c)||o(e,c,i(t,c))}},xt=/#|\.prototype\./,Ct=function(e,t){var n=jt[kt(e)];return n==Dt||n!=At&&(k(t)?u(t):!!t)},kt=Ct.normalize=function(e){return String(e).replace(xt,".").toLowerCase()},jt=Ct.data={},At=Ct.NATIVE="N",Dt=Ct.POLYFILL="P",Lt=Ct,Bt=Ie.f,Mt=function(e,t){var n,r,o,i,a,u=e.target,f=e.global,l=e.stat;if(n=f?c:l?c[u]||Z(u,{}):(c[u]||{}).prototype)for(r in t){if(i=t[r],o=e.noTargetGet?(a=Bt(n,r))&&a.value:n[r],!Lt(f?r:u+(l?".":"#")+r,e.forced)&&void 0!==o){if(typeof i==typeof o)continue;Rt(i,o)}(e.sham||o&&o.sham)&&Me(i,"sham",!0),ct(n,r,i,e)}},Nt={};Nt[_e("toStringTag")]="z";var Vt,Ft="[object z]"===String(Nt),Ut=_e("toStringTag"),Gt=c.Object,Kt="Arguments"==O(function(){return arguments}()),$t=Ft?O:function(e){var t,n,r;return void 0===e?"Undefined":null===e?"Null":"string"==typeof(n=function(e,t){try{return e[t]}catch(e){}}(t=Gt(e),Ut))?n:Kt?O(t):"Object"==(r=O(t))&&k(t.callee)?"Arguments":r},Ht=c.String,Wt=function(e){if("Symbol"===$t(e))throw TypeError("Cannot convert a Symbol value to a string");return Ht(e)},Jt=function(){var e=xe(this),t="";return e.global&&(t+="g"),e.ignoreCase&&(t+="i"),e.multiline&&(t+="m"),e.dotAll&&(t+="s"),e.unicode&&(t+="u"),e.sticky&&(t+="y"),t},zt=c.RegExp,Yt=u((function(){var e=zt("a","y");return e.lastIndex=2,null!=e.exec("abcd")})),qt=Yt||u((function(){return!zt("a","y").sticky})),Qt={BROKEN_CARET:Yt||u((function(){var e=zt("^r","gy");return e.lastIndex=2,null!=e.exec("str")})),MISSED_STICKY:qt,UNSUPPORTED_Y:Yt},Xt=Object.keys||function(e){return wt(e,St)},Zt=f&&!Ee?Object.defineProperties:function(e,t){xe(e);for(var n,r=C(t),o=Xt(t),i=o.length,a=0;i>a;)Be.f(e,n=o[a++],r[n]);return e},en={f:Zt},tn=D("document","documentElement"),nn=We("IE_PROTO"),rn=function(){},on=function(e){return"<script>"+e+"</"+"script>"},an=function(e){e.write(on("")),e.close();var t=e.parentWindow.Object;return e=null,t},cn=function(){try{Vt=new ActiveXObject("htmlfile")}catch(e){}var e,t;cn="undefined"!=typeof document?document.domain&&Vt?an(Vt):((t=Se("iframe")).style.display="none",tn.appendChild(t),t.src=String("javascript:"),(e=t.contentWindow.document).open(),e.write(on("document.F=Object")),e.close(),e.F):an(Vt);for(var n=St.length;n--;)delete cn.prototype[St[n]];return cn()};Je[nn]=!0;var un=Object.create||function(e,t){var n;return null!==e?(rn.prototype=xe(e),n=new rn,rn.prototype=null,n[nn]=e):n=cn(),void 0===t?n:en.f(n,t)},fn=c.RegExp,ln=u((function(){var e=fn(".","s");return!(e.dotAll&&e.exec("\n")&&"s"===e.flags)})),sn=c.RegExp,pn=u((function(){var e=sn("(?<a>b)","g");return"b"!==e.exec("b").groups.a||"bc"!=="b".replace(e,"$<a>c")})),dn=nt.get,gn=ne("native-string-replace",String.prototype.replace),_n=RegExp.prototype.exec,vn=_n,hn=w("".charAt),yn=w("".indexOf),bn=w("".replace),mn=w("".slice),wn=function(){var e=/a/,t=/b*/g;return p(_n,e,"a"),p(_n,t,"a"),0!==e.lastIndex||0!==t.lastIndex}(),Sn=Qt.BROKEN_CARET,Pn=void 0!==/()??/.exec("")[1];(wn||Pn||Sn||ln||pn)&&(vn=function(e){var t,n,r,o,i,a,c,u=this,f=dn(u),l=Wt(e),s=f.raw;if(s)return s.lastIndex=u.lastIndex,t=p(vn,s,l),u.lastIndex=s.lastIndex,t;var d=f.groups,g=Sn&&u.sticky,_=p(Jt,u),v=u.source,h=0,y=l;if(g&&(_=bn(_,"y",""),-1===yn(_,"g")&&(_+="g"),y=mn(l,u.lastIndex),u.lastIndex>0&&(!u.multiline||u.multiline&&"\n"!==hn(l,u.lastIndex-1))&&(v="(?: "+v+")",y=" "+y,h++),n=new RegExp("^(?:"+v+")",_)),Pn&&(n=new RegExp("^"+v+"$(?!\\s)",_)),wn&&(r=u.lastIndex),o=p(_n,g?n:u,y),g?o?(o.input=mn(o.input,h),o[0]=mn(o[0],h),o.index=u.lastIndex,u.lastIndex+=o[0].length):u.lastIndex=0:wn&&o&&(u.lastIndex=u.global?o.index+o[0].length:r),Pn&&o&&o.length>1&&p(gn,o[0],n,(function(){for(i=1;i<arguments.length-2;i++)void 0===arguments[i]&&(o[i]=void 0)})),o&&d)for(o.groups=a=un(null),i=0;i<d.length;i++)a[(c=d[i])[0]]=o[c[1]];return o});var On=vn;Mt({target:"RegExp",proto:!0,forced:/./.exec!==On},{exec:On});var In=_e("species"),En=RegExp.prototype,Tn=function(e,t,n,r){var o=_e(e),i=!u((function(){var t={};return t[o]=function(){return 7},7!=""[e](t)})),a=i&&!u((function(){var t=!1,n=/a/;return"split"===e&&((n={}).constructor={},n.constructor[In]=function(){return n},n.flags="",n[o]=/./[o]),n.exec=function(){return t=!0,null},n[o](""),!t}));if(!i||!a||n){var c=w(/./[o]),f=t(o,""[e],(function(e,t,n,r,o){var a=w(e),u=t.exec;return u===On||u===En.exec?i&&!o?{done:!0,value:c(t,n,r)}:{done:!0,value:a(n,t,r)}:{done:!1}}));ct(String.prototype,e,f[0]),ct(En,o,f[1])}r&&Me(En[o],"sham",!0)},Rn=w("".charAt),xn=w("".charCodeAt),Cn=w("".slice),kn=function(e){return function(t,n){var r,o,i=Wt(x(t)),a=lt(n),c=i.length;return a<0||a>=c?e?"":void 0:(r=xn(i,a))<55296||r>56319||a+1===c||(o=xn(i,a+1))<56320||o>57343?e?Rn(i,a):r:e?Cn(i,a,a+2):o-56320+(r-55296<<10)+65536}},jn={codeAt:kn(!1),charAt:kn(!0)},An=jn.charAt,Dn=function(e,t,n){return t+(n?An(e,t).length:1)},Ln=c.TypeError,Bn=function(e,t){var n=e.exec;if(k(n)){var r=p(n,e,t);return null!==r&&xe(r),r}if("RegExp"===O(e))return p(On,e,t);throw Ln("RegExp#exec called on incompatible receiver")};Tn("match",(function(e,t,n){return[function(t){var n=x(this),r=null==t?void 0:q(t,e);return r?p(r,t,n):new RegExp(t)[e](Wt(n))},function(e){var r=xe(this),o=Wt(e),i=n(t,r,o);if(i.done)return i.value;if(!r.global)return Bn(r,o);var a=r.unicode;r.lastIndex=0;for(var c,u=[],f=0;null!==(c=Bn(r,o));){var l=Wt(c[0]);u[f]=l,""===l&&(r.lastIndex=Dn(o,_t(r.lastIndex),a)),f++}return 0===f?null:u}]}));var Mn={CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0},Nn=Se("span").classList,Vn=Nn&&Nn.constructor&&Nn.constructor.prototype,Fn=Vn===Object.prototype?void 0:Vn,Un=w(w.bind),Gn=function(e,t){return Y(e),void 0===t?e:l?Un(e,t):function(){return e.apply(t,arguments)}},Kn=Array.isArray||function(e){return"Array"==O(e)},$n=function(){},Hn=[],Wn=D("Reflect","construct"),Jn=/^\s*(?:class|function)\b/,zn=w(Jn.exec),Yn=!Jn.exec($n),qn=function(e){if(!k(e))return!1;try{return Wn($n,Hn,e),!0}catch(e){return!1}},Qn=function(e){if(!k(e))return!1;switch($t(e)){case"AsyncFunction":case"GeneratorFunction":case"AsyncGeneratorFunction":return!1}try{return Yn||!!zn(Jn,Ge(e))}catch(e){return!0}};Qn.sham=!0;var Xn=!Wn||u((function(){var e;return qn(qn.call)||!qn(Object)||!qn((function(){e=!0}))||e}))?Qn:qn,Zn=_e("species"),er=c.Array,tr=function(e,t){return new(function(e){var t;return Kn(e)&&(t=e.constructor,(Xn(t)&&(t===er||Kn(t.prototype))||j(t)&&null===(t=t[Zn]))&&(t=void 0)),void 0===t?er:t}(e))(0===t?0:t)},nr=w([].push),rr=function(e){var t=1==e,n=2==e,r=3==e,o=4==e,i=6==e,a=7==e,c=5==e||i;return function(u,f,l,s){for(var p,d,g=oe(u),_=T(g),v=Gn(f,l),h=vt(_),y=0,b=s||tr,m=t?b(u,h):n||a?b(u,0):void 0;h>y;y++)if((c||y in _)&&(d=v(p=_[y],y,g),e))if(t)m[y]=d;else if(d)switch(e){case 3:return!0;case 5:return p;case 6:return y;case 2:nr(m,p)}else switch(e){case 4:return!1;case 7:nr(m,p)}return i?-1:r||o?o:m}},or={forEach:rr(0),map:rr(1),filter:rr(2),some:rr(3),every:rr(4),find:rr(5),findIndex:rr(6),filterReject:rr(7)},ir=function(e,t){var n=[][e];return!!n&&u((function(){n.call(null,t||function(){return 1},1)}))},ar=or.forEach,cr=ir("forEach")?[].forEach:function(e){return ar(this,e,arguments.length>1?arguments[1]:void 0)},ur=function(e){if(e&&e.forEach!==cr)try{Me(e,"forEach",cr)}catch(t){e.forEach=cr}};for(var fr in Mn)Mn[fr]&&ur(c[fr]&&c[fr].prototype);ur(Fn);var lr=function(e,t,n){var r=be(t);r in e?Be.f(e,r,v(0,n)):e[r]=n},sr=_e("species"),pr=function(e){return U>=51||!u((function(){var t=[];return(t.constructor={})[sr]=function(){return{foo:1}},1!==t[e](Boolean).foo}))},dr=_e("isConcatSpreadable"),gr=9007199254740991,_r="Maximum allowed index exceeded",vr=c.TypeError,hr=U>=51||!u((function(){var e=[];return e[dr]=!1,e.concat()[0]!==e})),yr=pr("concat"),br=function(e){if(!j(e))return!1;var t=e[dr];return void 0!==t?!!t:Kn(e)};Mt({target:"Array",proto:!0,forced:!hr||!yr},{concat:function(e){var t,n,r,o,i,a=oe(this),c=tr(a,0),u=0;for(t=-1,r=arguments.length;t<r;t++)if(br(i=-1===t?a:arguments[t])){if(u+(o=vt(i))>gr)throw vr(_r);for(n=0;n<o;n++,u++)n in i&&lr(c,u,i[n])}else{if(u>=gr)throw vr(_r);lr(c,u++,i)}return c.length=u,c}});var mr=Function.prototype,wr=mr.apply,Sr=mr.call,Pr="object"==typeof Reflect&&Reflect.apply||(l?Sr.bind(wr):function(){return Sr.apply(wr,arguments)}),Or=Math.floor,Ir=w("".charAt),Er=w("".replace),Tr=w("".slice),Rr=/\$([$&'`]|\d{1,2}|<[^>]*>)/g,xr=/\$([$&'`]|\d{1,2})/g,Cr=function(e,t,n,r,o,i){var a=n+e.length,c=r.length,u=xr;return void 0!==o&&(o=oe(o),u=Rr),Er(i,u,(function(i,u){var f;switch(Ir(u,0)){case"$":return"$";case"&":return e;case"`":return Tr(t,0,n);case"'":return Tr(t,a);case"<":f=o[Tr(u,1,-1)];break;default:var l=+u;if(0===l)return i;if(l>c){var s=Or(l/10);return 0===s?i:s<=c?void 0===r[s-1]?Ir(u,1):r[s-1]+Ir(u,1):i}f=r[l-1]}return void 0===f?"":f}))},kr=_e("replace"),jr=Math.max,Ar=Math.min,Dr=w([].concat),Lr=w([].push),Br=w("".indexOf),Mr=w("".slice),Nr="$0"==="a".replace(/./,"$0"),Vr=!!/./[kr]&&""===/./[kr]("a","$0");Tn("replace",(function(e,t,n){var r=Vr?"$":"$0";return[function(e,n){var r=x(this),o=null==e?void 0:q(e,kr);return o?p(o,e,r,n):p(t,Wt(r),e,n)},function(e,o){var i=xe(this),a=Wt(e);if("string"==typeof o&&-1===Br(o,r)&&-1===Br(o,"$<")){var c=n(t,i,a,o);if(c.done)return c.value}var u=k(o);u||(o=Wt(o));var f=i.global;if(f){var l=i.unicode;i.lastIndex=0}for(var s=[];;){var p=Bn(i,a);if(null===p)break;if(Lr(s,p),!f)break;""===Wt(p[0])&&(i.lastIndex=Dn(a,_t(i.lastIndex),l))}for(var d,g="",_=0,v=0;v<s.length;v++){for(var h=Wt((p=s[v])[0]),y=jr(Ar(lt(p.index),a.length),0),b=[],m=1;m<p.length;m++)Lr(b,void 0===(d=p[m])?d:String(d));var w=p.groups;if(u){var S=Dr([h],b,y,a);void 0!==w&&Lr(S,w);var P=Wt(Pr(o,void 0,S))}else P=Cr(h,a,y,b,w,o);y>=_&&(g+=Mr(a,_,y)+P,_=y+h.length)}return g+Mr(a,_)}]}),!!u((function(){var e=/./;return e.exec=function(){var e=[];return e.groups={a:"7"},e},"7"!=="".replace(e,"$<a>")}))||!Nr||Vr);var Fr=yt.indexOf,Ur=w([].indexOf),Gr=!!Ur&&1/Ur([1],1,-0)<0,Kr=ir("indexOf");Mt({target:"Array",proto:!0,forced:Gr||!Kr},{indexOf:function(e){var t=arguments.length>1?arguments[1]:void 0;return Gr?Ur(this,e,t)||0:Fr(this,e,t)}});var $r=Ft?{}.toString:function(){return"[object "+$t(this)+"]"};Ft||ct(Object.prototype,"toString",$r,{unsafe:!0});var Hr=at.PROPER,Wr="toString",Jr=RegExp.prototype,zr=Jr.toString,Yr=w(Jt),qr=u((function(){return"/a/b"!=zr.call({source:"a",flags:"b"})})),Qr=Hr&&zr.name!=Wr;(qr||Qr)&&ct(RegExp.prototype,Wr,(function(){var e=xe(this),t=Wt(e.source),n=e.flags;return"/"+t+"/"+Wt(void 0===n&&L(Jr,e)&&!("flags"in Jr)?Yr(e):n)}),{unsafe:!0});var Xr=_e("match"),Zr=function(e){var t;return j(e)&&(void 0!==(t=e[Xr])?!!t:"RegExp"==O(e))},eo=c.TypeError,to=_e("species"),no=function(e,t){var n,r=xe(e).constructor;return void 0===r||null==(n=xe(r)[to])?t:function(e){if(Xn(e))return e;throw eo(J(e)+" is not a constructor")}(n)},ro=c.Array,oo=Math.max,io=function(e,t,n){for(var r=vt(e),o=dt(t,r),i=dt(void 0===n?r:n,r),a=ro(oo(i-o,0)),c=0;o<i;o++,c++)lr(a,c,e[o]);return a.length=c,a},ao=Qt.UNSUPPORTED_Y,co=4294967295,uo=Math.min,fo=[].push,lo=w(/./.exec),so=w(fo),po=w("".slice),go=!u((function(){var e=/(?:)/,t=e.exec;e.exec=function(){return t.apply(this,arguments)};var n="ab".split(e);return 2!==n.length||"a"!==n[0]||"b"!==n[1]}));Tn("split",(function(e,t,n){var r;return r="c"=="abbc".split(/(b)*/)[1]||4!="test".split(/(?:)/,-1).length||2!="ab".split(/(?:ab)*/).length||4!=".".split(/(.?)(.?)/).length||".".split(/()()/).length>1||"".split(/.?/).length?function(e,n){var r=Wt(x(this)),o=void 0===n?co:n>>>0;if(0===o)return[];if(void 0===e)return[r];if(!Zr(e))return p(t,r,e,o);for(var i,a,c,u=[],f=(e.ignoreCase?"i":"")+(e.multiline?"m":"")+(e.unicode?"u":"")+(e.sticky?"y":""),l=0,s=new RegExp(e.source,f+"g");(i=p(On,s,r))&&!((a=s.lastIndex)>l&&(so(u,po(r,l,i.index)),i.length>1&&i.index<r.length&&Pr(fo,u,io(i,1)),c=i[0].length,l=a,u.length>=o));)s.lastIndex===i.index&&s.lastIndex++;return l===r.length?!c&&lo(s,"")||so(u,""):so(u,po(r,l)),u.length>o?io(u,0,o):u}:"0".split(void 0,0).length?function(e,n){return void 0===e&&0===n?[]:p(t,this,e,n)}:t,[function(t,n){var o=x(this),i=null==t?void 0:q(t,e);return i?p(i,t,o,n):p(r,Wt(o),t,n)},function(e,o){var i=xe(this),a=Wt(e),c=n(r,i,a,o,r!==t);if(c.done)return c.value;var u=no(i,RegExp),f=i.unicode,l=(i.ignoreCase?"i":"")+(i.multiline?"m":"")+(i.unicode?"u":"")+(ao?"g":"y"),s=new u(ao?"^(?:"+i.source+")":i,l),p=void 0===o?co:o>>>0;if(0===p)return[];if(0===a.length)return null===Bn(s,a)?[a]:[];for(var d=0,g=0,_=[];g<a.length;){s.lastIndex=ao?0:g;var v,h=Bn(s,ao?po(a,g):a);if(null===h||(v=uo(_t(s.lastIndex+(ao?g:0)),a.length))===d)g=Dn(a,g,f);else{if(so(_,po(a,d,g)),_.length===p)return _;for(var y=1;y<=h.length-1;y++)if(so(_,h[y]),_.length===p)return _;g=d=v}}return so(_,po(a,d)),_}]}),!go,ao);var _o=c.Promise,vo=c.String,ho=c.TypeError,yo=Object.setPrototypeOf||("__proto__"in{}?function(){var e,t=!1,n={};try{(e=w(Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set))(n,[]),t=n instanceof Array}catch(e){}return function(n,r){return xe(n),function(e){if("object"==typeof e||k(e))return e;throw ho("Can't set "+vo(e)+" as a prototype")}(r),t?e(n,r):n.__proto__=r,n}}():void 0),bo=Be.f,mo=_e("toStringTag"),wo=function(e,t,n){e&&!n&&(e=e.prototype),e&&!ae(e,mo)&&bo(e,mo,{configurable:!0,value:t})},So=_e("species"),Po=function(e){var t=D(e),n=Be.f;f&&t&&!t[So]&&n(t,So,{configurable:!0,get:function(){return this}})},Oo=c.TypeError,Io={},Eo=_e("iterator"),To=Array.prototype,Ro=function(e){return void 0!==e&&(Io.Array===e||To[Eo]===e)},xo=_e("iterator"),Co=function(e){if(null!=e)return q(e,xo)||q(e,"@@iterator")||Io[$t(e)]},ko=c.TypeError,jo=function(e,t){var n=arguments.length<2?Co(e):t;if(Y(n))return xe(p(n,e));throw ko(J(e)+" is not iterable")},Ao=function(e,t,n){var r,o;xe(e);try{if(!(r=q(e,"return"))){if("throw"===t)throw n;return n}r=p(r,e)}catch(e){o=!0,r=e}if("throw"===t)throw n;if(o)throw r;return xe(r),n},Do=c.TypeError,Lo=function(e,t){this.stopped=e,this.result=t},Bo=Lo.prototype,Mo=function(e,t,n){var r,o,i,a,c,u,f,l=n&&n.that,s=!(!n||!n.AS_ENTRIES),d=!(!n||!n.IS_ITERATOR),g=!(!n||!n.INTERRUPTED),_=Gn(t,l),v=function(e){return r&&Ao(r,"normal",e),new Lo(!0,e)},h=function(e){return s?(xe(e),g?_(e[0],e[1],v):_(e[0],e[1])):g?_(e,v):_(e)};if(d)r=e;else{if(!(o=Co(e)))throw Do(J(e)+" is not iterable");if(Ro(o)){for(i=0,a=vt(e);a>i;i++)if((c=h(e[i]))&&L(Bo,c))return c;return new Lo(!1)}r=jo(e,o)}for(u=r.next;!(f=p(u,r)).done;){try{c=h(f.value)}catch(e){Ao(r,"throw",e)}if("object"==typeof c&&c&&L(Bo,c))return c}return new Lo(!1)},No=_e("iterator"),Vo=!1;try{var Fo=0,Uo={next:function(){return{done:!!Fo++}},return:function(){Vo=!0}};Uo[No]=function(){return this},Array.from(Uo,(function(){throw 2}))}catch(e){}var Go,Ko,$o,Ho,Wo=function(e,t){if(!t&&!Vo)return!1;var n=!1;try{var r={};r[No]=function(){return{next:function(){return{done:n=!0}}}},e(r)}catch(e){}return n},Jo=w([].slice),zo=c.TypeError,Yo=function(e,t){if(e<t)throw zo("Not enough arguments");return e},qo=/(?:ipad|iphone|ipod).*applewebkit/i.test(B),Qo="process"==O(c.process),Xo=c.setImmediate,Zo=c.clearImmediate,ei=c.process,ti=c.Dispatch,ni=c.Function,ri=c.MessageChannel,oi=c.String,ii=0,ai={},ci="onreadystatechange";try{Go=c.location}catch(e){}var ui=function(e){if(ae(ai,e)){var t=ai[e];delete ai[e],t()}},fi=function(e){return function(){ui(e)}},li=function(e){ui(e.data)},si=function(e){c.postMessage(oi(e),Go.protocol+"//"+Go.host)};Xo&&Zo||(Xo=function(e){Yo(arguments.length,1);var t=k(e)?e:ni(e),n=Jo(arguments,1);return ai[++ii]=function(){Pr(t,void 0,n)},Ko(ii),ii},Zo=function(e){delete ai[e]},Qo?Ko=function(e){ei.nextTick(fi(e))}:ti&&ti.now?Ko=function(e){ti.now(fi(e))}:ri&&!qo?(Ho=($o=new ri).port2,$o.port1.onmessage=li,Ko=Gn(Ho.postMessage,Ho)):c.addEventListener&&k(c.postMessage)&&!c.importScripts&&Go&&"file:"!==Go.protocol&&!u(si)?(Ko=si,c.addEventListener("message",li,!1)):Ko=ci in Se("script")?function(e){tn.appendChild(Se("script")).onreadystatechange=function(){tn.removeChild(this),ui(e)}}:function(e){setTimeout(fi(e),0)});var pi,di,gi,_i,vi,hi,yi,bi,mi={set:Xo,clear:Zo},wi=/ipad|iphone|ipod/i.test(B)&&void 0!==c.Pebble,Si=/web0s(?!.*chrome)/i.test(B),Pi=Ie.f,Oi=mi.set,Ii=c.MutationObserver||c.WebKitMutationObserver,Ei=c.document,Ti=c.process,Ri=c.Promise,xi=Pi(c,"queueMicrotask"),Ci=xi&&xi.value;Ci||(pi=function(){var e,t;for(Qo&&(e=Ti.domain)&&e.exit();di;){t=di.fn,di=di.next;try{t()}catch(e){throw di?_i():gi=void 0,e}}gi=void 0,e&&e.enter()},qo||Qo||Si||!Ii||!Ei?!wi&&Ri&&Ri.resolve?((yi=Ri.resolve(void 0)).constructor=Ri,bi=Gn(yi.then,yi),_i=function(){bi(pi)}):Qo?_i=function(){Ti.nextTick(pi)}:(Oi=Gn(Oi,c),_i=function(){Oi(pi)}):(vi=!0,hi=Ei.createTextNode(""),new Ii(pi).observe(hi,{characterData:!0}),_i=function(){hi.data=vi=!vi}));var ki=Ci||function(e){var t={fn:e,next:void 0};gi&&(gi.next=t),di||(di=t,_i()),gi=t},ji=function(e){var t,n;this.promise=new e((function(e,r){if(void 0!==t||void 0!==n)throw TypeError("Bad Promise constructor");t=e,n=r})),this.resolve=Y(t),this.reject=Y(n)},Ai={f:function(e){return new ji(e)}},Di=function(e){try{return{error:!1,value:e()}}catch(e){return{error:!0,value:e}}},Li=function(){this.head=null,this.tail=null};Li.prototype={add:function(e){var t={item:e,next:null};this.head?this.tail.next=t:this.head=t,this.tail=t},get:function(){var e=this.head;if(e)return this.head=e.next,this.tail===e&&(this.tail=null),e.item}};var Bi,Mi,Ni,Vi,Fi=Li,Ui="object"==typeof window,Gi=mi.set,Ki=_e("species"),$i="Promise",Hi=nt.getterFor($i),Wi=nt.set,Ji=nt.getterFor($i),zi=_o&&_o.prototype,Yi=_o,qi=zi,Qi=c.TypeError,Xi=c.document,Zi=c.process,ea=Ai.f,ta=ea,na=!!(Xi&&Xi.createEvent&&c.dispatchEvent),ra=k(c.PromiseRejectionEvent),oa="unhandledrejection",ia=!1,aa=Lt($i,(function(){var e=Ge(Yi),t=e!==String(Yi);if(!t&&66===U)return!0;if(U>=51&&/native code/.test(e))return!1;var n=new Yi((function(e){e(1)})),r=function(e){e((function(){}),(function(){}))};return(n.constructor={})[Ki]=r,!(ia=n.then((function(){}))instanceof r)||!t&&Ui&&!ra})),ca=aa||!Wo((function(e){Yi.all(e).catch((function(){}))})),ua=function(e){var t;return!(!j(e)||!k(t=e.then))&&t},fa=function(e,t){var n,r,o,i=t.value,a=1==t.state,c=a?e.ok:e.fail,u=e.resolve,f=e.reject,l=e.domain;try{c?(a||(2===t.rejection&&ga(t),t.rejection=1),!0===c?n=i:(l&&l.enter(),n=c(i),l&&(l.exit(),o=!0)),n===e.promise?f(Qi("Promise-chain cycle")):(r=ua(n))?p(r,n,u,f):u(n)):f(i)}catch(e){l&&!o&&l.exit(),f(e)}},la=function(e,t){e.notified||(e.notified=!0,ki((function(){for(var n,r=e.reactions;n=r.get();)fa(n,e);e.notified=!1,t&&!e.rejection&&pa(e)})))},sa=function(e,t,n){var r,o;na?((r=Xi.createEvent("Event")).promise=t,r.reason=n,r.initEvent(e,!1,!0),c.dispatchEvent(r)):r={promise:t,reason:n},!ra&&(o=c["on"+e])?o(r):e===oa&&function(e,t){var n=c.console;n&&n.error&&(1==arguments.length?n.error(e):n.error(e,t))}("Unhandled promise rejection",n)},pa=function(e){p(Gi,c,(function(){var t,n=e.facade,r=e.value;if(da(e)&&(t=Di((function(){Qo?Zi.emit("unhandledRejection",r,n):sa(oa,n,r)})),e.rejection=Qo||da(e)?2:1,t.error))throw t.value}))},da=function(e){return 1!==e.rejection&&!e.parent},ga=function(e){p(Gi,c,(function(){var t=e.facade;Qo?Zi.emit("rejectionHandled",t):sa("rejectionhandled",t,e.value)}))},_a=function(e,t,n){return function(r){e(t,r,n)}},va=function(e,t,n){e.done||(e.done=!0,n&&(e=n),e.value=t,e.state=2,la(e,!0))},ha=function(e,t,n){if(!e.done){e.done=!0,n&&(e=n);try{if(e.facade===t)throw Qi("Promise can't be resolved itself");var r=ua(t);r?ki((function(){var n={done:!1};try{p(r,t,_a(ha,n,e),_a(va,n,e))}catch(t){va(n,t,e)}})):(e.value=t,e.state=1,la(e,!1))}catch(t){va({done:!1},t,e)}}};if(aa&&(qi=(Yi=function(e){!function(e,t){if(L(t,e))return e;throw Oo("Incorrect invocation")}(this,qi),Y(e),p(Bi,this);var t=Hi(this);try{e(_a(ha,t),_a(va,t))}catch(e){va(t,e)}}).prototype,(Bi=function(e){Wi(this,{type:$i,done:!1,notified:!1,parent:!1,reactions:new Fi,rejection:!1,state:0,value:void 0})}).prototype=function(e,t,n){for(var r in t)ct(e,r,t[r],n);return e}(qi,{then:function(e,t){var n=Ji(this),r=ea(no(this,Yi));return n.parent=!0,r.ok=!k(e)||e,r.fail=k(t)&&t,r.domain=Qo?Zi.domain:void 0,0==n.state?n.reactions.add(r):ki((function(){fa(r,n)})),r.promise},catch:function(e){return this.then(void 0,e)}}),Mi=function(){var e=new Bi,t=Hi(e);this.promise=e,this.resolve=_a(ha,t),this.reject=_a(va,t)},Ai.f=ea=function(e){return e===Yi||e===Ni?new Mi(e):ta(e)},k(_o)&&zi!==Object.prototype)){Vi=zi.then,ia||(ct(zi,"then",(function(e,t){var n=this;return new Yi((function(e,t){p(Vi,n,e,t)})).then(e,t)}),{unsafe:!0}),ct(zi,"catch",qi.catch,{unsafe:!0}));try{delete zi.constructor}catch(e){}yo&&yo(zi,qi)}Mt({global:!0,wrap:!0,forced:aa},{Promise:Yi}),wo(Yi,$i,!1),Po($i),Ni=D($i),Mt({target:$i,stat:!0,forced:aa},{reject:function(e){var t=ea(this);return p(t.reject,void 0,e),t.promise}}),Mt({target:$i,stat:!0,forced:aa},{resolve:function(e){return function(e,t){if(xe(e),j(t)&&t.constructor===e)return t;var n=Ai.f(e);return(0,n.resolve)(t),n.promise}(this,e)}}),Mt({target:$i,stat:!0,forced:ca},{all:function(e){var t=this,n=ea(t),r=n.resolve,o=n.reject,i=Di((function(){var n=Y(t.resolve),i=[],a=0,c=1;Mo(e,(function(e){var u=a++,f=!1;c++,p(n,t,e).then((function(e){f||(f=!0,i[u]=e,--c||r(i))}),o)})),--c||r(i)}));return i.error&&o(i.value),n.promise},race:function(e){var t=this,n=ea(t),r=n.reject,o=Di((function(){var o=Y(t.resolve);Mo(e,(function(e){p(o,t,e).then(n.resolve,r)}))}));return o.error&&r(o.value),n.promise}});var ya=_e("unscopables"),ba=Array.prototype;null==ba[ya]&&Be.f(ba,ya,{configurable:!0,value:un(null)});var ma,wa,Sa,Pa=function(e){ba[ya][e]=!0},Oa=!u((function(){function e(){}return e.prototype.constructor=null,Object.getPrototypeOf(new e)!==e.prototype})),Ia=We("IE_PROTO"),Ea=c.Object,Ta=Ea.prototype,Ra=Oa?Ea.getPrototypeOf:function(e){var t=oe(e);if(ae(t,Ia))return t[Ia];var n=t.constructor;return k(n)&&t instanceof n?n.prototype:t instanceof Ea?Ta:null},xa=_e("iterator"),Ca=!1;[].keys&&("next"in(Sa=[].keys())?(wa=Ra(Ra(Sa)))!==Object.prototype&&(ma=wa):Ca=!0);var ka=null==ma||u((function(){var e={};return ma[xa].call(e)!==e}));ka&&(ma={}),k(ma[xa])||ct(ma,xa,(function(){return this}));var ja={IteratorPrototype:ma,BUGGY_SAFARI_ITERATORS:Ca},Aa=ja.IteratorPrototype,Da=function(){return this},La=at.PROPER,Ba=at.CONFIGURABLE,Ma=ja.IteratorPrototype,Na=ja.BUGGY_SAFARI_ITERATORS,Va=_e("iterator"),Fa="keys",Ua="values",Ga="entries",Ka=function(){return this},$a=function(e,t,n,r,o,i,a){!function(e,t,n,r){var o=t+" Iterator";e.prototype=un(Aa,{next:v(+!r,n)}),wo(e,o,!1),Io[o]=Da}(n,t,r);var c,u,f,l=function(e){if(e===o&&h)return h;if(!Na&&e in g)return g[e];switch(e){case Fa:case Ua:case Ga:return function(){return new n(this,e)}}return function(){return new n(this)}},s=t+" Iterator",d=!1,g=e.prototype,_=g[Va]||g["@@iterator"]||o&&g[o],h=!Na&&_||l(o),y="Array"==t&&g.entries||_;if(y&&(c=Ra(y.call(new e)))!==Object.prototype&&c.next&&(Ra(c)!==Ma&&(yo?yo(c,Ma):k(c[Va])||ct(c,Va,Ka)),wo(c,s,!0)),La&&o==Ua&&_&&_.name!==Ua&&(Ba?Me(g,"name",Ua):(d=!0,h=function(){return p(_,this)})),o)if(u={values:l(Ua),keys:i?h:l(Fa),entries:l(Ga)},a)for(f in u)(Na||d||!(f in g))&&ct(g,f,u[f]);else Mt({target:t,proto:!0,forced:Na||d},u);return g[Va]!==h&&ct(g,Va,h,{name:o}),Io[t]=h,u},Ha=Be.f,Wa="Array Iterator",Ja=nt.set,za=nt.getterFor(Wa),Ya=$a(Array,"Array",(function(e,t){Ja(this,{type:Wa,target:C(e),index:0,kind:t})}),(function(){var e=za(this),t=e.target,n=e.kind,r=e.index++;return!t||r>=t.length?(e.target=void 0,{value:void 0,done:!0}):"keys"==n?{value:r,done:!1}:"values"==n?{value:t[r],done:!1}:{value:[r,t[r]],done:!1}}),"values"),qa=Io.Arguments=Io.Array;if(Pa("keys"),Pa("values"),Pa("entries"),f&&"values"!==qa.name)try{Ha(qa,"name",{value:"values"})}catch(e){}var Qa=jn.charAt,Xa="String Iterator",Za=nt.set,ec=nt.getterFor(Xa);$a(String,"String",(function(e){Za(this,{type:Xa,string:Wt(e),index:0})}),(function(){var e,t=ec(this),n=t.string,r=t.index;return r>=n.length?{value:void 0,done:!0}:(e=Qa(n,r),t.index+=e.length,{value:e,done:!1})}));var tc=_e("iterator"),nc=_e("toStringTag"),rc=Ya.values,oc=function(e,t){if(e){if(e[tc]!==rc)try{Me(e,tc,rc)}catch(t){e[tc]=rc}if(e[nc]||Me(e,nc,t),Mn[t])for(var n in Ya)if(e[n]!==Ya[n])try{Me(e,n,Ya[n])}catch(t){e[n]=Ya[n]}}};for(var ic in Mn)oc(c[ic]&&c[ic].prototype,ic);oc(Fn,"DOMTokenList");var ac=pr("splice"),cc=c.TypeError,uc=Math.max,fc=Math.min,lc=9007199254740991,sc="Maximum allowed length exceeded";Mt({target:"Array",proto:!0,forced:!ac},{splice:function(e,t){var n,r,o,i,a,c,u=oe(this),f=vt(u),l=dt(e,f),s=arguments.length;if(0===s?n=r=0:1===s?(n=0,r=f-l):(n=s-2,r=fc(uc(lt(t),0),f-l)),f+n-r>lc)throw cc(sc);for(o=tr(u,r),i=0;i<r;i++)(a=l+i)in u&&lr(o,i,u[a]);if(o.length=r,n<r){for(i=l;i<f-r;i++)c=i+n,(a=i+r)in u?u[c]=u[a]:delete u[c];for(i=f;i>f-r+n;i--)delete u[i-1]}else if(n>r)for(i=f-r;i>l;i--)c=i+n-1,(a=i+r-1)in u?u[c]=u[a]:delete u[c];for(i=0;i<n;i++)u[i+l]=arguments[i+2];return u.length=f-r+n,o}});var pc=u((function(){Xt(1)}));Mt({target:"Object",stat:!0,forced:pc},{keys:function(e){return Xt(oe(e))}});var dc=pr("slice"),gc=_e("species"),_c=c.Array,vc=Math.max;Mt({target:"Array",proto:!0,forced:!dc},{slice:function(e,t){var n,r,o,i=C(this),a=vt(i),c=dt(e,a),u=dt(void 0===t?a:t,a);if(Kn(i)&&(n=i.constructor,(Xn(n)&&(n===_c||Kn(n.prototype))||j(n)&&null===(n=n[gc]))&&(n=void 0),n===_c||void 0===n))return Jo(i,c,u);for(r=new(void 0===n?_c:n)(vc(u-c,0)),o=0;c<u;c++,o++)c in i&&lr(r,o,i[c]);return r.length=o,r}});var hc,yc="\t\n\v\f\r                　\u2028\u2029\ufeff",bc=w("".replace),mc="["+yc+"]",wc=RegExp("^"+mc+mc+"*"),Sc=RegExp(mc+mc+"*$"),Pc=function(e){return function(t){var n=Wt(x(t));return 1&e&&(n=bc(n,wc,"")),2&e&&(n=bc(n,Sc,"")),n}},Oc={start:Pc(1),end:Pc(2),trim:Pc(3)},Ic=at.PROPER,Ec=Oc.trim;Mt({target:"String",proto:!0,forced:(hc="trim",u((function(){return!!yc[hc]()||"​᠎"!=="​᠎"[hc]()||Ic&&yc[hc].name!==hc})))},{trim:function(){return Ec(this)}});var Tc=function(e,t,n){var r,o;return yo&&k(r=t.constructor)&&r!==n&&j(o=r.prototype)&&o!==n.prototype&&yo(e,o),e},Rc=w(1..valueOf),xc=Ot.f,Cc=Ie.f,kc=Be.f,jc=Oc.trim,Ac="Number",Dc=c.Number,Lc=Dc.prototype,Bc=c.TypeError,Mc=w("".slice),Nc=w("".charCodeAt),Vc=function(e){var t=ye(e,"number");return"bigint"==typeof t?t:Fc(t)},Fc=function(e){var t,n,r,o,i,a,c,u,f=ye(e,"number");if(H(f))throw Bc("Cannot convert a Symbol value to a number");if("string"==typeof f&&f.length>2)if(f=jc(f),43===(t=Nc(f,0))||45===t){if(88===(n=Nc(f,2))||120===n)return NaN}else if(48===t){switch(Nc(f,1)){case 66:case 98:r=2,o=49;break;case 79:case 111:r=8,o=55;break;default:return+f}for(a=(i=Mc(f,2)).length,c=0;c<a;c++)if((u=Nc(i,c))<48||u>o)return NaN;return parseInt(i,r)}return+f};if(Lt(Ac,!Dc(" 0o1")||!Dc("0b1")||Dc("+0x1"))){for(var Uc,Gc=function(e){var t=arguments.length<1?0:Dc(Vc(e)),n=this;return L(Lc,n)&&u((function(){Rc(n)}))?Tc(Object(t),n,Gc):t},Kc=f?xc(Dc):"MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,EPSILON,MAX_SAFE_INTEGER,MIN_SAFE_INTEGER,isFinite,isInteger,isNaN,isSafeInteger,parseFloat,parseInt,fromString,range".split(","),$c=0;Kc.length>$c;$c++)ae(Dc,Uc=Kc[$c])&&!ae(Gc,Uc)&&kc(Gc,Uc,Cc(Dc,Uc));Gc.prototype=Lc,Lc.constructor=Gc,ct(c,Ac,Gc)}var Hc=or.map,Wc=pr("map");Mt({target:"Array",proto:!0,forced:!Wc},{map:function(e){return Hc(this,e,arguments.length>1?arguments[1]:void 0)}});var Jc=or.findIndex,zc="findIndex",Yc=!0;zc in[]&&Array(1).findIndex((function(){Yc=!1})),Mt({target:"Array",proto:!0,forced:Yc},{findIndex:function(e){return Jc(this,e,arguments.length>1?arguments[1]:void 0)}}),Pa(zc);var qc=Math.min,Qc=[].lastIndexOf,Xc=!!Qc&&1/[1].lastIndexOf(1,-0)<0,Zc=ir("lastIndexOf"),eu=Xc||!Zc?function(e){if(Xc)return Pr(Qc,this,arguments)||0;var t=C(this),n=vt(t),r=n-1;for(arguments.length>1&&(r=qc(r,lt(arguments[1]))),r<0&&(r=n+r);r>=0;r--)if(r in t&&t[r]===e)return r||0;return-1}:Qc;Mt({target:"Array",proto:!0,forced:eu!==[].lastIndexOf},{lastIndexOf:eu});var tu=Be.f,nu=Ot.f,ru=nt.enforce,ou=_e("match"),iu=c.RegExp,au=iu.prototype,cu=c.SyntaxError,uu=w(Jt),fu=w(au.exec),lu=w("".charAt),su=w("".replace),pu=w("".indexOf),du=w("".slice),gu=/^\?<[^\s\d!#%&*+<=>@^][^\s!#%&*+<=>@^]*>/,_u=/a/g,vu=/a/g,hu=new iu(_u)!==_u,yu=Qt.MISSED_STICKY,bu=Qt.UNSUPPORTED_Y,mu=f&&(!hu||yu||ln||pn||u((function(){return vu[ou]=!1,iu(_u)!=_u||iu(vu)==vu||"/a/i"!=iu(_u,"i")})));if(Lt("RegExp",mu)){for(var wu=function(e,t){var n,r,o,i,a,c,u=L(au,this),f=Zr(e),l=void 0===t,s=[],p=e;if(!u&&f&&l&&e.constructor===wu)return e;if((f||L(au,e))&&(e=e.source,l&&(t="flags"in p?p.flags:uu(p))),e=void 0===e?"":Wt(e),t=void 0===t?"":Wt(t),p=e,ln&&"dotAll"in _u&&(r=!!t&&pu(t,"s")>-1)&&(t=su(t,/s/g,"")),n=t,yu&&"sticky"in _u&&(o=!!t&&pu(t,"y")>-1)&&bu&&(t=su(t,/y/g,"")),pn&&(i=function(e){for(var t,n=e.length,r=0,o="",i=[],a={},c=!1,u=!1,f=0,l="";r<=n;r++){if("\\"===(t=lu(e,r)))t+=lu(e,++r);else if("]"===t)c=!1;else if(!c)switch(!0){case"["===t:c=!0;break;case"("===t:fu(gu,du(e,r+1))&&(r+=2,u=!0),o+=t,f++;continue;case">"===t&&u:if(""===l||ae(a,l))throw new cu("Invalid capture group name");a[l]=!0,i[i.length]=[l,f],u=!1,l="";continue}u?l+=t:o+=t}return[o,i]}(e),e=i[0],s=i[1]),a=Tc(iu(e,t),u?this:au,wu),(r||o||s.length)&&(c=ru(a),r&&(c.dotAll=!0,c.raw=wu(function(e){for(var t,n=e.length,r=0,o="",i=!1;r<=n;r++)"\\"!==(t=lu(e,r))?i||"."!==t?("["===t?i=!0:"]"===t&&(i=!1),o+=t):o+="[\\s\\S]":o+=t+lu(e,++r);return o}(e),n)),o&&(c.sticky=!0),s.length&&(c.groups=s)),e!==p)try{Me(a,"source",""===p?"(?:)":p)}catch(e){}return a},Su=function(e){e in wu||tu(wu,e,{configurable:!0,get:function(){return iu[e]},set:function(t){iu[e]=t}})},Pu=nu(iu),Ou=0;Pu.length>Ou;)Su(Pu[Ou++]);au.constructor=wu,wu.prototype=au,ct(c,"RegExp",wu)}Po("RegExp");var Iu=Ot.f,Eu="object"==typeof window&&window&&Object.getOwnPropertyNames?Object.getOwnPropertyNames(window):[],Tu={f:function(e){return Eu&&"Window"==O(e)?function(e){try{return Iu(e)}catch(e){return io(Eu)}}(e):Iu(C(e))}},Ru={f:_e},xu=c,Cu=Be.f,ku=function(e){var t=xu.Symbol||(xu.Symbol={});ae(t,e)||Cu(t,e,{value:Ru.f(e)})},ju=or.forEach,Au=We("hidden"),Du="Symbol",Lu=_e("toPrimitive"),Bu=nt.set,Mu=nt.getterFor(Du),Nu=Object.prototype,Vu=c.Symbol,Fu=Vu&&Vu.prototype,Uu=c.TypeError,Gu=c.QObject,Ku=D("JSON","stringify"),$u=Ie.f,Hu=Be.f,Wu=Tu.f,Ju=_.f,zu=w([].push),Yu=ne("symbols"),qu=ne("op-symbols"),Qu=ne("string-to-symbol-registry"),Xu=ne("symbol-to-string-registry"),Zu=ne("wks"),ef=!Gu||!Gu.prototype||!Gu.prototype.findChild,tf=f&&u((function(){return 7!=un(Hu({},"a",{get:function(){return Hu(this,"a",{value:7}).a}})).a}))?function(e,t,n){var r=$u(Nu,t);r&&delete Nu[t],Hu(e,t,n),r&&e!==Nu&&Hu(Nu,t,r)}:Hu,nf=function(e,t){var n=Yu[e]=un(Fu);return Bu(n,{type:Du,tag:e,description:t}),f||(n.description=t),n},rf=function(e,t,n){e===Nu&&rf(qu,t,n),xe(e);var r=be(t);return xe(n),ae(Yu,r)?(n.enumerable?(ae(e,Au)&&e[Au][r]&&(e[Au][r]=!1),n=un(n,{enumerable:v(0,!1)})):(ae(e,Au)||Hu(e,Au,v(1,{})),e[Au][r]=!0),tf(e,r,n)):Hu(e,r,n)},of=function(e,t){xe(e);var n=C(t),r=Xt(n).concat(ff(n));return ju(r,(function(t){f&&!p(af,n,t)||rf(e,t,n[t])})),e},af=function(e){var t=be(e),n=p(Ju,this,t);return!(this===Nu&&ae(Yu,t)&&!ae(qu,t))&&(!(n||!ae(this,t)||!ae(Yu,t)||ae(this,Au)&&this[Au][t])||n)},cf=function(e,t){var n=C(e),r=be(t);if(n!==Nu||!ae(Yu,r)||ae(qu,r)){var o=$u(n,r);return!o||!ae(Yu,r)||ae(n,Au)&&n[Au][r]||(o.enumerable=!0),o}},uf=function(e){var t=Wu(C(e)),n=[];return ju(t,(function(e){ae(Yu,e)||ae(Je,e)||zu(n,e)})),n},ff=function(e){var t=e===Nu,n=Wu(t?qu:C(e)),r=[];return ju(n,(function(e){!ae(Yu,e)||t&&!ae(Nu,e)||zu(r,Yu[e])})),r};if(G||(Vu=function(){if(L(Fu,this))throw Uu("Symbol is not a constructor");var e=arguments.length&&void 0!==arguments[0]?Wt(arguments[0]):void 0,t=le(e),n=function(e){this===Nu&&p(n,qu,e),ae(this,Au)&&ae(this[Au],t)&&(this[Au][t]=!1),tf(this,t,v(1,e))};return f&&ef&&tf(Nu,t,{configurable:!0,set:n}),nf(t,e)},Fu=Vu.prototype,ct(Fu,"toString",(function(){return Mu(this).tag})),ct(Vu,"withoutSetter",(function(e){return nf(le(e),e)})),_.f=af,Be.f=rf,en.f=of,Ie.f=cf,Ot.f=Tu.f=uf,It.f=ff,Ru.f=function(e){return nf(_e(e),e)},f&&(Hu(Fu,"description",{configurable:!0,get:function(){return Mu(this).description}}),ct(Nu,"propertyIsEnumerable",af,{unsafe:!0}))),Mt({global:!0,wrap:!0,forced:!G,sham:!G},{Symbol:Vu}),ju(Xt(Zu),(function(e){ku(e)})),Mt({target:Du,stat:!0,forced:!G},{for:function(e){var t=Wt(e);if(ae(Qu,t))return Qu[t];var n=Vu(t);return Qu[t]=n,Xu[n]=t,n},keyFor:function(e){if(!H(e))throw Uu(e+" is not a symbol");if(ae(Xu,e))return Xu[e]},useSetter:function(){ef=!0},useSimple:function(){ef=!1}}),Mt({target:"Object",stat:!0,forced:!G,sham:!f},{create:function(e,t){return void 0===t?un(e):of(un(e),t)},defineProperty:rf,defineProperties:of,getOwnPropertyDescriptor:cf}),Mt({target:"Object",stat:!0,forced:!G},{getOwnPropertyNames:uf,getOwnPropertySymbols:ff}),Mt({target:"Object",stat:!0,forced:u((function(){It.f(1)}))},{getOwnPropertySymbols:function(e){return It.f(oe(e))}}),Ku){var lf=!G||u((function(){var e=Vu();return"[null]"!=Ku([e])||"{}"!=Ku({a:e})||"{}"!=Ku(Object(e))}));Mt({target:"JSON",stat:!0,forced:lf},{stringify:function(e,t,n){var r=Jo(arguments),o=t;if((j(t)||void 0!==e)&&!H(e))return Kn(t)||(t=function(e,t){if(k(o)&&(t=p(o,this,e,t)),!H(t))return t}),r[1]=t,Pr(Ku,null,r)}})}if(!Fu[Lu]){var sf=Fu.valueOf;ct(Fu,Lu,(function(e){return p(sf,this)}))}wo(Vu,Du),Je[Au]=!0;var pf=Be.f,df=c.Symbol,gf=df&&df.prototype;if(f&&k(df)&&(!("description"in gf)||void 0!==df().description)){var _f={},vf=function(){var e=arguments.length<1||void 0===arguments[0]?void 0:Wt(arguments[0]),t=L(gf,this)?new df(e):void 0===e?df():df(e);return""===e&&(_f[t]=!0),t};Rt(vf,df),vf.prototype=gf,gf.constructor=vf;var hf="Symbol(test)"==String(df("test")),yf=w(gf.toString),bf=w(gf.valueOf),mf=/^Symbol\((.*)\)[^)]+$/,wf=w("".replace),Sf=w("".slice);pf(gf,"description",{configurable:!0,get:function(){var e=bf(this),t=yf(e);if(ae(_f,e))return"";var n=hf?Sf(t,7,-1):wf(t,mf,"$1");return""===n?void 0:n}}),Mt({global:!0,forced:!0},{Symbol:vf})}var Pf=u((function(){Ra(1)}));Mt({target:"Object",stat:!0,forced:Pf,sham:!Oa},{getPrototypeOf:function(e){return Ra(oe(e))}}),ku("iterator");var Of=function(e,t,n,r){try{return r?t(xe(n)[0],n[1]):t(n)}catch(t){Ao(e,"throw",t)}},If=c.Array,Ef=!Wo((function(e){Array.from(e)}));Mt({target:"Array",stat:!0,forced:Ef},{from:function(e){var t=oe(e),n=Xn(this),r=arguments.length,o=r>1?arguments[1]:void 0,i=void 0!==o;i&&(o=Gn(o,r>2?arguments[2]:void 0));var a,c,u,f,l,s,d=Co(t),g=0;if(!d||this==If&&Ro(d))for(a=vt(t),c=n?new this(a):If(a);a>g;g++)s=i?o(t[g],g):t[g],lr(c,g,s);else for(l=(f=jo(t,d)).next,c=n?new this:[];!(u=p(l,f)).done;g++)s=i?Of(f,o,[u.value,g],!0):u.value,lr(c,g,s);return c.length=g,c}});var Tf=Object.prototype.toString;function Rf(e){return!!/(?:^|\/)__(dd|plugin)__\//.test(e)||!!("undefined"!=typeof __ddAppCode__&&__ddAppCode__["".concat(e,".json")]||{}).usingComponents}function xf(){}function Cf(t){var n=e(t);return null!==t&&"object"!==n&&"function"!==n?t:null}function kf(e,t){if("function"!=typeof t)throw new TypeError("customizer is must be a Function");if("function"==typeof e)return e;var n=Tf.call(e);if("[object Array]"===n)return[];if("[object Object]"===n&&e.constructor===Object)return{};if("[object Date]"===n)return new Date(e.getTime());if("[object RegExp]"===n){var r=String(e),o=r.lastIndexOf("/");return new RegExp(r.slice(1,o),r.slice(o+1))}var i=t(e);return void 0!==i?i:null}var jf="function"==typeof Object.keys?function(e){return Object.keys(e)}:function(t){var n,r=e(t);if(null===t||"function"!==r&&"object"!==r)throw new TypeError("obj must be an Object");var o=[];for(n in t)Object.prototype.hasOwnProperty.call(t,n)&&o.push(n);return o};function Af(e,t){if("[object Array]"!==Tf.call(e))throw new TypeError("array must be an Array");for(var n,r=e.length,o=0;o<r;++o)if((n=e[o])===t||n!=n&&t!=t)return o;return-1}function Df(t){for(var n=[],r=1;r<arguments.length;r++)n[r-1]=arguments[r];var o=0<n.length&&void 0!==n[0]?n[0]:xf;if(null===t)return null;var i=Cf(t);if(null!==i)return i;var a=kf(t,o),c=null!==a?a:t,u=function t(n,r,o,i,a){if(null===n)return null;var c=Cf(n);if(null!==c)return c;for(var u,f,l,s,p,d,g,_,v,h="function"==typeof Symbol?function(e){return Object.getOwnPropertySymbols(e)}:function(){return[]},y=jf(n).concat(h(n)),b=y.length,m=0;m<b;++m)d=p=s=void 0,-1===(l=Af(i,f=n[u=y[m]]))?(_=r,p=null!==(s=null!==(v=Cf(g=f))?v:kf(g,_))?s:f,null!==f&&/^(?:function|object)$/.test(e(f))&&(i.push(f),a.push(p))):d=a[l],o[u]=d||t(f,r,p,i,a);return o};return u(t,o,c,[t],[c])}function Lf(e){var t;return((t=e).options||{}).addGlobalClass,t.pageLifetimes,t.lifetimes,t.definitionFilter,t.behaviors&&t.behaviors.forEach((function(e){})),t}function Bf(e,t){(null===t||t>e.length)&&(t=e.length);for(var n=new Array(t),r=0;r<t;r++)n[r]=e[r];return n}var Mf=__virtualDOM__.convertComponentAliasToRoute,Nf=__virtualDOM__.convertRouteToComponentAlias;function Vf(e){return"[object Object]"===Object.prototype.toString.call(e)}function Ff(e,t){return e.__ddExparserNodeId__&&Object.prototype.hasOwnProperty.call(Object.getPrototypeOf(e),t)||Object.prototype.hasOwnProperty.call(e,t)}function Uf(e,t){for(var n,r={},o=e,i=0;i<t.length;i++)Number(t[i])===t[i]&&t[i]%1==0?Array.isArray(o)||(r[n]=[],o=r[n]):Vf(o)||(r[n]={},o=r[n]),n=t[i],o=(r=o)[t[i]];return{obj:r,key:n}}var Gf,Kf={hostAppId:null},$f=null,Hf={scene:0,scene_note:null,sessionid:null,usedstate:null,referpagepath:null,clickTimestamp:null,prescene:null,prescene_note:null,publicLibVersion:null,hostAppId:null},Wf=function(){function e(){this.isInitialLoading=!0,this.orientationChangeCount=0,this.startCostTime=null,this.startType=null}return e.prototype.setQuery=function(e){this.query=e},e.prototype.setOnAppShow=function(n){Kf=t(Kf,n),e._assignForClientOnShow(Kf,n)},e.prototype.setOnAppHide=function(e){$f=t($f,e)},e.prototype.setOnLaunch=function(n){(Hf=t(Hf,n)).hostAppId=__ddConfig.host&&__ddConfig.host.appId||"",e._assignForClientOnShow(Hf,n)},e.prototype.reportShowPage=function(){e._checkDeferred(),e.checkShowOptions()},e.prototype.setReadyTime=function(t){this.pageReadyTime=t,e._checkDeferred()},e.prototype.reportHidePage=function(){e._checkDeferred(),e.checkShowOptions()},e.checkShowOptions=function(){var t=Hf,n=e.showOptions||{};n.scene=t.scene||0,n.scene_note=t.scene_note,n.sessionid=t.sessionid,n.usedstate=t.usedstate,n.referpagepath=t.referpagepath,n.clickTimestamp=t.clickTimestamp,n.prescene=t.prescene,n.prescene_note=t.prescene_note,n.publicLibVersion=t.publicLibVersion;var r=e.query,o=[];r&&Object.keys(r)&&Object.keys(r).forEach((function(e){o.push("".concat(encodeURIComponent(e),"=").concat(encodeURIComponent(r[e])))})),n.query=o.join("&")},e._checkDeferred=function(){if(this.deferred&&this.deferred.length)for(var e=this.deferred;e.length;)e.pop()()},e._assignForClientOnShow=function(e,t){e.scene_note=t.scene_note||t.sceneNote||"",e.referpagepath=t.referpagepath||"",e.usedstate=t.usedstate||t.usedState,e.prescene=t.prescene,e.prescene_note=t.prescene_note||t.presceneNote||"",e.clickTimestamp=Date.now()},e}(),Jf=["onLoad","onReady","onShow","onHide","onUnload","onResize","onStackShow","onStackHide"],zf=0,Yf=1,qf=5,Qf=6,Xf=7,Zf={appLaunchTime:0,appFgTime:0,appRouteTime:0,newPageTime:0,pageReadyTime:0},el=function(){},tl=function(){function e(){}return e.create=function(e,t){var n=__virtualDOM__.addView(e?Number(e):1,t),r=exparser.Element.getMethodCaller(n);if(r.__ddWebViewId__=Number(e)||1,r.__route__=t,r.route=t,r.__displayReporter=new Wf,n.__customConstructor__===__virtualDOM__.Page){var o=n.getRootBehavior().methods,i=r.__freeData__;for(var a in o)r[a]=o[a].bind(r);for(var a in i)r[a]=Df(i[a])}var c=!0;return r.__callPageLifeTime__=function(e){for(var t,o=[],i=1;i<arguments.length;i++)o[i-1]=arguments[i];var a=this[e]||el;if(e)switch(e){case"onLoad":var u=r.__displayReporter;u.setQuery.apply(u,o);break;case"onShow":r.__displayReporter.reportShowPage(),n.triggerPageLifeTime("show",o);break;case"onReady":r.__displayReporter.setReadyTime(Date.now());break;case"onHide":case"onUnload":var f=this.__toRoute__,l=this.__isBack__,s=this.__notReportHide__;delete this.__toRoute__,delete this.__isBack__,delete this.__notReportHide__,s||r.__displayReporter.reportHidePage(f,l),"onHide"===e&&n.triggerPageLifeTime("hide",o),"onUnload"===e&&(null===(t=null===__appServiceSDK__||void 0===__appServiceSDK__?void 0:__appServiceSDK__.dd)||void 0===t||t.skiaCanvasRemove(r.__ddWebViewId__));break;case"onResize":var p=o[0]||{};c!==p.deviceOrientation&&(c=p.deviceOrientation,r.__displayReporter.addOrientationChangeCount()),n.triggerPageLifeTime("resize",o);break;case"onStackShow":r.__displayReporter.reportShowPage(),n.triggerPageLifeTime("stackShow",o);break;case"onStackHide":r.__displayReporter.reportShowPage(),n.triggerPageLifeTime("stackHide",o)}"".concat(this.__route__,": ").concat(e," have been invoked2");var d=a.apply(this,o);return d},Jf.forEach((function(e){var t=r[e];r[e]=function(){for(var e,n=[],r=0;r<arguments.length;r++)n[r]=arguments[r];var o=t||el;try{e=o.apply(this,n)}catch(e){__appServiceSDK__.reportUncaughtError({info:e.toString(),stack:e.stack})}return e}.bind(r)})),{page:r,node:n}},e.destroy=function(t){var n=t&&t.__ddWebViewId__;"number"==typeof n&&n>0&&(__virtualDOM__.removeView(n),e.safeDestroyLifeCycleWithContext(t))},e.safeDestroyLifeCycleWithContext=function(e){try{for(var t=void 0,n=0,r=Jf;n<r.length;n++)e[t=r[n]]=null;e.__displayReporter=null;var o=__virtualDOM__.TreeManager.get(e&&e.__ddWebViewId__);if(o&&o.root){var i=o.root.getRootBehavior().methods;for(t in i)e[t]=null}if(e.__freeData__)for(t in e.__freeData__)e[t]=null;e.__callPageLifeTime__=null}catch(e){}},e}();
/*! *****************************************************************************
  Copyright (c) Microsoft Corporation.

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
  REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
  AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
  INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
  LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
  OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
  PERFORMANCE OF THIS SOFTWARE.
  ***************************************************************************** */
function nl(e,t,n,r){return new(n||(n=Promise))((function(o,i){function a(e){try{u(r.next(e))}catch(e){i(e)}}function c(e){try{u(r.throw(e))}catch(e){i(e)}}function u(e){var t;e.done?o(e.value):(t=e.value,t instanceof n?t:new n((function(e){e(t)}))).then(a,c)}u((r=r.apply(e,t||[])).next())}))}function rl(e,t){var n,r,o,i,a={label:0,sent:function(){if(1&o[0])throw o[1];return o[1]},trys:[],ops:[]};return i={next:c(0),throw:c(1),return:c(2)},"function"==typeof Symbol&&(i[Symbol.iterator]=function(){return this}),i;function c(i){return function(c){return function(i){if(n)throw new TypeError("Generator is already executing.");for(;a;)try{if(n=1,r&&(o=2&i[0]?r.return:i[0]?r.throw||((o=r.return)&&o.call(r),0):r.next)&&!(o=o.call(r,i[1])).done)return o;switch(r=0,o&&(i=[2&i[0],o.value]),i[0]){case 0:case 1:o=i;break;case 4:return a.label++,{value:i[1],done:!1};case 5:a.label++,r=i[1],i=[0];continue;case 7:i=a.ops.pop(),a.trys.pop();continue;default:if(!(o=a.trys,(o=o.length>0&&o[o.length-1])||6!==i[0]&&2!==i[0])){a=0;continue}if(3===i[0]&&(!o||i[1]>o[0]&&i[1]<o[3])){a.label=i[1];break}if(6===i[0]&&a.label<o[1]){a.label=o[1],o=i;break}if(o&&a.label<o[2]){a.label=o[2],a.ops.push(i);break}o[2]&&a.ops.pop(),a.trys.pop();continue}i=t.call(e,a)}catch(e){i=[6,e],r=0}finally{n=o=0}if(5&i[0])throw i[1];return{value:i[0]?i[1]:void 0,done:!0}}([i,c])}}}function ol(e,t){return nl(this,void 0,void 0,(function(){var n,r,o,i,a,c,u,f,l,s;return rl(this,(function(p){switch(p.label){case 0:if(n=t[e],d=n.packages,"[object Array]"!==Object.prototype.toString.call(d))return[2,Promise.reject("packages must be an array.")];for(r=[],o=[],i=0,a=n.packages;i<a.length;i++)c=a[i],__subPackageNames__&&Object.prototype.hasOwnProperty.call(__subPackageNames__,c)&&(c=__subPackageNames__[c]),__appServiceSDK__.getPackageLoadStatus(c)?r.push(c):o.push(c);if(0===o.length)return[2,n.packages.length!==o.length?"These packages have already been loaded [".concat(r.join(", "),"]"):"Packages empty."];p.label=1;case 1:return p.trys.push([1,5,,6]),u=[],[4,Promise.all(o.map((function(e){return new Promise((function(t){didiJsBridge.invoke({method:"preloadSubPackage",data:{package:e},callback:function(n){var r=e;__appServiceSDK__.getPackageLoadStatus(e)?r+=" loaded.":n&&n.data&&n.data.success||u.push(n.data.errMsg),t(r)}})}))})))];case 2:return f=p.sent(),u.length?[4,Promise.reject(u.join("\r\n"))]:[3,4];case 3:return[2,p.sent()];case 4:return l="(Rule page: ".concat(e,") Loaded subPackages [").concat(f.join(", "),"]"),r.length&&(l+="\r\n"+"ignore subPackages [".concat(r.join(", "),"]")),[2,l];case 5:return s=p.sent(),[2,Promise.reject(s)];case 6:return[2]}var d}))}))}var il,al,cl={},ul={},fl={},ll=[],sl="",pl=null,dl={},gl=["onLaunch","onShow","onHide","onUnlaunch","onError"],_l=[],vl={},hl=null,yl=[],bl={click:null},ml=[],wl=!1,Sl=[],Pl=!1,Ol=Object.prototype.hasOwnProperty,Il=0,El=0,Tl=0,Rl=0,xl=0,Cl=0,kl=null,jl=null,Al=!0,Dl=!1,Ll={},Bl={},Ml=[],Nl=function(e){"string"==typeof e&&(sl=e)},Vl=!1,Fl=function(){},Ul=function(){function e(){}return e.App=function(e){t(e,vl),vl={},hl=new Hl(e)},e.Page=function(e){Gl(e,"/")},e.Component=function(e){Lf(e),function(e,t,n,r,o){var i;i=void 0!==o?o:{};var a=!1;(i.__wxRouteBegin||Gf)&&(a=!0);i.__wxRouteBegin?i.__wxRouteBegin=!1:Gf=!1;var c=__virtualDOM__.Component(e,t,n,r),u=Mf(c);c&&(dl[u]=exparser.Component._list[c]),fl[u]=a,String(c)}(e,"/")},e.Behavior=function(e){return Lf(e),__virtualDOM__.Behavior(e)},e.getCurrentRoute=function(){return sl},e.hasPageRoute=function(e){return!!function(e){for(var t=0;t<__ddConfig.pages.length;t++)if(__ddConfig.pages[t]===e)return!0;return!1}(e)||void 0!==fl[e]},e.getCurrentPagesByDomain=function(e){var t=[];return ll.forEach((function(n){e&&function(e){if(/^__dd__\//.test(e||""))return"//";var t=e.match(/(?:^|\/)__plugin__\/(.*?)\//);return t?t[1]:"/"}(n.route)!==e?t.push(null):t.push(n.page)})),t},e.getCurrentPages=function(){return e.getCurrentPagesByDomain("/")},e.setCurrentRoute=function(e){sl=e},e.getPageByWebviewId=function(e){return Ol.call(cl,e)?cl[e].page:null},e.getCurrentPageWithAdditionalInfo=function(){return il},e.registerGetApp=function(e){Hl(e)},e.getApp=function(e){return(arguments.length>0&&void 0!==e?e:{}).allowDefault?hl||vl:hl},e.__createPluginGlobal=function(t,n){var r={__wxAppCode__:{},__wxAppCurrentFile__:""},o="".concat(t,"/").concat(n);return{__wxAppCode__:{},__wxAppCurrentFile__:"",Page:function(e){Gl(e,o,r.__wxAppCode__,r.__wxAppCurrentFile__,r)},getCurrentPages:function(){return e.getCurrentPagesByDomain(t)},Behavior:function(e){return __virtualDOM__.Behavior(e)},publishDomainComponents:function(e){return __virtualDOM__.publishDomainComponents(o,e)},beforeFactory:function(){}}},e}();function Gl(e,t,n,r,o){var i={__wxRoute:!1,__wxRouteBegin:!1};arguments.length<4&&void 0!==o&&(i=o);var a=i.__wxRoute?"":__ddAppCurrentFile__&&__ddAppCurrentFile__.replace(/\.js$/,""),c=Nf(a),u=Mf(c),f=Rf(u),l=__virtualDOM__.Page(e,t,n,"".concat(a,".js"));dl[u]=e,f&&(dl[u]=exparser.Component._list[l]),fl[u]=!0}var Kl=[];function $l(e){var t=__ddConfig.tabBar&&__ddConfig.tabBar.list||[];if(!t&&!t.length)return!1;t.forEach((function(e){Kl.push(e.pagePath)}));var n=-1!==Kl.indexOf(e.route)||-1!==Kl.indexOf("".concat(e.route,".html"));return Kl=[],n}function Hl(e){var t=this;void 0===e&&(e={});var n=this,r=this;function o(e){for(var t=0;t<gl.length;++t)if(gl[t]===e)return!0;return!1}for(var i in gl.forEach((function(r){n[r]=function(){for(var n=[],o=0;o<arguments.length;o++)n[o]=arguments[o];var i=e[r]||Fl;try{i.apply(t,n)}catch(e){__appServiceSDK__.reportUncaughtError({info:e.toString(),stack:e.stack})}}.bind(n)})),e)"getCurrentPage"===i?"App's ".concat(i," is write-protected"):o(i)||("function"==typeof e[i]?n[i]=function(n){for(var r,o=[],i=1;i<arguments.length;i++)o[i-1]=arguments[i];try{r=e[n].apply(t,o)}catch(e){}return r}.bind(n,i):n[i]=e[i]);var a=__appServiceSDK__.getLaunchOptionsSync(),c=__appServiceSDK__.getEnterOptionsSync();r.__appId__=null==a?void 0:a.appId,r.onLaunch(a),r.onShow(c),_l.push({app:r,preventOnShow:!0,preventStackOnShow:!0})}function Wl(e){try{!function(e,t,n,r,o,i,a){t=Number(t),Zf.appRouteTime=Date.now();var c=Object.keys(n).map((function(e){return"".concat(encodeURIComponent(e)," = ").concat(n[e])})).join("&"),u="/".concat(e).concat(c?"?".concat(c):""),f=a.stackId||-1;if("navigateTo"===r){if(Reporter.traceBeginEvent("framework","onnavigateto"),$l({route:e}))return;o?(il&&Jl(il,e),"min"===o?(pl=ll[ll.length-1],Ol.call(cl,t)?"navigateTo with an already exist webViewId ".concat(t):ql(e,u,t,n)):"max"===o&&pl&&(Nl(e),il=pl,ll.push(il),il.page.__callPageLifeTime__("onShow"),pl=null)):(il&&Jl(il,e),Ol.call(cl,t)?"navigateTo with an already exist webViewId ".concat(t):ql(e,u,t,n,{initialRenderingCacheData:i})),Reporter.traceEndEvent()}else if("redirectTo"===r){if(Reporter.traceBeginEvent("framework","onredirectto"),$l({route:e}))return;il&&Ql(il,e),Ol.call(cl,t)?"redirectTo with an already exist webViewId ".concat(t):ql(e,u,t,n,{initialRenderingCacheData:i}),Reporter.traceEndEvent()}else if("navigateBack"===r)-1===t&&(pl=null),o?"min"===o?(pl=ll[ll.length-1],Zl(t,!0)):"max"===o&&(pl=null,Zl(t)):Zl(t);else if("switchTab"===r){if(!$l({route:e}))return;if(Reporter.traceBeginEvent("framework","onswitchtab"),ll&&ll.length&&ll[ll.length-1].webViewId===t)return;var l=void 0,s=void 0,p=!0,d=!0;if(0===ll.length)return ql(e,u,t,n,{initialRenderingCacheData:i}),void ns();for(;1<ll.length;)pl&&pl.webViewId===ll[ll.length-1].webViewId?(ll=ll.slice(0,ll.length-1)).length?Nl(ll[ll.length-1].route):Nl(""):Ql(ll[ll.length-1],e),p=!1;if(ll[0].webViewId===t)il=ll[0],pl=ll[0],p||(il.page.__callPageLifeTime__("onShow"),ns());else if($l(ll[0])?(d=!1,p&&Jl(ll[0],e)):pl&&pl.webViewId===ll[0].webViewId?(ll=ll.slice(0,ll.length-1),Nl("")):Ql(ll[0],e),Ol.call(cl,t)){var g=void 0;l=(g=cl[t]).page,s=g.node,ll=[il={webViewId:t,route:e,page:l,node:s}],l.__callPageLifeTime__("onShow"),ns(),pl=ll[0],rs("enterPage",l),rs("switchTab",l)}else ll=[],ql(e,u,t,n,{isMainTabBarPage:d,initialRenderingCacheData:i}),ns();Reporter.traceEndEvent()}else if("pageReload"===r){Reporter.traceBeginEvent("framework","onpagereload");for(var _=0;_<ll.length;++_){var v=ll[_];v.webViewId===t&&(v.page.__toRoute__=e,v.page.__callPageLifeTime__("onUnload"),v.node&&tl.destroy(v.page),delete cl[v.webViewId])}m=e,w=u,S=t,P=n,O=i,I=a.prerender,Zf.appLaunchTime=Date.now(),Zf.appFgTime=Date.now(),ql(m,w,S,P,{initialRenderingCacheData:O,prerender:I},!0),Reporter.traceEndEvent()}else if("appLaunch"===r||"appLaunchStack"===r)Reporter.traceBeginEvent("framework","onapplaunch"),Zf.appLaunchTime=Date.now(),Zf.appFgTime=Date.now(),Ol.call(cl,t)?"appLaunch with an already exist webViewId ".concat(t):ql(e,u,t,n,{initialRenderingCacheData:i,prerender:a.prerender},!1,f),Reporter.traceEndEvent();else if("reLaunch"===r||"autoReLaunch"===r){Reporter.traceBeginEvent("framework","onrelaunch");var h=!1;for("reLaunch"===r&&(h=!0);0<ll.length;){var y=!0;h=h&&(y=!1),Ql(ll[ll.length-1],e,!1,y)}ql(e,u,t,n,{initialRenderingCacheData:i,prerender:a.prerender}),Reporter.traceEndEvent()}else"dismissPip"===r?pl&&(b=pl)&&(0<=ll.findIndex((function(e){return e.webViewId===pl.webViewId}))?pl=null:(b.page.__callPageLifeTime__("onUnload"),b.node&&tl.destroy(b.page),delete cl[b.webViewId],rs("pageUnload",b.page),rs("leavePage",b.page))):"Illegal open type: ".concat(r);var b;var m,w,S,P,O,I}(e.path,e.webViewId,e.query||{},e.openType,e.pipMode,e.initialRenderingCacheData,e)}catch(e){Reporter.errorReport({key:"service-error",type:"appRouteTrigger",error:"[service-error]: appRouteTrigger error : ".concat(e)}),Reporter.ravenReport("pub_saga_error_message_bt",{key:"service-error",type:"appRouteTrigger",error:"[service-error]: appRouteTrigger error : ".concat(e),fail:function(e){}})}}didiJsBridge.subscribe({event:"listenServiceInjectCostTiming",callback:function(e){var t=e.data&&e.data.timing;__appServiceSDK__.reportToMiniBackend("tech_saga_js_timing",{timing:injectServiceTiming+t})}}),didiJsBridge.on({event:"destroyInstance",callback:function(){try{didiJsBridge.clearAll(),(__virtualDOM__.TreeManager.listViewId()||[]).forEach((function(e){__virtualDOM__.removeView(e)})),__ddAppCode__=null,__appServiceEngine__=null,__WXML_GLOBAL__=null,__appServiceSDK__=null}catch(e){}}}),didiJsBridge.on({event:"showStack",callback:function(e){var t,n=e.stackId||(null===(t=e.data)||void 0===t?void 0:t.stackId)||-1;if(n){currentStackId=n;var r,o=__appServiceSDK__.getEnterOptionsSync();void 0===(r=o)&&(r={}),_l.forEach((function(e){e.preventStackOnShow||e.app.onShow(r),e.preventStackOnShow=!1})),ul[n]?(ll=ul[n],(il=ll&&ll.length&&ll[ll.length-1]||null)&&il.page&&il.page.__callPageLifeTime__("onStackShow",o),il&&il.page&&il.page.__callPageLifeTime__("onShow")):(ul[n]=[],ll=ul[n],Nl(""))}}}),didiJsBridge.on({event:"hideStack",callback:function(e){var t,n,r,o=e.stackId||(null===(t=e.data)||void 0===t?void 0:t.stackId)||-1;o&&ul[o]&&(ul[o]=ll,il&&(null===(n=null==il?void 0:il.page)||void 0===n||n.__callPageLifeTime__("onHide")),null===(r=null==il?void 0:il.page)||void 0===r||r.__callPageLifeTime__("onStackHide"))}}),didiJsBridge.on({event:"removeStack",callback:function(e){var t,n=e.stackId||(null===(t=e.data)||void 0===t?void 0:t.stackId)||-1;if(n&&ul[n]){for(var r=ul[n],o=r.length-1;o>=0;o--)Ql(r[o],r[o].path);delete ul[n]}}}),didiJsBridge.on({event:"onAppError",callback:function(e){var t=__appServiceEngine__.getApp();t&&t.onError&&t.onError(e.data)}}),didiJsBridge.on({event:"switchTabLoadJSFileToDataThreadRequire"},(function(e){var t=e.data.route,n=e.data.index;e.fromNative&&__ddConfig&&__ddConfig.tabBar&&__ddConfig.tabBar.list&&__ddConfig.tabBar.list[n]&&tabBarTapList.push({index:n,pagePath:(__ddConfig.tabBar.list[n].pagePath||"").replace(/\.html$/,""),text:__ddConfig.tabBar.list[n].text}),__appServiceSDK__.installPackageByRoute(t,(function(){didiJsBridge.invoke({method:"switchTabLoadJSFileToDataThreadFinish",data:{index:n}})}))})),__appServiceSDK__.onPageReload((function(e){e.path;!function(e,t){if(Ol.call(cl,t)){var n=cl[t].statesData;cl[t].statesData=void 0,__virtualDOM__.restoreView(t),Yl(cl[t],t,Date.now(),n||{},!0)}}(0,e.webViewId)})),__appServiceSDK__.onAppShow((function(e){void 0===e&&(e={isLaunch:!1,path:""}),e.isLaunch&&rs("launch"),Nl(e.path),function(e){e=e||Bl,_l.forEach((function(t){t.preventOnShow||t.app.onShow(e),t.preventOnShow=!1})),Bl=e}(__appServiceSDK__.getEnterOptionsSync()),rs("foreground");var t=void 0;(t=Ul.getCurrentPagesByDomain("")).length&&("function"==typeof t[t.length-1].__callPageLifeTime__&&t[t.length-1].__callPageLifeTime__("onShow"),rs("enterPage",t[t.length-1],!0))})),__appServiceSDK__.onAppRoute((function(e){__ddConfig&&__ddConfig.preloadRule&&Object.prototype.hasOwnProperty.call(__ddConfig.preloadRule,e.path)&&dd.nextTick((function(){ol(e.path,__ddConfig.preloadRule).then((function(e){})).catch((function(e){}))}));var t=__appServiceSDK__.RouteTask.getCurrentTask();null===t||t.resolved?Wl(e):t.rejected?(Reporter.errorReport({key:"service-error",type:"getCurrentTask",error:"[service-error]: getCurrentTask error"}),Reporter.ravenReport("pub_saga_error_message_bt",{key:"service-error",type:"getCurrentTask",error:"[service-error]: getCurrentTask error",fail:function(e){}})):t.pending&&t.addTask(Wl.bind(void 0,e))})),__appServiceSDK__.onAppRouteDone((function(){Dl=!0,ml.forEach((function(e){rs.apply(void 0,function(e){return function(e){if(Array.isArray(e))return Bf(e)}(e)||function(e){if("undefined"!=typeof Symbol&&Symbol.iterator in Object(e))return Array.from(e)}(e)||function(e,t){if(e){if("string"==typeof e)return Bf(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(n):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?Bf(e,t):void 0}}(e)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}(e))})),ml=[]})),__appServiceSDK__.onPullDownRefresh((function(){var e=Ul.getCurrentPagesByDomain("");if(e.length){var t=e[e.length-1];"function"==typeof t.__callPageLifeTime__&&t.__callPageLifeTime__("onPullDownRefresh");var n=Ul.getCurrentPageWithAdditionalInfo().page;n&&rs("pullDownRefresh",n,!0)}}));function Jl(e,t){Reporter.traceBeginEvent("framework","onhidepage"),e.page.__toRoute__=t,e.page.__callPageLifeTime__("onHide"),rs("leavePage",e.page),Reporter.traceEndEvent()}didiJsBridge.subscribe({event:"initReadyForPrerender",callback:function(e){__appServiceSDK__.onAppRouteInit(e)}}),didiJsBridge.subscribe({event:"onShareAppMessage",callback:function(e){var t={};il.page.onShareAppMessage&&(t=il.page.onShareAppMessage.apply(il.page,[e.data||{}])||{});var n,r=t.promise;delete t.promise,"Promise"!==(n=r,Object.prototype.toString.call(n).split(" ")[1].split("]")[0])&&(r=Promise.resolve(t));var o=new Promise((function(e){setTimeout((function(){e(t)}),3e3)}));Promise.race([o,r]).then((function(e){void 0===e&&(e={}),dd.customShare({type:"miniApp",title:e.title,content:e.title,image:e.imageUrl,ext:{path:e.path}})}))}}),didiJsBridge.subscribe({event:"PAGE_EVENT",callback:function(e){if("__DOMReady"===(e=e.data||{}).eventName&&il&&il.page&&(Reporter.pageLoadReport(il.page.route,il.page.__ddWebViewId__),il.page.__callPageLifeTime__&&il.page.__callPageLifeTime__("onReady")),il.page&&il.page[e.eventName])return il.page[e.eventName].apply(il.page,[e.data])}}),didiJsBridge.on({event:"onPageScroll"},(function(e){if(il.page&&"function"==typeof il.page.onPageScroll)return il.page.onPageScroll.apply(il.page,[e.data])})),didiJsBridge.invoke({method:"getSdkReportPoint",data:{event:"tech_saga_launch_app"},callback:function(e){try{e.data.data&&Reporter.reportAppLaunchTime(e.data.data)}catch(e){}}}),__appServiceSDK__.onAppHide((function(e){void 0===e&&(e={mode:""});var t,n=Ul.getCurrentPagesByDomain("");n.length&&("function"==typeof n[n.length-1].__callPageLifeTime__&&n[n.length-1].__callPageLifeTime__("onHide"),rs("leavePage",Ul.getCurrentPageWithAdditionalInfo().page,!0)),t=e,_l&&_l.forEach((function(e){7===__ddConfig.appType?e.app.onHide(t):e.app.onHide()})),rs("background")})),__appServiceSDK__.onAppEnterBackground();var zl={emit:function(e,t,n){__appServiceSDK__.invokeWebviewMethod("appDataChange",e,t,n)}};function Yl(e,t,n,r,o,i){var a=e.page,c=Object();c.webViewId=t,c.enablePullUpRefresh=Ff(a,"onReachBottom"),c.enablePageScroll=Ff(a,"onPageScroll"),c.onReachBottomDistance=function(e){try{var t=__ddConfig.page[e].window&&__ddConfig.page[e].window.onReachBottomDistance;if(__ddConfig.page[e].onReachBottomDistance&&(t=__ddConfig.page[e].onReachBottomDistance),"number"==typeof t)return t}catch(e){}}(a.__route__),c.statesData=r,c.scene=undefined,c.route=a.__route__,c.query=a.options,c.lastRoute=e.lastRoute,c.lastQuery=e.lastQuery,c.wxConfig={accountInfo:__ddConfig&&__ddConfig.accountInfo||{},appContactInfo:__ddConfig&&__ddConfig.appContactInfo||{},appLaunchInfo:__ddConfig&&__ddConfig.appLaunchInfo||{},plugins:__ddConfig&&__ddConfig.plugins||{}},c.windowConfig=__ddConfig&&__ddConfig.page&&__ddConfig.page[a.__route__]&&__ddConfig.page[a.__route__].window||{},c.onPageScrollThrottle=__ddConfig&&__ddConfig.page&&__ddConfig.page[a.__route__]&&__ddConfig.page[a.__route__].onPageScrollThrottle||null,c.keyScrollTop=__ddConfig&&__ddConfig.page&&__ddConfig.page[a.__route__]&&__ddConfig.page[a.__route__].keyScrollTop||null,c.debug=__ddConfig&&__ddConfig.debug,c.appId=__ddConfig&&__ddConfig.accountInfo&&__ddConfig.accountInfo.appId,c.appLaunchTime=Zf.appLaunchTime,c.appFgTime=Zf.appFgTime,c.isTabBarPage=e.isTabBarPage,c.isMainTabBarPage=e.isMainTabBarPage,c.navigationStyle=__ddConfig&&__ddConfig.global&&__ddConfig.global.window&&__ddConfig.global.window.navigationStyle,c.needGetSubjectInfo=!Vl,c.perfData=(yl[qf]=Date.now(),yl[zf]=Al?1:0,yl[Xf]=__ddConfig.isSubContext?1:0,yl[Yf]=__ddConfig.onReadyStart,yl[Qf]=__ddConfig.onReadyEnd||0,Al=!1,yl),c.isReload=o,c.fontFaceRecords=__appServiceSDK__.fontFaceRecords,c.prerender=i;var u={ext:c,options:{firstRender:!0,timestamp:n,path:a.__route__}};zl.emit(u,t),rs("pageReady",a)}function ql(e,t,n,r,o,i,a){void 0===o&&(o={}),void 0===i&&(i=!1);var c=function(e){void 0===e&&(e=-1);if(e<0)return ll;return ul[e]=ul[e]||[],ul[e]}(a);Reporter.traceBeginEvent("framework","pushpageinfostask");var u=al;al=void 0;var f=Rf(e);Zf.newPageTime=Date.now(),Nl(e);var l=tl.create(n,e),s=l.page,p=Df(r);if((il={page:s,webViewId:n,route:e,rawPath:t,lastRoute:il?il.route:"",lastQuery:il?il.page.options:{},node:l.node,isTabBarPage:null}).isMainTabBarPage=o.isMainTabBarPage||!1,i){for(var d=-1,g=0;g<c.length;g++)c[g].webViewId===n&&(d=g);-1!==d&&(c.splice(d,1,il),d===c.length&&(c.length?Nl(c[c.length-1].route):Nl("")))}else c.push(il);s.__exitState__=u;var _={};Object.keys(p).forEach((function(e){var t=p[e];try{_[e]=decodeURIComponent(t)}catch(n){_[e]=t}})),__virtualDOM__.attachView(n,_),/^__dd__\//.test(e)&&n.setData(undefined),s.options=p,Yl(il,n,Zf.newPageTime,!0,!1,o.prerender||!1),o.initialRenderingCacheData&&s.setData(o.initialRenderingCacheData),s.__callPageLifeTime__("onLoad",r),s.__callPageLifeTime__("onShow"),cl[n]={page:s,route:e,rawPath:t,webViewId:n,statesData:null,node:f?l.node:void 0},rs("pageLoad",s),rs("enterPage",s),Reporter.traceEndEvent()}function Ql(e,t,n,r){Reporter.traceBeginEvent("framework","unloadpage"),e.page.__toRoute__=t,e.page.__isBack__=n,e.page.__notReportHide__=r,e.page.__callPageLifeTime__("onUnload"),e.node&&tl.destroy(e.page),delete cl[e.webViewId],(ll=ll.slice(0,ll.length-1)).length?Nl(ll[ll.length-1].route):Nl(""),rs("pageUnload",e.page),rs("leavePage",e.page),ul[currentStackId]=null,ul[currentStackId]=ll,Reporter.traceEndEvent()}function Xl(e){e.__ddSlotChildren&&e.__ddSlotChildren.length>0&&e.__ddSlotChildren.forEach((function(e){Xl(e),"dd-web-view"===e.is&&e.__methodCaller&&e.__methodCaller.triggerEvent("message",{data:Ml})}))}function Zl(e,t){Reporter.traceBeginEvent("framework","navigateback");for(var n,r=1<arguments.length&&void 0!==t&&t,o=!1,i=ll.length-1,a=cl&&cl[e]&&cl[e].route||"";0<i;i--){var c=ll[i];if(c&&Ml.length&&c.node&&(Xl(c.node),Ml.length=0),c.webViewId===e){o=!0,il=c;break}if(!r&&pl&&pl.webViewId===c.webViewId)ll=ll.slice(0,ll.length-1);else{r&&pl&&pl.webViewId===c.webViewId?(Jl(c),(ll=ll.slice(0,ll.length-1)).length?Nl(ll[ll.length-1].route):Nl("")):Ql(c,a,!0)}}1!==ll.length||o||(n=ll[0]).webViewId===e&&(o=!0,il=n),o?(il.page.__callPageLifeTime__("onShow"),rs("enterPage",il.page)):"navigateBack with an unexist webViewId ".concat(e),Reporter.traceEndEvent()}function es(e,t){Object.keys(e.data||{}).forEach((function(n){var r,o,i,a,c,u,f,l,s=e.data[n],p=t&&t.data||{};if("$"!==s.charAt(0)||void 0===(r=function(e){var t=0;switch(e){case"PAGE_TIME":return 0<=(t=Tl?Date.now()-Tl-Rl:0)?t:null;case"APP_TIME":return 0<=(t=Il?Date.now()-Il-El:0)?t:null;case"CURRENT_PAGE":return jl||null;case"LAST_PAGE":return kl||null;default:return}}(s.substr(1)))){if(0===s.indexOf("$APP"))return i=n,c=(o=e).data[i],void((u=Uf((l&&l.allowDefault?hl||vl:hl)||{},c.replace("$APP.",""))).obj&&void 0!==u.obj[u.key]&&("number"!=typeof(a=u.obj[u.key])&&"string"!=typeof a&&"boolean"!=typeof a||(Ll[o.eventID].data[i]=a)));if(t&&(e.page===t.__route__||"ANY_PAGE"===e.page)){if(0===s.indexOf("$DATASET")&&(f=s.replace("$DATASET.",""),r=Uf(e.dataset||{},function(e){for(var t=[],n=e.length,r="",o=0,i=!1,a=0;a<n;a++){var c=e[a];"\\"===c?a+1<n&&("."===e[a+1]||"["===e[a+1]||"]"===e[a+1])?(r+=e[a+1],a++):r+="\\":"."===c?r&&(t.push(r),r=""):"["===c?i=!0:"]"===c?(i=!1,t.push(o),o=0):i?o=10*o+c.charCodeAt(0)-48:r+=c}return t}(f)),r.obj&&void 0!==r.obj[r.key]&&(Ll[e.eventID].data[n]=r.obj[r.key],!0)),0===s.indexOf("$COMP")&&"number"==typeof e.nodeId){var d=__virtualDOM__.getNoapproutedeById(e.nodeId,e.webViewId);if(!(d=__virtualDOM__.getNodeById(e.nodeId,e.webViewId)))return;var g=exparser.Element.getMethodCaller(d);g&&(s=s.replace("$COMP.",""),p=g.data)}if(-1<s.indexOf("[]")){if((e.index||[]).forEach((function(e){s=s.replace("[]","[".concat(e,"]"))})),-1<s.indexOf("[-1]")||-1<s.indexOf("[]"))return;var _=s.match(/\[(\d+)\]\.\$INDEX$/);_&&(Ll[e.eventID].data[n]=Number(_[1]),!0)}if(void 0===(r=Uf(p,s)).obj||void 0===r.key||void 0===r.obj[r.key])return;Ll[e.eventID].data[n]=r.obj[r.key]}}else null!==r&&(Ll[e.eventID].data[n]=r)}))}function ts(e,t){if("start"!==e.action&&("start_and_report"!==e.action||(Ll[e.eventID]={eventID:e.eventID,data:{},extra:e.extra})),Ll[e.eventID]){var n,r,o=t||Ul.getCurrentPageWithAdditionalInfo()&&Ul.getCurrentPageWithAdditionalInfo().page;es(e,o),"report"!==e.action&&"start_and_report"!==e.action||(n=e.eventID,r=[],Object.keys(Ll[n].data).forEach((function(e){r.push({id:e,value:Ll[n].data[e]})})),Ll[n].data=r,Ll[n].page=o,Ll[n].version=("undefined"!=typeof __libVersionInfo__?__libVersionInfo__.version:0)||0,Ll[n].uid=Date.now().toString(16)+Math.random().toString(16).substr(2),Ll[n].type=0)}}function ns(){for(var e=0;e<tabBarTapList.length;e++){var t=tabBarTapList.shift();if(t.pagePath===il.route||t.pagePath==="/".concat(il.route)||"/".concat(t.pagePath)===il.route){il.page.onTabItemTap&&il.page.onTabItemTap.call(il.page,t);break}}}function rs(e,t,n){var r,o;if("pageReady"===e&&t){if(t){var i=t.__route__,a=bl.click;r=[],a&&(a.forEach((function(e){e.page!==i&&"ANY_PAGE"!==e.page||!e.element||r.push({eventID:e.eventID,page:e.page,element:e.element,action:e.action})})),0!==r.length&&__appServiceSDK__.publishAnalyticsConfig(r,[Number(t&&t.__ddWebViewId__)]))}}else if(Pl)Sl.push(e);else{if("launch"===e&&!wl)return Il=Date.now(),Pl=wl=!0,Sl.push(e),void __appServiceSDK__.getAppConfig({type:1,complete:function(e){Pl=!1,e.data&&function(e,t){var n={};try{n=JSON.parse(e.data)}catch(e){n={}}var r={},o=Ul.getCurrentPageWithAdditionalInfo(),i=n;"[object Array]"===Object.prototype.toString.call(i)&&i.forEach((function(e){var t=e.eventTarget;"[object Object]"===Object.prototype.toString.call(t)&&(t=[t]),t&&t.length&&t.forEach((function(t){var n=t.trigger||"click";r[n]||(r[n]=[]),("click"!==n||/^([.#][a-zA-Z_][^.#]* ?)+$/.test(t.element&&t.element.trim()))&&r[n].push({eventID:e.eventID,page:t.page,element:t.element&&t.element.trim(),data:t.data,action:t.action,extra:e.extra})}))})),bl=r,r={},t||(Sl.forEach((function(e){rs(e,o&&o.page,!0)})),Sl=[]),rs("pageReady",o&&o.page)}(e)}});if(Dl){n||("enterPage"===e?(Tl=Date.now(),Rl=0,jl=t&&t.__route__):"leavePage"===e?kl=t&&t.__route__:"background"===e?xl=Date.now():"foreground"===e&&(Cl=Date.now(),xl&&xl<Cl&&(Rl+=Cl-xl,El+=Cl-xl)));var c=["enterPage","leavePage","pageLoad","pageUnload","pullDownRefresh","switchTab"];(o=bl[e])&&("enterPage"===e&&t&&"page/component/index"===t.__route__&&__ddConfig.accountInfo&&o.map((function(e){return e.eventID})),o.forEach((function(n){n&&(-1<c.indexOf(e)?(t&&n.page===(t&&t.__route__)||"ANY_PAGE"===n.page)&&ts(n,t):ts(n))})))}}}return didiJsBridge.subscribe({event:"h5PostMessage"},(function(e){var t=e&&e.data&&e.data.params;if(t&&t.data){var n=t.data;for(var r in"string"==typeof n&&(n=JSON.parse(n)),n)"data"===r&&Ml.push(n[r])}})),{App:Ul.App,Component:Ul.Component,Page:Ul.Page,Behavior:Ul.Behavior,getApp:Ul.getApp,__createPluginGlobal:Ul.__createPluginGlobal,getCurrentRoute:Ul.getCurrentRoute,getCurrentPagesByDomain:Ul.getCurrentPagesByDomain,getCurrentPages:Ul.getCurrentPages,getCurrentPageWithAdditionalInfo:Ul.getCurrentPageWithAdditionalInfo}}();

!function(global) {
  /**
   * 将 page 等挂在 global 上
   */
  global.navigateBack = __appServiceSDK__.navigateBackNative;
  global.App = __appServiceEngine__.App;
  global.Page = __appServiceEngine__.Page;
  global.Behavior = __appServiceEngine__.Behavior;
  global.Component = __appServiceEngine__.Component;
  global.getApp = __appServiceEngine__.getApp;
  global.getCurrentPages = __appServiceEngine__.getCurrentPages;
  // global.wx = global.dd = __appServiceSDK__.dd;
  global.wx = global.dd = __appServiceSDK__.proxySDK;
  /**
   * 将 wx 的方法挂在全局上
   */
  var wxApiMap = [
    "drawCanvas",
    "createContext",
    "createCanvasContext",
    "canvasToTempFilePath",
    "canvasGetImageData",
    "canvasPutImageData",
    "createOffscreenCanvas",
    "getAccountInfoSync",
    "getShareInfo",
    "authPrivateMessage",
    "pageScrollTo",
    "chooseInvoiceTitle",
    "chooseInvoice",
    "arrayBufferToBase64",
    "base64ToArrayBuffer",
    "openSetting",
    "getExtConfig",
    "chooseMedia",
    "previewMedia",
    "chooseMultiMedia",
    "chooseMessageFile",
    "chooseWeChatContact",
    "uploadEncryptedFileToCDN",
    "onUploadEncryptedFileToCDNProgress",
    "uploadToCommonCDN",
    "getExtConfigSync",
    "showShareMenu",
    "hideShareMenu",
    "updateShareMenu",
    "shareAppMessageForFakeNative",
    "openUrl",
    "setNavigationBarColor",
    "setNavigationBarAlpha",
    "showShareImageMenu",
    "vibrateShort",
    "vibrateLong",
    "getSetting",
    "checkIsSupportFacialRecognition",
    "startFacialRecognitionVerify",
    "startFacialRecognitionVerifyAndUploadVideo",
    "startCustomFacialRecognitionVerify",
    "startCustomFacialRecognitionVerifyAndUploadVideo",
    "sendBizRedPacket",
    "sendGoldenRedPacket",
    "openGoldenRedPacketDetail",
    "showRedPackage",
    "addPhoneContact",
    "setScreenBrightness",
    "getScreenBrightness",
    "shareToWeRun",
    "getWeRunData",
    "uploadWeRunData",
    "addWeRunData",
    "canIUse",
    "checkBridgeExist",
    "setPageStyle",
    "triggerGettingWidgetData",
    "navigateToMiniProgram",
    "navigateToMiniProgramDirectly",
    "navigateToDevMiniProgram",
    "navigateBackMiniProgram",
    "launchMiniProgram",
    "launchApplicationDirectly",
    "launchApplicationForNative",
    "setNavigationBarRightButton",
    "onTapNavigationBarRightButton",
    "setTopBarText",
    "setTabBarBadge",
    "removeTabBarBadge",
    "showTabBarRedDot",
    "hideTabBarRedDot",
    "showTabBar",
    "hideTabBar",
    "setTabBarStyle",
    "setTabBarItem",
    "setBackgroundColor",
    "setBackgroundTextStyle",
    "setEnableDebug",
    "captureScreen",
    "onUserCaptureScreen",
    "offUserCaptureScreen",
    "setKeepScreenOn",
    "checkIsSupportSoterAuthentication",
    "startSoterAuthentication",
    "checkIsSoterEnrolledInDevice",
    "openDeliveryList",
    "navigateBackH5",
    "openBusinessView",
    "navigateBackApplication",
    "navigateBackNative",
    "reportIDKey",
    "reportKeyValue",
    "setWindowSize",
    "setNavigationBarTitle",
    "showNavigationBarLoading",
    "hideNavigationBarLoading",
    "hideHomeButton",
    "startPullDownRefresh",
    "stopPullDownRefresh",
    "operateWXData",
    "getOpenDeviceId",
    "getMenuButtonBoundingClientRect",
    "getSelectedTextRange",
    "enableAlertBeforeUnload",
    "disableAlertBeforeUnload",
    "makeBluetoothPair",
    "openBluetoothAdapter",
    "closeBluetoothAdapter",
    "getBluetoothAdapterState",
    "onBluetoothAdapterStateChange",
    "offBluetoothAdapterStateChange",
    "startBluetoothDevicesDiscovery",
    "stopBluetoothDevicesDiscovery",
    "getBluetoothDevices",
    "getConnectedBluetoothDevices",
    "createBLEConnection",
    "setBLEMTU",
    "closeBLEConnection",
    "getBLEDeviceServices",
    "getBLEDeviceRSSI",
    "getBLEDeviceCharacteristics",
    "createBLEPeripheralServer",
    "onBLEPeripheralConnectionStateChanged",
    "offBLEPeripheralConnectionStateChanged",
    "notifyBLECharacteristicValueChanged",
    "notifyBLECharacteristicValueChange",
    "readBLECharacteristicValue",
    "writeBLECharacteristicValue",
    "onBluetoothDeviceFound",
    "offBluetoothDeviceFound",
    "onBLEConnectionStateChanged",
    "onBLEConnectionStateChange",
    "onBLECharacteristicValueChange",
    "offBLEConnectionStateChanged",
    "offBLEConnectionStateChange",
    "offBLECharacteristicValueChange",
    "startBeaconDiscovery",
    "stopBeaconDiscovery",
    "getBeacons",
    "onBeaconUpdate",
    "offBeaconUpdate",
    "onBeaconServiceChange",
    "offBeaconServiceChange",
    "startWifi",
    "stopWifi",
    "getWifiList",
    "getConnectedWifi",
    "connectWifi",
    "presetWifiList",
    "setWifiList",
    "onGetWifiList",
    "onWifiConnected",
    "offGetWifiList",
    "offWifiConnected",
    "onEvaluateWifi",
    "getHCEState",
    "startHCE",
    "stopHCE",
    "sendHCEMessage",
    "onHCEMessage",
    "offHCEMessage",
    "getNFCAdapter",
    "startLocalServiceDiscovery",
    "stopLocalServiceDiscovery",
    "onLocalServiceFound",
    "offLocalServiceFound",
    "onLocalServiceLost",
    "offLocalServiceLost",
    "onLocalServiceDiscoveryStop",
    "offLocalServiceDiscoveryStop",
    "onLocalServiceResolveFail",
    "offLocalServiceResolveFail",
    "redirectTo",
    "reLaunch",
    "navigateTo",
    "switchTab",
    "navigateBack",
    "onAppShow",
    "offAppShow",
    "onAppHide",
    "offAppHide",
    "onError",
    "offError",
    "onUnhandledRejection",
    "offUnhandledRejection",
    "getLaunchOptionsSync",
    "getEnterOptionsSync",
    "onWindowResize",
    "offWindowResize",
    "setPageOrientation",
    "getStorage",
    "getStorageSync",
    "setStorage",
    "setStorageSync",
    "removeStorage",
    "removeStorageSync",
    "clearStorage",
    "clearStorageSync",
    "getStorageInfo",
    "getStorageInfoSync",
    "getBackgroundFetchData",
    "onBackgroundFetchData",
    "setBackgroundFetchToken",
    "getBackgroundFetchToken",
    "request",
    "connectSocket",
    "closeSocket",
    "sendSocketMessage",
    "onSocketOpen",
    "onSocketClose",
    "onSocketMessage",
    "onSocketError",
    "uploadFile",
    "downloadFile",
    "addNativeDownloadTask",
    "downloadApp",
    "installDownloadApp",
    "getAppInstallState",
    "queryDownloadAppTask",
    "cancelDownloadAppTask",
    "resumeDownloadAppTask",
    "pauseDownloadAppTask",
    "onDownloadAppStateChange",
    "downloadAppForIOS",
    "calRqt",
    "secureTunnel",
    "chooseImage",
    "previewImage",
    "getImageInfo",
    "saveImageToPhotosAlbum",
    "compressImage",
    "startRecord",
    "stopRecord",
    "playVoice",
    "pauseVoice",
    "stopVoice",
    "onVoicePlayEnd",
    "chooseVideo",
    "saveVideoToPhotosAlbum",
    "getVideoInfo",
    "compressVideo",
    "loadFontFace",
    "createMediaContainer",
    "createMediaRecorder",
    "createVideoDecoder",
    "openVideoEditor",
    "createMediaAudioPlayer",
    "getLocation",
    "openLocation",
    "chooseLocation",
    "onLocationChange",
    "offLocationChange",
    "startLocationUpdateBackground",
    "startLocationUpdate",
    "stopLocationUpdate",
    "getNetworkType",
    "onNetworkStatusChange",
    "offNetworkStatusChange",
    "getSystemInfo",
    "getSystemInfoSync",
    "getSystemSetting",
    "getSystemInfoAsync",
    "getBatteryInfo",
    "getBatteryInfoSync",
    "startAccelerometer",
    "stopAccelerometer",
    "onAccelerometerChange",
    "offAccelerometerChange",
    "startCompass",
    "stopCompass",
    "onCompassChange",
    "offCompassChange",
    "startDeviceMotionListening",
    "stopDeviceMotionListening",
    "onDeviceMotionChange",
    "offDeviceMotionChange",
    "startGyroscope",
    "stopGyroscope",
    "onGyroscopeChange",
    "offGyroscopeChange",
    "checkIsOpenAccessibility",
    "reportAction",
    "getBackgroundAudioManager",
    "getRecorderManager",
    "getBackgroundAudioPlayerState",
    "playBackgroundAudio",
    "pauseBackgroundAudio",
    "seekBackgroundAudio",
    "stopBackgroundAudio",
    "onBackgroundAudioPlay",
    "onBackgroundAudioPause",
    "onBackgroundAudioStop",
    "joinVoIPChat",
    "exitVoIPChat",
    "updateVoIPChatMuteConfig",
    "onVoIPChatMembersChanged",
    "onVoIPChatSpeakersChanged",
    "onVoIPChatInterrupted",
    "offVoIPChatMembersChanged",
    "offVoIPChatSpeakersChanged",
    "offVoIPChatInterrupted",
    "subscribeVoIPVideoMembers",
    "onVoIPVideoMembersChanged",
    "offVoIPVideoMembersChanged",
    "join1v1Chat",
    "setEnable1v1Chat",
    "requestSubscribeMessage",
    "login",
    "logout",
    "checkSession",
    "authorize",
    "getUserInfo",
    "requestPayment",
    "verifyPaymentPassword",
    "bindPaymentCard",
    "requestPaymentToBank",
    "requestVirtualPayment",
    "openOfflinePayView",
    "openWCPayCardList",
    "requestMallPayment",
    "setCurrentPaySpeech",
    "loadPaySpeechDialectConfig",
    "requestJointPayment",
    "getWCPayOverseaPrepayRequest",
    "requestH5Transaction",
    "openWCPayOverseaPaymentReceive",
    "handleWCPayOverseaWalletBuffer",
    "requestVerifyUserIdentity",
    "phoneBindCardVerifySms",
    "faceVerifyForPay",
    "openOfficialAccountProfile",
    "openUserProfile",
    "requestBizSplitBillPayment",
    "openSelectPayment",
    "requestEntrustAuthorization",
    "requestFacetoFacePayment",
    "requestQueryCashier",
    "openMiniProgramProfile",
    "openMiniProgramSearch",
    "openMiniProgramHistoryList",
    "openMiniProgramStarList",
    "batchGetContactDirectly",
    "preloadMiniProgramEnvDirectly",
    "predownloadMiniProgramPackageDirectly",
    "preventApplePayUI",
    "getWxSecData",
    "addCard",
    "openCard",
    "checkTrafficCardConditions",
    "queryTrafficCardInfo",
    "issueTrafficCard",
    "rechargeTrafficCard",
    "setDefaultTrafficCard",
    "scanCode",
    "openQRCode",
    "scanItem",
    "chooseAddress",
    "saveFile",
    "openDocument",
    "getSavedFileList",
    "getSavedFileInfo",
    "getFileInfo",
    "removeSavedFile",
    "getFileSystemManager",
    "saveFileToDisk",
    "getABTestConfig",
    "chooseContact",
    "removeUserCloudStorage",
    "setUserCloudStorage",
    "makePhoneCall",
    "makeVoIPCall",
    "onAppRoute",
    "onAppRouteDone",
    "onAppEnterBackground",
    "onAppEnterForeground",
    "onAppUnhang",
    "onPageReload",
    "onPageNotFound",
    "offPageNotFound",
    "onThemeChange",
    "offThemeChange",
    "onCopyUrl",
    "offCopyUrl",
    "createAnimation",
    "createInnerAudioContext",
    "getAvailableAudioSources",
    "onAudioInterruptionBegin",
    "offAudioInterruptionBegin",
    "onAudioInterruptionEnd",
    "offAudioInterruptionEnd",
    "setInnerAudioOption",
    "createAudioContext",
    "createVideoContext",
    "createMapContext",
    "createCameraContext",
    "createLivePlayerContext",
    "createLivePusherContext",
    "onWebviewEvent",
    "onNativeEvent",
    "hideKeyboard",
    "onKeyboardHeightChange",
    "offKeyboardHeightChange",
    "getPublicLibVersion",
    "showModal",
    "showToast",
    "hideToast",
    "showLoading",
    "hideLoading",
    "showActionSheet",
    "showShareActionSheet",
    "reportAnalytics",
    "reportMonitor",
    "getClipboardData",
    "setClipboardData",
    "createSelectorQuery",
    "createIntersectionObserver",
    "createMediaQueryObserver",
    "nextTick",
    "updatePerfData",
    "traceEvent",
    "onMemoryWarning",
    "offMemoryWarning",
    "reportPerformance",
    "getPerformance",
    "getUpdateManager",
    "updateWeChatApp",
    "createWorker",
    "voiceSplitJoint",
    "uploadSilkVoice",
    "downloadSilkVoice",
    "getResPath",
    "setResPath",
    "setCookies",
    "getCookies",
    "faceDetect",
    "initFaceDetect",
    "stopFaceDetect",
    "createBufferURL",
    "revokeBufferURL",
    "createSignal",
    "bindGroup",
    "joinGroup",
    "getLabInfo",
    "setLabInfo",
    "createUDPSocket",
    "env",
    "error",
    "isSystemError",
    "isSDKError",
    "isThirdError",
    "createRewardedVideoAd",
    "createInterstitialAd",
    "createCustomAd",
    "preloadVideoAd",
    "preloadAd",
    "getLogManager",
    "getRealtimeLogManager",
    "getExptInfoSync",
    "reportEvent",
    "getChannelsLiveInfo",
    "openChannelsLive",
    "openChannelsActivity",
    "openChannelsUserProfile",
    "cloud",
    "serviceMarket",
    "version",
    "chooseShareGroup",
    "enterContact",
    "getGroupEnterInfo",
    "getBaseMethods",
    "updateCoverView",
  ];
  var noop = function() {

  };
  for (var key of wxApiMap) {
    if (!wx.hasOwnProperty(key)) {
      wx[key] = noop;
    }
  }

  /**
   * Modules Logic (__wxModule__)
   */

  // 开发者的 JS 逻辑模块
  var JSModules = {};
  var exportPackages = {}; // 存储导出模块
  var MODULES_STATUS_UNLOAD = 1; // 未加载
  var MODULES_STATUS_LOADED = 2; // 已加载
  var MAIN_PACKAGE_NAME = '';

  /**
   * require & define
   */
  /**
   * @param path 文件路径
   * @returns string[] 每一级的文件名列表
   */
  function getFolderNameList(path) {
    var result = []
    var n = path.split("/")
    for (var i = 0, len = n.length; i < len; ++i) {
      var token = n[i];
      if ("" !== token && "." !== token)
        if (".." === token) {
          if (0 === result.length) {
            result = null;
            break
          }
          result.pop()
        } else {
          i + 1 < len && ".." === n[i + 1]
            ? i++
            : result.push(token)
        }
    }
    return result
  }

  function p(e) {
    var t = getFolderNameList(e + "/index.js").join("/");
    return getFolderNameList[t]
      ? t
      : (t = getFolderNameList(e).join("/"), /\.js$/.test(t) || (t += ".js"), getFolderNameList[t] ? t : "")
  }

  /**
   * 返回 define 内部 code 运行时的 require 函数
   * @param name {string} 声明的模块名
   * @returns {Function}
   */
  function requireFactory(name) {
    // var matchVal = name.match(/(.*)\/([^/]+)?$/)
    // var modulePath = matchVal && matchVal[1] ? matchVal[1] : './'
    /**
     * 业务代码中的 require 函数
     * @param modulePath {string} 引用的模块名
     */
    const requireInstance = function(requireModulePath) {
      var matchVal = name.match(/(.*)\/([^/]+)?$/)
      var modulePath = matchVal && matchVal[1] ? matchVal[1] : './'
      if (typeof requireModulePath !== 'string') {
        throw new Error("require args must be a string")
      }
      var absFolderNameList = getFolderNameList(modulePath + '/' + requireModulePath)
      try {
        var __requirePath = absFolderNameList.join("/")
        __requirePath = function(e, t, n) {
          var r = e;
          if (!(/\.js$/.test(r))) {
            r += ".js"
          }
          if ("string" == typeof r && JSModules[r]) {
            return r
          }
          var o = getFolderNameList(t);
          if (!o) {
            throw new Error("can not find module : " + n)
          }
          for (var i = e.substring(o.join("/").length); o.length;) {
            var a, s = o.join("/") + "/miniprogram_npm" + i;
            if (a = p(s)) break;
            o.pop()
          }
          return a || (i = "/" === i[0] ? i : "/" + i, a = p(s = "miniprogram_npm" + i)), a || e
        }(__requirePath, modulePath, requireModulePath);

        return require(__requirePath)
      } catch (e) {
        throw e
      }
    }

    requireInstance.async = function(src) {
      return new Promise(function(resolve, reject) {
        resolve(requireInstance(src))
      });
    }

    return requireInstance;
  }

  /**
   * 定义 js 逻辑模块
   * @param name {string}
   * @param factoryLogicContent {Function} 包装开发者 JS 文件逻辑的可执行函数 (使用形参占位来屏蔽敏感变量)
   */
  var define = function(name, factoryLogicContent) {
    JSModules[name] = {
      status: MODULES_STATUS_UNLOAD,
      factory: factoryLogicContent,
      exports: undefined
    }
  }

  // let require_ts = 0
  // let now = 0
  // let ts = 0
  /**
   * 执行某 js 逻辑模块
   * @param name {string}
   * @param multi {boolean} 是否会引用多次
   */
  var require = function(name, multi = true) {
    if (typeof name !== 'string') {
      throw new Error("require args must be a string")
    }
    name.endsWith('.js') || (name += '.js');
    var requireModule = JSModules[name] // 反解此处还有不少 npm 包的加载与其他 check 逻辑，暂时省略
    if (!requireModule) {
      throw new Error('module "' + name + '" is not defined')
    }
    var module = {
      exports: {}
    }
    var factory = requireModule.factory

    // 如果仅引用一次
    if (!multi || exportPackages[name]) {
      delete requireModule.exports
      requireModule.status = MODULES_STATUS_UNLOAD
      exportPackages[name] = true;
      factory && factory(requireFactory(name), module, module.exports, Foundation.getExportConfig(), Foundation.getExportConfig())
      return module.exports
    }

    if (requireModule.status === MODULES_STATUS_UNLOAD) {
      requireModule.exports = module.exports
      requireModule.status = MODULES_STATUS_LOADED
      var result
      try {
        if (factory) {
          result = factory(requireFactory(name), module, module.exports, Foundation.getExportConfig(), Foundation.getExportConfig())
        }
      } catch (err) {
        requireModule.status = MODULES_STATUS_UNLOAD
        // 执行js模块未处理异常
        __appServiceSDK__.reportUncaughtError({
          info: err.toString(),
          stack: err.stack
        })
      }
      requireModule.exports = module.exports === undefined
        ? result
        : module.exports
    }

    return requireModule.exports
  }

  var definePackageLogicMap = {}; // 定义 js 模块的代码块

  /**
   * 收集代码包的逻辑
   * @param packageName {string} 代码包名
   * @param define {Function} 定义 (js 运行时代码)
   */
  function blockPackageLogic(packageName, define) {
    definePackageLogicMap[packageName] = define
  }

  /**
   * 释放代码包逻辑
   * @param state
   * @param packageDir
   */
  function flushPackageLogic(packageDir = __MAIN_PKG_DIR__) {
    if (typeof definePackageLogicMap[packageDir] === 'function') {
      definePackageLogicMap[packageDir]()
      definePackageLogicMap[packageDir] = null
      delete definePackageLogicMap[packageDir]
    }
  }

  global.require = require;
  global.define = define;
  global.__block__ = blockPackageLogic;
  global.__define__ = flushPackageLogic; //  定义代码包
}(globalThis);
// 由于Foundation模块会改写__ddConfig的引用,所以__wxConfig最后赋值
__wxConfig = __ddConfig
var __ddAppCode__ = __ddAppCode__ || {};
typeof __ddLibrary.onEnd === 'function' && __ddLibrary.onEnd();
__ddLibrary = undefined;
var dmServiceInvokeCostTime = Date.now() - dmServiceInvokeStartTime
